alarm

package
v0.0.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 16, 2026 License: CC0-1.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

const (
	AlarmManagerService_CanScheduleExactAlarms_FullMethodName    = "/alarm.AlarmManagerService/CanScheduleExactAlarms"
	AlarmManagerService_Cancel1_FullMethodName                   = "/alarm.AlarmManagerService/Cancel1"
	AlarmManagerService_Cancel1_1_FullMethodName                 = "/alarm.AlarmManagerService/Cancel1_1"
	AlarmManagerService_CancelAll_FullMethodName                 = "/alarm.AlarmManagerService/CancelAll"
	AlarmManagerService_GetNextAlarmClock_FullMethodName         = "/alarm.AlarmManagerService/GetNextAlarmClock"
	AlarmManagerService_Set_FullMethodName                       = "/alarm.AlarmManagerService/Set"
	AlarmManagerService_SetAlarmClock_FullMethodName             = "/alarm.AlarmManagerService/SetAlarmClock"
	AlarmManagerService_SetAndAllowWhileIdle_FullMethodName      = "/alarm.AlarmManagerService/SetAndAllowWhileIdle"
	AlarmManagerService_SetExact_FullMethodName                  = "/alarm.AlarmManagerService/SetExact"
	AlarmManagerService_SetExactAndAllowWhileIdle_FullMethodName = "/alarm.AlarmManagerService/SetExactAndAllowWhileIdle"
	AlarmManagerService_SetInexactRepeating_FullMethodName       = "/alarm.AlarmManagerService/SetInexactRepeating"
	AlarmManagerService_SetRepeating_FullMethodName              = "/alarm.AlarmManagerService/SetRepeating"
	AlarmManagerService_SetTime_FullMethodName                   = "/alarm.AlarmManagerService/SetTime"
	AlarmManagerService_SetTimeZone_FullMethodName               = "/alarm.AlarmManagerService/SetTimeZone"
	AlarmManagerService_SetWindow4_FullMethodName                = "/alarm.AlarmManagerService/SetWindow4"
	AlarmManagerService_SetWindow6_1_FullMethodName              = "/alarm.AlarmManagerService/SetWindow6_1"
)
const (
	AlarmManagerAlarmClockInfoService_DescribeContents_FullMethodName = "/alarm.AlarmManagerAlarmClockInfoService/DescribeContents"
	AlarmManagerAlarmClockInfoService_GetShowIntent_FullMethodName    = "/alarm.AlarmManagerAlarmClockInfoService/GetShowIntent"
	AlarmManagerAlarmClockInfoService_GetTriggerTime_FullMethodName   = "/alarm.AlarmManagerAlarmClockInfoService/GetTriggerTime"
	AlarmManagerAlarmClockInfoService_WriteToParcel_FullMethodName    = "/alarm.AlarmManagerAlarmClockInfoService/WriteToParcel"
)

Variables

var AlarmManagerAlarmClockInfoService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "alarm.AlarmManagerAlarmClockInfoService",
	HandlerType: (*AlarmManagerAlarmClockInfoServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "DescribeContents",
			Handler:    _AlarmManagerAlarmClockInfoService_DescribeContents_Handler,
		},
		{
			MethodName: "GetShowIntent",
			Handler:    _AlarmManagerAlarmClockInfoService_GetShowIntent_Handler,
		},
		{
			MethodName: "GetTriggerTime",
			Handler:    _AlarmManagerAlarmClockInfoService_GetTriggerTime_Handler,
		},
		{
			MethodName: "WriteToParcel",
			Handler:    _AlarmManagerAlarmClockInfoService_WriteToParcel_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/alarm/alarm.proto",
}

AlarmManagerAlarmClockInfoService_ServiceDesc is the grpc.ServiceDesc for AlarmManagerAlarmClockInfoService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var AlarmManagerService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "alarm.AlarmManagerService",
	HandlerType: (*AlarmManagerServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "CanScheduleExactAlarms",
			Handler:    _AlarmManagerService_CanScheduleExactAlarms_Handler,
		},
		{
			MethodName: "Cancel1",
			Handler:    _AlarmManagerService_Cancel1_Handler,
		},
		{
			MethodName: "Cancel1_1",
			Handler:    _AlarmManagerService_Cancel1_1_Handler,
		},
		{
			MethodName: "CancelAll",
			Handler:    _AlarmManagerService_CancelAll_Handler,
		},
		{
			MethodName: "GetNextAlarmClock",
			Handler:    _AlarmManagerService_GetNextAlarmClock_Handler,
		},
		{
			MethodName: "Set",
			Handler:    _AlarmManagerService_Set_Handler,
		},
		{
			MethodName: "SetAlarmClock",
			Handler:    _AlarmManagerService_SetAlarmClock_Handler,
		},
		{
			MethodName: "SetAndAllowWhileIdle",
			Handler:    _AlarmManagerService_SetAndAllowWhileIdle_Handler,
		},
		{
			MethodName: "SetExact",
			Handler:    _AlarmManagerService_SetExact_Handler,
		},
		{
			MethodName: "SetExactAndAllowWhileIdle",
			Handler:    _AlarmManagerService_SetExactAndAllowWhileIdle_Handler,
		},
		{
			MethodName: "SetInexactRepeating",
			Handler:    _AlarmManagerService_SetInexactRepeating_Handler,
		},
		{
			MethodName: "SetRepeating",
			Handler:    _AlarmManagerService_SetRepeating_Handler,
		},
		{
			MethodName: "SetTime",
			Handler:    _AlarmManagerService_SetTime_Handler,
		},
		{
			MethodName: "SetTimeZone",
			Handler:    _AlarmManagerService_SetTimeZone_Handler,
		},
		{
			MethodName: "SetWindow4",
			Handler:    _AlarmManagerService_SetWindow4_Handler,
		},
		{
			MethodName: "SetWindow6_1",
			Handler:    _AlarmManagerService_SetWindow6_1_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/alarm/alarm.proto",
}

AlarmManagerService_ServiceDesc is the grpc.ServiceDesc for AlarmManagerService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var File_proto_alarm_alarm_proto protoreflect.FileDescriptor

Functions

func RegisterAlarmManagerAlarmClockInfoServiceServer

func RegisterAlarmManagerAlarmClockInfoServiceServer(s grpc.ServiceRegistrar, srv AlarmManagerAlarmClockInfoServiceServer)

func RegisterAlarmManagerServiceServer

func RegisterAlarmManagerServiceServer(s grpc.ServiceRegistrar, srv AlarmManagerServiceServer)

Types

type AlarmManagerAlarmClockInfoServiceClient

type AlarmManagerAlarmClockInfoServiceClient interface {
	DescribeContents(ctx context.Context, in *DescribeContentsRequest, opts ...grpc.CallOption) (*DescribeContentsResponse, error)
	GetShowIntent(ctx context.Context, in *GetShowIntentRequest, opts ...grpc.CallOption) (*GetShowIntentResponse, error)
	GetTriggerTime(ctx context.Context, in *GetTriggerTimeRequest, opts ...grpc.CallOption) (*GetTriggerTimeResponse, error)
	WriteToParcel(ctx context.Context, in *WriteToParcelRequest, opts ...grpc.CallOption) (*WriteToParcelResponse, error)
}

AlarmManagerAlarmClockInfoServiceClient is the client API for AlarmManagerAlarmClockInfoService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type AlarmManagerAlarmClockInfoServiceServer

type AlarmManagerAlarmClockInfoServiceServer interface {
	DescribeContents(context.Context, *DescribeContentsRequest) (*DescribeContentsResponse, error)
	GetShowIntent(context.Context, *GetShowIntentRequest) (*GetShowIntentResponse, error)
	GetTriggerTime(context.Context, *GetTriggerTimeRequest) (*GetTriggerTimeResponse, error)
	WriteToParcel(context.Context, *WriteToParcelRequest) (*WriteToParcelResponse, error)
	// contains filtered or unexported methods
}

AlarmManagerAlarmClockInfoServiceServer is the server API for AlarmManagerAlarmClockInfoService service. All implementations must embed UnimplementedAlarmManagerAlarmClockInfoServiceServer for forward compatibility.

type AlarmManagerServiceClient

type AlarmManagerServiceClient interface {
	CanScheduleExactAlarms(ctx context.Context, in *CanScheduleExactAlarmsRequest, opts ...grpc.CallOption) (*CanScheduleExactAlarmsResponse, error)
	Cancel1(ctx context.Context, in *Cancel1Request, opts ...grpc.CallOption) (*Cancel1Response, error)
	Cancel1_1(ctx context.Context, in *Cancel1_1Request, opts ...grpc.CallOption) (*Cancel1_1Response, error)
	CancelAll(ctx context.Context, in *CancelAllRequest, opts ...grpc.CallOption) (*CancelAllResponse, error)
	GetNextAlarmClock(ctx context.Context, in *GetNextAlarmClockRequest, opts ...grpc.CallOption) (*GetNextAlarmClockResponse, error)
	Set(ctx context.Context, in *SetRequest, opts ...grpc.CallOption) (*SetResponse, error)
	SetAlarmClock(ctx context.Context, in *SetAlarmClockRequest, opts ...grpc.CallOption) (*SetAlarmClockResponse, error)
	SetAndAllowWhileIdle(ctx context.Context, in *SetAndAllowWhileIdleRequest, opts ...grpc.CallOption) (*SetAndAllowWhileIdleResponse, error)
	SetExact(ctx context.Context, in *SetExactRequest, opts ...grpc.CallOption) (*SetExactResponse, error)
	SetExactAndAllowWhileIdle(ctx context.Context, in *SetExactAndAllowWhileIdleRequest, opts ...grpc.CallOption) (*SetExactAndAllowWhileIdleResponse, error)
	SetInexactRepeating(ctx context.Context, in *SetInexactRepeatingRequest, opts ...grpc.CallOption) (*SetInexactRepeatingResponse, error)
	SetRepeating(ctx context.Context, in *SetRepeatingRequest, opts ...grpc.CallOption) (*SetRepeatingResponse, error)
	SetTime(ctx context.Context, in *SetTimeRequest, opts ...grpc.CallOption) (*SetTimeResponse, error)
	SetTimeZone(ctx context.Context, in *SetTimeZoneRequest, opts ...grpc.CallOption) (*SetTimeZoneResponse, error)
	SetWindow4(ctx context.Context, in *SetWindow4Request, opts ...grpc.CallOption) (*SetWindow4Response, error)
	SetWindow6_1(ctx context.Context, in *SetWindow6_1Request, opts ...grpc.CallOption) (*SetWindow6_1Response, error)
}

AlarmManagerServiceClient is the client API for AlarmManagerService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type AlarmManagerServiceServer

AlarmManagerServiceServer is the server API for AlarmManagerService service. All implementations must embed UnimplementedAlarmManagerServiceServer for forward compatibility.

type CanScheduleExactAlarmsRequest

type CanScheduleExactAlarmsRequest struct {
	// contains filtered or unexported fields
}

func (*CanScheduleExactAlarmsRequest) Descriptor deprecated

func (*CanScheduleExactAlarmsRequest) Descriptor() ([]byte, []int)

Deprecated: Use CanScheduleExactAlarmsRequest.ProtoReflect.Descriptor instead.

func (*CanScheduleExactAlarmsRequest) ProtoMessage

func (*CanScheduleExactAlarmsRequest) ProtoMessage()

func (*CanScheduleExactAlarmsRequest) ProtoReflect

func (*CanScheduleExactAlarmsRequest) Reset

func (x *CanScheduleExactAlarmsRequest) Reset()

func (*CanScheduleExactAlarmsRequest) String

type CanScheduleExactAlarmsResponse

type CanScheduleExactAlarmsResponse struct {
	Result bool `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*CanScheduleExactAlarmsResponse) Descriptor deprecated

func (*CanScheduleExactAlarmsResponse) Descriptor() ([]byte, []int)

Deprecated: Use CanScheduleExactAlarmsResponse.ProtoReflect.Descriptor instead.

func (*CanScheduleExactAlarmsResponse) GetResult

func (x *CanScheduleExactAlarmsResponse) GetResult() bool

func (*CanScheduleExactAlarmsResponse) ProtoMessage

func (*CanScheduleExactAlarmsResponse) ProtoMessage()

func (*CanScheduleExactAlarmsResponse) ProtoReflect

func (*CanScheduleExactAlarmsResponse) Reset

func (x *CanScheduleExactAlarmsResponse) Reset()

func (*CanScheduleExactAlarmsResponse) String

type Cancel1Request

type Cancel1Request struct {
	Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*Cancel1Request) Descriptor deprecated

func (*Cancel1Request) Descriptor() ([]byte, []int)

Deprecated: Use Cancel1Request.ProtoReflect.Descriptor instead.

func (*Cancel1Request) GetArg0

func (x *Cancel1Request) GetArg0() int64

func (*Cancel1Request) ProtoMessage

func (*Cancel1Request) ProtoMessage()

func (*Cancel1Request) ProtoReflect

func (x *Cancel1Request) ProtoReflect() protoreflect.Message

func (*Cancel1Request) Reset

func (x *Cancel1Request) Reset()

func (*Cancel1Request) String

func (x *Cancel1Request) String() string

type Cancel1Response

type Cancel1Response struct {
	// contains filtered or unexported fields
}

func (*Cancel1Response) Descriptor deprecated

func (*Cancel1Response) Descriptor() ([]byte, []int)

Deprecated: Use Cancel1Response.ProtoReflect.Descriptor instead.

func (*Cancel1Response) ProtoMessage

func (*Cancel1Response) ProtoMessage()

func (*Cancel1Response) ProtoReflect

func (x *Cancel1Response) ProtoReflect() protoreflect.Message

func (*Cancel1Response) Reset

func (x *Cancel1Response) Reset()

func (*Cancel1Response) String

func (x *Cancel1Response) String() string

type Cancel1_1Request

type Cancel1_1Request struct {
	Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*Cancel1_1Request) Descriptor deprecated

func (*Cancel1_1Request) Descriptor() ([]byte, []int)

Deprecated: Use Cancel1_1Request.ProtoReflect.Descriptor instead.

func (*Cancel1_1Request) GetArg0

func (x *Cancel1_1Request) GetArg0() int64

func (*Cancel1_1Request) ProtoMessage

func (*Cancel1_1Request) ProtoMessage()

func (*Cancel1_1Request) ProtoReflect

func (x *Cancel1_1Request) ProtoReflect() protoreflect.Message

func (*Cancel1_1Request) Reset

func (x *Cancel1_1Request) Reset()

func (*Cancel1_1Request) String

func (x *Cancel1_1Request) String() string

type Cancel1_1Response

type Cancel1_1Response struct {
	// contains filtered or unexported fields
}

func (*Cancel1_1Response) Descriptor deprecated

func (*Cancel1_1Response) Descriptor() ([]byte, []int)

Deprecated: Use Cancel1_1Response.ProtoReflect.Descriptor instead.

func (*Cancel1_1Response) ProtoMessage

func (*Cancel1_1Response) ProtoMessage()

func (*Cancel1_1Response) ProtoReflect

func (x *Cancel1_1Response) ProtoReflect() protoreflect.Message

func (*Cancel1_1Response) Reset

func (x *Cancel1_1Response) Reset()

func (*Cancel1_1Response) String

func (x *Cancel1_1Response) String() string

type CancelAllRequest

type CancelAllRequest struct {
	// contains filtered or unexported fields
}

func (*CancelAllRequest) Descriptor deprecated

func (*CancelAllRequest) Descriptor() ([]byte, []int)

Deprecated: Use CancelAllRequest.ProtoReflect.Descriptor instead.

func (*CancelAllRequest) ProtoMessage

func (*CancelAllRequest) ProtoMessage()

func (*CancelAllRequest) ProtoReflect

func (x *CancelAllRequest) ProtoReflect() protoreflect.Message

func (*CancelAllRequest) Reset

func (x *CancelAllRequest) Reset()

func (*CancelAllRequest) String

func (x *CancelAllRequest) String() string

type CancelAllResponse

type CancelAllResponse struct {
	// contains filtered or unexported fields
}

func (*CancelAllResponse) Descriptor deprecated

func (*CancelAllResponse) Descriptor() ([]byte, []int)

Deprecated: Use CancelAllResponse.ProtoReflect.Descriptor instead.

func (*CancelAllResponse) ProtoMessage

func (*CancelAllResponse) ProtoMessage()

func (*CancelAllResponse) ProtoReflect

func (x *CancelAllResponse) ProtoReflect() protoreflect.Message

func (*CancelAllResponse) Reset

func (x *CancelAllResponse) Reset()

func (*CancelAllResponse) String

func (x *CancelAllResponse) String() string

type DescribeContentsRequest

type DescribeContentsRequest struct {
	// contains filtered or unexported fields
}

func (*DescribeContentsRequest) Descriptor deprecated

func (*DescribeContentsRequest) Descriptor() ([]byte, []int)

Deprecated: Use DescribeContentsRequest.ProtoReflect.Descriptor instead.

func (*DescribeContentsRequest) ProtoMessage

func (*DescribeContentsRequest) ProtoMessage()

func (*DescribeContentsRequest) ProtoReflect

func (x *DescribeContentsRequest) ProtoReflect() protoreflect.Message

func (*DescribeContentsRequest) Reset

func (x *DescribeContentsRequest) Reset()

func (*DescribeContentsRequest) String

func (x *DescribeContentsRequest) String() string

type DescribeContentsResponse

type DescribeContentsResponse struct {
	Result int32 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*DescribeContentsResponse) Descriptor deprecated

func (*DescribeContentsResponse) Descriptor() ([]byte, []int)

Deprecated: Use DescribeContentsResponse.ProtoReflect.Descriptor instead.

func (*DescribeContentsResponse) GetResult

func (x *DescribeContentsResponse) GetResult() int32

func (*DescribeContentsResponse) ProtoMessage

func (*DescribeContentsResponse) ProtoMessage()

func (*DescribeContentsResponse) ProtoReflect

func (x *DescribeContentsResponse) ProtoReflect() protoreflect.Message

func (*DescribeContentsResponse) Reset

func (x *DescribeContentsResponse) Reset()

func (*DescribeContentsResponse) String

func (x *DescribeContentsResponse) String() string

type GetNextAlarmClockRequest

type GetNextAlarmClockRequest struct {
	// contains filtered or unexported fields
}

func (*GetNextAlarmClockRequest) Descriptor deprecated

func (*GetNextAlarmClockRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetNextAlarmClockRequest.ProtoReflect.Descriptor instead.

func (*GetNextAlarmClockRequest) ProtoMessage

func (*GetNextAlarmClockRequest) ProtoMessage()

func (*GetNextAlarmClockRequest) ProtoReflect

func (x *GetNextAlarmClockRequest) ProtoReflect() protoreflect.Message

func (*GetNextAlarmClockRequest) Reset

func (x *GetNextAlarmClockRequest) Reset()

func (*GetNextAlarmClockRequest) String

func (x *GetNextAlarmClockRequest) String() string

type GetNextAlarmClockResponse

type GetNextAlarmClockResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetNextAlarmClockResponse) Descriptor deprecated

func (*GetNextAlarmClockResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetNextAlarmClockResponse.ProtoReflect.Descriptor instead.

func (*GetNextAlarmClockResponse) GetResult

func (x *GetNextAlarmClockResponse) GetResult() int64

func (*GetNextAlarmClockResponse) ProtoMessage

func (*GetNextAlarmClockResponse) ProtoMessage()

func (*GetNextAlarmClockResponse) ProtoReflect

func (*GetNextAlarmClockResponse) Reset

func (x *GetNextAlarmClockResponse) Reset()

func (*GetNextAlarmClockResponse) String

func (x *GetNextAlarmClockResponse) String() string

type GetShowIntentRequest

type GetShowIntentRequest struct {
	// contains filtered or unexported fields
}

func (*GetShowIntentRequest) Descriptor deprecated

func (*GetShowIntentRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetShowIntentRequest.ProtoReflect.Descriptor instead.

func (*GetShowIntentRequest) ProtoMessage

func (*GetShowIntentRequest) ProtoMessage()

func (*GetShowIntentRequest) ProtoReflect

func (x *GetShowIntentRequest) ProtoReflect() protoreflect.Message

func (*GetShowIntentRequest) Reset

func (x *GetShowIntentRequest) Reset()

func (*GetShowIntentRequest) String

func (x *GetShowIntentRequest) String() string

type GetShowIntentResponse

type GetShowIntentResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetShowIntentResponse) Descriptor deprecated

func (*GetShowIntentResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetShowIntentResponse.ProtoReflect.Descriptor instead.

func (*GetShowIntentResponse) GetResult

func (x *GetShowIntentResponse) GetResult() int64

func (*GetShowIntentResponse) ProtoMessage

func (*GetShowIntentResponse) ProtoMessage()

func (*GetShowIntentResponse) ProtoReflect

func (x *GetShowIntentResponse) ProtoReflect() protoreflect.Message

func (*GetShowIntentResponse) Reset

func (x *GetShowIntentResponse) Reset()

func (*GetShowIntentResponse) String

func (x *GetShowIntentResponse) String() string

type GetTriggerTimeRequest

type GetTriggerTimeRequest struct {
	// contains filtered or unexported fields
}

func (*GetTriggerTimeRequest) Descriptor deprecated

func (*GetTriggerTimeRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetTriggerTimeRequest.ProtoReflect.Descriptor instead.

func (*GetTriggerTimeRequest) ProtoMessage

func (*GetTriggerTimeRequest) ProtoMessage()

func (*GetTriggerTimeRequest) ProtoReflect

func (x *GetTriggerTimeRequest) ProtoReflect() protoreflect.Message

func (*GetTriggerTimeRequest) Reset

func (x *GetTriggerTimeRequest) Reset()

func (*GetTriggerTimeRequest) String

func (x *GetTriggerTimeRequest) String() string

type GetTriggerTimeResponse

type GetTriggerTimeResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetTriggerTimeResponse) Descriptor deprecated

func (*GetTriggerTimeResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetTriggerTimeResponse.ProtoReflect.Descriptor instead.

func (*GetTriggerTimeResponse) GetResult

func (x *GetTriggerTimeResponse) GetResult() int64

func (*GetTriggerTimeResponse) ProtoMessage

func (*GetTriggerTimeResponse) ProtoMessage()

func (*GetTriggerTimeResponse) ProtoReflect

func (x *GetTriggerTimeResponse) ProtoReflect() protoreflect.Message

func (*GetTriggerTimeResponse) Reset

func (x *GetTriggerTimeResponse) Reset()

func (*GetTriggerTimeResponse) String

func (x *GetTriggerTimeResponse) String() string

type SetAlarmClockRequest

type SetAlarmClockRequest struct {
	Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	Arg1 int64 `protobuf:"varint,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
	// contains filtered or unexported fields
}

func (*SetAlarmClockRequest) Descriptor deprecated

func (*SetAlarmClockRequest) Descriptor() ([]byte, []int)

Deprecated: Use SetAlarmClockRequest.ProtoReflect.Descriptor instead.

func (*SetAlarmClockRequest) GetArg0

func (x *SetAlarmClockRequest) GetArg0() int64

func (*SetAlarmClockRequest) GetArg1

func (x *SetAlarmClockRequest) GetArg1() int64

func (*SetAlarmClockRequest) ProtoMessage

func (*SetAlarmClockRequest) ProtoMessage()

func (*SetAlarmClockRequest) ProtoReflect

func (x *SetAlarmClockRequest) ProtoReflect() protoreflect.Message

func (*SetAlarmClockRequest) Reset

func (x *SetAlarmClockRequest) Reset()

func (*SetAlarmClockRequest) String

func (x *SetAlarmClockRequest) String() string

type SetAlarmClockResponse

type SetAlarmClockResponse struct {
	// contains filtered or unexported fields
}

func (*SetAlarmClockResponse) Descriptor deprecated

func (*SetAlarmClockResponse) Descriptor() ([]byte, []int)

Deprecated: Use SetAlarmClockResponse.ProtoReflect.Descriptor instead.

func (*SetAlarmClockResponse) ProtoMessage

func (*SetAlarmClockResponse) ProtoMessage()

func (*SetAlarmClockResponse) ProtoReflect

func (x *SetAlarmClockResponse) ProtoReflect() protoreflect.Message

func (*SetAlarmClockResponse) Reset

func (x *SetAlarmClockResponse) Reset()

func (*SetAlarmClockResponse) String

func (x *SetAlarmClockResponse) String() string

type SetAndAllowWhileIdleRequest

type SetAndAllowWhileIdleRequest struct {
	Arg0 int32 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	Arg1 int64 `protobuf:"varint,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
	Arg2 int64 `protobuf:"varint,3,opt,name=arg2,proto3" json:"arg2,omitempty"`
	// contains filtered or unexported fields
}

func (*SetAndAllowWhileIdleRequest) Descriptor deprecated

func (*SetAndAllowWhileIdleRequest) Descriptor() ([]byte, []int)

Deprecated: Use SetAndAllowWhileIdleRequest.ProtoReflect.Descriptor instead.

func (*SetAndAllowWhileIdleRequest) GetArg0

func (x *SetAndAllowWhileIdleRequest) GetArg0() int32

func (*SetAndAllowWhileIdleRequest) GetArg1

func (x *SetAndAllowWhileIdleRequest) GetArg1() int64

func (*SetAndAllowWhileIdleRequest) GetArg2

func (x *SetAndAllowWhileIdleRequest) GetArg2() int64

func (*SetAndAllowWhileIdleRequest) ProtoMessage

func (*SetAndAllowWhileIdleRequest) ProtoMessage()

func (*SetAndAllowWhileIdleRequest) ProtoReflect

func (*SetAndAllowWhileIdleRequest) Reset

func (x *SetAndAllowWhileIdleRequest) Reset()

func (*SetAndAllowWhileIdleRequest) String

func (x *SetAndAllowWhileIdleRequest) String() string

type SetAndAllowWhileIdleResponse

type SetAndAllowWhileIdleResponse struct {
	// contains filtered or unexported fields
}

func (*SetAndAllowWhileIdleResponse) Descriptor deprecated

func (*SetAndAllowWhileIdleResponse) Descriptor() ([]byte, []int)

Deprecated: Use SetAndAllowWhileIdleResponse.ProtoReflect.Descriptor instead.

func (*SetAndAllowWhileIdleResponse) ProtoMessage

func (*SetAndAllowWhileIdleResponse) ProtoMessage()

func (*SetAndAllowWhileIdleResponse) ProtoReflect

func (*SetAndAllowWhileIdleResponse) Reset

func (x *SetAndAllowWhileIdleResponse) Reset()

func (*SetAndAllowWhileIdleResponse) String

type SetExactAndAllowWhileIdleRequest

type SetExactAndAllowWhileIdleRequest struct {
	Arg0 int32 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	Arg1 int64 `protobuf:"varint,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
	Arg2 int64 `protobuf:"varint,3,opt,name=arg2,proto3" json:"arg2,omitempty"`
	// contains filtered or unexported fields
}

func (*SetExactAndAllowWhileIdleRequest) Descriptor deprecated

func (*SetExactAndAllowWhileIdleRequest) Descriptor() ([]byte, []int)

Deprecated: Use SetExactAndAllowWhileIdleRequest.ProtoReflect.Descriptor instead.

func (*SetExactAndAllowWhileIdleRequest) GetArg0

func (*SetExactAndAllowWhileIdleRequest) GetArg1

func (*SetExactAndAllowWhileIdleRequest) GetArg2

func (*SetExactAndAllowWhileIdleRequest) ProtoMessage

func (*SetExactAndAllowWhileIdleRequest) ProtoMessage()

func (*SetExactAndAllowWhileIdleRequest) ProtoReflect

func (*SetExactAndAllowWhileIdleRequest) Reset

func (*SetExactAndAllowWhileIdleRequest) String

type SetExactAndAllowWhileIdleResponse

type SetExactAndAllowWhileIdleResponse struct {
	// contains filtered or unexported fields
}

func (*SetExactAndAllowWhileIdleResponse) Descriptor deprecated

func (*SetExactAndAllowWhileIdleResponse) Descriptor() ([]byte, []int)

Deprecated: Use SetExactAndAllowWhileIdleResponse.ProtoReflect.Descriptor instead.

func (*SetExactAndAllowWhileIdleResponse) ProtoMessage

func (*SetExactAndAllowWhileIdleResponse) ProtoMessage()

func (*SetExactAndAllowWhileIdleResponse) ProtoReflect

func (*SetExactAndAllowWhileIdleResponse) Reset

func (*SetExactAndAllowWhileIdleResponse) String

type SetExactRequest

type SetExactRequest struct {
	Arg0 int32 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	Arg1 int64 `protobuf:"varint,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
	Arg2 int64 `protobuf:"varint,3,opt,name=arg2,proto3" json:"arg2,omitempty"`
	// contains filtered or unexported fields
}

func (*SetExactRequest) Descriptor deprecated

func (*SetExactRequest) Descriptor() ([]byte, []int)

Deprecated: Use SetExactRequest.ProtoReflect.Descriptor instead.

func (*SetExactRequest) GetArg0

func (x *SetExactRequest) GetArg0() int32

func (*SetExactRequest) GetArg1

func (x *SetExactRequest) GetArg1() int64

func (*SetExactRequest) GetArg2

func (x *SetExactRequest) GetArg2() int64

func (*SetExactRequest) ProtoMessage

func (*SetExactRequest) ProtoMessage()

func (*SetExactRequest) ProtoReflect

func (x *SetExactRequest) ProtoReflect() protoreflect.Message

func (*SetExactRequest) Reset

func (x *SetExactRequest) Reset()

func (*SetExactRequest) String

func (x *SetExactRequest) String() string

type SetExactResponse

type SetExactResponse struct {
	// contains filtered or unexported fields
}

func (*SetExactResponse) Descriptor deprecated

func (*SetExactResponse) Descriptor() ([]byte, []int)

Deprecated: Use SetExactResponse.ProtoReflect.Descriptor instead.

func (*SetExactResponse) ProtoMessage

func (*SetExactResponse) ProtoMessage()

func (*SetExactResponse) ProtoReflect

func (x *SetExactResponse) ProtoReflect() protoreflect.Message

func (*SetExactResponse) Reset

func (x *SetExactResponse) Reset()

func (*SetExactResponse) String

func (x *SetExactResponse) String() string

type SetInexactRepeatingRequest

type SetInexactRepeatingRequest struct {
	Arg0 int32 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	Arg1 int64 `protobuf:"varint,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
	Arg2 int64 `protobuf:"varint,3,opt,name=arg2,proto3" json:"arg2,omitempty"`
	Arg3 int64 `protobuf:"varint,4,opt,name=arg3,proto3" json:"arg3,omitempty"`
	// contains filtered or unexported fields
}

func (*SetInexactRepeatingRequest) Descriptor deprecated

func (*SetInexactRepeatingRequest) Descriptor() ([]byte, []int)

Deprecated: Use SetInexactRepeatingRequest.ProtoReflect.Descriptor instead.

func (*SetInexactRepeatingRequest) GetArg0

func (x *SetInexactRepeatingRequest) GetArg0() int32

func (*SetInexactRepeatingRequest) GetArg1

func (x *SetInexactRepeatingRequest) GetArg1() int64

func (*SetInexactRepeatingRequest) GetArg2

func (x *SetInexactRepeatingRequest) GetArg2() int64

func (*SetInexactRepeatingRequest) GetArg3

func (x *SetInexactRepeatingRequest) GetArg3() int64

func (*SetInexactRepeatingRequest) ProtoMessage

func (*SetInexactRepeatingRequest) ProtoMessage()

func (*SetInexactRepeatingRequest) ProtoReflect

func (*SetInexactRepeatingRequest) Reset

func (x *SetInexactRepeatingRequest) Reset()

func (*SetInexactRepeatingRequest) String

func (x *SetInexactRepeatingRequest) String() string

type SetInexactRepeatingResponse

type SetInexactRepeatingResponse struct {
	// contains filtered or unexported fields
}

func (*SetInexactRepeatingResponse) Descriptor deprecated

func (*SetInexactRepeatingResponse) Descriptor() ([]byte, []int)

Deprecated: Use SetInexactRepeatingResponse.ProtoReflect.Descriptor instead.

func (*SetInexactRepeatingResponse) ProtoMessage

func (*SetInexactRepeatingResponse) ProtoMessage()

func (*SetInexactRepeatingResponse) ProtoReflect

func (*SetInexactRepeatingResponse) Reset

func (x *SetInexactRepeatingResponse) Reset()

func (*SetInexactRepeatingResponse) String

func (x *SetInexactRepeatingResponse) String() string

type SetRepeatingRequest

type SetRepeatingRequest struct {
	Arg0 int32 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	Arg1 int64 `protobuf:"varint,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
	Arg2 int64 `protobuf:"varint,3,opt,name=arg2,proto3" json:"arg2,omitempty"`
	Arg3 int64 `protobuf:"varint,4,opt,name=arg3,proto3" json:"arg3,omitempty"`
	// contains filtered or unexported fields
}

func (*SetRepeatingRequest) Descriptor deprecated

func (*SetRepeatingRequest) Descriptor() ([]byte, []int)

Deprecated: Use SetRepeatingRequest.ProtoReflect.Descriptor instead.

func (*SetRepeatingRequest) GetArg0

func (x *SetRepeatingRequest) GetArg0() int32

func (*SetRepeatingRequest) GetArg1

func (x *SetRepeatingRequest) GetArg1() int64

func (*SetRepeatingRequest) GetArg2

func (x *SetRepeatingRequest) GetArg2() int64

func (*SetRepeatingRequest) GetArg3

func (x *SetRepeatingRequest) GetArg3() int64

func (*SetRepeatingRequest) ProtoMessage

func (*SetRepeatingRequest) ProtoMessage()

func (*SetRepeatingRequest) ProtoReflect

func (x *SetRepeatingRequest) ProtoReflect() protoreflect.Message

func (*SetRepeatingRequest) Reset

func (x *SetRepeatingRequest) Reset()

func (*SetRepeatingRequest) String

func (x *SetRepeatingRequest) String() string

type SetRepeatingResponse

type SetRepeatingResponse struct {
	// contains filtered or unexported fields
}

func (*SetRepeatingResponse) Descriptor deprecated

func (*SetRepeatingResponse) Descriptor() ([]byte, []int)

Deprecated: Use SetRepeatingResponse.ProtoReflect.Descriptor instead.

func (*SetRepeatingResponse) ProtoMessage

func (*SetRepeatingResponse) ProtoMessage()

func (*SetRepeatingResponse) ProtoReflect

func (x *SetRepeatingResponse) ProtoReflect() protoreflect.Message

func (*SetRepeatingResponse) Reset

func (x *SetRepeatingResponse) Reset()

func (*SetRepeatingResponse) String

func (x *SetRepeatingResponse) String() string

type SetRequest

type SetRequest struct {
	Arg0 int32 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	Arg1 int64 `protobuf:"varint,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
	Arg2 int64 `protobuf:"varint,3,opt,name=arg2,proto3" json:"arg2,omitempty"`
	// contains filtered or unexported fields
}

func (*SetRequest) Descriptor deprecated

func (*SetRequest) Descriptor() ([]byte, []int)

Deprecated: Use SetRequest.ProtoReflect.Descriptor instead.

func (*SetRequest) GetArg0

func (x *SetRequest) GetArg0() int32

func (*SetRequest) GetArg1

func (x *SetRequest) GetArg1() int64

func (*SetRequest) GetArg2

func (x *SetRequest) GetArg2() int64

func (*SetRequest) ProtoMessage

func (*SetRequest) ProtoMessage()

func (*SetRequest) ProtoReflect

func (x *SetRequest) ProtoReflect() protoreflect.Message

func (*SetRequest) Reset

func (x *SetRequest) Reset()

func (*SetRequest) String

func (x *SetRequest) String() string

type SetResponse

type SetResponse struct {
	// contains filtered or unexported fields
}

func (*SetResponse) Descriptor deprecated

func (*SetResponse) Descriptor() ([]byte, []int)

Deprecated: Use SetResponse.ProtoReflect.Descriptor instead.

func (*SetResponse) ProtoMessage

func (*SetResponse) ProtoMessage()

func (*SetResponse) ProtoReflect

func (x *SetResponse) ProtoReflect() protoreflect.Message

func (*SetResponse) Reset

func (x *SetResponse) Reset()

func (*SetResponse) String

func (x *SetResponse) String() string

type SetTimeRequest

type SetTimeRequest struct {
	Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*SetTimeRequest) Descriptor deprecated

func (*SetTimeRequest) Descriptor() ([]byte, []int)

Deprecated: Use SetTimeRequest.ProtoReflect.Descriptor instead.

func (*SetTimeRequest) GetArg0

func (x *SetTimeRequest) GetArg0() int64

func (*SetTimeRequest) ProtoMessage

func (*SetTimeRequest) ProtoMessage()

func (*SetTimeRequest) ProtoReflect

func (x *SetTimeRequest) ProtoReflect() protoreflect.Message

func (*SetTimeRequest) Reset

func (x *SetTimeRequest) Reset()

func (*SetTimeRequest) String

func (x *SetTimeRequest) String() string

type SetTimeResponse

type SetTimeResponse struct {
	// contains filtered or unexported fields
}

func (*SetTimeResponse) Descriptor deprecated

func (*SetTimeResponse) Descriptor() ([]byte, []int)

Deprecated: Use SetTimeResponse.ProtoReflect.Descriptor instead.

func (*SetTimeResponse) ProtoMessage

func (*SetTimeResponse) ProtoMessage()

func (*SetTimeResponse) ProtoReflect

func (x *SetTimeResponse) ProtoReflect() protoreflect.Message

func (*SetTimeResponse) Reset

func (x *SetTimeResponse) Reset()

func (*SetTimeResponse) String

func (x *SetTimeResponse) String() string

type SetTimeZoneRequest

type SetTimeZoneRequest struct {
	Arg0 string `protobuf:"bytes,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*SetTimeZoneRequest) Descriptor deprecated

func (*SetTimeZoneRequest) Descriptor() ([]byte, []int)

Deprecated: Use SetTimeZoneRequest.ProtoReflect.Descriptor instead.

func (*SetTimeZoneRequest) GetArg0

func (x *SetTimeZoneRequest) GetArg0() string

func (*SetTimeZoneRequest) ProtoMessage

func (*SetTimeZoneRequest) ProtoMessage()

func (*SetTimeZoneRequest) ProtoReflect

func (x *SetTimeZoneRequest) ProtoReflect() protoreflect.Message

func (*SetTimeZoneRequest) Reset

func (x *SetTimeZoneRequest) Reset()

func (*SetTimeZoneRequest) String

func (x *SetTimeZoneRequest) String() string

type SetTimeZoneResponse

type SetTimeZoneResponse struct {
	// contains filtered or unexported fields
}

func (*SetTimeZoneResponse) Descriptor deprecated

func (*SetTimeZoneResponse) Descriptor() ([]byte, []int)

Deprecated: Use SetTimeZoneResponse.ProtoReflect.Descriptor instead.

func (*SetTimeZoneResponse) ProtoMessage

func (*SetTimeZoneResponse) ProtoMessage()

func (*SetTimeZoneResponse) ProtoReflect

func (x *SetTimeZoneResponse) ProtoReflect() protoreflect.Message

func (*SetTimeZoneResponse) Reset

func (x *SetTimeZoneResponse) Reset()

func (*SetTimeZoneResponse) String

func (x *SetTimeZoneResponse) String() string

type SetWindow4Request

type SetWindow4Request struct {
	Arg0 int32 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	Arg1 int64 `protobuf:"varint,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
	Arg2 int64 `protobuf:"varint,3,opt,name=arg2,proto3" json:"arg2,omitempty"`
	Arg3 int64 `protobuf:"varint,4,opt,name=arg3,proto3" json:"arg3,omitempty"`
	// contains filtered or unexported fields
}

func (*SetWindow4Request) Descriptor deprecated

func (*SetWindow4Request) Descriptor() ([]byte, []int)

Deprecated: Use SetWindow4Request.ProtoReflect.Descriptor instead.

func (*SetWindow4Request) GetArg0

func (x *SetWindow4Request) GetArg0() int32

func (*SetWindow4Request) GetArg1

func (x *SetWindow4Request) GetArg1() int64

func (*SetWindow4Request) GetArg2

func (x *SetWindow4Request) GetArg2() int64

func (*SetWindow4Request) GetArg3

func (x *SetWindow4Request) GetArg3() int64

func (*SetWindow4Request) ProtoMessage

func (*SetWindow4Request) ProtoMessage()

func (*SetWindow4Request) ProtoReflect

func (x *SetWindow4Request) ProtoReflect() protoreflect.Message

func (*SetWindow4Request) Reset

func (x *SetWindow4Request) Reset()

func (*SetWindow4Request) String

func (x *SetWindow4Request) String() string

type SetWindow4Response

type SetWindow4Response struct {
	// contains filtered or unexported fields
}

func (*SetWindow4Response) Descriptor deprecated

func (*SetWindow4Response) Descriptor() ([]byte, []int)

Deprecated: Use SetWindow4Response.ProtoReflect.Descriptor instead.

func (*SetWindow4Response) ProtoMessage

func (*SetWindow4Response) ProtoMessage()

func (*SetWindow4Response) ProtoReflect

func (x *SetWindow4Response) ProtoReflect() protoreflect.Message

func (*SetWindow4Response) Reset

func (x *SetWindow4Response) Reset()

func (*SetWindow4Response) String

func (x *SetWindow4Response) String() string

type SetWindow6_1Request

type SetWindow6_1Request struct {
	Arg0 int32  `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	Arg1 int64  `protobuf:"varint,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
	Arg2 int64  `protobuf:"varint,3,opt,name=arg2,proto3" json:"arg2,omitempty"`
	Arg3 string `protobuf:"bytes,4,opt,name=arg3,proto3" json:"arg3,omitempty"`
	Arg4 int64  `protobuf:"varint,5,opt,name=arg4,proto3" json:"arg4,omitempty"`
	Arg5 int64  `protobuf:"varint,6,opt,name=arg5,proto3" json:"arg5,omitempty"`
	// contains filtered or unexported fields
}

func (*SetWindow6_1Request) Descriptor deprecated

func (*SetWindow6_1Request) Descriptor() ([]byte, []int)

Deprecated: Use SetWindow6_1Request.ProtoReflect.Descriptor instead.

func (*SetWindow6_1Request) GetArg0

func (x *SetWindow6_1Request) GetArg0() int32

func (*SetWindow6_1Request) GetArg1

func (x *SetWindow6_1Request) GetArg1() int64

func (*SetWindow6_1Request) GetArg2

func (x *SetWindow6_1Request) GetArg2() int64

func (*SetWindow6_1Request) GetArg3

func (x *SetWindow6_1Request) GetArg3() string

func (*SetWindow6_1Request) GetArg4

func (x *SetWindow6_1Request) GetArg4() int64

func (*SetWindow6_1Request) GetArg5

func (x *SetWindow6_1Request) GetArg5() int64

func (*SetWindow6_1Request) ProtoMessage

func (*SetWindow6_1Request) ProtoMessage()

func (*SetWindow6_1Request) ProtoReflect

func (x *SetWindow6_1Request) ProtoReflect() protoreflect.Message

func (*SetWindow6_1Request) Reset

func (x *SetWindow6_1Request) Reset()

func (*SetWindow6_1Request) String

func (x *SetWindow6_1Request) String() string

type SetWindow6_1Response

type SetWindow6_1Response struct {
	// contains filtered or unexported fields
}

func (*SetWindow6_1Response) Descriptor deprecated

func (*SetWindow6_1Response) Descriptor() ([]byte, []int)

Deprecated: Use SetWindow6_1Response.ProtoReflect.Descriptor instead.

func (*SetWindow6_1Response) ProtoMessage

func (*SetWindow6_1Response) ProtoMessage()

func (*SetWindow6_1Response) ProtoReflect

func (x *SetWindow6_1Response) ProtoReflect() protoreflect.Message

func (*SetWindow6_1Response) Reset

func (x *SetWindow6_1Response) Reset()

func (*SetWindow6_1Response) String

func (x *SetWindow6_1Response) String() string

type UnimplementedAlarmManagerAlarmClockInfoServiceServer

type UnimplementedAlarmManagerAlarmClockInfoServiceServer struct{}

UnimplementedAlarmManagerAlarmClockInfoServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedAlarmManagerAlarmClockInfoServiceServer) DescribeContents

func (UnimplementedAlarmManagerAlarmClockInfoServiceServer) GetShowIntent

func (UnimplementedAlarmManagerAlarmClockInfoServiceServer) GetTriggerTime

func (UnimplementedAlarmManagerAlarmClockInfoServiceServer) WriteToParcel

type UnimplementedAlarmManagerServiceServer

type UnimplementedAlarmManagerServiceServer struct{}

UnimplementedAlarmManagerServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedAlarmManagerServiceServer) Cancel1

func (UnimplementedAlarmManagerServiceServer) Cancel1_1

func (UnimplementedAlarmManagerServiceServer) CancelAll

func (UnimplementedAlarmManagerServiceServer) GetNextAlarmClock

func (UnimplementedAlarmManagerServiceServer) Set

func (UnimplementedAlarmManagerServiceServer) SetAlarmClock

func (UnimplementedAlarmManagerServiceServer) SetAndAllowWhileIdle

func (UnimplementedAlarmManagerServiceServer) SetExact

func (UnimplementedAlarmManagerServiceServer) SetInexactRepeating

func (UnimplementedAlarmManagerServiceServer) SetRepeating

func (UnimplementedAlarmManagerServiceServer) SetTime

func (UnimplementedAlarmManagerServiceServer) SetTimeZone

func (UnimplementedAlarmManagerServiceServer) SetWindow4

func (UnimplementedAlarmManagerServiceServer) SetWindow6_1

type UnsafeAlarmManagerAlarmClockInfoServiceServer

type UnsafeAlarmManagerAlarmClockInfoServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeAlarmManagerAlarmClockInfoServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to AlarmManagerAlarmClockInfoServiceServer will result in compilation errors.

type UnsafeAlarmManagerServiceServer

type UnsafeAlarmManagerServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeAlarmManagerServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to AlarmManagerServiceServer will result in compilation errors.

type WriteToParcelRequest

type WriteToParcelRequest struct {
	Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	Arg1 int32 `protobuf:"varint,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
	// contains filtered or unexported fields
}

func (*WriteToParcelRequest) Descriptor deprecated

func (*WriteToParcelRequest) Descriptor() ([]byte, []int)

Deprecated: Use WriteToParcelRequest.ProtoReflect.Descriptor instead.

func (*WriteToParcelRequest) GetArg0

func (x *WriteToParcelRequest) GetArg0() int64

func (*WriteToParcelRequest) GetArg1

func (x *WriteToParcelRequest) GetArg1() int32

func (*WriteToParcelRequest) ProtoMessage

func (*WriteToParcelRequest) ProtoMessage()

func (*WriteToParcelRequest) ProtoReflect

func (x *WriteToParcelRequest) ProtoReflect() protoreflect.Message

func (*WriteToParcelRequest) Reset

func (x *WriteToParcelRequest) Reset()

func (*WriteToParcelRequest) String

func (x *WriteToParcelRequest) String() string

type WriteToParcelResponse

type WriteToParcelResponse struct {
	// contains filtered or unexported fields
}

func (*WriteToParcelResponse) Descriptor deprecated

func (*WriteToParcelResponse) Descriptor() ([]byte, []int)

Deprecated: Use WriteToParcelResponse.ProtoReflect.Descriptor instead.

func (*WriteToParcelResponse) ProtoMessage

func (*WriteToParcelResponse) ProtoMessage()

func (*WriteToParcelResponse) ProtoReflect

func (x *WriteToParcelResponse) ProtoReflect() protoreflect.Message

func (*WriteToParcelResponse) Reset

func (x *WriteToParcelResponse) Reset()

func (*WriteToParcelResponse) String

func (x *WriteToParcelResponse) String() string

Jump to