biometrics

package
v0.0.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 29, 2026 License: CC0-1.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

const (
	PromptVerticalListContentViewService_DescribeContents_FullMethodName              = "/biometrics.PromptVerticalListContentViewService/DescribeContents"
	PromptVerticalListContentViewService_GetDescription_FullMethodName                = "/biometrics.PromptVerticalListContentViewService/GetDescription"
	PromptVerticalListContentViewService_GetListItems_FullMethodName                  = "/biometrics.PromptVerticalListContentViewService/GetListItems"
	PromptVerticalListContentViewService_WriteToParcel_FullMethodName                 = "/biometrics.PromptVerticalListContentViewService/WriteToParcel"
	PromptVerticalListContentViewService_GetMaxEachItemCharacterNumber_FullMethodName = "/biometrics.PromptVerticalListContentViewService/GetMaxEachItemCharacterNumber"
	PromptVerticalListContentViewService_GetMaxItemCount_FullMethodName               = "/biometrics.PromptVerticalListContentViewService/GetMaxItemCount"
)
const (
	PromptVerticalListContentViewBuilderService_AddListItem1_FullMethodName   = "/biometrics.PromptVerticalListContentViewBuilderService/AddListItem1"
	PromptVerticalListContentViewBuilderService_AddListItem2_1_FullMethodName = "/biometrics.PromptVerticalListContentViewBuilderService/AddListItem2_1"
	PromptVerticalListContentViewBuilderService_Build_FullMethodName          = "/biometrics.PromptVerticalListContentViewBuilderService/Build"
	PromptVerticalListContentViewBuilderService_SetDescription_FullMethodName = "/biometrics.PromptVerticalListContentViewBuilderService/SetDescription"
)
const (
	PromptContentItemBulletedTextService_NewPromptContentItemBulletedText_FullMethodName = "/biometrics.PromptContentItemBulletedTextService/NewPromptContentItemBulletedText"
	PromptContentItemBulletedTextService_DescribeContents_FullMethodName                 = "/biometrics.PromptContentItemBulletedTextService/DescribeContents"
	PromptContentItemBulletedTextService_WriteToParcel_FullMethodName                    = "/biometrics.PromptContentItemBulletedTextService/WriteToParcel"
)
const (
	PromptContentItemPlainTextService_NewPromptContentItemPlainText_FullMethodName = "/biometrics.PromptContentItemPlainTextService/NewPromptContentItemPlainText"
	PromptContentItemPlainTextService_DescribeContents_FullMethodName              = "/biometrics.PromptContentItemPlainTextService/DescribeContents"
	PromptContentItemPlainTextService_WriteToParcel_FullMethodName                 = "/biometrics.PromptContentItemPlainTextService/WriteToParcel"
)
const (
	PromptContentViewWithMoreOptionsButtonService_DescribeContents_FullMethodName             = "/biometrics.PromptContentViewWithMoreOptionsButtonService/DescribeContents"
	PromptContentViewWithMoreOptionsButtonService_GetDescription_FullMethodName               = "/biometrics.PromptContentViewWithMoreOptionsButtonService/GetDescription"
	PromptContentViewWithMoreOptionsButtonService_GetMoreOptionsButtonListener_FullMethodName = "/biometrics.PromptContentViewWithMoreOptionsButtonService/GetMoreOptionsButtonListener"
	PromptContentViewWithMoreOptionsButtonService_WriteToParcel_FullMethodName                = "/biometrics.PromptContentViewWithMoreOptionsButtonService/WriteToParcel"
)
const (
	PromptContentViewWithMoreOptionsButtonBuilderService_Build_FullMethodName                        = "/biometrics.PromptContentViewWithMoreOptionsButtonBuilderService/Build"
	PromptContentViewWithMoreOptionsButtonBuilderService_SetDescription_FullMethodName               = "/biometrics.PromptContentViewWithMoreOptionsButtonBuilderService/SetDescription"
	PromptContentViewWithMoreOptionsButtonBuilderService_SetMoreOptionsButtonListener_FullMethodName = "/biometrics.PromptContentViewWithMoreOptionsButtonBuilderService/SetMoreOptionsButtonListener"
)

Variables

var File_proto_biometrics_biometrics_proto protoreflect.FileDescriptor
var PromptContentItemBulletedTextService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "biometrics.PromptContentItemBulletedTextService",
	HandlerType: (*PromptContentItemBulletedTextServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "NewPromptContentItemBulletedText",
			Handler:    _PromptContentItemBulletedTextService_NewPromptContentItemBulletedText_Handler,
		},
		{
			MethodName: "DescribeContents",
			Handler:    _PromptContentItemBulletedTextService_DescribeContents_Handler,
		},
		{
			MethodName: "WriteToParcel",
			Handler:    _PromptContentItemBulletedTextService_WriteToParcel_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/biometrics/biometrics.proto",
}

PromptContentItemBulletedTextService_ServiceDesc is the grpc.ServiceDesc for PromptContentItemBulletedTextService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var PromptContentItemPlainTextService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "biometrics.PromptContentItemPlainTextService",
	HandlerType: (*PromptContentItemPlainTextServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "NewPromptContentItemPlainText",
			Handler:    _PromptContentItemPlainTextService_NewPromptContentItemPlainText_Handler,
		},
		{
			MethodName: "DescribeContents",
			Handler:    _PromptContentItemPlainTextService_DescribeContents_Handler,
		},
		{
			MethodName: "WriteToParcel",
			Handler:    _PromptContentItemPlainTextService_WriteToParcel_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/biometrics/biometrics.proto",
}

PromptContentItemPlainTextService_ServiceDesc is the grpc.ServiceDesc for PromptContentItemPlainTextService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var PromptContentViewWithMoreOptionsButtonBuilderService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "biometrics.PromptContentViewWithMoreOptionsButtonBuilderService",
	HandlerType: (*PromptContentViewWithMoreOptionsButtonBuilderServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "Build",
			Handler:    _PromptContentViewWithMoreOptionsButtonBuilderService_Build_Handler,
		},
		{
			MethodName: "SetDescription",
			Handler:    _PromptContentViewWithMoreOptionsButtonBuilderService_SetDescription_Handler,
		},
		{
			MethodName: "SetMoreOptionsButtonListener",
			Handler:    _PromptContentViewWithMoreOptionsButtonBuilderService_SetMoreOptionsButtonListener_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/biometrics/biometrics.proto",
}

PromptContentViewWithMoreOptionsButtonBuilderService_ServiceDesc is the grpc.ServiceDesc for PromptContentViewWithMoreOptionsButtonBuilderService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var PromptContentViewWithMoreOptionsButtonService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "biometrics.PromptContentViewWithMoreOptionsButtonService",
	HandlerType: (*PromptContentViewWithMoreOptionsButtonServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "DescribeContents",
			Handler:    _PromptContentViewWithMoreOptionsButtonService_DescribeContents_Handler,
		},
		{
			MethodName: "GetDescription",
			Handler:    _PromptContentViewWithMoreOptionsButtonService_GetDescription_Handler,
		},
		{
			MethodName: "GetMoreOptionsButtonListener",
			Handler:    _PromptContentViewWithMoreOptionsButtonService_GetMoreOptionsButtonListener_Handler,
		},
		{
			MethodName: "WriteToParcel",
			Handler:    _PromptContentViewWithMoreOptionsButtonService_WriteToParcel_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/biometrics/biometrics.proto",
}

PromptContentViewWithMoreOptionsButtonService_ServiceDesc is the grpc.ServiceDesc for PromptContentViewWithMoreOptionsButtonService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var PromptVerticalListContentViewBuilderService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "biometrics.PromptVerticalListContentViewBuilderService",
	HandlerType: (*PromptVerticalListContentViewBuilderServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "AddListItem1",
			Handler:    _PromptVerticalListContentViewBuilderService_AddListItem1_Handler,
		},
		{
			MethodName: "AddListItem2_1",
			Handler:    _PromptVerticalListContentViewBuilderService_AddListItem2_1_Handler,
		},
		{
			MethodName: "Build",
			Handler:    _PromptVerticalListContentViewBuilderService_Build_Handler,
		},
		{
			MethodName: "SetDescription",
			Handler:    _PromptVerticalListContentViewBuilderService_SetDescription_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/biometrics/biometrics.proto",
}

PromptVerticalListContentViewBuilderService_ServiceDesc is the grpc.ServiceDesc for PromptVerticalListContentViewBuilderService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var PromptVerticalListContentViewService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "biometrics.PromptVerticalListContentViewService",
	HandlerType: (*PromptVerticalListContentViewServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "DescribeContents",
			Handler:    _PromptVerticalListContentViewService_DescribeContents_Handler,
		},
		{
			MethodName: "GetDescription",
			Handler:    _PromptVerticalListContentViewService_GetDescription_Handler,
		},
		{
			MethodName: "GetListItems",
			Handler:    _PromptVerticalListContentViewService_GetListItems_Handler,
		},
		{
			MethodName: "WriteToParcel",
			Handler:    _PromptVerticalListContentViewService_WriteToParcel_Handler,
		},
		{
			MethodName: "GetMaxEachItemCharacterNumber",
			Handler:    _PromptVerticalListContentViewService_GetMaxEachItemCharacterNumber_Handler,
		},
		{
			MethodName: "GetMaxItemCount",
			Handler:    _PromptVerticalListContentViewService_GetMaxItemCount_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/biometrics/biometrics.proto",
}

PromptVerticalListContentViewService_ServiceDesc is the grpc.ServiceDesc for PromptVerticalListContentViewService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterPromptContentItemPlainTextServiceServer

func RegisterPromptContentItemPlainTextServiceServer(s grpc.ServiceRegistrar, srv PromptContentItemPlainTextServiceServer)

Types

type AddListItem1Request

type AddListItem1Request struct {
	Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*AddListItem1Request) Descriptor deprecated

func (*AddListItem1Request) Descriptor() ([]byte, []int)

Deprecated: Use AddListItem1Request.ProtoReflect.Descriptor instead.

func (*AddListItem1Request) GetArg0

func (x *AddListItem1Request) GetArg0() int64

func (*AddListItem1Request) ProtoMessage

func (*AddListItem1Request) ProtoMessage()

func (*AddListItem1Request) ProtoReflect

func (x *AddListItem1Request) ProtoReflect() protoreflect.Message

func (*AddListItem1Request) Reset

func (x *AddListItem1Request) Reset()

func (*AddListItem1Request) String

func (x *AddListItem1Request) String() string

type AddListItem1Response

type AddListItem1Response struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*AddListItem1Response) Descriptor deprecated

func (*AddListItem1Response) Descriptor() ([]byte, []int)

Deprecated: Use AddListItem1Response.ProtoReflect.Descriptor instead.

func (*AddListItem1Response) GetResult

func (x *AddListItem1Response) GetResult() int64

func (*AddListItem1Response) ProtoMessage

func (*AddListItem1Response) ProtoMessage()

func (*AddListItem1Response) ProtoReflect

func (x *AddListItem1Response) ProtoReflect() protoreflect.Message

func (*AddListItem1Response) Reset

func (x *AddListItem1Response) Reset()

func (*AddListItem1Response) String

func (x *AddListItem1Response) String() string

type AddListItem2_1Request

type AddListItem2_1Request struct {
	Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	Arg1 int32 `protobuf:"varint,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
	// contains filtered or unexported fields
}

func (*AddListItem2_1Request) Descriptor deprecated

func (*AddListItem2_1Request) Descriptor() ([]byte, []int)

Deprecated: Use AddListItem2_1Request.ProtoReflect.Descriptor instead.

func (*AddListItem2_1Request) GetArg0

func (x *AddListItem2_1Request) GetArg0() int64

func (*AddListItem2_1Request) GetArg1

func (x *AddListItem2_1Request) GetArg1() int32

func (*AddListItem2_1Request) ProtoMessage

func (*AddListItem2_1Request) ProtoMessage()

func (*AddListItem2_1Request) ProtoReflect

func (x *AddListItem2_1Request) ProtoReflect() protoreflect.Message

func (*AddListItem2_1Request) Reset

func (x *AddListItem2_1Request) Reset()

func (*AddListItem2_1Request) String

func (x *AddListItem2_1Request) String() string

type AddListItem2_1Response

type AddListItem2_1Response struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*AddListItem2_1Response) Descriptor deprecated

func (*AddListItem2_1Response) Descriptor() ([]byte, []int)

Deprecated: Use AddListItem2_1Response.ProtoReflect.Descriptor instead.

func (*AddListItem2_1Response) GetResult

func (x *AddListItem2_1Response) GetResult() int64

func (*AddListItem2_1Response) ProtoMessage

func (*AddListItem2_1Response) ProtoMessage()

func (*AddListItem2_1Response) ProtoReflect

func (x *AddListItem2_1Response) ProtoReflect() protoreflect.Message

func (*AddListItem2_1Response) Reset

func (x *AddListItem2_1Response) Reset()

func (*AddListItem2_1Response) String

func (x *AddListItem2_1Response) String() string

type BuildRequest

type BuildRequest struct {
	// contains filtered or unexported fields
}

func (*BuildRequest) Descriptor deprecated

func (*BuildRequest) Descriptor() ([]byte, []int)

Deprecated: Use BuildRequest.ProtoReflect.Descriptor instead.

func (*BuildRequest) ProtoMessage

func (*BuildRequest) ProtoMessage()

func (*BuildRequest) ProtoReflect

func (x *BuildRequest) ProtoReflect() protoreflect.Message

func (*BuildRequest) Reset

func (x *BuildRequest) Reset()

func (*BuildRequest) String

func (x *BuildRequest) String() string

type BuildResponse

type BuildResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*BuildResponse) Descriptor deprecated

func (*BuildResponse) Descriptor() ([]byte, []int)

Deprecated: Use BuildResponse.ProtoReflect.Descriptor instead.

func (*BuildResponse) GetResult

func (x *BuildResponse) GetResult() int64

func (*BuildResponse) ProtoMessage

func (*BuildResponse) ProtoMessage()

func (*BuildResponse) ProtoReflect

func (x *BuildResponse) ProtoReflect() protoreflect.Message

func (*BuildResponse) Reset

func (x *BuildResponse) Reset()

func (*BuildResponse) String

func (x *BuildResponse) String() string

type DescribeContentsRequest

type DescribeContentsRequest struct {
	// contains filtered or unexported fields
}

func (*DescribeContentsRequest) Descriptor deprecated

func (*DescribeContentsRequest) Descriptor() ([]byte, []int)

Deprecated: Use DescribeContentsRequest.ProtoReflect.Descriptor instead.

func (*DescribeContentsRequest) ProtoMessage

func (*DescribeContentsRequest) ProtoMessage()

func (*DescribeContentsRequest) ProtoReflect

func (x *DescribeContentsRequest) ProtoReflect() protoreflect.Message

func (*DescribeContentsRequest) Reset

func (x *DescribeContentsRequest) Reset()

func (*DescribeContentsRequest) String

func (x *DescribeContentsRequest) String() string

type DescribeContentsResponse

type DescribeContentsResponse struct {
	Result int32 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*DescribeContentsResponse) Descriptor deprecated

func (*DescribeContentsResponse) Descriptor() ([]byte, []int)

Deprecated: Use DescribeContentsResponse.ProtoReflect.Descriptor instead.

func (*DescribeContentsResponse) GetResult

func (x *DescribeContentsResponse) GetResult() int32

func (*DescribeContentsResponse) ProtoMessage

func (*DescribeContentsResponse) ProtoMessage()

func (*DescribeContentsResponse) ProtoReflect

func (x *DescribeContentsResponse) ProtoReflect() protoreflect.Message

func (*DescribeContentsResponse) Reset

func (x *DescribeContentsResponse) Reset()

func (*DescribeContentsResponse) String

func (x *DescribeContentsResponse) String() string

type GetDescriptionRequest

type GetDescriptionRequest struct {
	// contains filtered or unexported fields
}

func (*GetDescriptionRequest) Descriptor deprecated

func (*GetDescriptionRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetDescriptionRequest.ProtoReflect.Descriptor instead.

func (*GetDescriptionRequest) ProtoMessage

func (*GetDescriptionRequest) ProtoMessage()

func (*GetDescriptionRequest) ProtoReflect

func (x *GetDescriptionRequest) ProtoReflect() protoreflect.Message

func (*GetDescriptionRequest) Reset

func (x *GetDescriptionRequest) Reset()

func (*GetDescriptionRequest) String

func (x *GetDescriptionRequest) String() string

type GetDescriptionResponse

type GetDescriptionResponse struct {
	Result string `protobuf:"bytes,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetDescriptionResponse) Descriptor deprecated

func (*GetDescriptionResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetDescriptionResponse.ProtoReflect.Descriptor instead.

func (*GetDescriptionResponse) GetResult

func (x *GetDescriptionResponse) GetResult() string

func (*GetDescriptionResponse) ProtoMessage

func (*GetDescriptionResponse) ProtoMessage()

func (*GetDescriptionResponse) ProtoReflect

func (x *GetDescriptionResponse) ProtoReflect() protoreflect.Message

func (*GetDescriptionResponse) Reset

func (x *GetDescriptionResponse) Reset()

func (*GetDescriptionResponse) String

func (x *GetDescriptionResponse) String() string

type GetListItemsRequest

type GetListItemsRequest struct {
	// contains filtered or unexported fields
}

func (*GetListItemsRequest) Descriptor deprecated

func (*GetListItemsRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetListItemsRequest.ProtoReflect.Descriptor instead.

func (*GetListItemsRequest) ProtoMessage

func (*GetListItemsRequest) ProtoMessage()

func (*GetListItemsRequest) ProtoReflect

func (x *GetListItemsRequest) ProtoReflect() protoreflect.Message

func (*GetListItemsRequest) Reset

func (x *GetListItemsRequest) Reset()

func (*GetListItemsRequest) String

func (x *GetListItemsRequest) String() string

type GetListItemsResponse

type GetListItemsResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetListItemsResponse) Descriptor deprecated

func (*GetListItemsResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetListItemsResponse.ProtoReflect.Descriptor instead.

func (*GetListItemsResponse) GetResult

func (x *GetListItemsResponse) GetResult() int64

func (*GetListItemsResponse) ProtoMessage

func (*GetListItemsResponse) ProtoMessage()

func (*GetListItemsResponse) ProtoReflect

func (x *GetListItemsResponse) ProtoReflect() protoreflect.Message

func (*GetListItemsResponse) Reset

func (x *GetListItemsResponse) Reset()

func (*GetListItemsResponse) String

func (x *GetListItemsResponse) String() string

type GetMaxEachItemCharacterNumberRequest

type GetMaxEachItemCharacterNumberRequest struct {
	// contains filtered or unexported fields
}

func (*GetMaxEachItemCharacterNumberRequest) Descriptor deprecated

func (*GetMaxEachItemCharacterNumberRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetMaxEachItemCharacterNumberRequest.ProtoReflect.Descriptor instead.

func (*GetMaxEachItemCharacterNumberRequest) ProtoMessage

func (*GetMaxEachItemCharacterNumberRequest) ProtoMessage()

func (*GetMaxEachItemCharacterNumberRequest) ProtoReflect

func (*GetMaxEachItemCharacterNumberRequest) Reset

func (*GetMaxEachItemCharacterNumberRequest) String

type GetMaxEachItemCharacterNumberResponse

type GetMaxEachItemCharacterNumberResponse struct {
	Result int32 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetMaxEachItemCharacterNumberResponse) Descriptor deprecated

func (*GetMaxEachItemCharacterNumberResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetMaxEachItemCharacterNumberResponse.ProtoReflect.Descriptor instead.

func (*GetMaxEachItemCharacterNumberResponse) GetResult

func (*GetMaxEachItemCharacterNumberResponse) ProtoMessage

func (*GetMaxEachItemCharacterNumberResponse) ProtoMessage()

func (*GetMaxEachItemCharacterNumberResponse) ProtoReflect

func (*GetMaxEachItemCharacterNumberResponse) Reset

func (*GetMaxEachItemCharacterNumberResponse) String

type GetMaxItemCountRequest

type GetMaxItemCountRequest struct {
	// contains filtered or unexported fields
}

func (*GetMaxItemCountRequest) Descriptor deprecated

func (*GetMaxItemCountRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetMaxItemCountRequest.ProtoReflect.Descriptor instead.

func (*GetMaxItemCountRequest) ProtoMessage

func (*GetMaxItemCountRequest) ProtoMessage()

func (*GetMaxItemCountRequest) ProtoReflect

func (x *GetMaxItemCountRequest) ProtoReflect() protoreflect.Message

func (*GetMaxItemCountRequest) Reset

func (x *GetMaxItemCountRequest) Reset()

func (*GetMaxItemCountRequest) String

func (x *GetMaxItemCountRequest) String() string

type GetMaxItemCountResponse

type GetMaxItemCountResponse struct {
	Result int32 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetMaxItemCountResponse) Descriptor deprecated

func (*GetMaxItemCountResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetMaxItemCountResponse.ProtoReflect.Descriptor instead.

func (*GetMaxItemCountResponse) GetResult

func (x *GetMaxItemCountResponse) GetResult() int32

func (*GetMaxItemCountResponse) ProtoMessage

func (*GetMaxItemCountResponse) ProtoMessage()

func (*GetMaxItemCountResponse) ProtoReflect

func (x *GetMaxItemCountResponse) ProtoReflect() protoreflect.Message

func (*GetMaxItemCountResponse) Reset

func (x *GetMaxItemCountResponse) Reset()

func (*GetMaxItemCountResponse) String

func (x *GetMaxItemCountResponse) String() string

type GetMoreOptionsButtonListenerRequest

type GetMoreOptionsButtonListenerRequest struct {
	// contains filtered or unexported fields
}

func (*GetMoreOptionsButtonListenerRequest) Descriptor deprecated

func (*GetMoreOptionsButtonListenerRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetMoreOptionsButtonListenerRequest.ProtoReflect.Descriptor instead.

func (*GetMoreOptionsButtonListenerRequest) ProtoMessage

func (*GetMoreOptionsButtonListenerRequest) ProtoMessage()

func (*GetMoreOptionsButtonListenerRequest) ProtoReflect

func (*GetMoreOptionsButtonListenerRequest) Reset

func (*GetMoreOptionsButtonListenerRequest) String

type GetMoreOptionsButtonListenerResponse

type GetMoreOptionsButtonListenerResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetMoreOptionsButtonListenerResponse) Descriptor deprecated

func (*GetMoreOptionsButtonListenerResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetMoreOptionsButtonListenerResponse.ProtoReflect.Descriptor instead.

func (*GetMoreOptionsButtonListenerResponse) GetResult

func (*GetMoreOptionsButtonListenerResponse) ProtoMessage

func (*GetMoreOptionsButtonListenerResponse) ProtoMessage()

func (*GetMoreOptionsButtonListenerResponse) ProtoReflect

func (*GetMoreOptionsButtonListenerResponse) Reset

func (*GetMoreOptionsButtonListenerResponse) String

type NewPromptContentItemBulletedTextRequest

type NewPromptContentItemBulletedTextRequest struct {
	Arg0 string `protobuf:"bytes,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*NewPromptContentItemBulletedTextRequest) Descriptor deprecated

func (*NewPromptContentItemBulletedTextRequest) Descriptor() ([]byte, []int)

Deprecated: Use NewPromptContentItemBulletedTextRequest.ProtoReflect.Descriptor instead.

func (*NewPromptContentItemBulletedTextRequest) GetArg0

func (*NewPromptContentItemBulletedTextRequest) ProtoMessage

func (*NewPromptContentItemBulletedTextRequest) ProtoReflect

func (*NewPromptContentItemBulletedTextRequest) Reset

func (*NewPromptContentItemBulletedTextRequest) String

type NewPromptContentItemBulletedTextResponse

type NewPromptContentItemBulletedTextResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*NewPromptContentItemBulletedTextResponse) Descriptor deprecated

func (*NewPromptContentItemBulletedTextResponse) Descriptor() ([]byte, []int)

Deprecated: Use NewPromptContentItemBulletedTextResponse.ProtoReflect.Descriptor instead.

func (*NewPromptContentItemBulletedTextResponse) GetResult

func (*NewPromptContentItemBulletedTextResponse) ProtoMessage

func (*NewPromptContentItemBulletedTextResponse) ProtoReflect

func (*NewPromptContentItemBulletedTextResponse) Reset

func (*NewPromptContentItemBulletedTextResponse) String

type NewPromptContentItemPlainTextRequest

type NewPromptContentItemPlainTextRequest struct {
	Arg0 string `protobuf:"bytes,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*NewPromptContentItemPlainTextRequest) Descriptor deprecated

func (*NewPromptContentItemPlainTextRequest) Descriptor() ([]byte, []int)

Deprecated: Use NewPromptContentItemPlainTextRequest.ProtoReflect.Descriptor instead.

func (*NewPromptContentItemPlainTextRequest) GetArg0

func (*NewPromptContentItemPlainTextRequest) ProtoMessage

func (*NewPromptContentItemPlainTextRequest) ProtoMessage()

func (*NewPromptContentItemPlainTextRequest) ProtoReflect

func (*NewPromptContentItemPlainTextRequest) Reset

func (*NewPromptContentItemPlainTextRequest) String

type NewPromptContentItemPlainTextResponse

type NewPromptContentItemPlainTextResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*NewPromptContentItemPlainTextResponse) Descriptor deprecated

func (*NewPromptContentItemPlainTextResponse) Descriptor() ([]byte, []int)

Deprecated: Use NewPromptContentItemPlainTextResponse.ProtoReflect.Descriptor instead.

func (*NewPromptContentItemPlainTextResponse) GetResult

func (*NewPromptContentItemPlainTextResponse) ProtoMessage

func (*NewPromptContentItemPlainTextResponse) ProtoMessage()

func (*NewPromptContentItemPlainTextResponse) ProtoReflect

func (*NewPromptContentItemPlainTextResponse) Reset

func (*NewPromptContentItemPlainTextResponse) String

type PromptContentItemBulletedTextDescribeContentsRequest

type PromptContentItemBulletedTextDescribeContentsRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	// contains filtered or unexported fields
}

func (*PromptContentItemBulletedTextDescribeContentsRequest) Descriptor deprecated

Deprecated: Use PromptContentItemBulletedTextDescribeContentsRequest.ProtoReflect.Descriptor instead.

func (*PromptContentItemBulletedTextDescribeContentsRequest) GetHandle

func (*PromptContentItemBulletedTextDescribeContentsRequest) ProtoMessage

func (*PromptContentItemBulletedTextDescribeContentsRequest) ProtoReflect

func (*PromptContentItemBulletedTextDescribeContentsRequest) Reset

func (*PromptContentItemBulletedTextDescribeContentsRequest) String

type PromptContentItemBulletedTextServiceClient

type PromptContentItemBulletedTextServiceClient interface {
	NewPromptContentItemBulletedText(ctx context.Context, in *NewPromptContentItemBulletedTextRequest, opts ...grpc.CallOption) (*NewPromptContentItemBulletedTextResponse, error)
	DescribeContents(ctx context.Context, in *PromptContentItemBulletedTextDescribeContentsRequest, opts ...grpc.CallOption) (*DescribeContentsResponse, error)
	WriteToParcel(ctx context.Context, in *PromptContentItemBulletedTextWriteToParcelRequest, opts ...grpc.CallOption) (*WriteToParcelResponse, error)
}

PromptContentItemBulletedTextServiceClient is the client API for PromptContentItemBulletedTextService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type PromptContentItemBulletedTextServiceServer

type PromptContentItemBulletedTextServiceServer interface {
	NewPromptContentItemBulletedText(context.Context, *NewPromptContentItemBulletedTextRequest) (*NewPromptContentItemBulletedTextResponse, error)
	DescribeContents(context.Context, *PromptContentItemBulletedTextDescribeContentsRequest) (*DescribeContentsResponse, error)
	WriteToParcel(context.Context, *PromptContentItemBulletedTextWriteToParcelRequest) (*WriteToParcelResponse, error)
	// contains filtered or unexported methods
}

PromptContentItemBulletedTextServiceServer is the server API for PromptContentItemBulletedTextService service. All implementations must embed UnimplementedPromptContentItemBulletedTextServiceServer for forward compatibility.

type PromptContentItemBulletedTextWriteToParcelRequest

type PromptContentItemBulletedTextWriteToParcelRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	Arg0   int64 `protobuf:"varint,2,opt,name=arg0,proto3" json:"arg0,omitempty"`
	Arg1   int32 `protobuf:"varint,3,opt,name=arg1,proto3" json:"arg1,omitempty"`
	// contains filtered or unexported fields
}

func (*PromptContentItemBulletedTextWriteToParcelRequest) Descriptor deprecated

Deprecated: Use PromptContentItemBulletedTextWriteToParcelRequest.ProtoReflect.Descriptor instead.

func (*PromptContentItemBulletedTextWriteToParcelRequest) GetArg0

func (*PromptContentItemBulletedTextWriteToParcelRequest) GetArg1

func (*PromptContentItemBulletedTextWriteToParcelRequest) GetHandle

func (*PromptContentItemBulletedTextWriteToParcelRequest) ProtoMessage

func (*PromptContentItemBulletedTextWriteToParcelRequest) ProtoReflect

func (*PromptContentItemBulletedTextWriteToParcelRequest) Reset

func (*PromptContentItemBulletedTextWriteToParcelRequest) String

type PromptContentItemPlainTextDescribeContentsRequest

type PromptContentItemPlainTextDescribeContentsRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	// contains filtered or unexported fields
}

func (*PromptContentItemPlainTextDescribeContentsRequest) Descriptor deprecated

Deprecated: Use PromptContentItemPlainTextDescribeContentsRequest.ProtoReflect.Descriptor instead.

func (*PromptContentItemPlainTextDescribeContentsRequest) GetHandle

func (*PromptContentItemPlainTextDescribeContentsRequest) ProtoMessage

func (*PromptContentItemPlainTextDescribeContentsRequest) ProtoReflect

func (*PromptContentItemPlainTextDescribeContentsRequest) Reset

func (*PromptContentItemPlainTextDescribeContentsRequest) String

type PromptContentItemPlainTextServiceClient

type PromptContentItemPlainTextServiceClient interface {
	NewPromptContentItemPlainText(ctx context.Context, in *NewPromptContentItemPlainTextRequest, opts ...grpc.CallOption) (*NewPromptContentItemPlainTextResponse, error)
	DescribeContents(ctx context.Context, in *PromptContentItemPlainTextDescribeContentsRequest, opts ...grpc.CallOption) (*DescribeContentsResponse, error)
	WriteToParcel(ctx context.Context, in *PromptContentItemPlainTextWriteToParcelRequest, opts ...grpc.CallOption) (*WriteToParcelResponse, error)
}

PromptContentItemPlainTextServiceClient is the client API for PromptContentItemPlainTextService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type PromptContentItemPlainTextServiceServer

type PromptContentItemPlainTextServiceServer interface {
	NewPromptContentItemPlainText(context.Context, *NewPromptContentItemPlainTextRequest) (*NewPromptContentItemPlainTextResponse, error)
	DescribeContents(context.Context, *PromptContentItemPlainTextDescribeContentsRequest) (*DescribeContentsResponse, error)
	WriteToParcel(context.Context, *PromptContentItemPlainTextWriteToParcelRequest) (*WriteToParcelResponse, error)
	// contains filtered or unexported methods
}

PromptContentItemPlainTextServiceServer is the server API for PromptContentItemPlainTextService service. All implementations must embed UnimplementedPromptContentItemPlainTextServiceServer for forward compatibility.

type PromptContentItemPlainTextWriteToParcelRequest

type PromptContentItemPlainTextWriteToParcelRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	Arg0   int64 `protobuf:"varint,2,opt,name=arg0,proto3" json:"arg0,omitempty"`
	Arg1   int32 `protobuf:"varint,3,opt,name=arg1,proto3" json:"arg1,omitempty"`
	// contains filtered or unexported fields
}

func (*PromptContentItemPlainTextWriteToParcelRequest) Descriptor deprecated

Deprecated: Use PromptContentItemPlainTextWriteToParcelRequest.ProtoReflect.Descriptor instead.

func (*PromptContentItemPlainTextWriteToParcelRequest) GetArg0

func (*PromptContentItemPlainTextWriteToParcelRequest) GetArg1

func (*PromptContentItemPlainTextWriteToParcelRequest) GetHandle

func (*PromptContentItemPlainTextWriteToParcelRequest) ProtoMessage

func (*PromptContentItemPlainTextWriteToParcelRequest) ProtoReflect

func (*PromptContentItemPlainTextWriteToParcelRequest) Reset

func (*PromptContentItemPlainTextWriteToParcelRequest) String

type PromptContentViewWithMoreOptionsButtonBuilderServiceClient

type PromptContentViewWithMoreOptionsButtonBuilderServiceClient interface {
	Build(ctx context.Context, in *BuildRequest, opts ...grpc.CallOption) (*BuildResponse, error)
	SetDescription(ctx context.Context, in *SetDescriptionRequest, opts ...grpc.CallOption) (*SetDescriptionResponse, error)
	SetMoreOptionsButtonListener(ctx context.Context, in *SetMoreOptionsButtonListenerRequest, opts ...grpc.CallOption) (*SetMoreOptionsButtonListenerResponse, error)
}

PromptContentViewWithMoreOptionsButtonBuilderServiceClient is the client API for PromptContentViewWithMoreOptionsButtonBuilderService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type PromptContentViewWithMoreOptionsButtonBuilderServiceServer

type PromptContentViewWithMoreOptionsButtonBuilderServiceServer interface {
	Build(context.Context, *BuildRequest) (*BuildResponse, error)
	SetDescription(context.Context, *SetDescriptionRequest) (*SetDescriptionResponse, error)
	SetMoreOptionsButtonListener(context.Context, *SetMoreOptionsButtonListenerRequest) (*SetMoreOptionsButtonListenerResponse, error)
	// contains filtered or unexported methods
}

PromptContentViewWithMoreOptionsButtonBuilderServiceServer is the server API for PromptContentViewWithMoreOptionsButtonBuilderService service. All implementations must embed UnimplementedPromptContentViewWithMoreOptionsButtonBuilderServiceServer for forward compatibility.

type PromptContentViewWithMoreOptionsButtonServiceClient

type PromptContentViewWithMoreOptionsButtonServiceClient interface {
	DescribeContents(ctx context.Context, in *DescribeContentsRequest, opts ...grpc.CallOption) (*DescribeContentsResponse, error)
	GetDescription(ctx context.Context, in *GetDescriptionRequest, opts ...grpc.CallOption) (*GetDescriptionResponse, error)
	GetMoreOptionsButtonListener(ctx context.Context, in *GetMoreOptionsButtonListenerRequest, opts ...grpc.CallOption) (*GetMoreOptionsButtonListenerResponse, error)
	WriteToParcel(ctx context.Context, in *WriteToParcelRequest, opts ...grpc.CallOption) (*WriteToParcelResponse, error)
}

PromptContentViewWithMoreOptionsButtonServiceClient is the client API for PromptContentViewWithMoreOptionsButtonService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type PromptContentViewWithMoreOptionsButtonServiceServer

type PromptContentViewWithMoreOptionsButtonServiceServer interface {
	DescribeContents(context.Context, *DescribeContentsRequest) (*DescribeContentsResponse, error)
	GetDescription(context.Context, *GetDescriptionRequest) (*GetDescriptionResponse, error)
	GetMoreOptionsButtonListener(context.Context, *GetMoreOptionsButtonListenerRequest) (*GetMoreOptionsButtonListenerResponse, error)
	WriteToParcel(context.Context, *WriteToParcelRequest) (*WriteToParcelResponse, error)
	// contains filtered or unexported methods
}

PromptContentViewWithMoreOptionsButtonServiceServer is the server API for PromptContentViewWithMoreOptionsButtonService service. All implementations must embed UnimplementedPromptContentViewWithMoreOptionsButtonServiceServer for forward compatibility.

type PromptVerticalListContentViewBuilderServiceClient

type PromptVerticalListContentViewBuilderServiceClient interface {
	AddListItem1(ctx context.Context, in *AddListItem1Request, opts ...grpc.CallOption) (*AddListItem1Response, error)
	AddListItem2_1(ctx context.Context, in *AddListItem2_1Request, opts ...grpc.CallOption) (*AddListItem2_1Response, error)
	Build(ctx context.Context, in *BuildRequest, opts ...grpc.CallOption) (*BuildResponse, error)
	SetDescription(ctx context.Context, in *SetDescriptionRequest, opts ...grpc.CallOption) (*SetDescriptionResponse, error)
}

PromptVerticalListContentViewBuilderServiceClient is the client API for PromptVerticalListContentViewBuilderService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type PromptVerticalListContentViewBuilderServiceServer

type PromptVerticalListContentViewBuilderServiceServer interface {
	AddListItem1(context.Context, *AddListItem1Request) (*AddListItem1Response, error)
	AddListItem2_1(context.Context, *AddListItem2_1Request) (*AddListItem2_1Response, error)
	Build(context.Context, *BuildRequest) (*BuildResponse, error)
	SetDescription(context.Context, *SetDescriptionRequest) (*SetDescriptionResponse, error)
	// contains filtered or unexported methods
}

PromptVerticalListContentViewBuilderServiceServer is the server API for PromptVerticalListContentViewBuilderService service. All implementations must embed UnimplementedPromptVerticalListContentViewBuilderServiceServer for forward compatibility.

type PromptVerticalListContentViewServiceClient

type PromptVerticalListContentViewServiceClient interface {
	DescribeContents(ctx context.Context, in *DescribeContentsRequest, opts ...grpc.CallOption) (*DescribeContentsResponse, error)
	GetDescription(ctx context.Context, in *GetDescriptionRequest, opts ...grpc.CallOption) (*GetDescriptionResponse, error)
	GetListItems(ctx context.Context, in *GetListItemsRequest, opts ...grpc.CallOption) (*GetListItemsResponse, error)
	WriteToParcel(ctx context.Context, in *WriteToParcelRequest, opts ...grpc.CallOption) (*WriteToParcelResponse, error)
	GetMaxEachItemCharacterNumber(ctx context.Context, in *GetMaxEachItemCharacterNumberRequest, opts ...grpc.CallOption) (*GetMaxEachItemCharacterNumberResponse, error)
	GetMaxItemCount(ctx context.Context, in *GetMaxItemCountRequest, opts ...grpc.CallOption) (*GetMaxItemCountResponse, error)
}

PromptVerticalListContentViewServiceClient is the client API for PromptVerticalListContentViewService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type PromptVerticalListContentViewServiceServer

type PromptVerticalListContentViewServiceServer interface {
	DescribeContents(context.Context, *DescribeContentsRequest) (*DescribeContentsResponse, error)
	GetDescription(context.Context, *GetDescriptionRequest) (*GetDescriptionResponse, error)
	GetListItems(context.Context, *GetListItemsRequest) (*GetListItemsResponse, error)
	WriteToParcel(context.Context, *WriteToParcelRequest) (*WriteToParcelResponse, error)
	GetMaxEachItemCharacterNumber(context.Context, *GetMaxEachItemCharacterNumberRequest) (*GetMaxEachItemCharacterNumberResponse, error)
	GetMaxItemCount(context.Context, *GetMaxItemCountRequest) (*GetMaxItemCountResponse, error)
	// contains filtered or unexported methods
}

PromptVerticalListContentViewServiceServer is the server API for PromptVerticalListContentViewService service. All implementations must embed UnimplementedPromptVerticalListContentViewServiceServer for forward compatibility.

type SetDescriptionRequest

type SetDescriptionRequest struct {
	Arg0 string `protobuf:"bytes,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*SetDescriptionRequest) Descriptor deprecated

func (*SetDescriptionRequest) Descriptor() ([]byte, []int)

Deprecated: Use SetDescriptionRequest.ProtoReflect.Descriptor instead.

func (*SetDescriptionRequest) GetArg0

func (x *SetDescriptionRequest) GetArg0() string

func (*SetDescriptionRequest) ProtoMessage

func (*SetDescriptionRequest) ProtoMessage()

func (*SetDescriptionRequest) ProtoReflect

func (x *SetDescriptionRequest) ProtoReflect() protoreflect.Message

func (*SetDescriptionRequest) Reset

func (x *SetDescriptionRequest) Reset()

func (*SetDescriptionRequest) String

func (x *SetDescriptionRequest) String() string

type SetDescriptionResponse

type SetDescriptionResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*SetDescriptionResponse) Descriptor deprecated

func (*SetDescriptionResponse) Descriptor() ([]byte, []int)

Deprecated: Use SetDescriptionResponse.ProtoReflect.Descriptor instead.

func (*SetDescriptionResponse) GetResult

func (x *SetDescriptionResponse) GetResult() int64

func (*SetDescriptionResponse) ProtoMessage

func (*SetDescriptionResponse) ProtoMessage()

func (*SetDescriptionResponse) ProtoReflect

func (x *SetDescriptionResponse) ProtoReflect() protoreflect.Message

func (*SetDescriptionResponse) Reset

func (x *SetDescriptionResponse) Reset()

func (*SetDescriptionResponse) String

func (x *SetDescriptionResponse) String() string

type SetMoreOptionsButtonListenerRequest

type SetMoreOptionsButtonListenerRequest struct {
	Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	Arg1 int64 `protobuf:"varint,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
	// contains filtered or unexported fields
}

func (*SetMoreOptionsButtonListenerRequest) Descriptor deprecated

func (*SetMoreOptionsButtonListenerRequest) Descriptor() ([]byte, []int)

Deprecated: Use SetMoreOptionsButtonListenerRequest.ProtoReflect.Descriptor instead.

func (*SetMoreOptionsButtonListenerRequest) GetArg0

func (*SetMoreOptionsButtonListenerRequest) GetArg1

func (*SetMoreOptionsButtonListenerRequest) ProtoMessage

func (*SetMoreOptionsButtonListenerRequest) ProtoMessage()

func (*SetMoreOptionsButtonListenerRequest) ProtoReflect

func (*SetMoreOptionsButtonListenerRequest) Reset

func (*SetMoreOptionsButtonListenerRequest) String

type SetMoreOptionsButtonListenerResponse

type SetMoreOptionsButtonListenerResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*SetMoreOptionsButtonListenerResponse) Descriptor deprecated

func (*SetMoreOptionsButtonListenerResponse) Descriptor() ([]byte, []int)

Deprecated: Use SetMoreOptionsButtonListenerResponse.ProtoReflect.Descriptor instead.

func (*SetMoreOptionsButtonListenerResponse) GetResult

func (*SetMoreOptionsButtonListenerResponse) ProtoMessage

func (*SetMoreOptionsButtonListenerResponse) ProtoMessage()

func (*SetMoreOptionsButtonListenerResponse) ProtoReflect

func (*SetMoreOptionsButtonListenerResponse) Reset

func (*SetMoreOptionsButtonListenerResponse) String

type UnimplementedPromptContentItemBulletedTextServiceServer

type UnimplementedPromptContentItemBulletedTextServiceServer struct{}

UnimplementedPromptContentItemBulletedTextServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

type UnimplementedPromptContentItemPlainTextServiceServer

type UnimplementedPromptContentItemPlainTextServiceServer struct{}

UnimplementedPromptContentItemPlainTextServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

type UnimplementedPromptContentViewWithMoreOptionsButtonBuilderServiceServer

type UnimplementedPromptContentViewWithMoreOptionsButtonBuilderServiceServer struct{}

UnimplementedPromptContentViewWithMoreOptionsButtonBuilderServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedPromptContentViewWithMoreOptionsButtonBuilderServiceServer) Build

func (UnimplementedPromptContentViewWithMoreOptionsButtonBuilderServiceServer) SetDescription

func (UnimplementedPromptContentViewWithMoreOptionsButtonBuilderServiceServer) SetMoreOptionsButtonListener

type UnimplementedPromptContentViewWithMoreOptionsButtonServiceServer

type UnimplementedPromptContentViewWithMoreOptionsButtonServiceServer struct{}

UnimplementedPromptContentViewWithMoreOptionsButtonServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedPromptContentViewWithMoreOptionsButtonServiceServer) DescribeContents

func (UnimplementedPromptContentViewWithMoreOptionsButtonServiceServer) GetDescription

func (UnimplementedPromptContentViewWithMoreOptionsButtonServiceServer) GetMoreOptionsButtonListener

func (UnimplementedPromptContentViewWithMoreOptionsButtonServiceServer) WriteToParcel

type UnimplementedPromptVerticalListContentViewBuilderServiceServer

type UnimplementedPromptVerticalListContentViewBuilderServiceServer struct{}

UnimplementedPromptVerticalListContentViewBuilderServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedPromptVerticalListContentViewBuilderServiceServer) AddListItem1

func (UnimplementedPromptVerticalListContentViewBuilderServiceServer) AddListItem2_1

func (UnimplementedPromptVerticalListContentViewBuilderServiceServer) Build

func (UnimplementedPromptVerticalListContentViewBuilderServiceServer) SetDescription

type UnimplementedPromptVerticalListContentViewServiceServer

type UnimplementedPromptVerticalListContentViewServiceServer struct{}

UnimplementedPromptVerticalListContentViewServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedPromptVerticalListContentViewServiceServer) DescribeContents

func (UnimplementedPromptVerticalListContentViewServiceServer) GetDescription

func (UnimplementedPromptVerticalListContentViewServiceServer) GetListItems

func (UnimplementedPromptVerticalListContentViewServiceServer) GetMaxItemCount

func (UnimplementedPromptVerticalListContentViewServiceServer) WriteToParcel

type UnsafePromptContentItemBulletedTextServiceServer

type UnsafePromptContentItemBulletedTextServiceServer interface {
	// contains filtered or unexported methods
}

UnsafePromptContentItemBulletedTextServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to PromptContentItemBulletedTextServiceServer will result in compilation errors.

type UnsafePromptContentItemPlainTextServiceServer

type UnsafePromptContentItemPlainTextServiceServer interface {
	// contains filtered or unexported methods
}

UnsafePromptContentItemPlainTextServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to PromptContentItemPlainTextServiceServer will result in compilation errors.

type UnsafePromptContentViewWithMoreOptionsButtonBuilderServiceServer

type UnsafePromptContentViewWithMoreOptionsButtonBuilderServiceServer interface {
	// contains filtered or unexported methods
}

UnsafePromptContentViewWithMoreOptionsButtonBuilderServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to PromptContentViewWithMoreOptionsButtonBuilderServiceServer will result in compilation errors.

type UnsafePromptContentViewWithMoreOptionsButtonServiceServer

type UnsafePromptContentViewWithMoreOptionsButtonServiceServer interface {
	// contains filtered or unexported methods
}

UnsafePromptContentViewWithMoreOptionsButtonServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to PromptContentViewWithMoreOptionsButtonServiceServer will result in compilation errors.

type UnsafePromptVerticalListContentViewBuilderServiceServer

type UnsafePromptVerticalListContentViewBuilderServiceServer interface {
	// contains filtered or unexported methods
}

UnsafePromptVerticalListContentViewBuilderServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to PromptVerticalListContentViewBuilderServiceServer will result in compilation errors.

type UnsafePromptVerticalListContentViewServiceServer

type UnsafePromptVerticalListContentViewServiceServer interface {
	// contains filtered or unexported methods
}

UnsafePromptVerticalListContentViewServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to PromptVerticalListContentViewServiceServer will result in compilation errors.

type WriteToParcelRequest

type WriteToParcelRequest struct {
	Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	Arg1 int32 `protobuf:"varint,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
	// contains filtered or unexported fields
}

func (*WriteToParcelRequest) Descriptor deprecated

func (*WriteToParcelRequest) Descriptor() ([]byte, []int)

Deprecated: Use WriteToParcelRequest.ProtoReflect.Descriptor instead.

func (*WriteToParcelRequest) GetArg0

func (x *WriteToParcelRequest) GetArg0() int64

func (*WriteToParcelRequest) GetArg1

func (x *WriteToParcelRequest) GetArg1() int32

func (*WriteToParcelRequest) ProtoMessage

func (*WriteToParcelRequest) ProtoMessage()

func (*WriteToParcelRequest) ProtoReflect

func (x *WriteToParcelRequest) ProtoReflect() protoreflect.Message

func (*WriteToParcelRequest) Reset

func (x *WriteToParcelRequest) Reset()

func (*WriteToParcelRequest) String

func (x *WriteToParcelRequest) String() string

type WriteToParcelResponse

type WriteToParcelResponse struct {
	// contains filtered or unexported fields
}

func (*WriteToParcelResponse) Descriptor deprecated

func (*WriteToParcelResponse) Descriptor() ([]byte, []int)

Deprecated: Use WriteToParcelResponse.ProtoReflect.Descriptor instead.

func (*WriteToParcelResponse) ProtoMessage

func (*WriteToParcelResponse) ProtoMessage()

func (*WriteToParcelResponse) ProtoReflect

func (x *WriteToParcelResponse) ProtoReflect() protoreflect.Message

func (*WriteToParcelResponse) Reset

func (x *WriteToParcelResponse) Reset()

func (*WriteToParcelResponse) String

func (x *WriteToParcelResponse) String() string

Jump to