blob

package
v0.0.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 16, 2026 License: CC0-1.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

const (
	BlobStoreManagerService_AbandonSession_FullMethodName              = "/blob.BlobStoreManagerService/AbandonSession"
	BlobStoreManagerService_AcquireLease2_FullMethodName               = "/blob.BlobStoreManagerService/AcquireLease2"
	BlobStoreManagerService_AcquireLease3_1_FullMethodName             = "/blob.BlobStoreManagerService/AcquireLease3_1"
	BlobStoreManagerService_AcquireLease2_2_FullMethodName             = "/blob.BlobStoreManagerService/AcquireLease2_2"
	BlobStoreManagerService_AcquireLease3_3_FullMethodName             = "/blob.BlobStoreManagerService/AcquireLease3_3"
	BlobStoreManagerService_CreateSession_FullMethodName               = "/blob.BlobStoreManagerService/CreateSession"
	BlobStoreManagerService_GetLeasedBlobs_FullMethodName              = "/blob.BlobStoreManagerService/GetLeasedBlobs"
	BlobStoreManagerService_GetRemainingLeaseQuotaBytes_FullMethodName = "/blob.BlobStoreManagerService/GetRemainingLeaseQuotaBytes"
	BlobStoreManagerService_OpenBlob_FullMethodName                    = "/blob.BlobStoreManagerService/OpenBlob"
	BlobStoreManagerService_OpenSession_FullMethodName                 = "/blob.BlobStoreManagerService/OpenSession"
	BlobStoreManagerService_ReleaseLease_FullMethodName                = "/blob.BlobStoreManagerService/ReleaseLease"
)

Variables

var BlobStoreManagerService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "blob.BlobStoreManagerService",
	HandlerType: (*BlobStoreManagerServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "AbandonSession",
			Handler:    _BlobStoreManagerService_AbandonSession_Handler,
		},
		{
			MethodName: "AcquireLease2",
			Handler:    _BlobStoreManagerService_AcquireLease2_Handler,
		},
		{
			MethodName: "AcquireLease3_1",
			Handler:    _BlobStoreManagerService_AcquireLease3_1_Handler,
		},
		{
			MethodName: "AcquireLease2_2",
			Handler:    _BlobStoreManagerService_AcquireLease2_2_Handler,
		},
		{
			MethodName: "AcquireLease3_3",
			Handler:    _BlobStoreManagerService_AcquireLease3_3_Handler,
		},
		{
			MethodName: "CreateSession",
			Handler:    _BlobStoreManagerService_CreateSession_Handler,
		},
		{
			MethodName: "GetLeasedBlobs",
			Handler:    _BlobStoreManagerService_GetLeasedBlobs_Handler,
		},
		{
			MethodName: "GetRemainingLeaseQuotaBytes",
			Handler:    _BlobStoreManagerService_GetRemainingLeaseQuotaBytes_Handler,
		},
		{
			MethodName: "OpenBlob",
			Handler:    _BlobStoreManagerService_OpenBlob_Handler,
		},
		{
			MethodName: "OpenSession",
			Handler:    _BlobStoreManagerService_OpenSession_Handler,
		},
		{
			MethodName: "ReleaseLease",
			Handler:    _BlobStoreManagerService_ReleaseLease_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/blob/blob.proto",
}

BlobStoreManagerService_ServiceDesc is the grpc.ServiceDesc for BlobStoreManagerService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var File_proto_blob_blob_proto protoreflect.FileDescriptor

Functions

func RegisterBlobStoreManagerServiceServer

func RegisterBlobStoreManagerServiceServer(s grpc.ServiceRegistrar, srv BlobStoreManagerServiceServer)

Types

type AbandonSessionRequest

type AbandonSessionRequest struct {
	Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*AbandonSessionRequest) Descriptor deprecated

func (*AbandonSessionRequest) Descriptor() ([]byte, []int)

Deprecated: Use AbandonSessionRequest.ProtoReflect.Descriptor instead.

func (*AbandonSessionRequest) GetArg0

func (x *AbandonSessionRequest) GetArg0() int64

func (*AbandonSessionRequest) ProtoMessage

func (*AbandonSessionRequest) ProtoMessage()

func (*AbandonSessionRequest) ProtoReflect

func (x *AbandonSessionRequest) ProtoReflect() protoreflect.Message

func (*AbandonSessionRequest) Reset

func (x *AbandonSessionRequest) Reset()

func (*AbandonSessionRequest) String

func (x *AbandonSessionRequest) String() string

type AbandonSessionResponse

type AbandonSessionResponse struct {
	// contains filtered or unexported fields
}

func (*AbandonSessionResponse) Descriptor deprecated

func (*AbandonSessionResponse) Descriptor() ([]byte, []int)

Deprecated: Use AbandonSessionResponse.ProtoReflect.Descriptor instead.

func (*AbandonSessionResponse) ProtoMessage

func (*AbandonSessionResponse) ProtoMessage()

func (*AbandonSessionResponse) ProtoReflect

func (x *AbandonSessionResponse) ProtoReflect() protoreflect.Message

func (*AbandonSessionResponse) Reset

func (x *AbandonSessionResponse) Reset()

func (*AbandonSessionResponse) String

func (x *AbandonSessionResponse) String() string

type AcquireLease2Request

type AcquireLease2Request struct {
	Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	Arg1 int32 `protobuf:"varint,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
	// contains filtered or unexported fields
}

func (*AcquireLease2Request) Descriptor deprecated

func (*AcquireLease2Request) Descriptor() ([]byte, []int)

Deprecated: Use AcquireLease2Request.ProtoReflect.Descriptor instead.

func (*AcquireLease2Request) GetArg0

func (x *AcquireLease2Request) GetArg0() int64

func (*AcquireLease2Request) GetArg1

func (x *AcquireLease2Request) GetArg1() int32

func (*AcquireLease2Request) ProtoMessage

func (*AcquireLease2Request) ProtoMessage()

func (*AcquireLease2Request) ProtoReflect

func (x *AcquireLease2Request) ProtoReflect() protoreflect.Message

func (*AcquireLease2Request) Reset

func (x *AcquireLease2Request) Reset()

func (*AcquireLease2Request) String

func (x *AcquireLease2Request) String() string

type AcquireLease2Response

type AcquireLease2Response struct {
	// contains filtered or unexported fields
}

func (*AcquireLease2Response) Descriptor deprecated

func (*AcquireLease2Response) Descriptor() ([]byte, []int)

Deprecated: Use AcquireLease2Response.ProtoReflect.Descriptor instead.

func (*AcquireLease2Response) ProtoMessage

func (*AcquireLease2Response) ProtoMessage()

func (*AcquireLease2Response) ProtoReflect

func (x *AcquireLease2Response) ProtoReflect() protoreflect.Message

func (*AcquireLease2Response) Reset

func (x *AcquireLease2Response) Reset()

func (*AcquireLease2Response) String

func (x *AcquireLease2Response) String() string

type AcquireLease2_2Request

type AcquireLease2_2Request struct {
	Arg0 int64  `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	Arg1 string `protobuf:"bytes,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
	// contains filtered or unexported fields
}

func (*AcquireLease2_2Request) Descriptor deprecated

func (*AcquireLease2_2Request) Descriptor() ([]byte, []int)

Deprecated: Use AcquireLease2_2Request.ProtoReflect.Descriptor instead.

func (*AcquireLease2_2Request) GetArg0

func (x *AcquireLease2_2Request) GetArg0() int64

func (*AcquireLease2_2Request) GetArg1

func (x *AcquireLease2_2Request) GetArg1() string

func (*AcquireLease2_2Request) ProtoMessage

func (*AcquireLease2_2Request) ProtoMessage()

func (*AcquireLease2_2Request) ProtoReflect

func (x *AcquireLease2_2Request) ProtoReflect() protoreflect.Message

func (*AcquireLease2_2Request) Reset

func (x *AcquireLease2_2Request) Reset()

func (*AcquireLease2_2Request) String

func (x *AcquireLease2_2Request) String() string

type AcquireLease2_2Response

type AcquireLease2_2Response struct {
	// contains filtered or unexported fields
}

func (*AcquireLease2_2Response) Descriptor deprecated

func (*AcquireLease2_2Response) Descriptor() ([]byte, []int)

Deprecated: Use AcquireLease2_2Response.ProtoReflect.Descriptor instead.

func (*AcquireLease2_2Response) ProtoMessage

func (*AcquireLease2_2Response) ProtoMessage()

func (*AcquireLease2_2Response) ProtoReflect

func (x *AcquireLease2_2Response) ProtoReflect() protoreflect.Message

func (*AcquireLease2_2Response) Reset

func (x *AcquireLease2_2Response) Reset()

func (*AcquireLease2_2Response) String

func (x *AcquireLease2_2Response) String() string

type AcquireLease3_1Request

type AcquireLease3_1Request struct {
	Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	Arg1 int32 `protobuf:"varint,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
	Arg2 int64 `protobuf:"varint,3,opt,name=arg2,proto3" json:"arg2,omitempty"`
	// contains filtered or unexported fields
}

func (*AcquireLease3_1Request) Descriptor deprecated

func (*AcquireLease3_1Request) Descriptor() ([]byte, []int)

Deprecated: Use AcquireLease3_1Request.ProtoReflect.Descriptor instead.

func (*AcquireLease3_1Request) GetArg0

func (x *AcquireLease3_1Request) GetArg0() int64

func (*AcquireLease3_1Request) GetArg1

func (x *AcquireLease3_1Request) GetArg1() int32

func (*AcquireLease3_1Request) GetArg2

func (x *AcquireLease3_1Request) GetArg2() int64

func (*AcquireLease3_1Request) ProtoMessage

func (*AcquireLease3_1Request) ProtoMessage()

func (*AcquireLease3_1Request) ProtoReflect

func (x *AcquireLease3_1Request) ProtoReflect() protoreflect.Message

func (*AcquireLease3_1Request) Reset

func (x *AcquireLease3_1Request) Reset()

func (*AcquireLease3_1Request) String

func (x *AcquireLease3_1Request) String() string

type AcquireLease3_1Response

type AcquireLease3_1Response struct {
	// contains filtered or unexported fields
}

func (*AcquireLease3_1Response) Descriptor deprecated

func (*AcquireLease3_1Response) Descriptor() ([]byte, []int)

Deprecated: Use AcquireLease3_1Response.ProtoReflect.Descriptor instead.

func (*AcquireLease3_1Response) ProtoMessage

func (*AcquireLease3_1Response) ProtoMessage()

func (*AcquireLease3_1Response) ProtoReflect

func (x *AcquireLease3_1Response) ProtoReflect() protoreflect.Message

func (*AcquireLease3_1Response) Reset

func (x *AcquireLease3_1Response) Reset()

func (*AcquireLease3_1Response) String

func (x *AcquireLease3_1Response) String() string

type AcquireLease3_3Request

type AcquireLease3_3Request struct {
	Arg0 int64  `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	Arg1 string `protobuf:"bytes,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
	Arg2 int64  `protobuf:"varint,3,opt,name=arg2,proto3" json:"arg2,omitempty"`
	// contains filtered or unexported fields
}

func (*AcquireLease3_3Request) Descriptor deprecated

func (*AcquireLease3_3Request) Descriptor() ([]byte, []int)

Deprecated: Use AcquireLease3_3Request.ProtoReflect.Descriptor instead.

func (*AcquireLease3_3Request) GetArg0

func (x *AcquireLease3_3Request) GetArg0() int64

func (*AcquireLease3_3Request) GetArg1

func (x *AcquireLease3_3Request) GetArg1() string

func (*AcquireLease3_3Request) GetArg2

func (x *AcquireLease3_3Request) GetArg2() int64

func (*AcquireLease3_3Request) ProtoMessage

func (*AcquireLease3_3Request) ProtoMessage()

func (*AcquireLease3_3Request) ProtoReflect

func (x *AcquireLease3_3Request) ProtoReflect() protoreflect.Message

func (*AcquireLease3_3Request) Reset

func (x *AcquireLease3_3Request) Reset()

func (*AcquireLease3_3Request) String

func (x *AcquireLease3_3Request) String() string

type AcquireLease3_3Response

type AcquireLease3_3Response struct {
	// contains filtered or unexported fields
}

func (*AcquireLease3_3Response) Descriptor deprecated

func (*AcquireLease3_3Response) Descriptor() ([]byte, []int)

Deprecated: Use AcquireLease3_3Response.ProtoReflect.Descriptor instead.

func (*AcquireLease3_3Response) ProtoMessage

func (*AcquireLease3_3Response) ProtoMessage()

func (*AcquireLease3_3Response) ProtoReflect

func (x *AcquireLease3_3Response) ProtoReflect() protoreflect.Message

func (*AcquireLease3_3Response) Reset

func (x *AcquireLease3_3Response) Reset()

func (*AcquireLease3_3Response) String

func (x *AcquireLease3_3Response) String() string

type BlobStoreManagerServiceClient

BlobStoreManagerServiceClient is the client API for BlobStoreManagerService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type BlobStoreManagerServiceServer

BlobStoreManagerServiceServer is the server API for BlobStoreManagerService service. All implementations must embed UnimplementedBlobStoreManagerServiceServer for forward compatibility.

type CreateSessionRequest

type CreateSessionRequest struct {
	Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*CreateSessionRequest) Descriptor deprecated

func (*CreateSessionRequest) Descriptor() ([]byte, []int)

Deprecated: Use CreateSessionRequest.ProtoReflect.Descriptor instead.

func (*CreateSessionRequest) GetArg0

func (x *CreateSessionRequest) GetArg0() int64

func (*CreateSessionRequest) ProtoMessage

func (*CreateSessionRequest) ProtoMessage()

func (*CreateSessionRequest) ProtoReflect

func (x *CreateSessionRequest) ProtoReflect() protoreflect.Message

func (*CreateSessionRequest) Reset

func (x *CreateSessionRequest) Reset()

func (*CreateSessionRequest) String

func (x *CreateSessionRequest) String() string

type CreateSessionResponse

type CreateSessionResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*CreateSessionResponse) Descriptor deprecated

func (*CreateSessionResponse) Descriptor() ([]byte, []int)

Deprecated: Use CreateSessionResponse.ProtoReflect.Descriptor instead.

func (*CreateSessionResponse) GetResult

func (x *CreateSessionResponse) GetResult() int64

func (*CreateSessionResponse) ProtoMessage

func (*CreateSessionResponse) ProtoMessage()

func (*CreateSessionResponse) ProtoReflect

func (x *CreateSessionResponse) ProtoReflect() protoreflect.Message

func (*CreateSessionResponse) Reset

func (x *CreateSessionResponse) Reset()

func (*CreateSessionResponse) String

func (x *CreateSessionResponse) String() string

type GetLeasedBlobsRequest

type GetLeasedBlobsRequest struct {
	// contains filtered or unexported fields
}

func (*GetLeasedBlobsRequest) Descriptor deprecated

func (*GetLeasedBlobsRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetLeasedBlobsRequest.ProtoReflect.Descriptor instead.

func (*GetLeasedBlobsRequest) ProtoMessage

func (*GetLeasedBlobsRequest) ProtoMessage()

func (*GetLeasedBlobsRequest) ProtoReflect

func (x *GetLeasedBlobsRequest) ProtoReflect() protoreflect.Message

func (*GetLeasedBlobsRequest) Reset

func (x *GetLeasedBlobsRequest) Reset()

func (*GetLeasedBlobsRequest) String

func (x *GetLeasedBlobsRequest) String() string

type GetLeasedBlobsResponse

type GetLeasedBlobsResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetLeasedBlobsResponse) Descriptor deprecated

func (*GetLeasedBlobsResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetLeasedBlobsResponse.ProtoReflect.Descriptor instead.

func (*GetLeasedBlobsResponse) GetResult

func (x *GetLeasedBlobsResponse) GetResult() int64

func (*GetLeasedBlobsResponse) ProtoMessage

func (*GetLeasedBlobsResponse) ProtoMessage()

func (*GetLeasedBlobsResponse) ProtoReflect

func (x *GetLeasedBlobsResponse) ProtoReflect() protoreflect.Message

func (*GetLeasedBlobsResponse) Reset

func (x *GetLeasedBlobsResponse) Reset()

func (*GetLeasedBlobsResponse) String

func (x *GetLeasedBlobsResponse) String() string

type GetRemainingLeaseQuotaBytesRequest

type GetRemainingLeaseQuotaBytesRequest struct {
	// contains filtered or unexported fields
}

func (*GetRemainingLeaseQuotaBytesRequest) Descriptor deprecated

func (*GetRemainingLeaseQuotaBytesRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetRemainingLeaseQuotaBytesRequest.ProtoReflect.Descriptor instead.

func (*GetRemainingLeaseQuotaBytesRequest) ProtoMessage

func (*GetRemainingLeaseQuotaBytesRequest) ProtoMessage()

func (*GetRemainingLeaseQuotaBytesRequest) ProtoReflect

func (*GetRemainingLeaseQuotaBytesRequest) Reset

func (*GetRemainingLeaseQuotaBytesRequest) String

type GetRemainingLeaseQuotaBytesResponse

type GetRemainingLeaseQuotaBytesResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetRemainingLeaseQuotaBytesResponse) Descriptor deprecated

func (*GetRemainingLeaseQuotaBytesResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetRemainingLeaseQuotaBytesResponse.ProtoReflect.Descriptor instead.

func (*GetRemainingLeaseQuotaBytesResponse) GetResult

func (*GetRemainingLeaseQuotaBytesResponse) ProtoMessage

func (*GetRemainingLeaseQuotaBytesResponse) ProtoMessage()

func (*GetRemainingLeaseQuotaBytesResponse) ProtoReflect

func (*GetRemainingLeaseQuotaBytesResponse) Reset

func (*GetRemainingLeaseQuotaBytesResponse) String

type OpenBlobRequest

type OpenBlobRequest struct {
	Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*OpenBlobRequest) Descriptor deprecated

func (*OpenBlobRequest) Descriptor() ([]byte, []int)

Deprecated: Use OpenBlobRequest.ProtoReflect.Descriptor instead.

func (*OpenBlobRequest) GetArg0

func (x *OpenBlobRequest) GetArg0() int64

func (*OpenBlobRequest) ProtoMessage

func (*OpenBlobRequest) ProtoMessage()

func (*OpenBlobRequest) ProtoReflect

func (x *OpenBlobRequest) ProtoReflect() protoreflect.Message

func (*OpenBlobRequest) Reset

func (x *OpenBlobRequest) Reset()

func (*OpenBlobRequest) String

func (x *OpenBlobRequest) String() string

type OpenBlobResponse

type OpenBlobResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*OpenBlobResponse) Descriptor deprecated

func (*OpenBlobResponse) Descriptor() ([]byte, []int)

Deprecated: Use OpenBlobResponse.ProtoReflect.Descriptor instead.

func (*OpenBlobResponse) GetResult

func (x *OpenBlobResponse) GetResult() int64

func (*OpenBlobResponse) ProtoMessage

func (*OpenBlobResponse) ProtoMessage()

func (*OpenBlobResponse) ProtoReflect

func (x *OpenBlobResponse) ProtoReflect() protoreflect.Message

func (*OpenBlobResponse) Reset

func (x *OpenBlobResponse) Reset()

func (*OpenBlobResponse) String

func (x *OpenBlobResponse) String() string

type OpenSessionRequest

type OpenSessionRequest struct {
	Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*OpenSessionRequest) Descriptor deprecated

func (*OpenSessionRequest) Descriptor() ([]byte, []int)

Deprecated: Use OpenSessionRequest.ProtoReflect.Descriptor instead.

func (*OpenSessionRequest) GetArg0

func (x *OpenSessionRequest) GetArg0() int64

func (*OpenSessionRequest) ProtoMessage

func (*OpenSessionRequest) ProtoMessage()

func (*OpenSessionRequest) ProtoReflect

func (x *OpenSessionRequest) ProtoReflect() protoreflect.Message

func (*OpenSessionRequest) Reset

func (x *OpenSessionRequest) Reset()

func (*OpenSessionRequest) String

func (x *OpenSessionRequest) String() string

type OpenSessionResponse

type OpenSessionResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*OpenSessionResponse) Descriptor deprecated

func (*OpenSessionResponse) Descriptor() ([]byte, []int)

Deprecated: Use OpenSessionResponse.ProtoReflect.Descriptor instead.

func (*OpenSessionResponse) GetResult

func (x *OpenSessionResponse) GetResult() int64

func (*OpenSessionResponse) ProtoMessage

func (*OpenSessionResponse) ProtoMessage()

func (*OpenSessionResponse) ProtoReflect

func (x *OpenSessionResponse) ProtoReflect() protoreflect.Message

func (*OpenSessionResponse) Reset

func (x *OpenSessionResponse) Reset()

func (*OpenSessionResponse) String

func (x *OpenSessionResponse) String() string

type ReleaseLeaseRequest

type ReleaseLeaseRequest struct {
	Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*ReleaseLeaseRequest) Descriptor deprecated

func (*ReleaseLeaseRequest) Descriptor() ([]byte, []int)

Deprecated: Use ReleaseLeaseRequest.ProtoReflect.Descriptor instead.

func (*ReleaseLeaseRequest) GetArg0

func (x *ReleaseLeaseRequest) GetArg0() int64

func (*ReleaseLeaseRequest) ProtoMessage

func (*ReleaseLeaseRequest) ProtoMessage()

func (*ReleaseLeaseRequest) ProtoReflect

func (x *ReleaseLeaseRequest) ProtoReflect() protoreflect.Message

func (*ReleaseLeaseRequest) Reset

func (x *ReleaseLeaseRequest) Reset()

func (*ReleaseLeaseRequest) String

func (x *ReleaseLeaseRequest) String() string

type ReleaseLeaseResponse

type ReleaseLeaseResponse struct {
	// contains filtered or unexported fields
}

func (*ReleaseLeaseResponse) Descriptor deprecated

func (*ReleaseLeaseResponse) Descriptor() ([]byte, []int)

Deprecated: Use ReleaseLeaseResponse.ProtoReflect.Descriptor instead.

func (*ReleaseLeaseResponse) ProtoMessage

func (*ReleaseLeaseResponse) ProtoMessage()

func (*ReleaseLeaseResponse) ProtoReflect

func (x *ReleaseLeaseResponse) ProtoReflect() protoreflect.Message

func (*ReleaseLeaseResponse) Reset

func (x *ReleaseLeaseResponse) Reset()

func (*ReleaseLeaseResponse) String

func (x *ReleaseLeaseResponse) String() string

type UnimplementedBlobStoreManagerServiceServer

type UnimplementedBlobStoreManagerServiceServer struct{}

UnimplementedBlobStoreManagerServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedBlobStoreManagerServiceServer) AbandonSession

func (UnimplementedBlobStoreManagerServiceServer) AcquireLease2

func (UnimplementedBlobStoreManagerServiceServer) AcquireLease2_2

func (UnimplementedBlobStoreManagerServiceServer) AcquireLease3_1

func (UnimplementedBlobStoreManagerServiceServer) AcquireLease3_3

func (UnimplementedBlobStoreManagerServiceServer) CreateSession

func (UnimplementedBlobStoreManagerServiceServer) GetLeasedBlobs

func (UnimplementedBlobStoreManagerServiceServer) OpenBlob

func (UnimplementedBlobStoreManagerServiceServer) OpenSession

func (UnimplementedBlobStoreManagerServiceServer) ReleaseLease

type UnsafeBlobStoreManagerServiceServer

type UnsafeBlobStoreManagerServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeBlobStoreManagerServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to BlobStoreManagerServiceServer will result in compilation errors.

Jump to