Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterContractServiceServer(s grpc.ServiceRegistrar, srv ContractServiceServer)
- type ContractServiceClient
- type ContractServiceServer
- type StartViewCalendarEventInManagedProfileRequest
- func (*StartViewCalendarEventInManagedProfileRequest) Descriptor() ([]byte, []int)deprecated
- func (x *StartViewCalendarEventInManagedProfileRequest) GetArg0() int64
- func (x *StartViewCalendarEventInManagedProfileRequest) GetArg1() int64
- func (x *StartViewCalendarEventInManagedProfileRequest) GetArg2() int64
- func (x *StartViewCalendarEventInManagedProfileRequest) GetArg3() int64
- func (x *StartViewCalendarEventInManagedProfileRequest) GetArg4() bool
- func (x *StartViewCalendarEventInManagedProfileRequest) GetArg5() int32
- func (*StartViewCalendarEventInManagedProfileRequest) ProtoMessage()
- func (x *StartViewCalendarEventInManagedProfileRequest) ProtoReflect() protoreflect.Message
- func (x *StartViewCalendarEventInManagedProfileRequest) Reset()
- func (x *StartViewCalendarEventInManagedProfileRequest) String() string
- type StartViewCalendarEventInManagedProfileResponse
- func (*StartViewCalendarEventInManagedProfileResponse) Descriptor() ([]byte, []int)deprecated
- func (x *StartViewCalendarEventInManagedProfileResponse) GetResult() bool
- func (*StartViewCalendarEventInManagedProfileResponse) ProtoMessage()
- func (x *StartViewCalendarEventInManagedProfileResponse) ProtoReflect() protoreflect.Message
- func (x *StartViewCalendarEventInManagedProfileResponse) Reset()
- func (x *StartViewCalendarEventInManagedProfileResponse) String() string
- type UnimplementedContractServiceServer
- type UnsafeContractServiceServer
Constants ¶
const (
ContractService_StartViewCalendarEventInManagedProfile_FullMethodName = "/calendar.ContractService/StartViewCalendarEventInManagedProfile"
)
Variables ¶
var ContractService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "calendar.ContractService", HandlerType: (*ContractServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "StartViewCalendarEventInManagedProfile", Handler: _ContractService_StartViewCalendarEventInManagedProfile_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "proto/calendar/calendar.proto", }
ContractService_ServiceDesc is the grpc.ServiceDesc for ContractService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var File_proto_calendar_calendar_proto protoreflect.FileDescriptor
Functions ¶
func RegisterContractServiceServer ¶ added in v0.0.4
func RegisterContractServiceServer(s grpc.ServiceRegistrar, srv ContractServiceServer)
Types ¶
type ContractServiceClient ¶ added in v0.0.4
type ContractServiceClient interface {
StartViewCalendarEventInManagedProfile(ctx context.Context, in *StartViewCalendarEventInManagedProfileRequest, opts ...grpc.CallOption) (*StartViewCalendarEventInManagedProfileResponse, error)
}
ContractServiceClient is the client API for ContractService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewContractServiceClient ¶ added in v0.0.4
func NewContractServiceClient(cc grpc.ClientConnInterface) ContractServiceClient
type ContractServiceServer ¶ added in v0.0.4
type ContractServiceServer interface {
StartViewCalendarEventInManagedProfile(context.Context, *StartViewCalendarEventInManagedProfileRequest) (*StartViewCalendarEventInManagedProfileResponse, error)
// contains filtered or unexported methods
}
ContractServiceServer is the server API for ContractService service. All implementations must embed UnimplementedContractServiceServer for forward compatibility.
type StartViewCalendarEventInManagedProfileRequest ¶
type StartViewCalendarEventInManagedProfileRequest struct {
Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
Arg1 int64 `protobuf:"varint,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
Arg2 int64 `protobuf:"varint,3,opt,name=arg2,proto3" json:"arg2,omitempty"`
Arg3 int64 `protobuf:"varint,4,opt,name=arg3,proto3" json:"arg3,omitempty"`
Arg4 bool `protobuf:"varint,5,opt,name=arg4,proto3" json:"arg4,omitempty"`
Arg5 int32 `protobuf:"varint,6,opt,name=arg5,proto3" json:"arg5,omitempty"`
// contains filtered or unexported fields
}
func (*StartViewCalendarEventInManagedProfileRequest) Descriptor
deprecated
func (*StartViewCalendarEventInManagedProfileRequest) Descriptor() ([]byte, []int)
Deprecated: Use StartViewCalendarEventInManagedProfileRequest.ProtoReflect.Descriptor instead.
func (*StartViewCalendarEventInManagedProfileRequest) GetArg0 ¶
func (x *StartViewCalendarEventInManagedProfileRequest) GetArg0() int64
func (*StartViewCalendarEventInManagedProfileRequest) GetArg1 ¶
func (x *StartViewCalendarEventInManagedProfileRequest) GetArg1() int64
func (*StartViewCalendarEventInManagedProfileRequest) GetArg2 ¶
func (x *StartViewCalendarEventInManagedProfileRequest) GetArg2() int64
func (*StartViewCalendarEventInManagedProfileRequest) GetArg3 ¶
func (x *StartViewCalendarEventInManagedProfileRequest) GetArg3() int64
func (*StartViewCalendarEventInManagedProfileRequest) GetArg4 ¶
func (x *StartViewCalendarEventInManagedProfileRequest) GetArg4() bool
func (*StartViewCalendarEventInManagedProfileRequest) GetArg5 ¶
func (x *StartViewCalendarEventInManagedProfileRequest) GetArg5() int32
func (*StartViewCalendarEventInManagedProfileRequest) ProtoMessage ¶
func (*StartViewCalendarEventInManagedProfileRequest) ProtoMessage()
func (*StartViewCalendarEventInManagedProfileRequest) ProtoReflect ¶
func (x *StartViewCalendarEventInManagedProfileRequest) ProtoReflect() protoreflect.Message
func (*StartViewCalendarEventInManagedProfileRequest) Reset ¶
func (x *StartViewCalendarEventInManagedProfileRequest) Reset()
func (*StartViewCalendarEventInManagedProfileRequest) String ¶
func (x *StartViewCalendarEventInManagedProfileRequest) String() string
type StartViewCalendarEventInManagedProfileResponse ¶
type StartViewCalendarEventInManagedProfileResponse struct {
Result bool `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*StartViewCalendarEventInManagedProfileResponse) Descriptor
deprecated
func (*StartViewCalendarEventInManagedProfileResponse) Descriptor() ([]byte, []int)
Deprecated: Use StartViewCalendarEventInManagedProfileResponse.ProtoReflect.Descriptor instead.
func (*StartViewCalendarEventInManagedProfileResponse) GetResult ¶
func (x *StartViewCalendarEventInManagedProfileResponse) GetResult() bool
func (*StartViewCalendarEventInManagedProfileResponse) ProtoMessage ¶
func (*StartViewCalendarEventInManagedProfileResponse) ProtoMessage()
func (*StartViewCalendarEventInManagedProfileResponse) ProtoReflect ¶
func (x *StartViewCalendarEventInManagedProfileResponse) ProtoReflect() protoreflect.Message
func (*StartViewCalendarEventInManagedProfileResponse) Reset ¶
func (x *StartViewCalendarEventInManagedProfileResponse) Reset()
func (*StartViewCalendarEventInManagedProfileResponse) String ¶
func (x *StartViewCalendarEventInManagedProfileResponse) String() string
type UnimplementedContractServiceServer ¶ added in v0.0.4
type UnimplementedContractServiceServer struct{}
UnimplementedContractServiceServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedContractServiceServer) StartViewCalendarEventInManagedProfile ¶ added in v0.0.4
func (UnimplementedContractServiceServer) StartViewCalendarEventInManagedProfile(context.Context, *StartViewCalendarEventInManagedProfileRequest) (*StartViewCalendarEventInManagedProfileResponse, error)
type UnsafeContractServiceServer ¶ added in v0.0.4
type UnsafeContractServiceServer interface {
// contains filtered or unexported methods
}
UnsafeContractServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ContractServiceServer will result in compilation errors.