Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterManagerServiceServer(s grpc.ServiceRegistrar, srv ManagerServiceServer)
- type GetCameraCharacteristicsRequest
- func (*GetCameraCharacteristicsRequest) Descriptor() ([]byte, []int)deprecated
- func (x *GetCameraCharacteristicsRequest) GetArg0() string
- func (*GetCameraCharacteristicsRequest) ProtoMessage()
- func (x *GetCameraCharacteristicsRequest) ProtoReflect() protoreflect.Message
- func (x *GetCameraCharacteristicsRequest) Reset()
- func (x *GetCameraCharacteristicsRequest) String() string
- type GetCameraCharacteristicsResponse
- func (*GetCameraCharacteristicsResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetCameraCharacteristicsResponse) GetResult() int64
- func (*GetCameraCharacteristicsResponse) ProtoMessage()
- func (x *GetCameraCharacteristicsResponse) ProtoReflect() protoreflect.Message
- func (x *GetCameraCharacteristicsResponse) Reset()
- func (x *GetCameraCharacteristicsResponse) String() string
- type GetCameraDeviceSetupRequest
- func (*GetCameraDeviceSetupRequest) Descriptor() ([]byte, []int)deprecated
- func (x *GetCameraDeviceSetupRequest) GetArg0() string
- func (*GetCameraDeviceSetupRequest) ProtoMessage()
- func (x *GetCameraDeviceSetupRequest) ProtoReflect() protoreflect.Message
- func (x *GetCameraDeviceSetupRequest) Reset()
- func (x *GetCameraDeviceSetupRequest) String() string
- type GetCameraDeviceSetupResponse
- func (*GetCameraDeviceSetupResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetCameraDeviceSetupResponse) GetResult() int64
- func (*GetCameraDeviceSetupResponse) ProtoMessage()
- func (x *GetCameraDeviceSetupResponse) ProtoReflect() protoreflect.Message
- func (x *GetCameraDeviceSetupResponse) Reset()
- func (x *GetCameraDeviceSetupResponse) String() string
- type GetCameraExtensionCharacteristicsRequest
- func (*GetCameraExtensionCharacteristicsRequest) Descriptor() ([]byte, []int)deprecated
- func (x *GetCameraExtensionCharacteristicsRequest) GetArg0() string
- func (*GetCameraExtensionCharacteristicsRequest) ProtoMessage()
- func (x *GetCameraExtensionCharacteristicsRequest) ProtoReflect() protoreflect.Message
- func (x *GetCameraExtensionCharacteristicsRequest) Reset()
- func (x *GetCameraExtensionCharacteristicsRequest) String() string
- type GetCameraExtensionCharacteristicsResponse
- func (*GetCameraExtensionCharacteristicsResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetCameraExtensionCharacteristicsResponse) GetResult() int64
- func (*GetCameraExtensionCharacteristicsResponse) ProtoMessage()
- func (x *GetCameraExtensionCharacteristicsResponse) ProtoReflect() protoreflect.Message
- func (x *GetCameraExtensionCharacteristicsResponse) Reset()
- func (x *GetCameraExtensionCharacteristicsResponse) String() string
- type GetCameraIdListRequest
- type GetCameraIdListResponse
- func (*GetCameraIdListResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetCameraIdListResponse) GetResult() int64
- func (*GetCameraIdListResponse) ProtoMessage()
- func (x *GetCameraIdListResponse) ProtoReflect() protoreflect.Message
- func (x *GetCameraIdListResponse) Reset()
- func (x *GetCameraIdListResponse) String() string
- type GetConcurrentCameraIdsRequest
- func (*GetConcurrentCameraIdsRequest) Descriptor() ([]byte, []int)deprecated
- func (*GetConcurrentCameraIdsRequest) ProtoMessage()
- func (x *GetConcurrentCameraIdsRequest) ProtoReflect() protoreflect.Message
- func (x *GetConcurrentCameraIdsRequest) Reset()
- func (x *GetConcurrentCameraIdsRequest) String() string
- type GetConcurrentCameraIdsResponse
- func (*GetConcurrentCameraIdsResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetConcurrentCameraIdsResponse) GetResult() int64
- func (*GetConcurrentCameraIdsResponse) ProtoMessage()
- func (x *GetConcurrentCameraIdsResponse) ProtoReflect() protoreflect.Message
- func (x *GetConcurrentCameraIdsResponse) Reset()
- func (x *GetConcurrentCameraIdsResponse) String() string
- type GetTorchStrengthLevelRequest
- func (*GetTorchStrengthLevelRequest) Descriptor() ([]byte, []int)deprecated
- func (x *GetTorchStrengthLevelRequest) GetArg0() string
- func (*GetTorchStrengthLevelRequest) ProtoMessage()
- func (x *GetTorchStrengthLevelRequest) ProtoReflect() protoreflect.Message
- func (x *GetTorchStrengthLevelRequest) Reset()
- func (x *GetTorchStrengthLevelRequest) String() string
- type GetTorchStrengthLevelResponse
- func (*GetTorchStrengthLevelResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetTorchStrengthLevelResponse) GetResult() int32
- func (*GetTorchStrengthLevelResponse) ProtoMessage()
- func (x *GetTorchStrengthLevelResponse) ProtoReflect() protoreflect.Message
- func (x *GetTorchStrengthLevelResponse) Reset()
- func (x *GetTorchStrengthLevelResponse) String() string
- type IsCameraDeviceSetupSupportedRequest
- func (*IsCameraDeviceSetupSupportedRequest) Descriptor() ([]byte, []int)deprecated
- func (x *IsCameraDeviceSetupSupportedRequest) GetArg0() string
- func (*IsCameraDeviceSetupSupportedRequest) ProtoMessage()
- func (x *IsCameraDeviceSetupSupportedRequest) ProtoReflect() protoreflect.Message
- func (x *IsCameraDeviceSetupSupportedRequest) Reset()
- func (x *IsCameraDeviceSetupSupportedRequest) String() string
- type IsCameraDeviceSetupSupportedResponse
- func (*IsCameraDeviceSetupSupportedResponse) Descriptor() ([]byte, []int)deprecated
- func (x *IsCameraDeviceSetupSupportedResponse) GetResult() bool
- func (*IsCameraDeviceSetupSupportedResponse) ProtoMessage()
- func (x *IsCameraDeviceSetupSupportedResponse) ProtoReflect() protoreflect.Message
- func (x *IsCameraDeviceSetupSupportedResponse) Reset()
- func (x *IsCameraDeviceSetupSupportedResponse) String() string
- type IsConcurrentSessionConfigurationSupportedRequest
- func (*IsConcurrentSessionConfigurationSupportedRequest) Descriptor() ([]byte, []int)deprecated
- func (x *IsConcurrentSessionConfigurationSupportedRequest) GetArg0() int64
- func (*IsConcurrentSessionConfigurationSupportedRequest) ProtoMessage()
- func (x *IsConcurrentSessionConfigurationSupportedRequest) ProtoReflect() protoreflect.Message
- func (x *IsConcurrentSessionConfigurationSupportedRequest) Reset()
- func (x *IsConcurrentSessionConfigurationSupportedRequest) String() string
- type IsConcurrentSessionConfigurationSupportedResponse
- func (*IsConcurrentSessionConfigurationSupportedResponse) Descriptor() ([]byte, []int)deprecated
- func (x *IsConcurrentSessionConfigurationSupportedResponse) GetResult() bool
- func (*IsConcurrentSessionConfigurationSupportedResponse) ProtoMessage()
- func (x *IsConcurrentSessionConfigurationSupportedResponse) ProtoReflect() protoreflect.Message
- func (x *IsConcurrentSessionConfigurationSupportedResponse) Reset()
- func (x *IsConcurrentSessionConfigurationSupportedResponse) String() string
- type ManagerServiceClient
- type ManagerServiceServer
- type OpenCameraRequest
- func (*OpenCameraRequest) Descriptor() ([]byte, []int)deprecated
- func (x *OpenCameraRequest) GetArg0() string
- func (x *OpenCameraRequest) GetArg1() int64
- func (x *OpenCameraRequest) GetArg2() int64
- func (*OpenCameraRequest) ProtoMessage()
- func (x *OpenCameraRequest) ProtoReflect() protoreflect.Message
- func (x *OpenCameraRequest) Reset()
- func (x *OpenCameraRequest) String() string
- type OpenCameraResponse
- type RegisterAvailabilityCallbackRequest
- func (*RegisterAvailabilityCallbackRequest) Descriptor() ([]byte, []int)deprecated
- func (x *RegisterAvailabilityCallbackRequest) GetArg0() int64
- func (x *RegisterAvailabilityCallbackRequest) GetArg1() int64
- func (*RegisterAvailabilityCallbackRequest) ProtoMessage()
- func (x *RegisterAvailabilityCallbackRequest) ProtoReflect() protoreflect.Message
- func (x *RegisterAvailabilityCallbackRequest) Reset()
- func (x *RegisterAvailabilityCallbackRequest) String() string
- type RegisterAvailabilityCallbackResponse
- func (*RegisterAvailabilityCallbackResponse) Descriptor() ([]byte, []int)deprecated
- func (*RegisterAvailabilityCallbackResponse) ProtoMessage()
- func (x *RegisterAvailabilityCallbackResponse) ProtoReflect() protoreflect.Message
- func (x *RegisterAvailabilityCallbackResponse) Reset()
- func (x *RegisterAvailabilityCallbackResponse) String() string
- type RegisterTorchCallbackRequest
- func (*RegisterTorchCallbackRequest) Descriptor() ([]byte, []int)deprecated
- func (x *RegisterTorchCallbackRequest) GetArg0() int64
- func (x *RegisterTorchCallbackRequest) GetArg1() int64
- func (*RegisterTorchCallbackRequest) ProtoMessage()
- func (x *RegisterTorchCallbackRequest) ProtoReflect() protoreflect.Message
- func (x *RegisterTorchCallbackRequest) Reset()
- func (x *RegisterTorchCallbackRequest) String() string
- type RegisterTorchCallbackResponse
- func (*RegisterTorchCallbackResponse) Descriptor() ([]byte, []int)deprecated
- func (*RegisterTorchCallbackResponse) ProtoMessage()
- func (x *RegisterTorchCallbackResponse) ProtoReflect() protoreflect.Message
- func (x *RegisterTorchCallbackResponse) Reset()
- func (x *RegisterTorchCallbackResponse) String() string
- type SetTorchModeRequest
- func (*SetTorchModeRequest) Descriptor() ([]byte, []int)deprecated
- func (x *SetTorchModeRequest) GetArg0() string
- func (x *SetTorchModeRequest) GetArg1() bool
- func (*SetTorchModeRequest) ProtoMessage()
- func (x *SetTorchModeRequest) ProtoReflect() protoreflect.Message
- func (x *SetTorchModeRequest) Reset()
- func (x *SetTorchModeRequest) String() string
- type SetTorchModeResponse
- type TurnOnTorchWithStrengthLevelRequest
- func (*TurnOnTorchWithStrengthLevelRequest) Descriptor() ([]byte, []int)deprecated
- func (x *TurnOnTorchWithStrengthLevelRequest) GetArg0() string
- func (x *TurnOnTorchWithStrengthLevelRequest) GetArg1() int32
- func (*TurnOnTorchWithStrengthLevelRequest) ProtoMessage()
- func (x *TurnOnTorchWithStrengthLevelRequest) ProtoReflect() protoreflect.Message
- func (x *TurnOnTorchWithStrengthLevelRequest) Reset()
- func (x *TurnOnTorchWithStrengthLevelRequest) String() string
- type TurnOnTorchWithStrengthLevelResponse
- func (*TurnOnTorchWithStrengthLevelResponse) Descriptor() ([]byte, []int)deprecated
- func (*TurnOnTorchWithStrengthLevelResponse) ProtoMessage()
- func (x *TurnOnTorchWithStrengthLevelResponse) ProtoReflect() protoreflect.Message
- func (x *TurnOnTorchWithStrengthLevelResponse) Reset()
- func (x *TurnOnTorchWithStrengthLevelResponse) String() string
- type UnimplementedManagerServiceServer
- func (UnimplementedManagerServiceServer) GetCameraCharacteristics(context.Context, *GetCameraCharacteristicsRequest) (*GetCameraCharacteristicsResponse, error)
- func (UnimplementedManagerServiceServer) GetCameraDeviceSetup(context.Context, *GetCameraDeviceSetupRequest) (*GetCameraDeviceSetupResponse, error)
- func (UnimplementedManagerServiceServer) GetCameraExtensionCharacteristics(context.Context, *GetCameraExtensionCharacteristicsRequest) (*GetCameraExtensionCharacteristicsResponse, error)
- func (UnimplementedManagerServiceServer) GetCameraIdList(context.Context, *GetCameraIdListRequest) (*GetCameraIdListResponse, error)
- func (UnimplementedManagerServiceServer) GetConcurrentCameraIds(context.Context, *GetConcurrentCameraIdsRequest) (*GetConcurrentCameraIdsResponse, error)
- func (UnimplementedManagerServiceServer) GetTorchStrengthLevel(context.Context, *GetTorchStrengthLevelRequest) (*GetTorchStrengthLevelResponse, error)
- func (UnimplementedManagerServiceServer) IsCameraDeviceSetupSupported(context.Context, *IsCameraDeviceSetupSupportedRequest) (*IsCameraDeviceSetupSupportedResponse, error)
- func (UnimplementedManagerServiceServer) IsConcurrentSessionConfigurationSupported(context.Context, *IsConcurrentSessionConfigurationSupportedRequest) (*IsConcurrentSessionConfigurationSupportedResponse, error)
- func (UnimplementedManagerServiceServer) OpenCamera(context.Context, *OpenCameraRequest) (*OpenCameraResponse, error)
- func (UnimplementedManagerServiceServer) RegisterAvailabilityCallback(context.Context, *RegisterAvailabilityCallbackRequest) (*RegisterAvailabilityCallbackResponse, error)
- func (UnimplementedManagerServiceServer) RegisterTorchCallback(context.Context, *RegisterTorchCallbackRequest) (*RegisterTorchCallbackResponse, error)
- func (UnimplementedManagerServiceServer) SetTorchMode(context.Context, *SetTorchModeRequest) (*SetTorchModeResponse, error)
- func (UnimplementedManagerServiceServer) TurnOnTorchWithStrengthLevel(context.Context, *TurnOnTorchWithStrengthLevelRequest) (*TurnOnTorchWithStrengthLevelResponse, error)
- func (UnimplementedManagerServiceServer) UnregisterAvailabilityCallback(context.Context, *UnregisterAvailabilityCallbackRequest) (*UnregisterAvailabilityCallbackResponse, error)
- func (UnimplementedManagerServiceServer) UnregisterTorchCallback(context.Context, *UnregisterTorchCallbackRequest) (*UnregisterTorchCallbackResponse, error)
- type UnregisterAvailabilityCallbackRequest
- func (*UnregisterAvailabilityCallbackRequest) Descriptor() ([]byte, []int)deprecated
- func (x *UnregisterAvailabilityCallbackRequest) GetArg0() int64
- func (*UnregisterAvailabilityCallbackRequest) ProtoMessage()
- func (x *UnregisterAvailabilityCallbackRequest) ProtoReflect() protoreflect.Message
- func (x *UnregisterAvailabilityCallbackRequest) Reset()
- func (x *UnregisterAvailabilityCallbackRequest) String() string
- type UnregisterAvailabilityCallbackResponse
- func (*UnregisterAvailabilityCallbackResponse) Descriptor() ([]byte, []int)deprecated
- func (*UnregisterAvailabilityCallbackResponse) ProtoMessage()
- func (x *UnregisterAvailabilityCallbackResponse) ProtoReflect() protoreflect.Message
- func (x *UnregisterAvailabilityCallbackResponse) Reset()
- func (x *UnregisterAvailabilityCallbackResponse) String() string
- type UnregisterTorchCallbackRequest
- func (*UnregisterTorchCallbackRequest) Descriptor() ([]byte, []int)deprecated
- func (x *UnregisterTorchCallbackRequest) GetArg0() int64
- func (*UnregisterTorchCallbackRequest) ProtoMessage()
- func (x *UnregisterTorchCallbackRequest) ProtoReflect() protoreflect.Message
- func (x *UnregisterTorchCallbackRequest) Reset()
- func (x *UnregisterTorchCallbackRequest) String() string
- type UnregisterTorchCallbackResponse
- func (*UnregisterTorchCallbackResponse) Descriptor() ([]byte, []int)deprecated
- func (*UnregisterTorchCallbackResponse) ProtoMessage()
- func (x *UnregisterTorchCallbackResponse) ProtoReflect() protoreflect.Message
- func (x *UnregisterTorchCallbackResponse) Reset()
- func (x *UnregisterTorchCallbackResponse) String() string
- type UnsafeManagerServiceServer
Constants ¶
const ( ManagerService_GetCameraCharacteristics_FullMethodName = "/camera.ManagerService/GetCameraCharacteristics" ManagerService_GetCameraDeviceSetup_FullMethodName = "/camera.ManagerService/GetCameraDeviceSetup" ManagerService_GetCameraExtensionCharacteristics_FullMethodName = "/camera.ManagerService/GetCameraExtensionCharacteristics" ManagerService_GetCameraIdList_FullMethodName = "/camera.ManagerService/GetCameraIdList" ManagerService_GetConcurrentCameraIds_FullMethodName = "/camera.ManagerService/GetConcurrentCameraIds" ManagerService_GetTorchStrengthLevel_FullMethodName = "/camera.ManagerService/GetTorchStrengthLevel" ManagerService_IsCameraDeviceSetupSupported_FullMethodName = "/camera.ManagerService/IsCameraDeviceSetupSupported" ManagerService_IsConcurrentSessionConfigurationSupported_FullMethodName = "/camera.ManagerService/IsConcurrentSessionConfigurationSupported" ManagerService_OpenCamera_FullMethodName = "/camera.ManagerService/OpenCamera" ManagerService_RegisterAvailabilityCallback_FullMethodName = "/camera.ManagerService/RegisterAvailabilityCallback" ManagerService_RegisterTorchCallback_FullMethodName = "/camera.ManagerService/RegisterTorchCallback" ManagerService_SetTorchMode_FullMethodName = "/camera.ManagerService/SetTorchMode" ManagerService_TurnOnTorchWithStrengthLevel_FullMethodName = "/camera.ManagerService/TurnOnTorchWithStrengthLevel" ManagerService_UnregisterAvailabilityCallback_FullMethodName = "/camera.ManagerService/UnregisterAvailabilityCallback" ManagerService_UnregisterTorchCallback_FullMethodName = "/camera.ManagerService/UnregisterTorchCallback" )
Variables ¶
var File_proto_camera_camera_proto protoreflect.FileDescriptor
var ManagerService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "camera.ManagerService", HandlerType: (*ManagerServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "GetCameraCharacteristics", Handler: _ManagerService_GetCameraCharacteristics_Handler, }, { MethodName: "GetCameraDeviceSetup", Handler: _ManagerService_GetCameraDeviceSetup_Handler, }, { MethodName: "GetCameraExtensionCharacteristics", Handler: _ManagerService_GetCameraExtensionCharacteristics_Handler, }, { MethodName: "GetCameraIdList", Handler: _ManagerService_GetCameraIdList_Handler, }, { MethodName: "GetConcurrentCameraIds", Handler: _ManagerService_GetConcurrentCameraIds_Handler, }, { MethodName: "GetTorchStrengthLevel", Handler: _ManagerService_GetTorchStrengthLevel_Handler, }, { MethodName: "IsCameraDeviceSetupSupported", Handler: _ManagerService_IsCameraDeviceSetupSupported_Handler, }, { MethodName: "IsConcurrentSessionConfigurationSupported", Handler: _ManagerService_IsConcurrentSessionConfigurationSupported_Handler, }, { MethodName: "OpenCamera", Handler: _ManagerService_OpenCamera_Handler, }, { MethodName: "RegisterAvailabilityCallback", Handler: _ManagerService_RegisterAvailabilityCallback_Handler, }, { MethodName: "RegisterTorchCallback", Handler: _ManagerService_RegisterTorchCallback_Handler, }, { MethodName: "SetTorchMode", Handler: _ManagerService_SetTorchMode_Handler, }, { MethodName: "TurnOnTorchWithStrengthLevel", Handler: _ManagerService_TurnOnTorchWithStrengthLevel_Handler, }, { MethodName: "UnregisterAvailabilityCallback", Handler: _ManagerService_UnregisterAvailabilityCallback_Handler, }, { MethodName: "UnregisterTorchCallback", Handler: _ManagerService_UnregisterTorchCallback_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "proto/camera/camera.proto", }
ManagerService_ServiceDesc is the grpc.ServiceDesc for ManagerService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterManagerServiceServer ¶ added in v0.0.4
func RegisterManagerServiceServer(s grpc.ServiceRegistrar, srv ManagerServiceServer)
Types ¶
type GetCameraCharacteristicsRequest ¶
type GetCameraCharacteristicsRequest struct {
Arg0 string `protobuf:"bytes,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
// contains filtered or unexported fields
}
func (*GetCameraCharacteristicsRequest) Descriptor
deprecated
func (*GetCameraCharacteristicsRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetCameraCharacteristicsRequest.ProtoReflect.Descriptor instead.
func (*GetCameraCharacteristicsRequest) GetArg0 ¶
func (x *GetCameraCharacteristicsRequest) GetArg0() string
func (*GetCameraCharacteristicsRequest) ProtoMessage ¶
func (*GetCameraCharacteristicsRequest) ProtoMessage()
func (*GetCameraCharacteristicsRequest) ProtoReflect ¶
func (x *GetCameraCharacteristicsRequest) ProtoReflect() protoreflect.Message
func (*GetCameraCharacteristicsRequest) Reset ¶
func (x *GetCameraCharacteristicsRequest) Reset()
func (*GetCameraCharacteristicsRequest) String ¶
func (x *GetCameraCharacteristicsRequest) String() string
type GetCameraCharacteristicsResponse ¶
type GetCameraCharacteristicsResponse struct {
Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*GetCameraCharacteristicsResponse) Descriptor
deprecated
func (*GetCameraCharacteristicsResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetCameraCharacteristicsResponse.ProtoReflect.Descriptor instead.
func (*GetCameraCharacteristicsResponse) GetResult ¶
func (x *GetCameraCharacteristicsResponse) GetResult() int64
func (*GetCameraCharacteristicsResponse) ProtoMessage ¶
func (*GetCameraCharacteristicsResponse) ProtoMessage()
func (*GetCameraCharacteristicsResponse) ProtoReflect ¶
func (x *GetCameraCharacteristicsResponse) ProtoReflect() protoreflect.Message
func (*GetCameraCharacteristicsResponse) Reset ¶
func (x *GetCameraCharacteristicsResponse) Reset()
func (*GetCameraCharacteristicsResponse) String ¶
func (x *GetCameraCharacteristicsResponse) String() string
type GetCameraDeviceSetupRequest ¶
type GetCameraDeviceSetupRequest struct {
Arg0 string `protobuf:"bytes,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
// contains filtered or unexported fields
}
func (*GetCameraDeviceSetupRequest) Descriptor
deprecated
func (*GetCameraDeviceSetupRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetCameraDeviceSetupRequest.ProtoReflect.Descriptor instead.
func (*GetCameraDeviceSetupRequest) GetArg0 ¶
func (x *GetCameraDeviceSetupRequest) GetArg0() string
func (*GetCameraDeviceSetupRequest) ProtoMessage ¶
func (*GetCameraDeviceSetupRequest) ProtoMessage()
func (*GetCameraDeviceSetupRequest) ProtoReflect ¶
func (x *GetCameraDeviceSetupRequest) ProtoReflect() protoreflect.Message
func (*GetCameraDeviceSetupRequest) Reset ¶
func (x *GetCameraDeviceSetupRequest) Reset()
func (*GetCameraDeviceSetupRequest) String ¶
func (x *GetCameraDeviceSetupRequest) String() string
type GetCameraDeviceSetupResponse ¶
type GetCameraDeviceSetupResponse struct {
Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*GetCameraDeviceSetupResponse) Descriptor
deprecated
func (*GetCameraDeviceSetupResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetCameraDeviceSetupResponse.ProtoReflect.Descriptor instead.
func (*GetCameraDeviceSetupResponse) GetResult ¶
func (x *GetCameraDeviceSetupResponse) GetResult() int64
func (*GetCameraDeviceSetupResponse) ProtoMessage ¶
func (*GetCameraDeviceSetupResponse) ProtoMessage()
func (*GetCameraDeviceSetupResponse) ProtoReflect ¶
func (x *GetCameraDeviceSetupResponse) ProtoReflect() protoreflect.Message
func (*GetCameraDeviceSetupResponse) Reset ¶
func (x *GetCameraDeviceSetupResponse) Reset()
func (*GetCameraDeviceSetupResponse) String ¶
func (x *GetCameraDeviceSetupResponse) String() string
type GetCameraExtensionCharacteristicsRequest ¶
type GetCameraExtensionCharacteristicsRequest struct {
Arg0 string `protobuf:"bytes,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
// contains filtered or unexported fields
}
func (*GetCameraExtensionCharacteristicsRequest) Descriptor
deprecated
func (*GetCameraExtensionCharacteristicsRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetCameraExtensionCharacteristicsRequest.ProtoReflect.Descriptor instead.
func (*GetCameraExtensionCharacteristicsRequest) GetArg0 ¶
func (x *GetCameraExtensionCharacteristicsRequest) GetArg0() string
func (*GetCameraExtensionCharacteristicsRequest) ProtoMessage ¶
func (*GetCameraExtensionCharacteristicsRequest) ProtoMessage()
func (*GetCameraExtensionCharacteristicsRequest) ProtoReflect ¶
func (x *GetCameraExtensionCharacteristicsRequest) ProtoReflect() protoreflect.Message
func (*GetCameraExtensionCharacteristicsRequest) Reset ¶
func (x *GetCameraExtensionCharacteristicsRequest) Reset()
func (*GetCameraExtensionCharacteristicsRequest) String ¶
func (x *GetCameraExtensionCharacteristicsRequest) String() string
type GetCameraExtensionCharacteristicsResponse ¶
type GetCameraExtensionCharacteristicsResponse struct {
Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*GetCameraExtensionCharacteristicsResponse) Descriptor
deprecated
func (*GetCameraExtensionCharacteristicsResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetCameraExtensionCharacteristicsResponse.ProtoReflect.Descriptor instead.
func (*GetCameraExtensionCharacteristicsResponse) GetResult ¶
func (x *GetCameraExtensionCharacteristicsResponse) GetResult() int64
func (*GetCameraExtensionCharacteristicsResponse) ProtoMessage ¶
func (*GetCameraExtensionCharacteristicsResponse) ProtoMessage()
func (*GetCameraExtensionCharacteristicsResponse) ProtoReflect ¶
func (x *GetCameraExtensionCharacteristicsResponse) ProtoReflect() protoreflect.Message
func (*GetCameraExtensionCharacteristicsResponse) Reset ¶
func (x *GetCameraExtensionCharacteristicsResponse) Reset()
func (*GetCameraExtensionCharacteristicsResponse) String ¶
func (x *GetCameraExtensionCharacteristicsResponse) String() string
type GetCameraIdListRequest ¶
type GetCameraIdListRequest struct {
// contains filtered or unexported fields
}
func (*GetCameraIdListRequest) Descriptor
deprecated
func (*GetCameraIdListRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetCameraIdListRequest.ProtoReflect.Descriptor instead.
func (*GetCameraIdListRequest) ProtoMessage ¶
func (*GetCameraIdListRequest) ProtoMessage()
func (*GetCameraIdListRequest) ProtoReflect ¶
func (x *GetCameraIdListRequest) ProtoReflect() protoreflect.Message
func (*GetCameraIdListRequest) Reset ¶
func (x *GetCameraIdListRequest) Reset()
func (*GetCameraIdListRequest) String ¶
func (x *GetCameraIdListRequest) String() string
type GetCameraIdListResponse ¶
type GetCameraIdListResponse struct {
Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*GetCameraIdListResponse) Descriptor
deprecated
func (*GetCameraIdListResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetCameraIdListResponse.ProtoReflect.Descriptor instead.
func (*GetCameraIdListResponse) GetResult ¶
func (x *GetCameraIdListResponse) GetResult() int64
func (*GetCameraIdListResponse) ProtoMessage ¶
func (*GetCameraIdListResponse) ProtoMessage()
func (*GetCameraIdListResponse) ProtoReflect ¶
func (x *GetCameraIdListResponse) ProtoReflect() protoreflect.Message
func (*GetCameraIdListResponse) Reset ¶
func (x *GetCameraIdListResponse) Reset()
func (*GetCameraIdListResponse) String ¶
func (x *GetCameraIdListResponse) String() string
type GetConcurrentCameraIdsRequest ¶
type GetConcurrentCameraIdsRequest struct {
// contains filtered or unexported fields
}
func (*GetConcurrentCameraIdsRequest) Descriptor
deprecated
func (*GetConcurrentCameraIdsRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetConcurrentCameraIdsRequest.ProtoReflect.Descriptor instead.
func (*GetConcurrentCameraIdsRequest) ProtoMessage ¶
func (*GetConcurrentCameraIdsRequest) ProtoMessage()
func (*GetConcurrentCameraIdsRequest) ProtoReflect ¶
func (x *GetConcurrentCameraIdsRequest) ProtoReflect() protoreflect.Message
func (*GetConcurrentCameraIdsRequest) Reset ¶
func (x *GetConcurrentCameraIdsRequest) Reset()
func (*GetConcurrentCameraIdsRequest) String ¶
func (x *GetConcurrentCameraIdsRequest) String() string
type GetConcurrentCameraIdsResponse ¶
type GetConcurrentCameraIdsResponse struct {
Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*GetConcurrentCameraIdsResponse) Descriptor
deprecated
func (*GetConcurrentCameraIdsResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetConcurrentCameraIdsResponse.ProtoReflect.Descriptor instead.
func (*GetConcurrentCameraIdsResponse) GetResult ¶
func (x *GetConcurrentCameraIdsResponse) GetResult() int64
func (*GetConcurrentCameraIdsResponse) ProtoMessage ¶
func (*GetConcurrentCameraIdsResponse) ProtoMessage()
func (*GetConcurrentCameraIdsResponse) ProtoReflect ¶
func (x *GetConcurrentCameraIdsResponse) ProtoReflect() protoreflect.Message
func (*GetConcurrentCameraIdsResponse) Reset ¶
func (x *GetConcurrentCameraIdsResponse) Reset()
func (*GetConcurrentCameraIdsResponse) String ¶
func (x *GetConcurrentCameraIdsResponse) String() string
type GetTorchStrengthLevelRequest ¶
type GetTorchStrengthLevelRequest struct {
Arg0 string `protobuf:"bytes,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
// contains filtered or unexported fields
}
func (*GetTorchStrengthLevelRequest) Descriptor
deprecated
func (*GetTorchStrengthLevelRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetTorchStrengthLevelRequest.ProtoReflect.Descriptor instead.
func (*GetTorchStrengthLevelRequest) GetArg0 ¶
func (x *GetTorchStrengthLevelRequest) GetArg0() string
func (*GetTorchStrengthLevelRequest) ProtoMessage ¶
func (*GetTorchStrengthLevelRequest) ProtoMessage()
func (*GetTorchStrengthLevelRequest) ProtoReflect ¶
func (x *GetTorchStrengthLevelRequest) ProtoReflect() protoreflect.Message
func (*GetTorchStrengthLevelRequest) Reset ¶
func (x *GetTorchStrengthLevelRequest) Reset()
func (*GetTorchStrengthLevelRequest) String ¶
func (x *GetTorchStrengthLevelRequest) String() string
type GetTorchStrengthLevelResponse ¶
type GetTorchStrengthLevelResponse struct {
Result int32 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*GetTorchStrengthLevelResponse) Descriptor
deprecated
func (*GetTorchStrengthLevelResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetTorchStrengthLevelResponse.ProtoReflect.Descriptor instead.
func (*GetTorchStrengthLevelResponse) GetResult ¶
func (x *GetTorchStrengthLevelResponse) GetResult() int32
func (*GetTorchStrengthLevelResponse) ProtoMessage ¶
func (*GetTorchStrengthLevelResponse) ProtoMessage()
func (*GetTorchStrengthLevelResponse) ProtoReflect ¶
func (x *GetTorchStrengthLevelResponse) ProtoReflect() protoreflect.Message
func (*GetTorchStrengthLevelResponse) Reset ¶
func (x *GetTorchStrengthLevelResponse) Reset()
func (*GetTorchStrengthLevelResponse) String ¶
func (x *GetTorchStrengthLevelResponse) String() string
type IsCameraDeviceSetupSupportedRequest ¶
type IsCameraDeviceSetupSupportedRequest struct {
Arg0 string `protobuf:"bytes,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
// contains filtered or unexported fields
}
func (*IsCameraDeviceSetupSupportedRequest) Descriptor
deprecated
func (*IsCameraDeviceSetupSupportedRequest) Descriptor() ([]byte, []int)
Deprecated: Use IsCameraDeviceSetupSupportedRequest.ProtoReflect.Descriptor instead.
func (*IsCameraDeviceSetupSupportedRequest) GetArg0 ¶
func (x *IsCameraDeviceSetupSupportedRequest) GetArg0() string
func (*IsCameraDeviceSetupSupportedRequest) ProtoMessage ¶
func (*IsCameraDeviceSetupSupportedRequest) ProtoMessage()
func (*IsCameraDeviceSetupSupportedRequest) ProtoReflect ¶
func (x *IsCameraDeviceSetupSupportedRequest) ProtoReflect() protoreflect.Message
func (*IsCameraDeviceSetupSupportedRequest) Reset ¶
func (x *IsCameraDeviceSetupSupportedRequest) Reset()
func (*IsCameraDeviceSetupSupportedRequest) String ¶
func (x *IsCameraDeviceSetupSupportedRequest) String() string
type IsCameraDeviceSetupSupportedResponse ¶
type IsCameraDeviceSetupSupportedResponse struct {
Result bool `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*IsCameraDeviceSetupSupportedResponse) Descriptor
deprecated
func (*IsCameraDeviceSetupSupportedResponse) Descriptor() ([]byte, []int)
Deprecated: Use IsCameraDeviceSetupSupportedResponse.ProtoReflect.Descriptor instead.
func (*IsCameraDeviceSetupSupportedResponse) GetResult ¶
func (x *IsCameraDeviceSetupSupportedResponse) GetResult() bool
func (*IsCameraDeviceSetupSupportedResponse) ProtoMessage ¶
func (*IsCameraDeviceSetupSupportedResponse) ProtoMessage()
func (*IsCameraDeviceSetupSupportedResponse) ProtoReflect ¶
func (x *IsCameraDeviceSetupSupportedResponse) ProtoReflect() protoreflect.Message
func (*IsCameraDeviceSetupSupportedResponse) Reset ¶
func (x *IsCameraDeviceSetupSupportedResponse) Reset()
func (*IsCameraDeviceSetupSupportedResponse) String ¶
func (x *IsCameraDeviceSetupSupportedResponse) String() string
type IsConcurrentSessionConfigurationSupportedRequest ¶
type IsConcurrentSessionConfigurationSupportedRequest struct {
Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
// contains filtered or unexported fields
}
func (*IsConcurrentSessionConfigurationSupportedRequest) Descriptor
deprecated
func (*IsConcurrentSessionConfigurationSupportedRequest) Descriptor() ([]byte, []int)
Deprecated: Use IsConcurrentSessionConfigurationSupportedRequest.ProtoReflect.Descriptor instead.
func (*IsConcurrentSessionConfigurationSupportedRequest) GetArg0 ¶
func (x *IsConcurrentSessionConfigurationSupportedRequest) GetArg0() int64
func (*IsConcurrentSessionConfigurationSupportedRequest) ProtoMessage ¶
func (*IsConcurrentSessionConfigurationSupportedRequest) ProtoMessage()
func (*IsConcurrentSessionConfigurationSupportedRequest) ProtoReflect ¶
func (x *IsConcurrentSessionConfigurationSupportedRequest) ProtoReflect() protoreflect.Message
func (*IsConcurrentSessionConfigurationSupportedRequest) Reset ¶
func (x *IsConcurrentSessionConfigurationSupportedRequest) Reset()
func (*IsConcurrentSessionConfigurationSupportedRequest) String ¶
func (x *IsConcurrentSessionConfigurationSupportedRequest) String() string
type IsConcurrentSessionConfigurationSupportedResponse ¶
type IsConcurrentSessionConfigurationSupportedResponse struct {
Result bool `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*IsConcurrentSessionConfigurationSupportedResponse) Descriptor
deprecated
func (*IsConcurrentSessionConfigurationSupportedResponse) Descriptor() ([]byte, []int)
Deprecated: Use IsConcurrentSessionConfigurationSupportedResponse.ProtoReflect.Descriptor instead.
func (*IsConcurrentSessionConfigurationSupportedResponse) GetResult ¶
func (x *IsConcurrentSessionConfigurationSupportedResponse) GetResult() bool
func (*IsConcurrentSessionConfigurationSupportedResponse) ProtoMessage ¶
func (*IsConcurrentSessionConfigurationSupportedResponse) ProtoMessage()
func (*IsConcurrentSessionConfigurationSupportedResponse) ProtoReflect ¶
func (x *IsConcurrentSessionConfigurationSupportedResponse) ProtoReflect() protoreflect.Message
func (*IsConcurrentSessionConfigurationSupportedResponse) Reset ¶
func (x *IsConcurrentSessionConfigurationSupportedResponse) Reset()
func (*IsConcurrentSessionConfigurationSupportedResponse) String ¶
func (x *IsConcurrentSessionConfigurationSupportedResponse) String() string
type ManagerServiceClient ¶ added in v0.0.4
type ManagerServiceClient interface {
GetCameraCharacteristics(ctx context.Context, in *GetCameraCharacteristicsRequest, opts ...grpc.CallOption) (*GetCameraCharacteristicsResponse, error)
GetCameraDeviceSetup(ctx context.Context, in *GetCameraDeviceSetupRequest, opts ...grpc.CallOption) (*GetCameraDeviceSetupResponse, error)
GetCameraExtensionCharacteristics(ctx context.Context, in *GetCameraExtensionCharacteristicsRequest, opts ...grpc.CallOption) (*GetCameraExtensionCharacteristicsResponse, error)
GetCameraIdList(ctx context.Context, in *GetCameraIdListRequest, opts ...grpc.CallOption) (*GetCameraIdListResponse, error)
GetConcurrentCameraIds(ctx context.Context, in *GetConcurrentCameraIdsRequest, opts ...grpc.CallOption) (*GetConcurrentCameraIdsResponse, error)
GetTorchStrengthLevel(ctx context.Context, in *GetTorchStrengthLevelRequest, opts ...grpc.CallOption) (*GetTorchStrengthLevelResponse, error)
IsCameraDeviceSetupSupported(ctx context.Context, in *IsCameraDeviceSetupSupportedRequest, opts ...grpc.CallOption) (*IsCameraDeviceSetupSupportedResponse, error)
IsConcurrentSessionConfigurationSupported(ctx context.Context, in *IsConcurrentSessionConfigurationSupportedRequest, opts ...grpc.CallOption) (*IsConcurrentSessionConfigurationSupportedResponse, error)
OpenCamera(ctx context.Context, in *OpenCameraRequest, opts ...grpc.CallOption) (*OpenCameraResponse, error)
RegisterAvailabilityCallback(ctx context.Context, in *RegisterAvailabilityCallbackRequest, opts ...grpc.CallOption) (*RegisterAvailabilityCallbackResponse, error)
RegisterTorchCallback(ctx context.Context, in *RegisterTorchCallbackRequest, opts ...grpc.CallOption) (*RegisterTorchCallbackResponse, error)
SetTorchMode(ctx context.Context, in *SetTorchModeRequest, opts ...grpc.CallOption) (*SetTorchModeResponse, error)
TurnOnTorchWithStrengthLevel(ctx context.Context, in *TurnOnTorchWithStrengthLevelRequest, opts ...grpc.CallOption) (*TurnOnTorchWithStrengthLevelResponse, error)
UnregisterAvailabilityCallback(ctx context.Context, in *UnregisterAvailabilityCallbackRequest, opts ...grpc.CallOption) (*UnregisterAvailabilityCallbackResponse, error)
UnregisterTorchCallback(ctx context.Context, in *UnregisterTorchCallbackRequest, opts ...grpc.CallOption) (*UnregisterTorchCallbackResponse, error)
}
ManagerServiceClient is the client API for ManagerService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewManagerServiceClient ¶ added in v0.0.4
func NewManagerServiceClient(cc grpc.ClientConnInterface) ManagerServiceClient
type ManagerServiceServer ¶ added in v0.0.4
type ManagerServiceServer interface {
GetCameraCharacteristics(context.Context, *GetCameraCharacteristicsRequest) (*GetCameraCharacteristicsResponse, error)
GetCameraDeviceSetup(context.Context, *GetCameraDeviceSetupRequest) (*GetCameraDeviceSetupResponse, error)
GetCameraExtensionCharacteristics(context.Context, *GetCameraExtensionCharacteristicsRequest) (*GetCameraExtensionCharacteristicsResponse, error)
GetCameraIdList(context.Context, *GetCameraIdListRequest) (*GetCameraIdListResponse, error)
GetConcurrentCameraIds(context.Context, *GetConcurrentCameraIdsRequest) (*GetConcurrentCameraIdsResponse, error)
GetTorchStrengthLevel(context.Context, *GetTorchStrengthLevelRequest) (*GetTorchStrengthLevelResponse, error)
IsCameraDeviceSetupSupported(context.Context, *IsCameraDeviceSetupSupportedRequest) (*IsCameraDeviceSetupSupportedResponse, error)
IsConcurrentSessionConfigurationSupported(context.Context, *IsConcurrentSessionConfigurationSupportedRequest) (*IsConcurrentSessionConfigurationSupportedResponse, error)
OpenCamera(context.Context, *OpenCameraRequest) (*OpenCameraResponse, error)
RegisterAvailabilityCallback(context.Context, *RegisterAvailabilityCallbackRequest) (*RegisterAvailabilityCallbackResponse, error)
RegisterTorchCallback(context.Context, *RegisterTorchCallbackRequest) (*RegisterTorchCallbackResponse, error)
SetTorchMode(context.Context, *SetTorchModeRequest) (*SetTorchModeResponse, error)
TurnOnTorchWithStrengthLevel(context.Context, *TurnOnTorchWithStrengthLevelRequest) (*TurnOnTorchWithStrengthLevelResponse, error)
UnregisterAvailabilityCallback(context.Context, *UnregisterAvailabilityCallbackRequest) (*UnregisterAvailabilityCallbackResponse, error)
UnregisterTorchCallback(context.Context, *UnregisterTorchCallbackRequest) (*UnregisterTorchCallbackResponse, error)
// contains filtered or unexported methods
}
ManagerServiceServer is the server API for ManagerService service. All implementations must embed UnimplementedManagerServiceServer for forward compatibility.
type OpenCameraRequest ¶
type OpenCameraRequest struct {
Arg0 string `protobuf:"bytes,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
Arg1 int64 `protobuf:"varint,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
Arg2 int64 `protobuf:"varint,3,opt,name=arg2,proto3" json:"arg2,omitempty"`
// contains filtered or unexported fields
}
func (*OpenCameraRequest) Descriptor
deprecated
func (*OpenCameraRequest) Descriptor() ([]byte, []int)
Deprecated: Use OpenCameraRequest.ProtoReflect.Descriptor instead.
func (*OpenCameraRequest) GetArg0 ¶
func (x *OpenCameraRequest) GetArg0() string
func (*OpenCameraRequest) GetArg1 ¶
func (x *OpenCameraRequest) GetArg1() int64
func (*OpenCameraRequest) GetArg2 ¶
func (x *OpenCameraRequest) GetArg2() int64
func (*OpenCameraRequest) ProtoMessage ¶
func (*OpenCameraRequest) ProtoMessage()
func (*OpenCameraRequest) ProtoReflect ¶
func (x *OpenCameraRequest) ProtoReflect() protoreflect.Message
func (*OpenCameraRequest) Reset ¶
func (x *OpenCameraRequest) Reset()
func (*OpenCameraRequest) String ¶
func (x *OpenCameraRequest) String() string
type OpenCameraResponse ¶
type OpenCameraResponse struct {
// contains filtered or unexported fields
}
func (*OpenCameraResponse) Descriptor
deprecated
func (*OpenCameraResponse) Descriptor() ([]byte, []int)
Deprecated: Use OpenCameraResponse.ProtoReflect.Descriptor instead.
func (*OpenCameraResponse) ProtoMessage ¶
func (*OpenCameraResponse) ProtoMessage()
func (*OpenCameraResponse) ProtoReflect ¶
func (x *OpenCameraResponse) ProtoReflect() protoreflect.Message
func (*OpenCameraResponse) Reset ¶
func (x *OpenCameraResponse) Reset()
func (*OpenCameraResponse) String ¶
func (x *OpenCameraResponse) String() string
type RegisterAvailabilityCallbackRequest ¶
type RegisterAvailabilityCallbackRequest struct {
Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
Arg1 int64 `protobuf:"varint,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
// contains filtered or unexported fields
}
func (*RegisterAvailabilityCallbackRequest) Descriptor
deprecated
func (*RegisterAvailabilityCallbackRequest) Descriptor() ([]byte, []int)
Deprecated: Use RegisterAvailabilityCallbackRequest.ProtoReflect.Descriptor instead.
func (*RegisterAvailabilityCallbackRequest) GetArg0 ¶
func (x *RegisterAvailabilityCallbackRequest) GetArg0() int64
func (*RegisterAvailabilityCallbackRequest) GetArg1 ¶
func (x *RegisterAvailabilityCallbackRequest) GetArg1() int64
func (*RegisterAvailabilityCallbackRequest) ProtoMessage ¶
func (*RegisterAvailabilityCallbackRequest) ProtoMessage()
func (*RegisterAvailabilityCallbackRequest) ProtoReflect ¶
func (x *RegisterAvailabilityCallbackRequest) ProtoReflect() protoreflect.Message
func (*RegisterAvailabilityCallbackRequest) Reset ¶
func (x *RegisterAvailabilityCallbackRequest) Reset()
func (*RegisterAvailabilityCallbackRequest) String ¶
func (x *RegisterAvailabilityCallbackRequest) String() string
type RegisterAvailabilityCallbackResponse ¶
type RegisterAvailabilityCallbackResponse struct {
// contains filtered or unexported fields
}
func (*RegisterAvailabilityCallbackResponse) Descriptor
deprecated
func (*RegisterAvailabilityCallbackResponse) Descriptor() ([]byte, []int)
Deprecated: Use RegisterAvailabilityCallbackResponse.ProtoReflect.Descriptor instead.
func (*RegisterAvailabilityCallbackResponse) ProtoMessage ¶
func (*RegisterAvailabilityCallbackResponse) ProtoMessage()
func (*RegisterAvailabilityCallbackResponse) ProtoReflect ¶
func (x *RegisterAvailabilityCallbackResponse) ProtoReflect() protoreflect.Message
func (*RegisterAvailabilityCallbackResponse) Reset ¶
func (x *RegisterAvailabilityCallbackResponse) Reset()
func (*RegisterAvailabilityCallbackResponse) String ¶
func (x *RegisterAvailabilityCallbackResponse) String() string
type RegisterTorchCallbackRequest ¶
type RegisterTorchCallbackRequest struct {
Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
Arg1 int64 `protobuf:"varint,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
// contains filtered or unexported fields
}
func (*RegisterTorchCallbackRequest) Descriptor
deprecated
func (*RegisterTorchCallbackRequest) Descriptor() ([]byte, []int)
Deprecated: Use RegisterTorchCallbackRequest.ProtoReflect.Descriptor instead.
func (*RegisterTorchCallbackRequest) GetArg0 ¶
func (x *RegisterTorchCallbackRequest) GetArg0() int64
func (*RegisterTorchCallbackRequest) GetArg1 ¶
func (x *RegisterTorchCallbackRequest) GetArg1() int64
func (*RegisterTorchCallbackRequest) ProtoMessage ¶
func (*RegisterTorchCallbackRequest) ProtoMessage()
func (*RegisterTorchCallbackRequest) ProtoReflect ¶
func (x *RegisterTorchCallbackRequest) ProtoReflect() protoreflect.Message
func (*RegisterTorchCallbackRequest) Reset ¶
func (x *RegisterTorchCallbackRequest) Reset()
func (*RegisterTorchCallbackRequest) String ¶
func (x *RegisterTorchCallbackRequest) String() string
type RegisterTorchCallbackResponse ¶
type RegisterTorchCallbackResponse struct {
// contains filtered or unexported fields
}
func (*RegisterTorchCallbackResponse) Descriptor
deprecated
func (*RegisterTorchCallbackResponse) Descriptor() ([]byte, []int)
Deprecated: Use RegisterTorchCallbackResponse.ProtoReflect.Descriptor instead.
func (*RegisterTorchCallbackResponse) ProtoMessage ¶
func (*RegisterTorchCallbackResponse) ProtoMessage()
func (*RegisterTorchCallbackResponse) ProtoReflect ¶
func (x *RegisterTorchCallbackResponse) ProtoReflect() protoreflect.Message
func (*RegisterTorchCallbackResponse) Reset ¶
func (x *RegisterTorchCallbackResponse) Reset()
func (*RegisterTorchCallbackResponse) String ¶
func (x *RegisterTorchCallbackResponse) String() string
type SetTorchModeRequest ¶
type SetTorchModeRequest struct {
Arg0 string `protobuf:"bytes,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
Arg1 bool `protobuf:"varint,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
// contains filtered or unexported fields
}
func (*SetTorchModeRequest) Descriptor
deprecated
func (*SetTorchModeRequest) Descriptor() ([]byte, []int)
Deprecated: Use SetTorchModeRequest.ProtoReflect.Descriptor instead.
func (*SetTorchModeRequest) GetArg0 ¶
func (x *SetTorchModeRequest) GetArg0() string
func (*SetTorchModeRequest) GetArg1 ¶
func (x *SetTorchModeRequest) GetArg1() bool
func (*SetTorchModeRequest) ProtoMessage ¶
func (*SetTorchModeRequest) ProtoMessage()
func (*SetTorchModeRequest) ProtoReflect ¶
func (x *SetTorchModeRequest) ProtoReflect() protoreflect.Message
func (*SetTorchModeRequest) Reset ¶
func (x *SetTorchModeRequest) Reset()
func (*SetTorchModeRequest) String ¶
func (x *SetTorchModeRequest) String() string
type SetTorchModeResponse ¶
type SetTorchModeResponse struct {
// contains filtered or unexported fields
}
func (*SetTorchModeResponse) Descriptor
deprecated
func (*SetTorchModeResponse) Descriptor() ([]byte, []int)
Deprecated: Use SetTorchModeResponse.ProtoReflect.Descriptor instead.
func (*SetTorchModeResponse) ProtoMessage ¶
func (*SetTorchModeResponse) ProtoMessage()
func (*SetTorchModeResponse) ProtoReflect ¶
func (x *SetTorchModeResponse) ProtoReflect() protoreflect.Message
func (*SetTorchModeResponse) Reset ¶
func (x *SetTorchModeResponse) Reset()
func (*SetTorchModeResponse) String ¶
func (x *SetTorchModeResponse) String() string
type TurnOnTorchWithStrengthLevelRequest ¶
type TurnOnTorchWithStrengthLevelRequest struct {
Arg0 string `protobuf:"bytes,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
Arg1 int32 `protobuf:"varint,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
// contains filtered or unexported fields
}
func (*TurnOnTorchWithStrengthLevelRequest) Descriptor
deprecated
func (*TurnOnTorchWithStrengthLevelRequest) Descriptor() ([]byte, []int)
Deprecated: Use TurnOnTorchWithStrengthLevelRequest.ProtoReflect.Descriptor instead.
func (*TurnOnTorchWithStrengthLevelRequest) GetArg0 ¶
func (x *TurnOnTorchWithStrengthLevelRequest) GetArg0() string
func (*TurnOnTorchWithStrengthLevelRequest) GetArg1 ¶
func (x *TurnOnTorchWithStrengthLevelRequest) GetArg1() int32
func (*TurnOnTorchWithStrengthLevelRequest) ProtoMessage ¶
func (*TurnOnTorchWithStrengthLevelRequest) ProtoMessage()
func (*TurnOnTorchWithStrengthLevelRequest) ProtoReflect ¶
func (x *TurnOnTorchWithStrengthLevelRequest) ProtoReflect() protoreflect.Message
func (*TurnOnTorchWithStrengthLevelRequest) Reset ¶
func (x *TurnOnTorchWithStrengthLevelRequest) Reset()
func (*TurnOnTorchWithStrengthLevelRequest) String ¶
func (x *TurnOnTorchWithStrengthLevelRequest) String() string
type TurnOnTorchWithStrengthLevelResponse ¶
type TurnOnTorchWithStrengthLevelResponse struct {
// contains filtered or unexported fields
}
func (*TurnOnTorchWithStrengthLevelResponse) Descriptor
deprecated
func (*TurnOnTorchWithStrengthLevelResponse) Descriptor() ([]byte, []int)
Deprecated: Use TurnOnTorchWithStrengthLevelResponse.ProtoReflect.Descriptor instead.
func (*TurnOnTorchWithStrengthLevelResponse) ProtoMessage ¶
func (*TurnOnTorchWithStrengthLevelResponse) ProtoMessage()
func (*TurnOnTorchWithStrengthLevelResponse) ProtoReflect ¶
func (x *TurnOnTorchWithStrengthLevelResponse) ProtoReflect() protoreflect.Message
func (*TurnOnTorchWithStrengthLevelResponse) Reset ¶
func (x *TurnOnTorchWithStrengthLevelResponse) Reset()
func (*TurnOnTorchWithStrengthLevelResponse) String ¶
func (x *TurnOnTorchWithStrengthLevelResponse) String() string
type UnimplementedManagerServiceServer ¶ added in v0.0.4
type UnimplementedManagerServiceServer struct{}
UnimplementedManagerServiceServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedManagerServiceServer) GetCameraCharacteristics ¶ added in v0.0.4
func (UnimplementedManagerServiceServer) GetCameraCharacteristics(context.Context, *GetCameraCharacteristicsRequest) (*GetCameraCharacteristicsResponse, error)
func (UnimplementedManagerServiceServer) GetCameraDeviceSetup ¶ added in v0.0.4
func (UnimplementedManagerServiceServer) GetCameraDeviceSetup(context.Context, *GetCameraDeviceSetupRequest) (*GetCameraDeviceSetupResponse, error)
func (UnimplementedManagerServiceServer) GetCameraExtensionCharacteristics ¶ added in v0.0.4
func (UnimplementedManagerServiceServer) GetCameraExtensionCharacteristics(context.Context, *GetCameraExtensionCharacteristicsRequest) (*GetCameraExtensionCharacteristicsResponse, error)
func (UnimplementedManagerServiceServer) GetCameraIdList ¶ added in v0.0.4
func (UnimplementedManagerServiceServer) GetCameraIdList(context.Context, *GetCameraIdListRequest) (*GetCameraIdListResponse, error)
func (UnimplementedManagerServiceServer) GetConcurrentCameraIds ¶ added in v0.0.4
func (UnimplementedManagerServiceServer) GetConcurrentCameraIds(context.Context, *GetConcurrentCameraIdsRequest) (*GetConcurrentCameraIdsResponse, error)
func (UnimplementedManagerServiceServer) GetTorchStrengthLevel ¶ added in v0.0.4
func (UnimplementedManagerServiceServer) GetTorchStrengthLevel(context.Context, *GetTorchStrengthLevelRequest) (*GetTorchStrengthLevelResponse, error)
func (UnimplementedManagerServiceServer) IsCameraDeviceSetupSupported ¶ added in v0.0.4
func (UnimplementedManagerServiceServer) IsCameraDeviceSetupSupported(context.Context, *IsCameraDeviceSetupSupportedRequest) (*IsCameraDeviceSetupSupportedResponse, error)
func (UnimplementedManagerServiceServer) IsConcurrentSessionConfigurationSupported ¶ added in v0.0.4
func (UnimplementedManagerServiceServer) IsConcurrentSessionConfigurationSupported(context.Context, *IsConcurrentSessionConfigurationSupportedRequest) (*IsConcurrentSessionConfigurationSupportedResponse, error)
func (UnimplementedManagerServiceServer) OpenCamera ¶ added in v0.0.4
func (UnimplementedManagerServiceServer) OpenCamera(context.Context, *OpenCameraRequest) (*OpenCameraResponse, error)
func (UnimplementedManagerServiceServer) RegisterAvailabilityCallback ¶ added in v0.0.4
func (UnimplementedManagerServiceServer) RegisterAvailabilityCallback(context.Context, *RegisterAvailabilityCallbackRequest) (*RegisterAvailabilityCallbackResponse, error)
func (UnimplementedManagerServiceServer) RegisterTorchCallback ¶ added in v0.0.4
func (UnimplementedManagerServiceServer) RegisterTorchCallback(context.Context, *RegisterTorchCallbackRequest) (*RegisterTorchCallbackResponse, error)
func (UnimplementedManagerServiceServer) SetTorchMode ¶ added in v0.0.4
func (UnimplementedManagerServiceServer) SetTorchMode(context.Context, *SetTorchModeRequest) (*SetTorchModeResponse, error)
func (UnimplementedManagerServiceServer) TurnOnTorchWithStrengthLevel ¶ added in v0.0.4
func (UnimplementedManagerServiceServer) TurnOnTorchWithStrengthLevel(context.Context, *TurnOnTorchWithStrengthLevelRequest) (*TurnOnTorchWithStrengthLevelResponse, error)
func (UnimplementedManagerServiceServer) UnregisterAvailabilityCallback ¶ added in v0.0.4
func (UnimplementedManagerServiceServer) UnregisterAvailabilityCallback(context.Context, *UnregisterAvailabilityCallbackRequest) (*UnregisterAvailabilityCallbackResponse, error)
func (UnimplementedManagerServiceServer) UnregisterTorchCallback ¶ added in v0.0.4
func (UnimplementedManagerServiceServer) UnregisterTorchCallback(context.Context, *UnregisterTorchCallbackRequest) (*UnregisterTorchCallbackResponse, error)
type UnregisterAvailabilityCallbackRequest ¶
type UnregisterAvailabilityCallbackRequest struct {
Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
// contains filtered or unexported fields
}
func (*UnregisterAvailabilityCallbackRequest) Descriptor
deprecated
func (*UnregisterAvailabilityCallbackRequest) Descriptor() ([]byte, []int)
Deprecated: Use UnregisterAvailabilityCallbackRequest.ProtoReflect.Descriptor instead.
func (*UnregisterAvailabilityCallbackRequest) GetArg0 ¶
func (x *UnregisterAvailabilityCallbackRequest) GetArg0() int64
func (*UnregisterAvailabilityCallbackRequest) ProtoMessage ¶
func (*UnregisterAvailabilityCallbackRequest) ProtoMessage()
func (*UnregisterAvailabilityCallbackRequest) ProtoReflect ¶
func (x *UnregisterAvailabilityCallbackRequest) ProtoReflect() protoreflect.Message
func (*UnregisterAvailabilityCallbackRequest) Reset ¶
func (x *UnregisterAvailabilityCallbackRequest) Reset()
func (*UnregisterAvailabilityCallbackRequest) String ¶
func (x *UnregisterAvailabilityCallbackRequest) String() string
type UnregisterAvailabilityCallbackResponse ¶
type UnregisterAvailabilityCallbackResponse struct {
// contains filtered or unexported fields
}
func (*UnregisterAvailabilityCallbackResponse) Descriptor
deprecated
func (*UnregisterAvailabilityCallbackResponse) Descriptor() ([]byte, []int)
Deprecated: Use UnregisterAvailabilityCallbackResponse.ProtoReflect.Descriptor instead.
func (*UnregisterAvailabilityCallbackResponse) ProtoMessage ¶
func (*UnregisterAvailabilityCallbackResponse) ProtoMessage()
func (*UnregisterAvailabilityCallbackResponse) ProtoReflect ¶
func (x *UnregisterAvailabilityCallbackResponse) ProtoReflect() protoreflect.Message
func (*UnregisterAvailabilityCallbackResponse) Reset ¶
func (x *UnregisterAvailabilityCallbackResponse) Reset()
func (*UnregisterAvailabilityCallbackResponse) String ¶
func (x *UnregisterAvailabilityCallbackResponse) String() string
type UnregisterTorchCallbackRequest ¶
type UnregisterTorchCallbackRequest struct {
Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
// contains filtered or unexported fields
}
func (*UnregisterTorchCallbackRequest) Descriptor
deprecated
func (*UnregisterTorchCallbackRequest) Descriptor() ([]byte, []int)
Deprecated: Use UnregisterTorchCallbackRequest.ProtoReflect.Descriptor instead.
func (*UnregisterTorchCallbackRequest) GetArg0 ¶
func (x *UnregisterTorchCallbackRequest) GetArg0() int64
func (*UnregisterTorchCallbackRequest) ProtoMessage ¶
func (*UnregisterTorchCallbackRequest) ProtoMessage()
func (*UnregisterTorchCallbackRequest) ProtoReflect ¶
func (x *UnregisterTorchCallbackRequest) ProtoReflect() protoreflect.Message
func (*UnregisterTorchCallbackRequest) Reset ¶
func (x *UnregisterTorchCallbackRequest) Reset()
func (*UnregisterTorchCallbackRequest) String ¶
func (x *UnregisterTorchCallbackRequest) String() string
type UnregisterTorchCallbackResponse ¶
type UnregisterTorchCallbackResponse struct {
// contains filtered or unexported fields
}
func (*UnregisterTorchCallbackResponse) Descriptor
deprecated
func (*UnregisterTorchCallbackResponse) Descriptor() ([]byte, []int)
Deprecated: Use UnregisterTorchCallbackResponse.ProtoReflect.Descriptor instead.
func (*UnregisterTorchCallbackResponse) ProtoMessage ¶
func (*UnregisterTorchCallbackResponse) ProtoMessage()
func (*UnregisterTorchCallbackResponse) ProtoReflect ¶
func (x *UnregisterTorchCallbackResponse) ProtoReflect() protoreflect.Message
func (*UnregisterTorchCallbackResponse) Reset ¶
func (x *UnregisterTorchCallbackResponse) Reset()
func (*UnregisterTorchCallbackResponse) String ¶
func (x *UnregisterTorchCallbackResponse) String() string
type UnsafeManagerServiceServer ¶ added in v0.0.4
type UnsafeManagerServiceServer interface {
// contains filtered or unexported methods
}
UnsafeManagerServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ManagerServiceServer will result in compilation errors.