cdma

package
v0.0.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 29, 2026 License: CC0-1.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

const (
	CellLocationService_NewCellLocation_FullMethodName             = "/cdma.CellLocationService/NewCellLocation"
	CellLocationService_Equals_FullMethodName                      = "/cdma.CellLocationService/Equals"
	CellLocationService_FillInNotifierBundle_FullMethodName        = "/cdma.CellLocationService/FillInNotifierBundle"
	CellLocationService_GetBaseStationId_FullMethodName            = "/cdma.CellLocationService/GetBaseStationId"
	CellLocationService_GetBaseStationLatitude_FullMethodName      = "/cdma.CellLocationService/GetBaseStationLatitude"
	CellLocationService_GetBaseStationLongitude_FullMethodName     = "/cdma.CellLocationService/GetBaseStationLongitude"
	CellLocationService_GetNetworkId_FullMethodName                = "/cdma.CellLocationService/GetNetworkId"
	CellLocationService_GetSystemId_FullMethodName                 = "/cdma.CellLocationService/GetSystemId"
	CellLocationService_HashCode_FullMethodName                    = "/cdma.CellLocationService/HashCode"
	CellLocationService_SetCellLocationData3_FullMethodName        = "/cdma.CellLocationService/SetCellLocationData3"
	CellLocationService_SetCellLocationData5_1_FullMethodName      = "/cdma.CellLocationService/SetCellLocationData5_1"
	CellLocationService_SetStateInvalid_FullMethodName             = "/cdma.CellLocationService/SetStateInvalid"
	CellLocationService_ToString_FullMethodName                    = "/cdma.CellLocationService/ToString"
	CellLocationService_ConvertQuartSecToDecDegrees_FullMethodName = "/cdma.CellLocationService/ConvertQuartSecToDecDegrees"
)

Variables

var CellLocationService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "cdma.CellLocationService",
	HandlerType: (*CellLocationServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "NewCellLocation",
			Handler:    _CellLocationService_NewCellLocation_Handler,
		},
		{
			MethodName: "Equals",
			Handler:    _CellLocationService_Equals_Handler,
		},
		{
			MethodName: "FillInNotifierBundle",
			Handler:    _CellLocationService_FillInNotifierBundle_Handler,
		},
		{
			MethodName: "GetBaseStationId",
			Handler:    _CellLocationService_GetBaseStationId_Handler,
		},
		{
			MethodName: "GetBaseStationLatitude",
			Handler:    _CellLocationService_GetBaseStationLatitude_Handler,
		},
		{
			MethodName: "GetBaseStationLongitude",
			Handler:    _CellLocationService_GetBaseStationLongitude_Handler,
		},
		{
			MethodName: "GetNetworkId",
			Handler:    _CellLocationService_GetNetworkId_Handler,
		},
		{
			MethodName: "GetSystemId",
			Handler:    _CellLocationService_GetSystemId_Handler,
		},
		{
			MethodName: "HashCode",
			Handler:    _CellLocationService_HashCode_Handler,
		},
		{
			MethodName: "SetCellLocationData3",
			Handler:    _CellLocationService_SetCellLocationData3_Handler,
		},
		{
			MethodName: "SetCellLocationData5_1",
			Handler:    _CellLocationService_SetCellLocationData5_1_Handler,
		},
		{
			MethodName: "SetStateInvalid",
			Handler:    _CellLocationService_SetStateInvalid_Handler,
		},
		{
			MethodName: "ToString",
			Handler:    _CellLocationService_ToString_Handler,
		},
		{
			MethodName: "ConvertQuartSecToDecDegrees",
			Handler:    _CellLocationService_ConvertQuartSecToDecDegrees_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/cdma/cdma.proto",
}

CellLocationService_ServiceDesc is the grpc.ServiceDesc for CellLocationService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var File_proto_cdma_cdma_proto protoreflect.FileDescriptor

Functions

func RegisterCellLocationServiceServer

func RegisterCellLocationServiceServer(s grpc.ServiceRegistrar, srv CellLocationServiceServer)

Types

type CellLocationServiceClient

type CellLocationServiceClient interface {
	NewCellLocation(ctx context.Context, in *NewCellLocationRequest, opts ...grpc.CallOption) (*NewCellLocationResponse, error)
	Equals(ctx context.Context, in *EqualsRequest, opts ...grpc.CallOption) (*EqualsResponse, error)
	FillInNotifierBundle(ctx context.Context, in *FillInNotifierBundleRequest, opts ...grpc.CallOption) (*FillInNotifierBundleResponse, error)
	GetBaseStationId(ctx context.Context, in *GetBaseStationIdRequest, opts ...grpc.CallOption) (*GetBaseStationIdResponse, error)
	GetBaseStationLatitude(ctx context.Context, in *GetBaseStationLatitudeRequest, opts ...grpc.CallOption) (*GetBaseStationLatitudeResponse, error)
	GetBaseStationLongitude(ctx context.Context, in *GetBaseStationLongitudeRequest, opts ...grpc.CallOption) (*GetBaseStationLongitudeResponse, error)
	GetNetworkId(ctx context.Context, in *GetNetworkIdRequest, opts ...grpc.CallOption) (*GetNetworkIdResponse, error)
	GetSystemId(ctx context.Context, in *GetSystemIdRequest, opts ...grpc.CallOption) (*GetSystemIdResponse, error)
	HashCode(ctx context.Context, in *HashCodeRequest, opts ...grpc.CallOption) (*HashCodeResponse, error)
	SetCellLocationData3(ctx context.Context, in *SetCellLocationData3Request, opts ...grpc.CallOption) (*SetCellLocationData3Response, error)
	SetCellLocationData5_1(ctx context.Context, in *SetCellLocationData5_1Request, opts ...grpc.CallOption) (*SetCellLocationData5_1Response, error)
	SetStateInvalid(ctx context.Context, in *SetStateInvalidRequest, opts ...grpc.CallOption) (*SetStateInvalidResponse, error)
	ToString(ctx context.Context, in *ToStringRequest, opts ...grpc.CallOption) (*ToStringResponse, error)
	ConvertQuartSecToDecDegrees(ctx context.Context, in *ConvertQuartSecToDecDegreesRequest, opts ...grpc.CallOption) (*ConvertQuartSecToDecDegreesResponse, error)
}

CellLocationServiceClient is the client API for CellLocationService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type CellLocationServiceServer

CellLocationServiceServer is the server API for CellLocationService service. All implementations must embed UnimplementedCellLocationServiceServer for forward compatibility.

type ConvertQuartSecToDecDegreesRequest

type ConvertQuartSecToDecDegreesRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	Arg0   int32 `protobuf:"varint,2,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*ConvertQuartSecToDecDegreesRequest) Descriptor deprecated

func (*ConvertQuartSecToDecDegreesRequest) Descriptor() ([]byte, []int)

Deprecated: Use ConvertQuartSecToDecDegreesRequest.ProtoReflect.Descriptor instead.

func (*ConvertQuartSecToDecDegreesRequest) GetArg0

func (*ConvertQuartSecToDecDegreesRequest) GetHandle

func (*ConvertQuartSecToDecDegreesRequest) ProtoMessage

func (*ConvertQuartSecToDecDegreesRequest) ProtoMessage()

func (*ConvertQuartSecToDecDegreesRequest) ProtoReflect

func (*ConvertQuartSecToDecDegreesRequest) Reset

func (*ConvertQuartSecToDecDegreesRequest) String

type ConvertQuartSecToDecDegreesResponse

type ConvertQuartSecToDecDegreesResponse struct {
	Result float64 `protobuf:"fixed64,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*ConvertQuartSecToDecDegreesResponse) Descriptor deprecated

func (*ConvertQuartSecToDecDegreesResponse) Descriptor() ([]byte, []int)

Deprecated: Use ConvertQuartSecToDecDegreesResponse.ProtoReflect.Descriptor instead.

func (*ConvertQuartSecToDecDegreesResponse) GetResult

func (*ConvertQuartSecToDecDegreesResponse) ProtoMessage

func (*ConvertQuartSecToDecDegreesResponse) ProtoMessage()

func (*ConvertQuartSecToDecDegreesResponse) ProtoReflect

func (*ConvertQuartSecToDecDegreesResponse) Reset

func (*ConvertQuartSecToDecDegreesResponse) String

type EqualsRequest

type EqualsRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	Arg0   int64 `protobuf:"varint,2,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*EqualsRequest) Descriptor deprecated

func (*EqualsRequest) Descriptor() ([]byte, []int)

Deprecated: Use EqualsRequest.ProtoReflect.Descriptor instead.

func (*EqualsRequest) GetArg0

func (x *EqualsRequest) GetArg0() int64

func (*EqualsRequest) GetHandle

func (x *EqualsRequest) GetHandle() int64

func (*EqualsRequest) ProtoMessage

func (*EqualsRequest) ProtoMessage()

func (*EqualsRequest) ProtoReflect

func (x *EqualsRequest) ProtoReflect() protoreflect.Message

func (*EqualsRequest) Reset

func (x *EqualsRequest) Reset()

func (*EqualsRequest) String

func (x *EqualsRequest) String() string

type EqualsResponse

type EqualsResponse struct {
	Result bool `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*EqualsResponse) Descriptor deprecated

func (*EqualsResponse) Descriptor() ([]byte, []int)

Deprecated: Use EqualsResponse.ProtoReflect.Descriptor instead.

func (*EqualsResponse) GetResult

func (x *EqualsResponse) GetResult() bool

func (*EqualsResponse) ProtoMessage

func (*EqualsResponse) ProtoMessage()

func (*EqualsResponse) ProtoReflect

func (x *EqualsResponse) ProtoReflect() protoreflect.Message

func (*EqualsResponse) Reset

func (x *EqualsResponse) Reset()

func (*EqualsResponse) String

func (x *EqualsResponse) String() string

type FillInNotifierBundleRequest

type FillInNotifierBundleRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	Arg0   int64 `protobuf:"varint,2,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*FillInNotifierBundleRequest) Descriptor deprecated

func (*FillInNotifierBundleRequest) Descriptor() ([]byte, []int)

Deprecated: Use FillInNotifierBundleRequest.ProtoReflect.Descriptor instead.

func (*FillInNotifierBundleRequest) GetArg0

func (x *FillInNotifierBundleRequest) GetArg0() int64

func (*FillInNotifierBundleRequest) GetHandle

func (x *FillInNotifierBundleRequest) GetHandle() int64

func (*FillInNotifierBundleRequest) ProtoMessage

func (*FillInNotifierBundleRequest) ProtoMessage()

func (*FillInNotifierBundleRequest) ProtoReflect

func (*FillInNotifierBundleRequest) Reset

func (x *FillInNotifierBundleRequest) Reset()

func (*FillInNotifierBundleRequest) String

func (x *FillInNotifierBundleRequest) String() string

type FillInNotifierBundleResponse

type FillInNotifierBundleResponse struct {
	// contains filtered or unexported fields
}

func (*FillInNotifierBundleResponse) Descriptor deprecated

func (*FillInNotifierBundleResponse) Descriptor() ([]byte, []int)

Deprecated: Use FillInNotifierBundleResponse.ProtoReflect.Descriptor instead.

func (*FillInNotifierBundleResponse) ProtoMessage

func (*FillInNotifierBundleResponse) ProtoMessage()

func (*FillInNotifierBundleResponse) ProtoReflect

func (*FillInNotifierBundleResponse) Reset

func (x *FillInNotifierBundleResponse) Reset()

func (*FillInNotifierBundleResponse) String

type GetBaseStationIdRequest

type GetBaseStationIdRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	// contains filtered or unexported fields
}

func (*GetBaseStationIdRequest) Descriptor deprecated

func (*GetBaseStationIdRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetBaseStationIdRequest.ProtoReflect.Descriptor instead.

func (*GetBaseStationIdRequest) GetHandle

func (x *GetBaseStationIdRequest) GetHandle() int64

func (*GetBaseStationIdRequest) ProtoMessage

func (*GetBaseStationIdRequest) ProtoMessage()

func (*GetBaseStationIdRequest) ProtoReflect

func (x *GetBaseStationIdRequest) ProtoReflect() protoreflect.Message

func (*GetBaseStationIdRequest) Reset

func (x *GetBaseStationIdRequest) Reset()

func (*GetBaseStationIdRequest) String

func (x *GetBaseStationIdRequest) String() string

type GetBaseStationIdResponse

type GetBaseStationIdResponse struct {
	Result int32 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetBaseStationIdResponse) Descriptor deprecated

func (*GetBaseStationIdResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetBaseStationIdResponse.ProtoReflect.Descriptor instead.

func (*GetBaseStationIdResponse) GetResult

func (x *GetBaseStationIdResponse) GetResult() int32

func (*GetBaseStationIdResponse) ProtoMessage

func (*GetBaseStationIdResponse) ProtoMessage()

func (*GetBaseStationIdResponse) ProtoReflect

func (x *GetBaseStationIdResponse) ProtoReflect() protoreflect.Message

func (*GetBaseStationIdResponse) Reset

func (x *GetBaseStationIdResponse) Reset()

func (*GetBaseStationIdResponse) String

func (x *GetBaseStationIdResponse) String() string

type GetBaseStationLatitudeRequest

type GetBaseStationLatitudeRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	// contains filtered or unexported fields
}

func (*GetBaseStationLatitudeRequest) Descriptor deprecated

func (*GetBaseStationLatitudeRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetBaseStationLatitudeRequest.ProtoReflect.Descriptor instead.

func (*GetBaseStationLatitudeRequest) GetHandle

func (x *GetBaseStationLatitudeRequest) GetHandle() int64

func (*GetBaseStationLatitudeRequest) ProtoMessage

func (*GetBaseStationLatitudeRequest) ProtoMessage()

func (*GetBaseStationLatitudeRequest) ProtoReflect

func (*GetBaseStationLatitudeRequest) Reset

func (x *GetBaseStationLatitudeRequest) Reset()

func (*GetBaseStationLatitudeRequest) String

type GetBaseStationLatitudeResponse

type GetBaseStationLatitudeResponse struct {
	Result int32 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetBaseStationLatitudeResponse) Descriptor deprecated

func (*GetBaseStationLatitudeResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetBaseStationLatitudeResponse.ProtoReflect.Descriptor instead.

func (*GetBaseStationLatitudeResponse) GetResult

func (x *GetBaseStationLatitudeResponse) GetResult() int32

func (*GetBaseStationLatitudeResponse) ProtoMessage

func (*GetBaseStationLatitudeResponse) ProtoMessage()

func (*GetBaseStationLatitudeResponse) ProtoReflect

func (*GetBaseStationLatitudeResponse) Reset

func (x *GetBaseStationLatitudeResponse) Reset()

func (*GetBaseStationLatitudeResponse) String

type GetBaseStationLongitudeRequest

type GetBaseStationLongitudeRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	// contains filtered or unexported fields
}

func (*GetBaseStationLongitudeRequest) Descriptor deprecated

func (*GetBaseStationLongitudeRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetBaseStationLongitudeRequest.ProtoReflect.Descriptor instead.

func (*GetBaseStationLongitudeRequest) GetHandle

func (x *GetBaseStationLongitudeRequest) GetHandle() int64

func (*GetBaseStationLongitudeRequest) ProtoMessage

func (*GetBaseStationLongitudeRequest) ProtoMessage()

func (*GetBaseStationLongitudeRequest) ProtoReflect

func (*GetBaseStationLongitudeRequest) Reset

func (x *GetBaseStationLongitudeRequest) Reset()

func (*GetBaseStationLongitudeRequest) String

type GetBaseStationLongitudeResponse

type GetBaseStationLongitudeResponse struct {
	Result int32 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetBaseStationLongitudeResponse) Descriptor deprecated

func (*GetBaseStationLongitudeResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetBaseStationLongitudeResponse.ProtoReflect.Descriptor instead.

func (*GetBaseStationLongitudeResponse) GetResult

func (x *GetBaseStationLongitudeResponse) GetResult() int32

func (*GetBaseStationLongitudeResponse) ProtoMessage

func (*GetBaseStationLongitudeResponse) ProtoMessage()

func (*GetBaseStationLongitudeResponse) ProtoReflect

func (*GetBaseStationLongitudeResponse) Reset

func (*GetBaseStationLongitudeResponse) String

type GetNetworkIdRequest

type GetNetworkIdRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	// contains filtered or unexported fields
}

func (*GetNetworkIdRequest) Descriptor deprecated

func (*GetNetworkIdRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetNetworkIdRequest.ProtoReflect.Descriptor instead.

func (*GetNetworkIdRequest) GetHandle

func (x *GetNetworkIdRequest) GetHandle() int64

func (*GetNetworkIdRequest) ProtoMessage

func (*GetNetworkIdRequest) ProtoMessage()

func (*GetNetworkIdRequest) ProtoReflect

func (x *GetNetworkIdRequest) ProtoReflect() protoreflect.Message

func (*GetNetworkIdRequest) Reset

func (x *GetNetworkIdRequest) Reset()

func (*GetNetworkIdRequest) String

func (x *GetNetworkIdRequest) String() string

type GetNetworkIdResponse

type GetNetworkIdResponse struct {
	Result int32 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetNetworkIdResponse) Descriptor deprecated

func (*GetNetworkIdResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetNetworkIdResponse.ProtoReflect.Descriptor instead.

func (*GetNetworkIdResponse) GetResult

func (x *GetNetworkIdResponse) GetResult() int32

func (*GetNetworkIdResponse) ProtoMessage

func (*GetNetworkIdResponse) ProtoMessage()

func (*GetNetworkIdResponse) ProtoReflect

func (x *GetNetworkIdResponse) ProtoReflect() protoreflect.Message

func (*GetNetworkIdResponse) Reset

func (x *GetNetworkIdResponse) Reset()

func (*GetNetworkIdResponse) String

func (x *GetNetworkIdResponse) String() string

type GetSystemIdRequest

type GetSystemIdRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	// contains filtered or unexported fields
}

func (*GetSystemIdRequest) Descriptor deprecated

func (*GetSystemIdRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetSystemIdRequest.ProtoReflect.Descriptor instead.

func (*GetSystemIdRequest) GetHandle

func (x *GetSystemIdRequest) GetHandle() int64

func (*GetSystemIdRequest) ProtoMessage

func (*GetSystemIdRequest) ProtoMessage()

func (*GetSystemIdRequest) ProtoReflect

func (x *GetSystemIdRequest) ProtoReflect() protoreflect.Message

func (*GetSystemIdRequest) Reset

func (x *GetSystemIdRequest) Reset()

func (*GetSystemIdRequest) String

func (x *GetSystemIdRequest) String() string

type GetSystemIdResponse

type GetSystemIdResponse struct {
	Result int32 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetSystemIdResponse) Descriptor deprecated

func (*GetSystemIdResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetSystemIdResponse.ProtoReflect.Descriptor instead.

func (*GetSystemIdResponse) GetResult

func (x *GetSystemIdResponse) GetResult() int32

func (*GetSystemIdResponse) ProtoMessage

func (*GetSystemIdResponse) ProtoMessage()

func (*GetSystemIdResponse) ProtoReflect

func (x *GetSystemIdResponse) ProtoReflect() protoreflect.Message

func (*GetSystemIdResponse) Reset

func (x *GetSystemIdResponse) Reset()

func (*GetSystemIdResponse) String

func (x *GetSystemIdResponse) String() string

type HashCodeRequest

type HashCodeRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	// contains filtered or unexported fields
}

func (*HashCodeRequest) Descriptor deprecated

func (*HashCodeRequest) Descriptor() ([]byte, []int)

Deprecated: Use HashCodeRequest.ProtoReflect.Descriptor instead.

func (*HashCodeRequest) GetHandle

func (x *HashCodeRequest) GetHandle() int64

func (*HashCodeRequest) ProtoMessage

func (*HashCodeRequest) ProtoMessage()

func (*HashCodeRequest) ProtoReflect

func (x *HashCodeRequest) ProtoReflect() protoreflect.Message

func (*HashCodeRequest) Reset

func (x *HashCodeRequest) Reset()

func (*HashCodeRequest) String

func (x *HashCodeRequest) String() string

type HashCodeResponse

type HashCodeResponse struct {
	Result int32 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*HashCodeResponse) Descriptor deprecated

func (*HashCodeResponse) Descriptor() ([]byte, []int)

Deprecated: Use HashCodeResponse.ProtoReflect.Descriptor instead.

func (*HashCodeResponse) GetResult

func (x *HashCodeResponse) GetResult() int32

func (*HashCodeResponse) ProtoMessage

func (*HashCodeResponse) ProtoMessage()

func (*HashCodeResponse) ProtoReflect

func (x *HashCodeResponse) ProtoReflect() protoreflect.Message

func (*HashCodeResponse) Reset

func (x *HashCodeResponse) Reset()

func (*HashCodeResponse) String

func (x *HashCodeResponse) String() string

type NewCellLocationRequest

type NewCellLocationRequest struct {
	// contains filtered or unexported fields
}

func (*NewCellLocationRequest) Descriptor deprecated

func (*NewCellLocationRequest) Descriptor() ([]byte, []int)

Deprecated: Use NewCellLocationRequest.ProtoReflect.Descriptor instead.

func (*NewCellLocationRequest) ProtoMessage

func (*NewCellLocationRequest) ProtoMessage()

func (*NewCellLocationRequest) ProtoReflect

func (x *NewCellLocationRequest) ProtoReflect() protoreflect.Message

func (*NewCellLocationRequest) Reset

func (x *NewCellLocationRequest) Reset()

func (*NewCellLocationRequest) String

func (x *NewCellLocationRequest) String() string

type NewCellLocationResponse

type NewCellLocationResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*NewCellLocationResponse) Descriptor deprecated

func (*NewCellLocationResponse) Descriptor() ([]byte, []int)

Deprecated: Use NewCellLocationResponse.ProtoReflect.Descriptor instead.

func (*NewCellLocationResponse) GetResult

func (x *NewCellLocationResponse) GetResult() int64

func (*NewCellLocationResponse) ProtoMessage

func (*NewCellLocationResponse) ProtoMessage()

func (*NewCellLocationResponse) ProtoReflect

func (x *NewCellLocationResponse) ProtoReflect() protoreflect.Message

func (*NewCellLocationResponse) Reset

func (x *NewCellLocationResponse) Reset()

func (*NewCellLocationResponse) String

func (x *NewCellLocationResponse) String() string

type SetCellLocationData3Request

type SetCellLocationData3Request struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	Arg0   int32 `protobuf:"varint,2,opt,name=arg0,proto3" json:"arg0,omitempty"`
	Arg1   int32 `protobuf:"varint,3,opt,name=arg1,proto3" json:"arg1,omitempty"`
	Arg2   int32 `protobuf:"varint,4,opt,name=arg2,proto3" json:"arg2,omitempty"`
	// contains filtered or unexported fields
}

func (*SetCellLocationData3Request) Descriptor deprecated

func (*SetCellLocationData3Request) Descriptor() ([]byte, []int)

Deprecated: Use SetCellLocationData3Request.ProtoReflect.Descriptor instead.

func (*SetCellLocationData3Request) GetArg0

func (x *SetCellLocationData3Request) GetArg0() int32

func (*SetCellLocationData3Request) GetArg1

func (x *SetCellLocationData3Request) GetArg1() int32

func (*SetCellLocationData3Request) GetArg2

func (x *SetCellLocationData3Request) GetArg2() int32

func (*SetCellLocationData3Request) GetHandle

func (x *SetCellLocationData3Request) GetHandle() int64

func (*SetCellLocationData3Request) ProtoMessage

func (*SetCellLocationData3Request) ProtoMessage()

func (*SetCellLocationData3Request) ProtoReflect

func (*SetCellLocationData3Request) Reset

func (x *SetCellLocationData3Request) Reset()

func (*SetCellLocationData3Request) String

func (x *SetCellLocationData3Request) String() string

type SetCellLocationData3Response

type SetCellLocationData3Response struct {
	// contains filtered or unexported fields
}

func (*SetCellLocationData3Response) Descriptor deprecated

func (*SetCellLocationData3Response) Descriptor() ([]byte, []int)

Deprecated: Use SetCellLocationData3Response.ProtoReflect.Descriptor instead.

func (*SetCellLocationData3Response) ProtoMessage

func (*SetCellLocationData3Response) ProtoMessage()

func (*SetCellLocationData3Response) ProtoReflect

func (*SetCellLocationData3Response) Reset

func (x *SetCellLocationData3Response) Reset()

func (*SetCellLocationData3Response) String

type SetCellLocationData5_1Request

type SetCellLocationData5_1Request struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	Arg0   int32 `protobuf:"varint,2,opt,name=arg0,proto3" json:"arg0,omitempty"`
	Arg1   int32 `protobuf:"varint,3,opt,name=arg1,proto3" json:"arg1,omitempty"`
	Arg2   int32 `protobuf:"varint,4,opt,name=arg2,proto3" json:"arg2,omitempty"`
	Arg3   int32 `protobuf:"varint,5,opt,name=arg3,proto3" json:"arg3,omitempty"`
	Arg4   int32 `protobuf:"varint,6,opt,name=arg4,proto3" json:"arg4,omitempty"`
	// contains filtered or unexported fields
}

func (*SetCellLocationData5_1Request) Descriptor deprecated

func (*SetCellLocationData5_1Request) Descriptor() ([]byte, []int)

Deprecated: Use SetCellLocationData5_1Request.ProtoReflect.Descriptor instead.

func (*SetCellLocationData5_1Request) GetArg0

func (x *SetCellLocationData5_1Request) GetArg0() int32

func (*SetCellLocationData5_1Request) GetArg1

func (x *SetCellLocationData5_1Request) GetArg1() int32

func (*SetCellLocationData5_1Request) GetArg2

func (x *SetCellLocationData5_1Request) GetArg2() int32

func (*SetCellLocationData5_1Request) GetArg3

func (x *SetCellLocationData5_1Request) GetArg3() int32

func (*SetCellLocationData5_1Request) GetArg4

func (x *SetCellLocationData5_1Request) GetArg4() int32

func (*SetCellLocationData5_1Request) GetHandle

func (x *SetCellLocationData5_1Request) GetHandle() int64

func (*SetCellLocationData5_1Request) ProtoMessage

func (*SetCellLocationData5_1Request) ProtoMessage()

func (*SetCellLocationData5_1Request) ProtoReflect

func (*SetCellLocationData5_1Request) Reset

func (x *SetCellLocationData5_1Request) Reset()

func (*SetCellLocationData5_1Request) String

type SetCellLocationData5_1Response

type SetCellLocationData5_1Response struct {
	// contains filtered or unexported fields
}

func (*SetCellLocationData5_1Response) Descriptor deprecated

func (*SetCellLocationData5_1Response) Descriptor() ([]byte, []int)

Deprecated: Use SetCellLocationData5_1Response.ProtoReflect.Descriptor instead.

func (*SetCellLocationData5_1Response) ProtoMessage

func (*SetCellLocationData5_1Response) ProtoMessage()

func (*SetCellLocationData5_1Response) ProtoReflect

func (*SetCellLocationData5_1Response) Reset

func (x *SetCellLocationData5_1Response) Reset()

func (*SetCellLocationData5_1Response) String

type SetStateInvalidRequest

type SetStateInvalidRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	// contains filtered or unexported fields
}

func (*SetStateInvalidRequest) Descriptor deprecated

func (*SetStateInvalidRequest) Descriptor() ([]byte, []int)

Deprecated: Use SetStateInvalidRequest.ProtoReflect.Descriptor instead.

func (*SetStateInvalidRequest) GetHandle

func (x *SetStateInvalidRequest) GetHandle() int64

func (*SetStateInvalidRequest) ProtoMessage

func (*SetStateInvalidRequest) ProtoMessage()

func (*SetStateInvalidRequest) ProtoReflect

func (x *SetStateInvalidRequest) ProtoReflect() protoreflect.Message

func (*SetStateInvalidRequest) Reset

func (x *SetStateInvalidRequest) Reset()

func (*SetStateInvalidRequest) String

func (x *SetStateInvalidRequest) String() string

type SetStateInvalidResponse

type SetStateInvalidResponse struct {
	// contains filtered or unexported fields
}

func (*SetStateInvalidResponse) Descriptor deprecated

func (*SetStateInvalidResponse) Descriptor() ([]byte, []int)

Deprecated: Use SetStateInvalidResponse.ProtoReflect.Descriptor instead.

func (*SetStateInvalidResponse) ProtoMessage

func (*SetStateInvalidResponse) ProtoMessage()

func (*SetStateInvalidResponse) ProtoReflect

func (x *SetStateInvalidResponse) ProtoReflect() protoreflect.Message

func (*SetStateInvalidResponse) Reset

func (x *SetStateInvalidResponse) Reset()

func (*SetStateInvalidResponse) String

func (x *SetStateInvalidResponse) String() string

type ToStringRequest

type ToStringRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	// contains filtered or unexported fields
}

func (*ToStringRequest) Descriptor deprecated

func (*ToStringRequest) Descriptor() ([]byte, []int)

Deprecated: Use ToStringRequest.ProtoReflect.Descriptor instead.

func (*ToStringRequest) GetHandle

func (x *ToStringRequest) GetHandle() int64

func (*ToStringRequest) ProtoMessage

func (*ToStringRequest) ProtoMessage()

func (*ToStringRequest) ProtoReflect

func (x *ToStringRequest) ProtoReflect() protoreflect.Message

func (*ToStringRequest) Reset

func (x *ToStringRequest) Reset()

func (*ToStringRequest) String

func (x *ToStringRequest) String() string

type ToStringResponse

type ToStringResponse struct {
	Result string `protobuf:"bytes,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*ToStringResponse) Descriptor deprecated

func (*ToStringResponse) Descriptor() ([]byte, []int)

Deprecated: Use ToStringResponse.ProtoReflect.Descriptor instead.

func (*ToStringResponse) GetResult

func (x *ToStringResponse) GetResult() string

func (*ToStringResponse) ProtoMessage

func (*ToStringResponse) ProtoMessage()

func (*ToStringResponse) ProtoReflect

func (x *ToStringResponse) ProtoReflect() protoreflect.Message

func (*ToStringResponse) Reset

func (x *ToStringResponse) Reset()

func (*ToStringResponse) String

func (x *ToStringResponse) String() string

type UnimplementedCellLocationServiceServer

type UnimplementedCellLocationServiceServer struct{}

UnimplementedCellLocationServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedCellLocationServiceServer) Equals

func (UnimplementedCellLocationServiceServer) FillInNotifierBundle

func (UnimplementedCellLocationServiceServer) GetBaseStationId

func (UnimplementedCellLocationServiceServer) GetNetworkId

func (UnimplementedCellLocationServiceServer) GetSystemId

func (UnimplementedCellLocationServiceServer) HashCode

func (UnimplementedCellLocationServiceServer) NewCellLocation

func (UnimplementedCellLocationServiceServer) SetCellLocationData3

func (UnimplementedCellLocationServiceServer) SetStateInvalid

func (UnimplementedCellLocationServiceServer) ToString

type UnsafeCellLocationServiceServer

type UnsafeCellLocationServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeCellLocationServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to CellLocationServiceServer will result in compilation errors.

Jump to