classification

package
v0.0.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 29, 2026 License: CC0-1.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

const (
	FieldClassificationService_NewFieldClassification_FullMethodName = "/classification.FieldClassificationService/NewFieldClassification"
	FieldClassificationService_DescribeContents_FullMethodName       = "/classification.FieldClassificationService/DescribeContents"
	FieldClassificationService_GetAutofillId_FullMethodName          = "/classification.FieldClassificationService/GetAutofillId"
	FieldClassificationService_GetHints_FullMethodName               = "/classification.FieldClassificationService/GetHints"
	FieldClassificationService_ToString_FullMethodName               = "/classification.FieldClassificationService/ToString"
	FieldClassificationService_WriteToParcel_FullMethodName          = "/classification.FieldClassificationService/WriteToParcel"
)

Variables

var FieldClassificationService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "classification.FieldClassificationService",
	HandlerType: (*FieldClassificationServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "NewFieldClassification",
			Handler:    _FieldClassificationService_NewFieldClassification_Handler,
		},
		{
			MethodName: "DescribeContents",
			Handler:    _FieldClassificationService_DescribeContents_Handler,
		},
		{
			MethodName: "GetAutofillId",
			Handler:    _FieldClassificationService_GetAutofillId_Handler,
		},
		{
			MethodName: "GetHints",
			Handler:    _FieldClassificationService_GetHints_Handler,
		},
		{
			MethodName: "ToString",
			Handler:    _FieldClassificationService_ToString_Handler,
		},
		{
			MethodName: "WriteToParcel",
			Handler:    _FieldClassificationService_WriteToParcel_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/classification/classification.proto",
}

FieldClassificationService_ServiceDesc is the grpc.ServiceDesc for FieldClassificationService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var File_proto_classification_classification_proto protoreflect.FileDescriptor

Functions

func RegisterFieldClassificationServiceServer

func RegisterFieldClassificationServiceServer(s grpc.ServiceRegistrar, srv FieldClassificationServiceServer)

Types

type DescribeContentsRequest

type DescribeContentsRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	// contains filtered or unexported fields
}

func (*DescribeContentsRequest) Descriptor deprecated

func (*DescribeContentsRequest) Descriptor() ([]byte, []int)

Deprecated: Use DescribeContentsRequest.ProtoReflect.Descriptor instead.

func (*DescribeContentsRequest) GetHandle

func (x *DescribeContentsRequest) GetHandle() int64

func (*DescribeContentsRequest) ProtoMessage

func (*DescribeContentsRequest) ProtoMessage()

func (*DescribeContentsRequest) ProtoReflect

func (x *DescribeContentsRequest) ProtoReflect() protoreflect.Message

func (*DescribeContentsRequest) Reset

func (x *DescribeContentsRequest) Reset()

func (*DescribeContentsRequest) String

func (x *DescribeContentsRequest) String() string

type DescribeContentsResponse

type DescribeContentsResponse struct {
	Result int32 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*DescribeContentsResponse) Descriptor deprecated

func (*DescribeContentsResponse) Descriptor() ([]byte, []int)

Deprecated: Use DescribeContentsResponse.ProtoReflect.Descriptor instead.

func (*DescribeContentsResponse) GetResult

func (x *DescribeContentsResponse) GetResult() int32

func (*DescribeContentsResponse) ProtoMessage

func (*DescribeContentsResponse) ProtoMessage()

func (*DescribeContentsResponse) ProtoReflect

func (x *DescribeContentsResponse) ProtoReflect() protoreflect.Message

func (*DescribeContentsResponse) Reset

func (x *DescribeContentsResponse) Reset()

func (*DescribeContentsResponse) String

func (x *DescribeContentsResponse) String() string

type FieldClassificationServiceClient

type FieldClassificationServiceClient interface {
	NewFieldClassification(ctx context.Context, in *NewFieldClassificationRequest, opts ...grpc.CallOption) (*NewFieldClassificationResponse, error)
	DescribeContents(ctx context.Context, in *DescribeContentsRequest, opts ...grpc.CallOption) (*DescribeContentsResponse, error)
	GetAutofillId(ctx context.Context, in *GetAutofillIdRequest, opts ...grpc.CallOption) (*GetAutofillIdResponse, error)
	GetHints(ctx context.Context, in *GetHintsRequest, opts ...grpc.CallOption) (*GetHintsResponse, error)
	ToString(ctx context.Context, in *ToStringRequest, opts ...grpc.CallOption) (*ToStringResponse, error)
	WriteToParcel(ctx context.Context, in *WriteToParcelRequest, opts ...grpc.CallOption) (*WriteToParcelResponse, error)
}

FieldClassificationServiceClient is the client API for FieldClassificationService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type FieldClassificationServiceServer

type FieldClassificationServiceServer interface {
	NewFieldClassification(context.Context, *NewFieldClassificationRequest) (*NewFieldClassificationResponse, error)
	DescribeContents(context.Context, *DescribeContentsRequest) (*DescribeContentsResponse, error)
	GetAutofillId(context.Context, *GetAutofillIdRequest) (*GetAutofillIdResponse, error)
	GetHints(context.Context, *GetHintsRequest) (*GetHintsResponse, error)
	ToString(context.Context, *ToStringRequest) (*ToStringResponse, error)
	WriteToParcel(context.Context, *WriteToParcelRequest) (*WriteToParcelResponse, error)
	// contains filtered or unexported methods
}

FieldClassificationServiceServer is the server API for FieldClassificationService service. All implementations must embed UnimplementedFieldClassificationServiceServer for forward compatibility.

type GetAutofillIdRequest

type GetAutofillIdRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	// contains filtered or unexported fields
}

func (*GetAutofillIdRequest) Descriptor deprecated

func (*GetAutofillIdRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetAutofillIdRequest.ProtoReflect.Descriptor instead.

func (*GetAutofillIdRequest) GetHandle

func (x *GetAutofillIdRequest) GetHandle() int64

func (*GetAutofillIdRequest) ProtoMessage

func (*GetAutofillIdRequest) ProtoMessage()

func (*GetAutofillIdRequest) ProtoReflect

func (x *GetAutofillIdRequest) ProtoReflect() protoreflect.Message

func (*GetAutofillIdRequest) Reset

func (x *GetAutofillIdRequest) Reset()

func (*GetAutofillIdRequest) String

func (x *GetAutofillIdRequest) String() string

type GetAutofillIdResponse

type GetAutofillIdResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetAutofillIdResponse) Descriptor deprecated

func (*GetAutofillIdResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetAutofillIdResponse.ProtoReflect.Descriptor instead.

func (*GetAutofillIdResponse) GetResult

func (x *GetAutofillIdResponse) GetResult() int64

func (*GetAutofillIdResponse) ProtoMessage

func (*GetAutofillIdResponse) ProtoMessage()

func (*GetAutofillIdResponse) ProtoReflect

func (x *GetAutofillIdResponse) ProtoReflect() protoreflect.Message

func (*GetAutofillIdResponse) Reset

func (x *GetAutofillIdResponse) Reset()

func (*GetAutofillIdResponse) String

func (x *GetAutofillIdResponse) String() string

type GetHintsRequest

type GetHintsRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	// contains filtered or unexported fields
}

func (*GetHintsRequest) Descriptor deprecated

func (*GetHintsRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetHintsRequest.ProtoReflect.Descriptor instead.

func (*GetHintsRequest) GetHandle

func (x *GetHintsRequest) GetHandle() int64

func (*GetHintsRequest) ProtoMessage

func (*GetHintsRequest) ProtoMessage()

func (*GetHintsRequest) ProtoReflect

func (x *GetHintsRequest) ProtoReflect() protoreflect.Message

func (*GetHintsRequest) Reset

func (x *GetHintsRequest) Reset()

func (*GetHintsRequest) String

func (x *GetHintsRequest) String() string

type GetHintsResponse

type GetHintsResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetHintsResponse) Descriptor deprecated

func (*GetHintsResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetHintsResponse.ProtoReflect.Descriptor instead.

func (*GetHintsResponse) GetResult

func (x *GetHintsResponse) GetResult() int64

func (*GetHintsResponse) ProtoMessage

func (*GetHintsResponse) ProtoMessage()

func (*GetHintsResponse) ProtoReflect

func (x *GetHintsResponse) ProtoReflect() protoreflect.Message

func (*GetHintsResponse) Reset

func (x *GetHintsResponse) Reset()

func (*GetHintsResponse) String

func (x *GetHintsResponse) String() string

type NewFieldClassificationRequest

type NewFieldClassificationRequest struct {
	Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	Arg1 int64 `protobuf:"varint,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
	// contains filtered or unexported fields
}

func (*NewFieldClassificationRequest) Descriptor deprecated

func (*NewFieldClassificationRequest) Descriptor() ([]byte, []int)

Deprecated: Use NewFieldClassificationRequest.ProtoReflect.Descriptor instead.

func (*NewFieldClassificationRequest) GetArg0

func (x *NewFieldClassificationRequest) GetArg0() int64

func (*NewFieldClassificationRequest) GetArg1

func (x *NewFieldClassificationRequest) GetArg1() int64

func (*NewFieldClassificationRequest) ProtoMessage

func (*NewFieldClassificationRequest) ProtoMessage()

func (*NewFieldClassificationRequest) ProtoReflect

func (*NewFieldClassificationRequest) Reset

func (x *NewFieldClassificationRequest) Reset()

func (*NewFieldClassificationRequest) String

type NewFieldClassificationResponse

type NewFieldClassificationResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*NewFieldClassificationResponse) Descriptor deprecated

func (*NewFieldClassificationResponse) Descriptor() ([]byte, []int)

Deprecated: Use NewFieldClassificationResponse.ProtoReflect.Descriptor instead.

func (*NewFieldClassificationResponse) GetResult

func (x *NewFieldClassificationResponse) GetResult() int64

func (*NewFieldClassificationResponse) ProtoMessage

func (*NewFieldClassificationResponse) ProtoMessage()

func (*NewFieldClassificationResponse) ProtoReflect

func (*NewFieldClassificationResponse) Reset

func (x *NewFieldClassificationResponse) Reset()

func (*NewFieldClassificationResponse) String

type ToStringRequest

type ToStringRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	// contains filtered or unexported fields
}

func (*ToStringRequest) Descriptor deprecated

func (*ToStringRequest) Descriptor() ([]byte, []int)

Deprecated: Use ToStringRequest.ProtoReflect.Descriptor instead.

func (*ToStringRequest) GetHandle

func (x *ToStringRequest) GetHandle() int64

func (*ToStringRequest) ProtoMessage

func (*ToStringRequest) ProtoMessage()

func (*ToStringRequest) ProtoReflect

func (x *ToStringRequest) ProtoReflect() protoreflect.Message

func (*ToStringRequest) Reset

func (x *ToStringRequest) Reset()

func (*ToStringRequest) String

func (x *ToStringRequest) String() string

type ToStringResponse

type ToStringResponse struct {
	Result string `protobuf:"bytes,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*ToStringResponse) Descriptor deprecated

func (*ToStringResponse) Descriptor() ([]byte, []int)

Deprecated: Use ToStringResponse.ProtoReflect.Descriptor instead.

func (*ToStringResponse) GetResult

func (x *ToStringResponse) GetResult() string

func (*ToStringResponse) ProtoMessage

func (*ToStringResponse) ProtoMessage()

func (*ToStringResponse) ProtoReflect

func (x *ToStringResponse) ProtoReflect() protoreflect.Message

func (*ToStringResponse) Reset

func (x *ToStringResponse) Reset()

func (*ToStringResponse) String

func (x *ToStringResponse) String() string

type UnimplementedFieldClassificationServiceServer

type UnimplementedFieldClassificationServiceServer struct{}

UnimplementedFieldClassificationServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedFieldClassificationServiceServer) DescribeContents

func (UnimplementedFieldClassificationServiceServer) GetAutofillId

func (UnimplementedFieldClassificationServiceServer) GetHints

func (UnimplementedFieldClassificationServiceServer) NewFieldClassification

func (UnimplementedFieldClassificationServiceServer) ToString

func (UnimplementedFieldClassificationServiceServer) WriteToParcel

type UnsafeFieldClassificationServiceServer

type UnsafeFieldClassificationServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeFieldClassificationServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to FieldClassificationServiceServer will result in compilation errors.

type WriteToParcelRequest

type WriteToParcelRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	Arg0   int64 `protobuf:"varint,2,opt,name=arg0,proto3" json:"arg0,omitempty"`
	Arg1   int32 `protobuf:"varint,3,opt,name=arg1,proto3" json:"arg1,omitempty"`
	// contains filtered or unexported fields
}

func (*WriteToParcelRequest) Descriptor deprecated

func (*WriteToParcelRequest) Descriptor() ([]byte, []int)

Deprecated: Use WriteToParcelRequest.ProtoReflect.Descriptor instead.

func (*WriteToParcelRequest) GetArg0

func (x *WriteToParcelRequest) GetArg0() int64

func (*WriteToParcelRequest) GetArg1

func (x *WriteToParcelRequest) GetArg1() int32

func (*WriteToParcelRequest) GetHandle

func (x *WriteToParcelRequest) GetHandle() int64

func (*WriteToParcelRequest) ProtoMessage

func (*WriteToParcelRequest) ProtoMessage()

func (*WriteToParcelRequest) ProtoReflect

func (x *WriteToParcelRequest) ProtoReflect() protoreflect.Message

func (*WriteToParcelRequest) Reset

func (x *WriteToParcelRequest) Reset()

func (*WriteToParcelRequest) String

func (x *WriteToParcelRequest) String() string

type WriteToParcelResponse

type WriteToParcelResponse struct {
	// contains filtered or unexported fields
}

func (*WriteToParcelResponse) Descriptor deprecated

func (*WriteToParcelResponse) Descriptor() ([]byte, []int)

Deprecated: Use WriteToParcelResponse.ProtoReflect.Descriptor instead.

func (*WriteToParcelResponse) ProtoMessage

func (*WriteToParcelResponse) ProtoMessage()

func (*WriteToParcelResponse) ProtoReflect

func (x *WriteToParcelResponse) ProtoReflect() protoreflect.Message

func (*WriteToParcelResponse) Reset

func (x *WriteToParcelResponse) Reset()

func (*WriteToParcelResponse) String

func (x *WriteToParcelResponse) String() string

Jump to