content

package
v0.0.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 16, 2026 License: CC0-1.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

const (
	BroadcastReceiverService_GetSentFromPackage_FullMethodName = "/content.BroadcastReceiverService/GetSentFromPackage"
	BroadcastReceiverService_GetSentFromUid_FullMethodName     = "/content.BroadcastReceiverService/GetSentFromUid"
	BroadcastReceiverService_PeekService_FullMethodName        = "/content.BroadcastReceiverService/PeekService"
)

Variables

var BroadcastReceiverService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "content.BroadcastReceiverService",
	HandlerType: (*BroadcastReceiverServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "GetSentFromPackage",
			Handler:    _BroadcastReceiverService_GetSentFromPackage_Handler,
		},
		{
			MethodName: "GetSentFromUid",
			Handler:    _BroadcastReceiverService_GetSentFromUid_Handler,
		},
		{
			MethodName: "PeekService",
			Handler:    _BroadcastReceiverService_PeekService_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/content/content.proto",
}

BroadcastReceiverService_ServiceDesc is the grpc.ServiceDesc for BroadcastReceiverService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var File_proto_content_content_proto protoreflect.FileDescriptor

Functions

func RegisterBroadcastReceiverServiceServer

func RegisterBroadcastReceiverServiceServer(s grpc.ServiceRegistrar, srv BroadcastReceiverServiceServer)

Types

type BroadcastReceiverServiceClient

type BroadcastReceiverServiceClient interface {
	GetSentFromPackage(ctx context.Context, in *GetSentFromPackageRequest, opts ...grpc.CallOption) (*GetSentFromPackageResponse, error)
	GetSentFromUid(ctx context.Context, in *GetSentFromUidRequest, opts ...grpc.CallOption) (*GetSentFromUidResponse, error)
	PeekService(ctx context.Context, in *PeekServiceRequest, opts ...grpc.CallOption) (*PeekServiceResponse, error)
}

BroadcastReceiverServiceClient is the client API for BroadcastReceiverService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type BroadcastReceiverServiceServer

type BroadcastReceiverServiceServer interface {
	GetSentFromPackage(context.Context, *GetSentFromPackageRequest) (*GetSentFromPackageResponse, error)
	GetSentFromUid(context.Context, *GetSentFromUidRequest) (*GetSentFromUidResponse, error)
	PeekService(context.Context, *PeekServiceRequest) (*PeekServiceResponse, error)
	// contains filtered or unexported methods
}

BroadcastReceiverServiceServer is the server API for BroadcastReceiverService service. All implementations must embed UnimplementedBroadcastReceiverServiceServer for forward compatibility.

type GetSentFromPackageRequest

type GetSentFromPackageRequest struct {
	// contains filtered or unexported fields
}

func (*GetSentFromPackageRequest) Descriptor deprecated

func (*GetSentFromPackageRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetSentFromPackageRequest.ProtoReflect.Descriptor instead.

func (*GetSentFromPackageRequest) ProtoMessage

func (*GetSentFromPackageRequest) ProtoMessage()

func (*GetSentFromPackageRequest) ProtoReflect

func (*GetSentFromPackageRequest) Reset

func (x *GetSentFromPackageRequest) Reset()

func (*GetSentFromPackageRequest) String

func (x *GetSentFromPackageRequest) String() string

type GetSentFromPackageResponse

type GetSentFromPackageResponse struct {
	Result string `protobuf:"bytes,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetSentFromPackageResponse) Descriptor deprecated

func (*GetSentFromPackageResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetSentFromPackageResponse.ProtoReflect.Descriptor instead.

func (*GetSentFromPackageResponse) GetResult

func (x *GetSentFromPackageResponse) GetResult() string

func (*GetSentFromPackageResponse) ProtoMessage

func (*GetSentFromPackageResponse) ProtoMessage()

func (*GetSentFromPackageResponse) ProtoReflect

func (*GetSentFromPackageResponse) Reset

func (x *GetSentFromPackageResponse) Reset()

func (*GetSentFromPackageResponse) String

func (x *GetSentFromPackageResponse) String() string

type GetSentFromUidRequest

type GetSentFromUidRequest struct {
	// contains filtered or unexported fields
}

func (*GetSentFromUidRequest) Descriptor deprecated

func (*GetSentFromUidRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetSentFromUidRequest.ProtoReflect.Descriptor instead.

func (*GetSentFromUidRequest) ProtoMessage

func (*GetSentFromUidRequest) ProtoMessage()

func (*GetSentFromUidRequest) ProtoReflect

func (x *GetSentFromUidRequest) ProtoReflect() protoreflect.Message

func (*GetSentFromUidRequest) Reset

func (x *GetSentFromUidRequest) Reset()

func (*GetSentFromUidRequest) String

func (x *GetSentFromUidRequest) String() string

type GetSentFromUidResponse

type GetSentFromUidResponse struct {
	Result int32 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetSentFromUidResponse) Descriptor deprecated

func (*GetSentFromUidResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetSentFromUidResponse.ProtoReflect.Descriptor instead.

func (*GetSentFromUidResponse) GetResult

func (x *GetSentFromUidResponse) GetResult() int32

func (*GetSentFromUidResponse) ProtoMessage

func (*GetSentFromUidResponse) ProtoMessage()

func (*GetSentFromUidResponse) ProtoReflect

func (x *GetSentFromUidResponse) ProtoReflect() protoreflect.Message

func (*GetSentFromUidResponse) Reset

func (x *GetSentFromUidResponse) Reset()

func (*GetSentFromUidResponse) String

func (x *GetSentFromUidResponse) String() string

type PeekServiceRequest

type PeekServiceRequest struct {
	Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	Arg1 int64 `protobuf:"varint,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
	// contains filtered or unexported fields
}

func (*PeekServiceRequest) Descriptor deprecated

func (*PeekServiceRequest) Descriptor() ([]byte, []int)

Deprecated: Use PeekServiceRequest.ProtoReflect.Descriptor instead.

func (*PeekServiceRequest) GetArg0

func (x *PeekServiceRequest) GetArg0() int64

func (*PeekServiceRequest) GetArg1

func (x *PeekServiceRequest) GetArg1() int64

func (*PeekServiceRequest) ProtoMessage

func (*PeekServiceRequest) ProtoMessage()

func (*PeekServiceRequest) ProtoReflect

func (x *PeekServiceRequest) ProtoReflect() protoreflect.Message

func (*PeekServiceRequest) Reset

func (x *PeekServiceRequest) Reset()

func (*PeekServiceRequest) String

func (x *PeekServiceRequest) String() string

type PeekServiceResponse

type PeekServiceResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*PeekServiceResponse) Descriptor deprecated

func (*PeekServiceResponse) Descriptor() ([]byte, []int)

Deprecated: Use PeekServiceResponse.ProtoReflect.Descriptor instead.

func (*PeekServiceResponse) GetResult

func (x *PeekServiceResponse) GetResult() int64

func (*PeekServiceResponse) ProtoMessage

func (*PeekServiceResponse) ProtoMessage()

func (*PeekServiceResponse) ProtoReflect

func (x *PeekServiceResponse) ProtoReflect() protoreflect.Message

func (*PeekServiceResponse) Reset

func (x *PeekServiceResponse) Reset()

func (*PeekServiceResponse) String

func (x *PeekServiceResponse) String() string

type UnimplementedBroadcastReceiverServiceServer

type UnimplementedBroadcastReceiverServiceServer struct{}

UnimplementedBroadcastReceiverServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedBroadcastReceiverServiceServer) GetSentFromPackage

func (UnimplementedBroadcastReceiverServiceServer) GetSentFromUid

func (UnimplementedBroadcastReceiverServiceServer) PeekService

type UnsafeBroadcastReceiverServiceServer

type UnsafeBroadcastReceiverServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeBroadcastReceiverServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to BroadcastReceiverServiceServer will result in compilation errors.

Jump to