credentials

package
v0.0.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 22, 2026 License: CC0-1.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

const (
	GetCredentialRequestBuilderService_AddCredentialOption_FullMethodName = "/credentials.GetCredentialRequestBuilderService/AddCredentialOption"
	GetCredentialRequestBuilderService_Build_FullMethodName               = "/credentials.GetCredentialRequestBuilderService/Build"
)
const (
	PasswordCredentialService_ID_FullMethodName       = "/credentials.PasswordCredentialService/ID"
	PasswordCredentialService_Password_FullMethodName = "/credentials.PasswordCredentialService/Password"
)
const (
	ManagerService_CreateManagerRaw_FullMethodName = "/credentials.ManagerService/CreateManagerRaw"
)
const (
	PublicKeyCredentialService_AuthResponseJSON_FullMethodName = "/credentials.PublicKeyCredentialService/AuthResponseJSON"
)

Variables

var File_proto_credentials_credentials_proto protoreflect.FileDescriptor
var GetCredentialRequestBuilderService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "credentials.GetCredentialRequestBuilderService",
	HandlerType: (*GetCredentialRequestBuilderServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "AddCredentialOption",
			Handler:    _GetCredentialRequestBuilderService_AddCredentialOption_Handler,
		},
		{
			MethodName: "Build",
			Handler:    _GetCredentialRequestBuilderService_Build_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/credentials/credentials.proto",
}

GetCredentialRequestBuilderService_ServiceDesc is the grpc.ServiceDesc for GetCredentialRequestBuilderService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var ManagerService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "credentials.ManagerService",
	HandlerType: (*ManagerServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "CreateManagerRaw",
			Handler:    _ManagerService_CreateManagerRaw_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/credentials/credentials.proto",
}

ManagerService_ServiceDesc is the grpc.ServiceDesc for ManagerService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var PasswordCredentialService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "credentials.PasswordCredentialService",
	HandlerType: (*PasswordCredentialServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "ID",
			Handler:    _PasswordCredentialService_ID_Handler,
		},
		{
			MethodName: "Password",
			Handler:    _PasswordCredentialService_Password_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/credentials/credentials.proto",
}

PasswordCredentialService_ServiceDesc is the grpc.ServiceDesc for PasswordCredentialService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var PublicKeyCredentialService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "credentials.PublicKeyCredentialService",
	HandlerType: (*PublicKeyCredentialServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "AuthResponseJSON",
			Handler:    _PublicKeyCredentialService_AuthResponseJSON_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/credentials/credentials.proto",
}

PublicKeyCredentialService_ServiceDesc is the grpc.ServiceDesc for PublicKeyCredentialService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterManagerServiceServer

func RegisterManagerServiceServer(s grpc.ServiceRegistrar, srv ManagerServiceServer)

func RegisterPasswordCredentialServiceServer added in v0.0.4

func RegisterPasswordCredentialServiceServer(s grpc.ServiceRegistrar, srv PasswordCredentialServiceServer)

func RegisterPublicKeyCredentialServiceServer added in v0.0.4

func RegisterPublicKeyCredentialServiceServer(s grpc.ServiceRegistrar, srv PublicKeyCredentialServiceServer)

Types

type AddCredentialOptionRequest

type AddCredentialOptionRequest struct {
	Option int64 `protobuf:"varint,1,opt,name=option,proto3" json:"option,omitempty"`
	// contains filtered or unexported fields
}

func (*AddCredentialOptionRequest) Descriptor deprecated

func (*AddCredentialOptionRequest) Descriptor() ([]byte, []int)

Deprecated: Use AddCredentialOptionRequest.ProtoReflect.Descriptor instead.

func (*AddCredentialOptionRequest) GetOption

func (x *AddCredentialOptionRequest) GetOption() int64

func (*AddCredentialOptionRequest) ProtoMessage

func (*AddCredentialOptionRequest) ProtoMessage()

func (*AddCredentialOptionRequest) ProtoReflect

func (*AddCredentialOptionRequest) Reset

func (x *AddCredentialOptionRequest) Reset()

func (*AddCredentialOptionRequest) String

func (x *AddCredentialOptionRequest) String() string

type AddCredentialOptionResponse

type AddCredentialOptionResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*AddCredentialOptionResponse) Descriptor deprecated

func (*AddCredentialOptionResponse) Descriptor() ([]byte, []int)

Deprecated: Use AddCredentialOptionResponse.ProtoReflect.Descriptor instead.

func (*AddCredentialOptionResponse) GetResult

func (x *AddCredentialOptionResponse) GetResult() int64

func (*AddCredentialOptionResponse) ProtoMessage

func (*AddCredentialOptionResponse) ProtoMessage()

func (*AddCredentialOptionResponse) ProtoReflect

func (*AddCredentialOptionResponse) Reset

func (x *AddCredentialOptionResponse) Reset()

func (*AddCredentialOptionResponse) String

func (x *AddCredentialOptionResponse) String() string

type AuthResponseJSONRequest added in v0.0.4

type AuthResponseJSONRequest struct {
	// contains filtered or unexported fields
}

func (*AuthResponseJSONRequest) Descriptor deprecated added in v0.0.4

func (*AuthResponseJSONRequest) Descriptor() ([]byte, []int)

Deprecated: Use AuthResponseJSONRequest.ProtoReflect.Descriptor instead.

func (*AuthResponseJSONRequest) ProtoMessage added in v0.0.4

func (*AuthResponseJSONRequest) ProtoMessage()

func (*AuthResponseJSONRequest) ProtoReflect added in v0.0.4

func (x *AuthResponseJSONRequest) ProtoReflect() protoreflect.Message

func (*AuthResponseJSONRequest) Reset added in v0.0.4

func (x *AuthResponseJSONRequest) Reset()

func (*AuthResponseJSONRequest) String added in v0.0.4

func (x *AuthResponseJSONRequest) String() string

type AuthResponseJSONResponse added in v0.0.4

type AuthResponseJSONResponse struct {
	Result string `protobuf:"bytes,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*AuthResponseJSONResponse) Descriptor deprecated added in v0.0.4

func (*AuthResponseJSONResponse) Descriptor() ([]byte, []int)

Deprecated: Use AuthResponseJSONResponse.ProtoReflect.Descriptor instead.

func (*AuthResponseJSONResponse) GetResult added in v0.0.4

func (x *AuthResponseJSONResponse) GetResult() string

func (*AuthResponseJSONResponse) ProtoMessage added in v0.0.4

func (*AuthResponseJSONResponse) ProtoMessage()

func (*AuthResponseJSONResponse) ProtoReflect added in v0.0.4

func (x *AuthResponseJSONResponse) ProtoReflect() protoreflect.Message

func (*AuthResponseJSONResponse) Reset added in v0.0.4

func (x *AuthResponseJSONResponse) Reset()

func (*AuthResponseJSONResponse) String added in v0.0.4

func (x *AuthResponseJSONResponse) String() string

type BuildRequest

type BuildRequest struct {
	// contains filtered or unexported fields
}

func (*BuildRequest) Descriptor deprecated

func (*BuildRequest) Descriptor() ([]byte, []int)

Deprecated: Use BuildRequest.ProtoReflect.Descriptor instead.

func (*BuildRequest) ProtoMessage

func (*BuildRequest) ProtoMessage()

func (*BuildRequest) ProtoReflect

func (x *BuildRequest) ProtoReflect() protoreflect.Message

func (*BuildRequest) Reset

func (x *BuildRequest) Reset()

func (*BuildRequest) String

func (x *BuildRequest) String() string

type BuildResponse

type BuildResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*BuildResponse) Descriptor deprecated

func (*BuildResponse) Descriptor() ([]byte, []int)

Deprecated: Use BuildResponse.ProtoReflect.Descriptor instead.

func (*BuildResponse) GetResult

func (x *BuildResponse) GetResult() int64

func (*BuildResponse) ProtoMessage

func (*BuildResponse) ProtoMessage()

func (*BuildResponse) ProtoReflect

func (x *BuildResponse) ProtoReflect() protoreflect.Message

func (*BuildResponse) Reset

func (x *BuildResponse) Reset()

func (*BuildResponse) String

func (x *BuildResponse) String() string

type CreateManagerRawRequest

type CreateManagerRawRequest struct {
	Context int64 `protobuf:"varint,1,opt,name=context,proto3" json:"context,omitempty"`
	// contains filtered or unexported fields
}

func (*CreateManagerRawRequest) Descriptor deprecated

func (*CreateManagerRawRequest) Descriptor() ([]byte, []int)

Deprecated: Use CreateManagerRawRequest.ProtoReflect.Descriptor instead.

func (*CreateManagerRawRequest) GetContext added in v0.0.4

func (x *CreateManagerRawRequest) GetContext() int64

func (*CreateManagerRawRequest) ProtoMessage

func (*CreateManagerRawRequest) ProtoMessage()

func (*CreateManagerRawRequest) ProtoReflect

func (x *CreateManagerRawRequest) ProtoReflect() protoreflect.Message

func (*CreateManagerRawRequest) Reset

func (x *CreateManagerRawRequest) Reset()

func (*CreateManagerRawRequest) String

func (x *CreateManagerRawRequest) String() string

type CreateManagerRawResponse

type CreateManagerRawResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*CreateManagerRawResponse) Descriptor deprecated

func (*CreateManagerRawResponse) Descriptor() ([]byte, []int)

Deprecated: Use CreateManagerRawResponse.ProtoReflect.Descriptor instead.

func (*CreateManagerRawResponse) GetResult

func (x *CreateManagerRawResponse) GetResult() int64

func (*CreateManagerRawResponse) ProtoMessage

func (*CreateManagerRawResponse) ProtoMessage()

func (*CreateManagerRawResponse) ProtoReflect

func (x *CreateManagerRawResponse) ProtoReflect() protoreflect.Message

func (*CreateManagerRawResponse) Reset

func (x *CreateManagerRawResponse) Reset()

func (*CreateManagerRawResponse) String

func (x *CreateManagerRawResponse) String() string

type GetCredentialRequestBuilderServiceClient

type GetCredentialRequestBuilderServiceClient interface {
	AddCredentialOption(ctx context.Context, in *AddCredentialOptionRequest, opts ...grpc.CallOption) (*AddCredentialOptionResponse, error)
	Build(ctx context.Context, in *BuildRequest, opts ...grpc.CallOption) (*BuildResponse, error)
}

GetCredentialRequestBuilderServiceClient is the client API for GetCredentialRequestBuilderService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type GetCredentialRequestBuilderServiceServer

type GetCredentialRequestBuilderServiceServer interface {
	AddCredentialOption(context.Context, *AddCredentialOptionRequest) (*AddCredentialOptionResponse, error)
	Build(context.Context, *BuildRequest) (*BuildResponse, error)
	// contains filtered or unexported methods
}

GetCredentialRequestBuilderServiceServer is the server API for GetCredentialRequestBuilderService service. All implementations must embed UnimplementedGetCredentialRequestBuilderServiceServer for forward compatibility.

type IDRequest added in v0.0.4

type IDRequest struct {
	// contains filtered or unexported fields
}

func (*IDRequest) Descriptor deprecated added in v0.0.4

func (*IDRequest) Descriptor() ([]byte, []int)

Deprecated: Use IDRequest.ProtoReflect.Descriptor instead.

func (*IDRequest) ProtoMessage added in v0.0.4

func (*IDRequest) ProtoMessage()

func (*IDRequest) ProtoReflect added in v0.0.4

func (x *IDRequest) ProtoReflect() protoreflect.Message

func (*IDRequest) Reset added in v0.0.4

func (x *IDRequest) Reset()

func (*IDRequest) String added in v0.0.4

func (x *IDRequest) String() string

type IDResponse added in v0.0.4

type IDResponse struct {
	Result string `protobuf:"bytes,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*IDResponse) Descriptor deprecated added in v0.0.4

func (*IDResponse) Descriptor() ([]byte, []int)

Deprecated: Use IDResponse.ProtoReflect.Descriptor instead.

func (*IDResponse) GetResult added in v0.0.4

func (x *IDResponse) GetResult() string

func (*IDResponse) ProtoMessage added in v0.0.4

func (*IDResponse) ProtoMessage()

func (*IDResponse) ProtoReflect added in v0.0.4

func (x *IDResponse) ProtoReflect() protoreflect.Message

func (*IDResponse) Reset added in v0.0.4

func (x *IDResponse) Reset()

func (*IDResponse) String added in v0.0.4

func (x *IDResponse) String() string

type ManagerServiceClient

type ManagerServiceClient interface {
	CreateManagerRaw(ctx context.Context, in *CreateManagerRawRequest, opts ...grpc.CallOption) (*CreateManagerRawResponse, error)
}

ManagerServiceClient is the client API for ManagerService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type ManagerServiceServer

type ManagerServiceServer interface {
	CreateManagerRaw(context.Context, *CreateManagerRawRequest) (*CreateManagerRawResponse, error)
	// contains filtered or unexported methods
}

ManagerServiceServer is the server API for ManagerService service. All implementations must embed UnimplementedManagerServiceServer for forward compatibility.

type PasswordCredentialServiceClient added in v0.0.4

type PasswordCredentialServiceClient interface {
	ID(ctx context.Context, in *IDRequest, opts ...grpc.CallOption) (*IDResponse, error)
	Password(ctx context.Context, in *PasswordRequest, opts ...grpc.CallOption) (*PasswordResponse, error)
}

PasswordCredentialServiceClient is the client API for PasswordCredentialService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

func NewPasswordCredentialServiceClient added in v0.0.4

func NewPasswordCredentialServiceClient(cc grpc.ClientConnInterface) PasswordCredentialServiceClient

type PasswordCredentialServiceServer added in v0.0.4

type PasswordCredentialServiceServer interface {
	ID(context.Context, *IDRequest) (*IDResponse, error)
	Password(context.Context, *PasswordRequest) (*PasswordResponse, error)
	// contains filtered or unexported methods
}

PasswordCredentialServiceServer is the server API for PasswordCredentialService service. All implementations must embed UnimplementedPasswordCredentialServiceServer for forward compatibility.

type PasswordRequest added in v0.0.4

type PasswordRequest struct {
	// contains filtered or unexported fields
}

func (*PasswordRequest) Descriptor deprecated added in v0.0.4

func (*PasswordRequest) Descriptor() ([]byte, []int)

Deprecated: Use PasswordRequest.ProtoReflect.Descriptor instead.

func (*PasswordRequest) ProtoMessage added in v0.0.4

func (*PasswordRequest) ProtoMessage()

func (*PasswordRequest) ProtoReflect added in v0.0.4

func (x *PasswordRequest) ProtoReflect() protoreflect.Message

func (*PasswordRequest) Reset added in v0.0.4

func (x *PasswordRequest) Reset()

func (*PasswordRequest) String added in v0.0.4

func (x *PasswordRequest) String() string

type PasswordResponse added in v0.0.4

type PasswordResponse struct {
	Result string `protobuf:"bytes,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*PasswordResponse) Descriptor deprecated added in v0.0.4

func (*PasswordResponse) Descriptor() ([]byte, []int)

Deprecated: Use PasswordResponse.ProtoReflect.Descriptor instead.

func (*PasswordResponse) GetResult added in v0.0.4

func (x *PasswordResponse) GetResult() string

func (*PasswordResponse) ProtoMessage added in v0.0.4

func (*PasswordResponse) ProtoMessage()

func (*PasswordResponse) ProtoReflect added in v0.0.4

func (x *PasswordResponse) ProtoReflect() protoreflect.Message

func (*PasswordResponse) Reset added in v0.0.4

func (x *PasswordResponse) Reset()

func (*PasswordResponse) String added in v0.0.4

func (x *PasswordResponse) String() string

type PublicKeyCredentialServiceClient added in v0.0.4

type PublicKeyCredentialServiceClient interface {
	AuthResponseJSON(ctx context.Context, in *AuthResponseJSONRequest, opts ...grpc.CallOption) (*AuthResponseJSONResponse, error)
}

PublicKeyCredentialServiceClient is the client API for PublicKeyCredentialService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

func NewPublicKeyCredentialServiceClient added in v0.0.4

func NewPublicKeyCredentialServiceClient(cc grpc.ClientConnInterface) PublicKeyCredentialServiceClient

type PublicKeyCredentialServiceServer added in v0.0.4

type PublicKeyCredentialServiceServer interface {
	AuthResponseJSON(context.Context, *AuthResponseJSONRequest) (*AuthResponseJSONResponse, error)
	// contains filtered or unexported methods
}

PublicKeyCredentialServiceServer is the server API for PublicKeyCredentialService service. All implementations must embed UnimplementedPublicKeyCredentialServiceServer for forward compatibility.

type UnimplementedGetCredentialRequestBuilderServiceServer

type UnimplementedGetCredentialRequestBuilderServiceServer struct{}

UnimplementedGetCredentialRequestBuilderServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedGetCredentialRequestBuilderServiceServer) AddCredentialOption

func (UnimplementedGetCredentialRequestBuilderServiceServer) Build

type UnimplementedManagerServiceServer

type UnimplementedManagerServiceServer struct{}

UnimplementedManagerServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedManagerServiceServer) CreateManagerRaw

type UnimplementedPasswordCredentialServiceServer added in v0.0.4

type UnimplementedPasswordCredentialServiceServer struct{}

UnimplementedPasswordCredentialServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedPasswordCredentialServiceServer) ID added in v0.0.4

func (UnimplementedPasswordCredentialServiceServer) Password added in v0.0.4

type UnimplementedPublicKeyCredentialServiceServer added in v0.0.4

type UnimplementedPublicKeyCredentialServiceServer struct{}

UnimplementedPublicKeyCredentialServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedPublicKeyCredentialServiceServer) AuthResponseJSON added in v0.0.4

type UnsafeGetCredentialRequestBuilderServiceServer

type UnsafeGetCredentialRequestBuilderServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeGetCredentialRequestBuilderServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to GetCredentialRequestBuilderServiceServer will result in compilation errors.

type UnsafeManagerServiceServer

type UnsafeManagerServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeManagerServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ManagerServiceServer will result in compilation errors.

type UnsafePasswordCredentialServiceServer added in v0.0.4

type UnsafePasswordCredentialServiceServer interface {
	// contains filtered or unexported methods
}

UnsafePasswordCredentialServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to PasswordCredentialServiceServer will result in compilation errors.

type UnsafePublicKeyCredentialServiceServer added in v0.0.4

type UnsafePublicKeyCredentialServiceServer interface {
	// contains filtered or unexported methods
}

UnsafePublicKeyCredentialServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to PublicKeyCredentialServiceServer will result in compilation errors.

Jump to