displayhash

package
v0.0.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 29, 2026 License: CC0-1.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

const (
	VerifiedDisplayHashService_NewVerifiedDisplayHash_FullMethodName = "/displayhash.VerifiedDisplayHashService/NewVerifiedDisplayHash"
	VerifiedDisplayHashService_DescribeContents_FullMethodName       = "/displayhash.VerifiedDisplayHashService/DescribeContents"
	VerifiedDisplayHashService_GetBoundsInWindow_FullMethodName      = "/displayhash.VerifiedDisplayHashService/GetBoundsInWindow"
	VerifiedDisplayHashService_GetHashAlgorithm_FullMethodName       = "/displayhash.VerifiedDisplayHashService/GetHashAlgorithm"
	VerifiedDisplayHashService_GetImageHash_FullMethodName           = "/displayhash.VerifiedDisplayHashService/GetImageHash"
	VerifiedDisplayHashService_GetTimeMillis_FullMethodName          = "/displayhash.VerifiedDisplayHashService/GetTimeMillis"
	VerifiedDisplayHashService_ToString_FullMethodName               = "/displayhash.VerifiedDisplayHashService/ToString"
	VerifiedDisplayHashService_WriteToParcel_FullMethodName          = "/displayhash.VerifiedDisplayHashService/WriteToParcel"
)
const (
	DisplayHashService_DescribeContents_FullMethodName = "/displayhash.DisplayHashService/DescribeContents"
	DisplayHashService_ToString_FullMethodName         = "/displayhash.DisplayHashService/ToString"
	DisplayHashService_WriteToParcel_FullMethodName    = "/displayhash.DisplayHashService/WriteToParcel"
)
const (
	DisplayHashResultCallbackService_OnDisplayHashError_FullMethodName  = "/displayhash.DisplayHashResultCallbackService/OnDisplayHashError"
	DisplayHashResultCallbackService_OnDisplayHashResult_FullMethodName = "/displayhash.DisplayHashResultCallbackService/OnDisplayHashResult"
)
const (
	DisplayHashManagerService_GetSupportedHashAlgorithms_FullMethodName = "/displayhash.DisplayHashManagerService/GetSupportedHashAlgorithms"
	DisplayHashManagerService_VerifyDisplayHash_FullMethodName          = "/displayhash.DisplayHashManagerService/VerifyDisplayHash"
)

Variables

var DisplayHashManagerService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "displayhash.DisplayHashManagerService",
	HandlerType: (*DisplayHashManagerServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "GetSupportedHashAlgorithms",
			Handler:    _DisplayHashManagerService_GetSupportedHashAlgorithms_Handler,
		},
		{
			MethodName: "VerifyDisplayHash",
			Handler:    _DisplayHashManagerService_VerifyDisplayHash_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/displayhash/displayhash.proto",
}

DisplayHashManagerService_ServiceDesc is the grpc.ServiceDesc for DisplayHashManagerService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var DisplayHashResultCallbackService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "displayhash.DisplayHashResultCallbackService",
	HandlerType: (*DisplayHashResultCallbackServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "OnDisplayHashError",
			Handler:    _DisplayHashResultCallbackService_OnDisplayHashError_Handler,
		},
		{
			MethodName: "OnDisplayHashResult",
			Handler:    _DisplayHashResultCallbackService_OnDisplayHashResult_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/displayhash/displayhash.proto",
}

DisplayHashResultCallbackService_ServiceDesc is the grpc.ServiceDesc for DisplayHashResultCallbackService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var DisplayHashService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "displayhash.DisplayHashService",
	HandlerType: (*DisplayHashServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "DescribeContents",
			Handler:    _DisplayHashService_DescribeContents_Handler,
		},
		{
			MethodName: "ToString",
			Handler:    _DisplayHashService_ToString_Handler,
		},
		{
			MethodName: "WriteToParcel",
			Handler:    _DisplayHashService_WriteToParcel_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/displayhash/displayhash.proto",
}

DisplayHashService_ServiceDesc is the grpc.ServiceDesc for DisplayHashService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var File_proto_displayhash_displayhash_proto protoreflect.FileDescriptor
var VerifiedDisplayHashService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "displayhash.VerifiedDisplayHashService",
	HandlerType: (*VerifiedDisplayHashServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "NewVerifiedDisplayHash",
			Handler:    _VerifiedDisplayHashService_NewVerifiedDisplayHash_Handler,
		},
		{
			MethodName: "DescribeContents",
			Handler:    _VerifiedDisplayHashService_DescribeContents_Handler,
		},
		{
			MethodName: "GetBoundsInWindow",
			Handler:    _VerifiedDisplayHashService_GetBoundsInWindow_Handler,
		},
		{
			MethodName: "GetHashAlgorithm",
			Handler:    _VerifiedDisplayHashService_GetHashAlgorithm_Handler,
		},
		{
			MethodName: "GetImageHash",
			Handler:    _VerifiedDisplayHashService_GetImageHash_Handler,
		},
		{
			MethodName: "GetTimeMillis",
			Handler:    _VerifiedDisplayHashService_GetTimeMillis_Handler,
		},
		{
			MethodName: "ToString",
			Handler:    _VerifiedDisplayHashService_ToString_Handler,
		},
		{
			MethodName: "WriteToParcel",
			Handler:    _VerifiedDisplayHashService_WriteToParcel_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/displayhash/displayhash.proto",
}

VerifiedDisplayHashService_ServiceDesc is the grpc.ServiceDesc for VerifiedDisplayHashService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterDisplayHashManagerServiceServer

func RegisterDisplayHashManagerServiceServer(s grpc.ServiceRegistrar, srv DisplayHashManagerServiceServer)

func RegisterDisplayHashResultCallbackServiceServer

func RegisterDisplayHashResultCallbackServiceServer(s grpc.ServiceRegistrar, srv DisplayHashResultCallbackServiceServer)

func RegisterDisplayHashServiceServer

func RegisterDisplayHashServiceServer(s grpc.ServiceRegistrar, srv DisplayHashServiceServer)

func RegisterVerifiedDisplayHashServiceServer

func RegisterVerifiedDisplayHashServiceServer(s grpc.ServiceRegistrar, srv VerifiedDisplayHashServiceServer)

Types

type DescribeContentsRequest

type DescribeContentsRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	// contains filtered or unexported fields
}

func (*DescribeContentsRequest) Descriptor deprecated

func (*DescribeContentsRequest) Descriptor() ([]byte, []int)

Deprecated: Use DescribeContentsRequest.ProtoReflect.Descriptor instead.

func (*DescribeContentsRequest) GetHandle

func (x *DescribeContentsRequest) GetHandle() int64

func (*DescribeContentsRequest) ProtoMessage

func (*DescribeContentsRequest) ProtoMessage()

func (*DescribeContentsRequest) ProtoReflect

func (x *DescribeContentsRequest) ProtoReflect() protoreflect.Message

func (*DescribeContentsRequest) Reset

func (x *DescribeContentsRequest) Reset()

func (*DescribeContentsRequest) String

func (x *DescribeContentsRequest) String() string

type DescribeContentsResponse

type DescribeContentsResponse struct {
	Result int32 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*DescribeContentsResponse) Descriptor deprecated

func (*DescribeContentsResponse) Descriptor() ([]byte, []int)

Deprecated: Use DescribeContentsResponse.ProtoReflect.Descriptor instead.

func (*DescribeContentsResponse) GetResult

func (x *DescribeContentsResponse) GetResult() int32

func (*DescribeContentsResponse) ProtoMessage

func (*DescribeContentsResponse) ProtoMessage()

func (*DescribeContentsResponse) ProtoReflect

func (x *DescribeContentsResponse) ProtoReflect() protoreflect.Message

func (*DescribeContentsResponse) Reset

func (x *DescribeContentsResponse) Reset()

func (*DescribeContentsResponse) String

func (x *DescribeContentsResponse) String() string

type DisplayHashDescribeContentsRequest

type DisplayHashDescribeContentsRequest struct {
	// contains filtered or unexported fields
}

func (*DisplayHashDescribeContentsRequest) Descriptor deprecated

func (*DisplayHashDescribeContentsRequest) Descriptor() ([]byte, []int)

Deprecated: Use DisplayHashDescribeContentsRequest.ProtoReflect.Descriptor instead.

func (*DisplayHashDescribeContentsRequest) ProtoMessage

func (*DisplayHashDescribeContentsRequest) ProtoMessage()

func (*DisplayHashDescribeContentsRequest) ProtoReflect

func (*DisplayHashDescribeContentsRequest) Reset

func (*DisplayHashDescribeContentsRequest) String

type DisplayHashManagerServiceClient

type DisplayHashManagerServiceClient interface {
	GetSupportedHashAlgorithms(ctx context.Context, in *GetSupportedHashAlgorithmsRequest, opts ...grpc.CallOption) (*GetSupportedHashAlgorithmsResponse, error)
	VerifyDisplayHash(ctx context.Context, in *VerifyDisplayHashRequest, opts ...grpc.CallOption) (*VerifyDisplayHashResponse, error)
}

DisplayHashManagerServiceClient is the client API for DisplayHashManagerService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type DisplayHashManagerServiceServer

type DisplayHashManagerServiceServer interface {
	GetSupportedHashAlgorithms(context.Context, *GetSupportedHashAlgorithmsRequest) (*GetSupportedHashAlgorithmsResponse, error)
	VerifyDisplayHash(context.Context, *VerifyDisplayHashRequest) (*VerifyDisplayHashResponse, error)
	// contains filtered or unexported methods
}

DisplayHashManagerServiceServer is the server API for DisplayHashManagerService service. All implementations must embed UnimplementedDisplayHashManagerServiceServer for forward compatibility.

type DisplayHashResultCallbackServiceClient

type DisplayHashResultCallbackServiceClient interface {
	OnDisplayHashError(ctx context.Context, in *OnDisplayHashErrorRequest, opts ...grpc.CallOption) (*OnDisplayHashErrorResponse, error)
	OnDisplayHashResult(ctx context.Context, in *OnDisplayHashResultRequest, opts ...grpc.CallOption) (*OnDisplayHashResultResponse, error)
}

DisplayHashResultCallbackServiceClient is the client API for DisplayHashResultCallbackService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type DisplayHashResultCallbackServiceServer

type DisplayHashResultCallbackServiceServer interface {
	OnDisplayHashError(context.Context, *OnDisplayHashErrorRequest) (*OnDisplayHashErrorResponse, error)
	OnDisplayHashResult(context.Context, *OnDisplayHashResultRequest) (*OnDisplayHashResultResponse, error)
	// contains filtered or unexported methods
}

DisplayHashResultCallbackServiceServer is the server API for DisplayHashResultCallbackService service. All implementations must embed UnimplementedDisplayHashResultCallbackServiceServer for forward compatibility.

type DisplayHashServiceClient

type DisplayHashServiceClient interface {
	DescribeContents(ctx context.Context, in *DisplayHashDescribeContentsRequest, opts ...grpc.CallOption) (*DescribeContentsResponse, error)
	ToString(ctx context.Context, in *DisplayHashToStringRequest, opts ...grpc.CallOption) (*ToStringResponse, error)
	WriteToParcel(ctx context.Context, in *DisplayHashWriteToParcelRequest, opts ...grpc.CallOption) (*WriteToParcelResponse, error)
}

DisplayHashServiceClient is the client API for DisplayHashService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type DisplayHashServiceServer

type DisplayHashServiceServer interface {
	DescribeContents(context.Context, *DisplayHashDescribeContentsRequest) (*DescribeContentsResponse, error)
	ToString(context.Context, *DisplayHashToStringRequest) (*ToStringResponse, error)
	WriteToParcel(context.Context, *DisplayHashWriteToParcelRequest) (*WriteToParcelResponse, error)
	// contains filtered or unexported methods
}

DisplayHashServiceServer is the server API for DisplayHashService service. All implementations must embed UnimplementedDisplayHashServiceServer for forward compatibility.

type DisplayHashToStringRequest

type DisplayHashToStringRequest struct {
	// contains filtered or unexported fields
}

func (*DisplayHashToStringRequest) Descriptor deprecated

func (*DisplayHashToStringRequest) Descriptor() ([]byte, []int)

Deprecated: Use DisplayHashToStringRequest.ProtoReflect.Descriptor instead.

func (*DisplayHashToStringRequest) ProtoMessage

func (*DisplayHashToStringRequest) ProtoMessage()

func (*DisplayHashToStringRequest) ProtoReflect

func (*DisplayHashToStringRequest) Reset

func (x *DisplayHashToStringRequest) Reset()

func (*DisplayHashToStringRequest) String

func (x *DisplayHashToStringRequest) String() string

type DisplayHashWriteToParcelRequest

type DisplayHashWriteToParcelRequest struct {
	Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	Arg1 int32 `protobuf:"varint,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
	// contains filtered or unexported fields
}

func (*DisplayHashWriteToParcelRequest) Descriptor deprecated

func (*DisplayHashWriteToParcelRequest) Descriptor() ([]byte, []int)

Deprecated: Use DisplayHashWriteToParcelRequest.ProtoReflect.Descriptor instead.

func (*DisplayHashWriteToParcelRequest) GetArg0

func (*DisplayHashWriteToParcelRequest) GetArg1

func (*DisplayHashWriteToParcelRequest) ProtoMessage

func (*DisplayHashWriteToParcelRequest) ProtoMessage()

func (*DisplayHashWriteToParcelRequest) ProtoReflect

func (*DisplayHashWriteToParcelRequest) Reset

func (*DisplayHashWriteToParcelRequest) String

type GetBoundsInWindowRequest

type GetBoundsInWindowRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	// contains filtered or unexported fields
}

func (*GetBoundsInWindowRequest) Descriptor deprecated

func (*GetBoundsInWindowRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetBoundsInWindowRequest.ProtoReflect.Descriptor instead.

func (*GetBoundsInWindowRequest) GetHandle

func (x *GetBoundsInWindowRequest) GetHandle() int64

func (*GetBoundsInWindowRequest) ProtoMessage

func (*GetBoundsInWindowRequest) ProtoMessage()

func (*GetBoundsInWindowRequest) ProtoReflect

func (x *GetBoundsInWindowRequest) ProtoReflect() protoreflect.Message

func (*GetBoundsInWindowRequest) Reset

func (x *GetBoundsInWindowRequest) Reset()

func (*GetBoundsInWindowRequest) String

func (x *GetBoundsInWindowRequest) String() string

type GetBoundsInWindowResponse

type GetBoundsInWindowResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetBoundsInWindowResponse) Descriptor deprecated

func (*GetBoundsInWindowResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetBoundsInWindowResponse.ProtoReflect.Descriptor instead.

func (*GetBoundsInWindowResponse) GetResult

func (x *GetBoundsInWindowResponse) GetResult() int64

func (*GetBoundsInWindowResponse) ProtoMessage

func (*GetBoundsInWindowResponse) ProtoMessage()

func (*GetBoundsInWindowResponse) ProtoReflect

func (*GetBoundsInWindowResponse) Reset

func (x *GetBoundsInWindowResponse) Reset()

func (*GetBoundsInWindowResponse) String

func (x *GetBoundsInWindowResponse) String() string

type GetHashAlgorithmRequest

type GetHashAlgorithmRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	// contains filtered or unexported fields
}

func (*GetHashAlgorithmRequest) Descriptor deprecated

func (*GetHashAlgorithmRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetHashAlgorithmRequest.ProtoReflect.Descriptor instead.

func (*GetHashAlgorithmRequest) GetHandle

func (x *GetHashAlgorithmRequest) GetHandle() int64

func (*GetHashAlgorithmRequest) ProtoMessage

func (*GetHashAlgorithmRequest) ProtoMessage()

func (*GetHashAlgorithmRequest) ProtoReflect

func (x *GetHashAlgorithmRequest) ProtoReflect() protoreflect.Message

func (*GetHashAlgorithmRequest) Reset

func (x *GetHashAlgorithmRequest) Reset()

func (*GetHashAlgorithmRequest) String

func (x *GetHashAlgorithmRequest) String() string

type GetHashAlgorithmResponse

type GetHashAlgorithmResponse struct {
	Result string `protobuf:"bytes,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetHashAlgorithmResponse) Descriptor deprecated

func (*GetHashAlgorithmResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetHashAlgorithmResponse.ProtoReflect.Descriptor instead.

func (*GetHashAlgorithmResponse) GetResult

func (x *GetHashAlgorithmResponse) GetResult() string

func (*GetHashAlgorithmResponse) ProtoMessage

func (*GetHashAlgorithmResponse) ProtoMessage()

func (*GetHashAlgorithmResponse) ProtoReflect

func (x *GetHashAlgorithmResponse) ProtoReflect() protoreflect.Message

func (*GetHashAlgorithmResponse) Reset

func (x *GetHashAlgorithmResponse) Reset()

func (*GetHashAlgorithmResponse) String

func (x *GetHashAlgorithmResponse) String() string

type GetImageHashRequest

type GetImageHashRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	// contains filtered or unexported fields
}

func (*GetImageHashRequest) Descriptor deprecated

func (*GetImageHashRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetImageHashRequest.ProtoReflect.Descriptor instead.

func (*GetImageHashRequest) GetHandle

func (x *GetImageHashRequest) GetHandle() int64

func (*GetImageHashRequest) ProtoMessage

func (*GetImageHashRequest) ProtoMessage()

func (*GetImageHashRequest) ProtoReflect

func (x *GetImageHashRequest) ProtoReflect() protoreflect.Message

func (*GetImageHashRequest) Reset

func (x *GetImageHashRequest) Reset()

func (*GetImageHashRequest) String

func (x *GetImageHashRequest) String() string

type GetImageHashResponse

type GetImageHashResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetImageHashResponse) Descriptor deprecated

func (*GetImageHashResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetImageHashResponse.ProtoReflect.Descriptor instead.

func (*GetImageHashResponse) GetResult

func (x *GetImageHashResponse) GetResult() int64

func (*GetImageHashResponse) ProtoMessage

func (*GetImageHashResponse) ProtoMessage()

func (*GetImageHashResponse) ProtoReflect

func (x *GetImageHashResponse) ProtoReflect() protoreflect.Message

func (*GetImageHashResponse) Reset

func (x *GetImageHashResponse) Reset()

func (*GetImageHashResponse) String

func (x *GetImageHashResponse) String() string

type GetSupportedHashAlgorithmsRequest

type GetSupportedHashAlgorithmsRequest struct {
	// contains filtered or unexported fields
}

func (*GetSupportedHashAlgorithmsRequest) Descriptor deprecated

func (*GetSupportedHashAlgorithmsRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetSupportedHashAlgorithmsRequest.ProtoReflect.Descriptor instead.

func (*GetSupportedHashAlgorithmsRequest) ProtoMessage

func (*GetSupportedHashAlgorithmsRequest) ProtoMessage()

func (*GetSupportedHashAlgorithmsRequest) ProtoReflect

func (*GetSupportedHashAlgorithmsRequest) Reset

func (*GetSupportedHashAlgorithmsRequest) String

type GetSupportedHashAlgorithmsResponse

type GetSupportedHashAlgorithmsResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetSupportedHashAlgorithmsResponse) Descriptor deprecated

func (*GetSupportedHashAlgorithmsResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetSupportedHashAlgorithmsResponse.ProtoReflect.Descriptor instead.

func (*GetSupportedHashAlgorithmsResponse) GetResult

func (*GetSupportedHashAlgorithmsResponse) ProtoMessage

func (*GetSupportedHashAlgorithmsResponse) ProtoMessage()

func (*GetSupportedHashAlgorithmsResponse) ProtoReflect

func (*GetSupportedHashAlgorithmsResponse) Reset

func (*GetSupportedHashAlgorithmsResponse) String

type GetTimeMillisRequest

type GetTimeMillisRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	// contains filtered or unexported fields
}

func (*GetTimeMillisRequest) Descriptor deprecated

func (*GetTimeMillisRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetTimeMillisRequest.ProtoReflect.Descriptor instead.

func (*GetTimeMillisRequest) GetHandle

func (x *GetTimeMillisRequest) GetHandle() int64

func (*GetTimeMillisRequest) ProtoMessage

func (*GetTimeMillisRequest) ProtoMessage()

func (*GetTimeMillisRequest) ProtoReflect

func (x *GetTimeMillisRequest) ProtoReflect() protoreflect.Message

func (*GetTimeMillisRequest) Reset

func (x *GetTimeMillisRequest) Reset()

func (*GetTimeMillisRequest) String

func (x *GetTimeMillisRequest) String() string

type GetTimeMillisResponse

type GetTimeMillisResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetTimeMillisResponse) Descriptor deprecated

func (*GetTimeMillisResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetTimeMillisResponse.ProtoReflect.Descriptor instead.

func (*GetTimeMillisResponse) GetResult

func (x *GetTimeMillisResponse) GetResult() int64

func (*GetTimeMillisResponse) ProtoMessage

func (*GetTimeMillisResponse) ProtoMessage()

func (*GetTimeMillisResponse) ProtoReflect

func (x *GetTimeMillisResponse) ProtoReflect() protoreflect.Message

func (*GetTimeMillisResponse) Reset

func (x *GetTimeMillisResponse) Reset()

func (*GetTimeMillisResponse) String

func (x *GetTimeMillisResponse) String() string

type NewVerifiedDisplayHashRequest

type NewVerifiedDisplayHashRequest struct {
	Arg0 int64  `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	Arg1 int64  `protobuf:"varint,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
	Arg2 string `protobuf:"bytes,3,opt,name=arg2,proto3" json:"arg2,omitempty"`
	Arg3 int64  `protobuf:"varint,4,opt,name=arg3,proto3" json:"arg3,omitempty"`
	// contains filtered or unexported fields
}

func (*NewVerifiedDisplayHashRequest) Descriptor deprecated

func (*NewVerifiedDisplayHashRequest) Descriptor() ([]byte, []int)

Deprecated: Use NewVerifiedDisplayHashRequest.ProtoReflect.Descriptor instead.

func (*NewVerifiedDisplayHashRequest) GetArg0

func (x *NewVerifiedDisplayHashRequest) GetArg0() int64

func (*NewVerifiedDisplayHashRequest) GetArg1

func (x *NewVerifiedDisplayHashRequest) GetArg1() int64

func (*NewVerifiedDisplayHashRequest) GetArg2

func (*NewVerifiedDisplayHashRequest) GetArg3

func (x *NewVerifiedDisplayHashRequest) GetArg3() int64

func (*NewVerifiedDisplayHashRequest) ProtoMessage

func (*NewVerifiedDisplayHashRequest) ProtoMessage()

func (*NewVerifiedDisplayHashRequest) ProtoReflect

func (*NewVerifiedDisplayHashRequest) Reset

func (x *NewVerifiedDisplayHashRequest) Reset()

func (*NewVerifiedDisplayHashRequest) String

type NewVerifiedDisplayHashResponse

type NewVerifiedDisplayHashResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*NewVerifiedDisplayHashResponse) Descriptor deprecated

func (*NewVerifiedDisplayHashResponse) Descriptor() ([]byte, []int)

Deprecated: Use NewVerifiedDisplayHashResponse.ProtoReflect.Descriptor instead.

func (*NewVerifiedDisplayHashResponse) GetResult

func (x *NewVerifiedDisplayHashResponse) GetResult() int64

func (*NewVerifiedDisplayHashResponse) ProtoMessage

func (*NewVerifiedDisplayHashResponse) ProtoMessage()

func (*NewVerifiedDisplayHashResponse) ProtoReflect

func (*NewVerifiedDisplayHashResponse) Reset

func (x *NewVerifiedDisplayHashResponse) Reset()

func (*NewVerifiedDisplayHashResponse) String

type OnDisplayHashErrorRequest

type OnDisplayHashErrorRequest struct {
	Arg0 int32 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*OnDisplayHashErrorRequest) Descriptor deprecated

func (*OnDisplayHashErrorRequest) Descriptor() ([]byte, []int)

Deprecated: Use OnDisplayHashErrorRequest.ProtoReflect.Descriptor instead.

func (*OnDisplayHashErrorRequest) GetArg0

func (x *OnDisplayHashErrorRequest) GetArg0() int32

func (*OnDisplayHashErrorRequest) ProtoMessage

func (*OnDisplayHashErrorRequest) ProtoMessage()

func (*OnDisplayHashErrorRequest) ProtoReflect

func (*OnDisplayHashErrorRequest) Reset

func (x *OnDisplayHashErrorRequest) Reset()

func (*OnDisplayHashErrorRequest) String

func (x *OnDisplayHashErrorRequest) String() string

type OnDisplayHashErrorResponse

type OnDisplayHashErrorResponse struct {
	// contains filtered or unexported fields
}

func (*OnDisplayHashErrorResponse) Descriptor deprecated

func (*OnDisplayHashErrorResponse) Descriptor() ([]byte, []int)

Deprecated: Use OnDisplayHashErrorResponse.ProtoReflect.Descriptor instead.

func (*OnDisplayHashErrorResponse) ProtoMessage

func (*OnDisplayHashErrorResponse) ProtoMessage()

func (*OnDisplayHashErrorResponse) ProtoReflect

func (*OnDisplayHashErrorResponse) Reset

func (x *OnDisplayHashErrorResponse) Reset()

func (*OnDisplayHashErrorResponse) String

func (x *OnDisplayHashErrorResponse) String() string

type OnDisplayHashResultRequest

type OnDisplayHashResultRequest struct {
	Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*OnDisplayHashResultRequest) Descriptor deprecated

func (*OnDisplayHashResultRequest) Descriptor() ([]byte, []int)

Deprecated: Use OnDisplayHashResultRequest.ProtoReflect.Descriptor instead.

func (*OnDisplayHashResultRequest) GetArg0

func (x *OnDisplayHashResultRequest) GetArg0() int64

func (*OnDisplayHashResultRequest) ProtoMessage

func (*OnDisplayHashResultRequest) ProtoMessage()

func (*OnDisplayHashResultRequest) ProtoReflect

func (*OnDisplayHashResultRequest) Reset

func (x *OnDisplayHashResultRequest) Reset()

func (*OnDisplayHashResultRequest) String

func (x *OnDisplayHashResultRequest) String() string

type OnDisplayHashResultResponse

type OnDisplayHashResultResponse struct {
	// contains filtered or unexported fields
}

func (*OnDisplayHashResultResponse) Descriptor deprecated

func (*OnDisplayHashResultResponse) Descriptor() ([]byte, []int)

Deprecated: Use OnDisplayHashResultResponse.ProtoReflect.Descriptor instead.

func (*OnDisplayHashResultResponse) ProtoMessage

func (*OnDisplayHashResultResponse) ProtoMessage()

func (*OnDisplayHashResultResponse) ProtoReflect

func (*OnDisplayHashResultResponse) Reset

func (x *OnDisplayHashResultResponse) Reset()

func (*OnDisplayHashResultResponse) String

func (x *OnDisplayHashResultResponse) String() string

type ToStringRequest

type ToStringRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	// contains filtered or unexported fields
}

func (*ToStringRequest) Descriptor deprecated

func (*ToStringRequest) Descriptor() ([]byte, []int)

Deprecated: Use ToStringRequest.ProtoReflect.Descriptor instead.

func (*ToStringRequest) GetHandle

func (x *ToStringRequest) GetHandle() int64

func (*ToStringRequest) ProtoMessage

func (*ToStringRequest) ProtoMessage()

func (*ToStringRequest) ProtoReflect

func (x *ToStringRequest) ProtoReflect() protoreflect.Message

func (*ToStringRequest) Reset

func (x *ToStringRequest) Reset()

func (*ToStringRequest) String

func (x *ToStringRequest) String() string

type ToStringResponse

type ToStringResponse struct {
	Result string `protobuf:"bytes,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*ToStringResponse) Descriptor deprecated

func (*ToStringResponse) Descriptor() ([]byte, []int)

Deprecated: Use ToStringResponse.ProtoReflect.Descriptor instead.

func (*ToStringResponse) GetResult

func (x *ToStringResponse) GetResult() string

func (*ToStringResponse) ProtoMessage

func (*ToStringResponse) ProtoMessage()

func (*ToStringResponse) ProtoReflect

func (x *ToStringResponse) ProtoReflect() protoreflect.Message

func (*ToStringResponse) Reset

func (x *ToStringResponse) Reset()

func (*ToStringResponse) String

func (x *ToStringResponse) String() string

type UnimplementedDisplayHashManagerServiceServer

type UnimplementedDisplayHashManagerServiceServer struct{}

UnimplementedDisplayHashManagerServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedDisplayHashManagerServiceServer) VerifyDisplayHash

type UnimplementedDisplayHashResultCallbackServiceServer

type UnimplementedDisplayHashResultCallbackServiceServer struct{}

UnimplementedDisplayHashResultCallbackServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedDisplayHashResultCallbackServiceServer) OnDisplayHashError

func (UnimplementedDisplayHashResultCallbackServiceServer) OnDisplayHashResult

type UnimplementedDisplayHashServiceServer

type UnimplementedDisplayHashServiceServer struct{}

UnimplementedDisplayHashServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedDisplayHashServiceServer) ToString

func (UnimplementedDisplayHashServiceServer) WriteToParcel

type UnimplementedVerifiedDisplayHashServiceServer

type UnimplementedVerifiedDisplayHashServiceServer struct{}

UnimplementedVerifiedDisplayHashServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedVerifiedDisplayHashServiceServer) DescribeContents

func (UnimplementedVerifiedDisplayHashServiceServer) GetBoundsInWindow

func (UnimplementedVerifiedDisplayHashServiceServer) GetHashAlgorithm

func (UnimplementedVerifiedDisplayHashServiceServer) GetImageHash

func (UnimplementedVerifiedDisplayHashServiceServer) GetTimeMillis

func (UnimplementedVerifiedDisplayHashServiceServer) NewVerifiedDisplayHash

func (UnimplementedVerifiedDisplayHashServiceServer) ToString

func (UnimplementedVerifiedDisplayHashServiceServer) WriteToParcel

type UnsafeDisplayHashManagerServiceServer

type UnsafeDisplayHashManagerServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeDisplayHashManagerServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to DisplayHashManagerServiceServer will result in compilation errors.

type UnsafeDisplayHashResultCallbackServiceServer

type UnsafeDisplayHashResultCallbackServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeDisplayHashResultCallbackServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to DisplayHashResultCallbackServiceServer will result in compilation errors.

type UnsafeDisplayHashServiceServer

type UnsafeDisplayHashServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeDisplayHashServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to DisplayHashServiceServer will result in compilation errors.

type UnsafeVerifiedDisplayHashServiceServer

type UnsafeVerifiedDisplayHashServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeVerifiedDisplayHashServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to VerifiedDisplayHashServiceServer will result in compilation errors.

type VerifiedDisplayHashServiceClient

type VerifiedDisplayHashServiceClient interface {
	NewVerifiedDisplayHash(ctx context.Context, in *NewVerifiedDisplayHashRequest, opts ...grpc.CallOption) (*NewVerifiedDisplayHashResponse, error)
	DescribeContents(ctx context.Context, in *DescribeContentsRequest, opts ...grpc.CallOption) (*DescribeContentsResponse, error)
	GetBoundsInWindow(ctx context.Context, in *GetBoundsInWindowRequest, opts ...grpc.CallOption) (*GetBoundsInWindowResponse, error)
	GetHashAlgorithm(ctx context.Context, in *GetHashAlgorithmRequest, opts ...grpc.CallOption) (*GetHashAlgorithmResponse, error)
	GetImageHash(ctx context.Context, in *GetImageHashRequest, opts ...grpc.CallOption) (*GetImageHashResponse, error)
	GetTimeMillis(ctx context.Context, in *GetTimeMillisRequest, opts ...grpc.CallOption) (*GetTimeMillisResponse, error)
	ToString(ctx context.Context, in *ToStringRequest, opts ...grpc.CallOption) (*ToStringResponse, error)
	WriteToParcel(ctx context.Context, in *WriteToParcelRequest, opts ...grpc.CallOption) (*WriteToParcelResponse, error)
}

VerifiedDisplayHashServiceClient is the client API for VerifiedDisplayHashService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type VerifiedDisplayHashServiceServer

VerifiedDisplayHashServiceServer is the server API for VerifiedDisplayHashService service. All implementations must embed UnimplementedVerifiedDisplayHashServiceServer for forward compatibility.

type VerifyDisplayHashRequest

type VerifyDisplayHashRequest struct {
	Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*VerifyDisplayHashRequest) Descriptor deprecated

func (*VerifyDisplayHashRequest) Descriptor() ([]byte, []int)

Deprecated: Use VerifyDisplayHashRequest.ProtoReflect.Descriptor instead.

func (*VerifyDisplayHashRequest) GetArg0

func (x *VerifyDisplayHashRequest) GetArg0() int64

func (*VerifyDisplayHashRequest) ProtoMessage

func (*VerifyDisplayHashRequest) ProtoMessage()

func (*VerifyDisplayHashRequest) ProtoReflect

func (x *VerifyDisplayHashRequest) ProtoReflect() protoreflect.Message

func (*VerifyDisplayHashRequest) Reset

func (x *VerifyDisplayHashRequest) Reset()

func (*VerifyDisplayHashRequest) String

func (x *VerifyDisplayHashRequest) String() string

type VerifyDisplayHashResponse

type VerifyDisplayHashResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*VerifyDisplayHashResponse) Descriptor deprecated

func (*VerifyDisplayHashResponse) Descriptor() ([]byte, []int)

Deprecated: Use VerifyDisplayHashResponse.ProtoReflect.Descriptor instead.

func (*VerifyDisplayHashResponse) GetResult

func (x *VerifyDisplayHashResponse) GetResult() int64

func (*VerifyDisplayHashResponse) ProtoMessage

func (*VerifyDisplayHashResponse) ProtoMessage()

func (*VerifyDisplayHashResponse) ProtoReflect

func (*VerifyDisplayHashResponse) Reset

func (x *VerifyDisplayHashResponse) Reset()

func (*VerifyDisplayHashResponse) String

func (x *VerifyDisplayHashResponse) String() string

type WriteToParcelRequest

type WriteToParcelRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	Arg0   int64 `protobuf:"varint,2,opt,name=arg0,proto3" json:"arg0,omitempty"`
	Arg1   int32 `protobuf:"varint,3,opt,name=arg1,proto3" json:"arg1,omitempty"`
	// contains filtered or unexported fields
}

func (*WriteToParcelRequest) Descriptor deprecated

func (*WriteToParcelRequest) Descriptor() ([]byte, []int)

Deprecated: Use WriteToParcelRequest.ProtoReflect.Descriptor instead.

func (*WriteToParcelRequest) GetArg0

func (x *WriteToParcelRequest) GetArg0() int64

func (*WriteToParcelRequest) GetArg1

func (x *WriteToParcelRequest) GetArg1() int32

func (*WriteToParcelRequest) GetHandle

func (x *WriteToParcelRequest) GetHandle() int64

func (*WriteToParcelRequest) ProtoMessage

func (*WriteToParcelRequest) ProtoMessage()

func (*WriteToParcelRequest) ProtoReflect

func (x *WriteToParcelRequest) ProtoReflect() protoreflect.Message

func (*WriteToParcelRequest) Reset

func (x *WriteToParcelRequest) Reset()

func (*WriteToParcelRequest) String

func (x *WriteToParcelRequest) String() string

type WriteToParcelResponse

type WriteToParcelResponse struct {
	// contains filtered or unexported fields
}

func (*WriteToParcelResponse) Descriptor deprecated

func (*WriteToParcelResponse) Descriptor() ([]byte, []int)

Deprecated: Use WriteToParcelResponse.ProtoReflect.Descriptor instead.

func (*WriteToParcelResponse) ProtoMessage

func (*WriteToParcelResponse) ProtoMessage()

func (*WriteToParcelResponse) ProtoReflect

func (x *WriteToParcelResponse) ProtoReflect() protoreflect.Message

func (*WriteToParcelResponse) Reset

func (x *WriteToParcelResponse) Reset()

func (*WriteToParcelResponse) String

func (x *WriteToParcelResponse) String() string

Jump to