exceptions

package
v0.0.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 29, 2026 License: CC0-1.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

const (
	AppSearchExceptionService_NewAppSearchException_FullMethodName = "/exceptions.AppSearchExceptionService/NewAppSearchException"
	AppSearchExceptionService_GetResultCode_FullMethodName         = "/exceptions.AppSearchExceptionService/GetResultCode"
)
const (
	InvalidSelectorsExceptionService_NewInvalidSelectorsException_FullMethodName = "/exceptions.InvalidSelectorsExceptionService/NewInvalidSelectorsException"
	InvalidSelectorsExceptionService_GetIpSecPacketInfo_FullMethodName           = "/exceptions.InvalidSelectorsExceptionService/GetIpSecPacketInfo"
	InvalidSelectorsExceptionService_GetIpSecSpi_FullMethodName                  = "/exceptions.InvalidSelectorsExceptionService/GetIpSecSpi"
)
const (
	InvalidKeExceptionService_NewInvalidKeException_FullMethodName = "/exceptions.InvalidKeExceptionService/NewInvalidKeException"
	InvalidKeExceptionService_GetDhGroup_FullMethodName            = "/exceptions.InvalidKeExceptionService/GetDhGroup"
)
const (
	IkeNetworkLostExceptionService_NewIkeNetworkLostException_FullMethodName = "/exceptions.IkeNetworkLostExceptionService/NewIkeNetworkLostException"
	IkeNetworkLostExceptionService_GetNetwork_FullMethodName                 = "/exceptions.IkeNetworkLostExceptionService/GetNetwork"
)
const (
	InvalidMajorVersionExceptionService_NewInvalidMajorVersionException_FullMethodName = "/exceptions.InvalidMajorVersionExceptionService/NewInvalidMajorVersionException"
	InvalidMajorVersionExceptionService_GetMajorVersion_FullMethodName                 = "/exceptions.InvalidMajorVersionExceptionService/GetMajorVersion"
)
const (
	IkeIOExceptionService_NewIkeIOException_FullMethodName = "/exceptions.IkeIOExceptionService/NewIkeIOException"
	IkeIOExceptionService_GetCause0_FullMethodName         = "/exceptions.IkeIOExceptionService/GetCause0"
	IkeIOExceptionService_GetCause0_1_FullMethodName       = "/exceptions.IkeIOExceptionService/GetCause0_1"
)
const (
	IkeProtocolExceptionService_GetErrorType_FullMethodName = "/exceptions.IkeProtocolExceptionService/GetErrorType"
)

Variables

var AppSearchExceptionService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "exceptions.AppSearchExceptionService",
	HandlerType: (*AppSearchExceptionServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "NewAppSearchException",
			Handler:    _AppSearchExceptionService_NewAppSearchException_Handler,
		},
		{
			MethodName: "GetResultCode",
			Handler:    _AppSearchExceptionService_GetResultCode_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/exceptions/exceptions.proto",
}

AppSearchExceptionService_ServiceDesc is the grpc.ServiceDesc for AppSearchExceptionService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var File_proto_exceptions_exceptions_proto protoreflect.FileDescriptor
var IkeIOExceptionService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "exceptions.IkeIOExceptionService",
	HandlerType: (*IkeIOExceptionServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "NewIkeIOException",
			Handler:    _IkeIOExceptionService_NewIkeIOException_Handler,
		},
		{
			MethodName: "GetCause0",
			Handler:    _IkeIOExceptionService_GetCause0_Handler,
		},
		{
			MethodName: "GetCause0_1",
			Handler:    _IkeIOExceptionService_GetCause0_1_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/exceptions/exceptions.proto",
}

IkeIOExceptionService_ServiceDesc is the grpc.ServiceDesc for IkeIOExceptionService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var IkeNetworkLostExceptionService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "exceptions.IkeNetworkLostExceptionService",
	HandlerType: (*IkeNetworkLostExceptionServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "NewIkeNetworkLostException",
			Handler:    _IkeNetworkLostExceptionService_NewIkeNetworkLostException_Handler,
		},
		{
			MethodName: "GetNetwork",
			Handler:    _IkeNetworkLostExceptionService_GetNetwork_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/exceptions/exceptions.proto",
}

IkeNetworkLostExceptionService_ServiceDesc is the grpc.ServiceDesc for IkeNetworkLostExceptionService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var IkeProtocolExceptionService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "exceptions.IkeProtocolExceptionService",
	HandlerType: (*IkeProtocolExceptionServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "GetErrorType",
			Handler:    _IkeProtocolExceptionService_GetErrorType_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/exceptions/exceptions.proto",
}

IkeProtocolExceptionService_ServiceDesc is the grpc.ServiceDesc for IkeProtocolExceptionService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var InvalidKeExceptionService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "exceptions.InvalidKeExceptionService",
	HandlerType: (*InvalidKeExceptionServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "NewInvalidKeException",
			Handler:    _InvalidKeExceptionService_NewInvalidKeException_Handler,
		},
		{
			MethodName: "GetDhGroup",
			Handler:    _InvalidKeExceptionService_GetDhGroup_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/exceptions/exceptions.proto",
}

InvalidKeExceptionService_ServiceDesc is the grpc.ServiceDesc for InvalidKeExceptionService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var InvalidMajorVersionExceptionService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "exceptions.InvalidMajorVersionExceptionService",
	HandlerType: (*InvalidMajorVersionExceptionServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "NewInvalidMajorVersionException",
			Handler:    _InvalidMajorVersionExceptionService_NewInvalidMajorVersionException_Handler,
		},
		{
			MethodName: "GetMajorVersion",
			Handler:    _InvalidMajorVersionExceptionService_GetMajorVersion_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/exceptions/exceptions.proto",
}

InvalidMajorVersionExceptionService_ServiceDesc is the grpc.ServiceDesc for InvalidMajorVersionExceptionService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var InvalidSelectorsExceptionService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "exceptions.InvalidSelectorsExceptionService",
	HandlerType: (*InvalidSelectorsExceptionServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "NewInvalidSelectorsException",
			Handler:    _InvalidSelectorsExceptionService_NewInvalidSelectorsException_Handler,
		},
		{
			MethodName: "GetIpSecPacketInfo",
			Handler:    _InvalidSelectorsExceptionService_GetIpSecPacketInfo_Handler,
		},
		{
			MethodName: "GetIpSecSpi",
			Handler:    _InvalidSelectorsExceptionService_GetIpSecSpi_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/exceptions/exceptions.proto",
}

InvalidSelectorsExceptionService_ServiceDesc is the grpc.ServiceDesc for InvalidSelectorsExceptionService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterAppSearchExceptionServiceServer

func RegisterAppSearchExceptionServiceServer(s grpc.ServiceRegistrar, srv AppSearchExceptionServiceServer)

func RegisterIkeIOExceptionServiceServer

func RegisterIkeIOExceptionServiceServer(s grpc.ServiceRegistrar, srv IkeIOExceptionServiceServer)

func RegisterIkeNetworkLostExceptionServiceServer

func RegisterIkeNetworkLostExceptionServiceServer(s grpc.ServiceRegistrar, srv IkeNetworkLostExceptionServiceServer)

func RegisterIkeProtocolExceptionServiceServer

func RegisterIkeProtocolExceptionServiceServer(s grpc.ServiceRegistrar, srv IkeProtocolExceptionServiceServer)

func RegisterInvalidKeExceptionServiceServer

func RegisterInvalidKeExceptionServiceServer(s grpc.ServiceRegistrar, srv InvalidKeExceptionServiceServer)

func RegisterInvalidSelectorsExceptionServiceServer

func RegisterInvalidSelectorsExceptionServiceServer(s grpc.ServiceRegistrar, srv InvalidSelectorsExceptionServiceServer)

Types

type AppSearchExceptionServiceClient

type AppSearchExceptionServiceClient interface {
	NewAppSearchException(ctx context.Context, in *NewAppSearchExceptionRequest, opts ...grpc.CallOption) (*NewAppSearchExceptionResponse, error)
	GetResultCode(ctx context.Context, in *GetResultCodeRequest, opts ...grpc.CallOption) (*GetResultCodeResponse, error)
}

AppSearchExceptionServiceClient is the client API for AppSearchExceptionService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type AppSearchExceptionServiceServer

type AppSearchExceptionServiceServer interface {
	NewAppSearchException(context.Context, *NewAppSearchExceptionRequest) (*NewAppSearchExceptionResponse, error)
	GetResultCode(context.Context, *GetResultCodeRequest) (*GetResultCodeResponse, error)
	// contains filtered or unexported methods
}

AppSearchExceptionServiceServer is the server API for AppSearchExceptionService service. All implementations must embed UnimplementedAppSearchExceptionServiceServer for forward compatibility.

type GetCause0Request

type GetCause0Request struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	// contains filtered or unexported fields
}

func (*GetCause0Request) Descriptor deprecated

func (*GetCause0Request) Descriptor() ([]byte, []int)

Deprecated: Use GetCause0Request.ProtoReflect.Descriptor instead.

func (*GetCause0Request) GetHandle

func (x *GetCause0Request) GetHandle() int64

func (*GetCause0Request) ProtoMessage

func (*GetCause0Request) ProtoMessage()

func (*GetCause0Request) ProtoReflect

func (x *GetCause0Request) ProtoReflect() protoreflect.Message

func (*GetCause0Request) Reset

func (x *GetCause0Request) Reset()

func (*GetCause0Request) String

func (x *GetCause0Request) String() string

type GetCause0Response

type GetCause0Response struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetCause0Response) Descriptor deprecated

func (*GetCause0Response) Descriptor() ([]byte, []int)

Deprecated: Use GetCause0Response.ProtoReflect.Descriptor instead.

func (*GetCause0Response) GetResult

func (x *GetCause0Response) GetResult() int64

func (*GetCause0Response) ProtoMessage

func (*GetCause0Response) ProtoMessage()

func (*GetCause0Response) ProtoReflect

func (x *GetCause0Response) ProtoReflect() protoreflect.Message

func (*GetCause0Response) Reset

func (x *GetCause0Response) Reset()

func (*GetCause0Response) String

func (x *GetCause0Response) String() string

type GetCause0_1Request

type GetCause0_1Request struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	// contains filtered or unexported fields
}

func (*GetCause0_1Request) Descriptor deprecated

func (*GetCause0_1Request) Descriptor() ([]byte, []int)

Deprecated: Use GetCause0_1Request.ProtoReflect.Descriptor instead.

func (*GetCause0_1Request) GetHandle

func (x *GetCause0_1Request) GetHandle() int64

func (*GetCause0_1Request) ProtoMessage

func (*GetCause0_1Request) ProtoMessage()

func (*GetCause0_1Request) ProtoReflect

func (x *GetCause0_1Request) ProtoReflect() protoreflect.Message

func (*GetCause0_1Request) Reset

func (x *GetCause0_1Request) Reset()

func (*GetCause0_1Request) String

func (x *GetCause0_1Request) String() string

type GetCause0_1Response

type GetCause0_1Response struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetCause0_1Response) Descriptor deprecated

func (*GetCause0_1Response) Descriptor() ([]byte, []int)

Deprecated: Use GetCause0_1Response.ProtoReflect.Descriptor instead.

func (*GetCause0_1Response) GetResult

func (x *GetCause0_1Response) GetResult() int64

func (*GetCause0_1Response) ProtoMessage

func (*GetCause0_1Response) ProtoMessage()

func (*GetCause0_1Response) ProtoReflect

func (x *GetCause0_1Response) ProtoReflect() protoreflect.Message

func (*GetCause0_1Response) Reset

func (x *GetCause0_1Response) Reset()

func (*GetCause0_1Response) String

func (x *GetCause0_1Response) String() string

type GetDhGroupRequest

type GetDhGroupRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	// contains filtered or unexported fields
}

func (*GetDhGroupRequest) Descriptor deprecated

func (*GetDhGroupRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetDhGroupRequest.ProtoReflect.Descriptor instead.

func (*GetDhGroupRequest) GetHandle

func (x *GetDhGroupRequest) GetHandle() int64

func (*GetDhGroupRequest) ProtoMessage

func (*GetDhGroupRequest) ProtoMessage()

func (*GetDhGroupRequest) ProtoReflect

func (x *GetDhGroupRequest) ProtoReflect() protoreflect.Message

func (*GetDhGroupRequest) Reset

func (x *GetDhGroupRequest) Reset()

func (*GetDhGroupRequest) String

func (x *GetDhGroupRequest) String() string

type GetDhGroupResponse

type GetDhGroupResponse struct {
	Result int32 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetDhGroupResponse) Descriptor deprecated

func (*GetDhGroupResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetDhGroupResponse.ProtoReflect.Descriptor instead.

func (*GetDhGroupResponse) GetResult

func (x *GetDhGroupResponse) GetResult() int32

func (*GetDhGroupResponse) ProtoMessage

func (*GetDhGroupResponse) ProtoMessage()

func (*GetDhGroupResponse) ProtoReflect

func (x *GetDhGroupResponse) ProtoReflect() protoreflect.Message

func (*GetDhGroupResponse) Reset

func (x *GetDhGroupResponse) Reset()

func (*GetDhGroupResponse) String

func (x *GetDhGroupResponse) String() string

type GetErrorTypeRequest

type GetErrorTypeRequest struct {
	// contains filtered or unexported fields
}

func (*GetErrorTypeRequest) Descriptor deprecated

func (*GetErrorTypeRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetErrorTypeRequest.ProtoReflect.Descriptor instead.

func (*GetErrorTypeRequest) ProtoMessage

func (*GetErrorTypeRequest) ProtoMessage()

func (*GetErrorTypeRequest) ProtoReflect

func (x *GetErrorTypeRequest) ProtoReflect() protoreflect.Message

func (*GetErrorTypeRequest) Reset

func (x *GetErrorTypeRequest) Reset()

func (*GetErrorTypeRequest) String

func (x *GetErrorTypeRequest) String() string

type GetErrorTypeResponse

type GetErrorTypeResponse struct {
	Result int32 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetErrorTypeResponse) Descriptor deprecated

func (*GetErrorTypeResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetErrorTypeResponse.ProtoReflect.Descriptor instead.

func (*GetErrorTypeResponse) GetResult

func (x *GetErrorTypeResponse) GetResult() int32

func (*GetErrorTypeResponse) ProtoMessage

func (*GetErrorTypeResponse) ProtoMessage()

func (*GetErrorTypeResponse) ProtoReflect

func (x *GetErrorTypeResponse) ProtoReflect() protoreflect.Message

func (*GetErrorTypeResponse) Reset

func (x *GetErrorTypeResponse) Reset()

func (*GetErrorTypeResponse) String

func (x *GetErrorTypeResponse) String() string

type GetIpSecPacketInfoRequest

type GetIpSecPacketInfoRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	// contains filtered or unexported fields
}

func (*GetIpSecPacketInfoRequest) Descriptor deprecated

func (*GetIpSecPacketInfoRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetIpSecPacketInfoRequest.ProtoReflect.Descriptor instead.

func (*GetIpSecPacketInfoRequest) GetHandle

func (x *GetIpSecPacketInfoRequest) GetHandle() int64

func (*GetIpSecPacketInfoRequest) ProtoMessage

func (*GetIpSecPacketInfoRequest) ProtoMessage()

func (*GetIpSecPacketInfoRequest) ProtoReflect

func (*GetIpSecPacketInfoRequest) Reset

func (x *GetIpSecPacketInfoRequest) Reset()

func (*GetIpSecPacketInfoRequest) String

func (x *GetIpSecPacketInfoRequest) String() string

type GetIpSecPacketInfoResponse

type GetIpSecPacketInfoResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetIpSecPacketInfoResponse) Descriptor deprecated

func (*GetIpSecPacketInfoResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetIpSecPacketInfoResponse.ProtoReflect.Descriptor instead.

func (*GetIpSecPacketInfoResponse) GetResult

func (x *GetIpSecPacketInfoResponse) GetResult() int64

func (*GetIpSecPacketInfoResponse) ProtoMessage

func (*GetIpSecPacketInfoResponse) ProtoMessage()

func (*GetIpSecPacketInfoResponse) ProtoReflect

func (*GetIpSecPacketInfoResponse) Reset

func (x *GetIpSecPacketInfoResponse) Reset()

func (*GetIpSecPacketInfoResponse) String

func (x *GetIpSecPacketInfoResponse) String() string

type GetIpSecSpiRequest

type GetIpSecSpiRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	// contains filtered or unexported fields
}

func (*GetIpSecSpiRequest) Descriptor deprecated

func (*GetIpSecSpiRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetIpSecSpiRequest.ProtoReflect.Descriptor instead.

func (*GetIpSecSpiRequest) GetHandle

func (x *GetIpSecSpiRequest) GetHandle() int64

func (*GetIpSecSpiRequest) ProtoMessage

func (*GetIpSecSpiRequest) ProtoMessage()

func (*GetIpSecSpiRequest) ProtoReflect

func (x *GetIpSecSpiRequest) ProtoReflect() protoreflect.Message

func (*GetIpSecSpiRequest) Reset

func (x *GetIpSecSpiRequest) Reset()

func (*GetIpSecSpiRequest) String

func (x *GetIpSecSpiRequest) String() string

type GetIpSecSpiResponse

type GetIpSecSpiResponse struct {
	Result int32 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetIpSecSpiResponse) Descriptor deprecated

func (*GetIpSecSpiResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetIpSecSpiResponse.ProtoReflect.Descriptor instead.

func (*GetIpSecSpiResponse) GetResult

func (x *GetIpSecSpiResponse) GetResult() int32

func (*GetIpSecSpiResponse) ProtoMessage

func (*GetIpSecSpiResponse) ProtoMessage()

func (*GetIpSecSpiResponse) ProtoReflect

func (x *GetIpSecSpiResponse) ProtoReflect() protoreflect.Message

func (*GetIpSecSpiResponse) Reset

func (x *GetIpSecSpiResponse) Reset()

func (*GetIpSecSpiResponse) String

func (x *GetIpSecSpiResponse) String() string

type GetMajorVersionRequest

type GetMajorVersionRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	// contains filtered or unexported fields
}

func (*GetMajorVersionRequest) Descriptor deprecated

func (*GetMajorVersionRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetMajorVersionRequest.ProtoReflect.Descriptor instead.

func (*GetMajorVersionRequest) GetHandle

func (x *GetMajorVersionRequest) GetHandle() int64

func (*GetMajorVersionRequest) ProtoMessage

func (*GetMajorVersionRequest) ProtoMessage()

func (*GetMajorVersionRequest) ProtoReflect

func (x *GetMajorVersionRequest) ProtoReflect() protoreflect.Message

func (*GetMajorVersionRequest) Reset

func (x *GetMajorVersionRequest) Reset()

func (*GetMajorVersionRequest) String

func (x *GetMajorVersionRequest) String() string

type GetMajorVersionResponse

type GetMajorVersionResponse struct {
	Result uint32 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetMajorVersionResponse) Descriptor deprecated

func (*GetMajorVersionResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetMajorVersionResponse.ProtoReflect.Descriptor instead.

func (*GetMajorVersionResponse) GetResult

func (x *GetMajorVersionResponse) GetResult() uint32

func (*GetMajorVersionResponse) ProtoMessage

func (*GetMajorVersionResponse) ProtoMessage()

func (*GetMajorVersionResponse) ProtoReflect

func (x *GetMajorVersionResponse) ProtoReflect() protoreflect.Message

func (*GetMajorVersionResponse) Reset

func (x *GetMajorVersionResponse) Reset()

func (*GetMajorVersionResponse) String

func (x *GetMajorVersionResponse) String() string

type GetNetworkRequest

type GetNetworkRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	// contains filtered or unexported fields
}

func (*GetNetworkRequest) Descriptor deprecated

func (*GetNetworkRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetNetworkRequest.ProtoReflect.Descriptor instead.

func (*GetNetworkRequest) GetHandle

func (x *GetNetworkRequest) GetHandle() int64

func (*GetNetworkRequest) ProtoMessage

func (*GetNetworkRequest) ProtoMessage()

func (*GetNetworkRequest) ProtoReflect

func (x *GetNetworkRequest) ProtoReflect() protoreflect.Message

func (*GetNetworkRequest) Reset

func (x *GetNetworkRequest) Reset()

func (*GetNetworkRequest) String

func (x *GetNetworkRequest) String() string

type GetNetworkResponse

type GetNetworkResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetNetworkResponse) Descriptor deprecated

func (*GetNetworkResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetNetworkResponse.ProtoReflect.Descriptor instead.

func (*GetNetworkResponse) GetResult

func (x *GetNetworkResponse) GetResult() int64

func (*GetNetworkResponse) ProtoMessage

func (*GetNetworkResponse) ProtoMessage()

func (*GetNetworkResponse) ProtoReflect

func (x *GetNetworkResponse) ProtoReflect() protoreflect.Message

func (*GetNetworkResponse) Reset

func (x *GetNetworkResponse) Reset()

func (*GetNetworkResponse) String

func (x *GetNetworkResponse) String() string

type GetResultCodeRequest

type GetResultCodeRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	// contains filtered or unexported fields
}

func (*GetResultCodeRequest) Descriptor deprecated

func (*GetResultCodeRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetResultCodeRequest.ProtoReflect.Descriptor instead.

func (*GetResultCodeRequest) GetHandle

func (x *GetResultCodeRequest) GetHandle() int64

func (*GetResultCodeRequest) ProtoMessage

func (*GetResultCodeRequest) ProtoMessage()

func (*GetResultCodeRequest) ProtoReflect

func (x *GetResultCodeRequest) ProtoReflect() protoreflect.Message

func (*GetResultCodeRequest) Reset

func (x *GetResultCodeRequest) Reset()

func (*GetResultCodeRequest) String

func (x *GetResultCodeRequest) String() string

type GetResultCodeResponse

type GetResultCodeResponse struct {
	Result int32 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetResultCodeResponse) Descriptor deprecated

func (*GetResultCodeResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetResultCodeResponse.ProtoReflect.Descriptor instead.

func (*GetResultCodeResponse) GetResult

func (x *GetResultCodeResponse) GetResult() int32

func (*GetResultCodeResponse) ProtoMessage

func (*GetResultCodeResponse) ProtoMessage()

func (*GetResultCodeResponse) ProtoReflect

func (x *GetResultCodeResponse) ProtoReflect() protoreflect.Message

func (*GetResultCodeResponse) Reset

func (x *GetResultCodeResponse) Reset()

func (*GetResultCodeResponse) String

func (x *GetResultCodeResponse) String() string

type IkeIOExceptionServiceClient

type IkeIOExceptionServiceClient interface {
	NewIkeIOException(ctx context.Context, in *NewIkeIOExceptionRequest, opts ...grpc.CallOption) (*NewIkeIOExceptionResponse, error)
	GetCause0(ctx context.Context, in *GetCause0Request, opts ...grpc.CallOption) (*GetCause0Response, error)
	GetCause0_1(ctx context.Context, in *GetCause0_1Request, opts ...grpc.CallOption) (*GetCause0_1Response, error)
}

IkeIOExceptionServiceClient is the client API for IkeIOExceptionService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type IkeIOExceptionServiceServer

type IkeIOExceptionServiceServer interface {
	NewIkeIOException(context.Context, *NewIkeIOExceptionRequest) (*NewIkeIOExceptionResponse, error)
	GetCause0(context.Context, *GetCause0Request) (*GetCause0Response, error)
	GetCause0_1(context.Context, *GetCause0_1Request) (*GetCause0_1Response, error)
	// contains filtered or unexported methods
}

IkeIOExceptionServiceServer is the server API for IkeIOExceptionService service. All implementations must embed UnimplementedIkeIOExceptionServiceServer for forward compatibility.

type IkeNetworkLostExceptionServiceClient

type IkeNetworkLostExceptionServiceClient interface {
	NewIkeNetworkLostException(ctx context.Context, in *NewIkeNetworkLostExceptionRequest, opts ...grpc.CallOption) (*NewIkeNetworkLostExceptionResponse, error)
	GetNetwork(ctx context.Context, in *GetNetworkRequest, opts ...grpc.CallOption) (*GetNetworkResponse, error)
}

IkeNetworkLostExceptionServiceClient is the client API for IkeNetworkLostExceptionService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type IkeNetworkLostExceptionServiceServer

type IkeNetworkLostExceptionServiceServer interface {
	NewIkeNetworkLostException(context.Context, *NewIkeNetworkLostExceptionRequest) (*NewIkeNetworkLostExceptionResponse, error)
	GetNetwork(context.Context, *GetNetworkRequest) (*GetNetworkResponse, error)
	// contains filtered or unexported methods
}

IkeNetworkLostExceptionServiceServer is the server API for IkeNetworkLostExceptionService service. All implementations must embed UnimplementedIkeNetworkLostExceptionServiceServer for forward compatibility.

type IkeProtocolExceptionServiceClient

type IkeProtocolExceptionServiceClient interface {
	GetErrorType(ctx context.Context, in *GetErrorTypeRequest, opts ...grpc.CallOption) (*GetErrorTypeResponse, error)
}

IkeProtocolExceptionServiceClient is the client API for IkeProtocolExceptionService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type IkeProtocolExceptionServiceServer

type IkeProtocolExceptionServiceServer interface {
	GetErrorType(context.Context, *GetErrorTypeRequest) (*GetErrorTypeResponse, error)
	// contains filtered or unexported methods
}

IkeProtocolExceptionServiceServer is the server API for IkeProtocolExceptionService service. All implementations must embed UnimplementedIkeProtocolExceptionServiceServer for forward compatibility.

type InvalidKeExceptionServiceClient

type InvalidKeExceptionServiceClient interface {
	NewInvalidKeException(ctx context.Context, in *NewInvalidKeExceptionRequest, opts ...grpc.CallOption) (*NewInvalidKeExceptionResponse, error)
	GetDhGroup(ctx context.Context, in *GetDhGroupRequest, opts ...grpc.CallOption) (*GetDhGroupResponse, error)
}

InvalidKeExceptionServiceClient is the client API for InvalidKeExceptionService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type InvalidKeExceptionServiceServer

type InvalidKeExceptionServiceServer interface {
	NewInvalidKeException(context.Context, *NewInvalidKeExceptionRequest) (*NewInvalidKeExceptionResponse, error)
	GetDhGroup(context.Context, *GetDhGroupRequest) (*GetDhGroupResponse, error)
	// contains filtered or unexported methods
}

InvalidKeExceptionServiceServer is the server API for InvalidKeExceptionService service. All implementations must embed UnimplementedInvalidKeExceptionServiceServer for forward compatibility.

type InvalidMajorVersionExceptionServiceClient

type InvalidMajorVersionExceptionServiceClient interface {
	NewInvalidMajorVersionException(ctx context.Context, in *NewInvalidMajorVersionExceptionRequest, opts ...grpc.CallOption) (*NewInvalidMajorVersionExceptionResponse, error)
	GetMajorVersion(ctx context.Context, in *GetMajorVersionRequest, opts ...grpc.CallOption) (*GetMajorVersionResponse, error)
}

InvalidMajorVersionExceptionServiceClient is the client API for InvalidMajorVersionExceptionService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type InvalidMajorVersionExceptionServiceServer

type InvalidMajorVersionExceptionServiceServer interface {
	NewInvalidMajorVersionException(context.Context, *NewInvalidMajorVersionExceptionRequest) (*NewInvalidMajorVersionExceptionResponse, error)
	GetMajorVersion(context.Context, *GetMajorVersionRequest) (*GetMajorVersionResponse, error)
	// contains filtered or unexported methods
}

InvalidMajorVersionExceptionServiceServer is the server API for InvalidMajorVersionExceptionService service. All implementations must embed UnimplementedInvalidMajorVersionExceptionServiceServer for forward compatibility.

type InvalidSelectorsExceptionServiceClient

type InvalidSelectorsExceptionServiceClient interface {
	NewInvalidSelectorsException(ctx context.Context, in *NewInvalidSelectorsExceptionRequest, opts ...grpc.CallOption) (*NewInvalidSelectorsExceptionResponse, error)
	GetIpSecPacketInfo(ctx context.Context, in *GetIpSecPacketInfoRequest, opts ...grpc.CallOption) (*GetIpSecPacketInfoResponse, error)
	GetIpSecSpi(ctx context.Context, in *GetIpSecSpiRequest, opts ...grpc.CallOption) (*GetIpSecSpiResponse, error)
}

InvalidSelectorsExceptionServiceClient is the client API for InvalidSelectorsExceptionService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type InvalidSelectorsExceptionServiceServer

type InvalidSelectorsExceptionServiceServer interface {
	NewInvalidSelectorsException(context.Context, *NewInvalidSelectorsExceptionRequest) (*NewInvalidSelectorsExceptionResponse, error)
	GetIpSecPacketInfo(context.Context, *GetIpSecPacketInfoRequest) (*GetIpSecPacketInfoResponse, error)
	GetIpSecSpi(context.Context, *GetIpSecSpiRequest) (*GetIpSecSpiResponse, error)
	// contains filtered or unexported methods
}

InvalidSelectorsExceptionServiceServer is the server API for InvalidSelectorsExceptionService service. All implementations must embed UnimplementedInvalidSelectorsExceptionServiceServer for forward compatibility.

type NewAppSearchExceptionRequest

type NewAppSearchExceptionRequest struct {
	Arg0 int32 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*NewAppSearchExceptionRequest) Descriptor deprecated

func (*NewAppSearchExceptionRequest) Descriptor() ([]byte, []int)

Deprecated: Use NewAppSearchExceptionRequest.ProtoReflect.Descriptor instead.

func (*NewAppSearchExceptionRequest) GetArg0

func (x *NewAppSearchExceptionRequest) GetArg0() int32

func (*NewAppSearchExceptionRequest) ProtoMessage

func (*NewAppSearchExceptionRequest) ProtoMessage()

func (*NewAppSearchExceptionRequest) ProtoReflect

func (*NewAppSearchExceptionRequest) Reset

func (x *NewAppSearchExceptionRequest) Reset()

func (*NewAppSearchExceptionRequest) String

type NewAppSearchExceptionResponse

type NewAppSearchExceptionResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*NewAppSearchExceptionResponse) Descriptor deprecated

func (*NewAppSearchExceptionResponse) Descriptor() ([]byte, []int)

Deprecated: Use NewAppSearchExceptionResponse.ProtoReflect.Descriptor instead.

func (*NewAppSearchExceptionResponse) GetResult

func (x *NewAppSearchExceptionResponse) GetResult() int64

func (*NewAppSearchExceptionResponse) ProtoMessage

func (*NewAppSearchExceptionResponse) ProtoMessage()

func (*NewAppSearchExceptionResponse) ProtoReflect

func (*NewAppSearchExceptionResponse) Reset

func (x *NewAppSearchExceptionResponse) Reset()

func (*NewAppSearchExceptionResponse) String

type NewIkeIOExceptionRequest

type NewIkeIOExceptionRequest struct {
	Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*NewIkeIOExceptionRequest) Descriptor deprecated

func (*NewIkeIOExceptionRequest) Descriptor() ([]byte, []int)

Deprecated: Use NewIkeIOExceptionRequest.ProtoReflect.Descriptor instead.

func (*NewIkeIOExceptionRequest) GetArg0

func (x *NewIkeIOExceptionRequest) GetArg0() int64

func (*NewIkeIOExceptionRequest) ProtoMessage

func (*NewIkeIOExceptionRequest) ProtoMessage()

func (*NewIkeIOExceptionRequest) ProtoReflect

func (x *NewIkeIOExceptionRequest) ProtoReflect() protoreflect.Message

func (*NewIkeIOExceptionRequest) Reset

func (x *NewIkeIOExceptionRequest) Reset()

func (*NewIkeIOExceptionRequest) String

func (x *NewIkeIOExceptionRequest) String() string

type NewIkeIOExceptionResponse

type NewIkeIOExceptionResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*NewIkeIOExceptionResponse) Descriptor deprecated

func (*NewIkeIOExceptionResponse) Descriptor() ([]byte, []int)

Deprecated: Use NewIkeIOExceptionResponse.ProtoReflect.Descriptor instead.

func (*NewIkeIOExceptionResponse) GetResult

func (x *NewIkeIOExceptionResponse) GetResult() int64

func (*NewIkeIOExceptionResponse) ProtoMessage

func (*NewIkeIOExceptionResponse) ProtoMessage()

func (*NewIkeIOExceptionResponse) ProtoReflect

func (*NewIkeIOExceptionResponse) Reset

func (x *NewIkeIOExceptionResponse) Reset()

func (*NewIkeIOExceptionResponse) String

func (x *NewIkeIOExceptionResponse) String() string

type NewIkeNetworkLostExceptionRequest

type NewIkeNetworkLostExceptionRequest struct {
	Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*NewIkeNetworkLostExceptionRequest) Descriptor deprecated

func (*NewIkeNetworkLostExceptionRequest) Descriptor() ([]byte, []int)

Deprecated: Use NewIkeNetworkLostExceptionRequest.ProtoReflect.Descriptor instead.

func (*NewIkeNetworkLostExceptionRequest) GetArg0

func (*NewIkeNetworkLostExceptionRequest) ProtoMessage

func (*NewIkeNetworkLostExceptionRequest) ProtoMessage()

func (*NewIkeNetworkLostExceptionRequest) ProtoReflect

func (*NewIkeNetworkLostExceptionRequest) Reset

func (*NewIkeNetworkLostExceptionRequest) String

type NewIkeNetworkLostExceptionResponse

type NewIkeNetworkLostExceptionResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*NewIkeNetworkLostExceptionResponse) Descriptor deprecated

func (*NewIkeNetworkLostExceptionResponse) Descriptor() ([]byte, []int)

Deprecated: Use NewIkeNetworkLostExceptionResponse.ProtoReflect.Descriptor instead.

func (*NewIkeNetworkLostExceptionResponse) GetResult

func (*NewIkeNetworkLostExceptionResponse) ProtoMessage

func (*NewIkeNetworkLostExceptionResponse) ProtoMessage()

func (*NewIkeNetworkLostExceptionResponse) ProtoReflect

func (*NewIkeNetworkLostExceptionResponse) Reset

func (*NewIkeNetworkLostExceptionResponse) String

type NewInvalidKeExceptionRequest

type NewInvalidKeExceptionRequest struct {
	Arg0 int32 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*NewInvalidKeExceptionRequest) Descriptor deprecated

func (*NewInvalidKeExceptionRequest) Descriptor() ([]byte, []int)

Deprecated: Use NewInvalidKeExceptionRequest.ProtoReflect.Descriptor instead.

func (*NewInvalidKeExceptionRequest) GetArg0

func (x *NewInvalidKeExceptionRequest) GetArg0() int32

func (*NewInvalidKeExceptionRequest) ProtoMessage

func (*NewInvalidKeExceptionRequest) ProtoMessage()

func (*NewInvalidKeExceptionRequest) ProtoReflect

func (*NewInvalidKeExceptionRequest) Reset

func (x *NewInvalidKeExceptionRequest) Reset()

func (*NewInvalidKeExceptionRequest) String

type NewInvalidKeExceptionResponse

type NewInvalidKeExceptionResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*NewInvalidKeExceptionResponse) Descriptor deprecated

func (*NewInvalidKeExceptionResponse) Descriptor() ([]byte, []int)

Deprecated: Use NewInvalidKeExceptionResponse.ProtoReflect.Descriptor instead.

func (*NewInvalidKeExceptionResponse) GetResult

func (x *NewInvalidKeExceptionResponse) GetResult() int64

func (*NewInvalidKeExceptionResponse) ProtoMessage

func (*NewInvalidKeExceptionResponse) ProtoMessage()

func (*NewInvalidKeExceptionResponse) ProtoReflect

func (*NewInvalidKeExceptionResponse) Reset

func (x *NewInvalidKeExceptionResponse) Reset()

func (*NewInvalidKeExceptionResponse) String

type NewInvalidMajorVersionExceptionRequest

type NewInvalidMajorVersionExceptionRequest struct {
	Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*NewInvalidMajorVersionExceptionRequest) Descriptor deprecated

func (*NewInvalidMajorVersionExceptionRequest) Descriptor() ([]byte, []int)

Deprecated: Use NewInvalidMajorVersionExceptionRequest.ProtoReflect.Descriptor instead.

func (*NewInvalidMajorVersionExceptionRequest) GetArg0

func (*NewInvalidMajorVersionExceptionRequest) ProtoMessage

func (*NewInvalidMajorVersionExceptionRequest) ProtoReflect

func (*NewInvalidMajorVersionExceptionRequest) Reset

func (*NewInvalidMajorVersionExceptionRequest) String

type NewInvalidMajorVersionExceptionResponse

type NewInvalidMajorVersionExceptionResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*NewInvalidMajorVersionExceptionResponse) Descriptor deprecated

func (*NewInvalidMajorVersionExceptionResponse) Descriptor() ([]byte, []int)

Deprecated: Use NewInvalidMajorVersionExceptionResponse.ProtoReflect.Descriptor instead.

func (*NewInvalidMajorVersionExceptionResponse) GetResult

func (*NewInvalidMajorVersionExceptionResponse) ProtoMessage

func (*NewInvalidMajorVersionExceptionResponse) ProtoReflect

func (*NewInvalidMajorVersionExceptionResponse) Reset

func (*NewInvalidMajorVersionExceptionResponse) String

type NewInvalidSelectorsExceptionRequest

type NewInvalidSelectorsExceptionRequest struct {
	Arg0 int32 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	Arg1 int64 `protobuf:"varint,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
	// contains filtered or unexported fields
}

func (*NewInvalidSelectorsExceptionRequest) Descriptor deprecated

func (*NewInvalidSelectorsExceptionRequest) Descriptor() ([]byte, []int)

Deprecated: Use NewInvalidSelectorsExceptionRequest.ProtoReflect.Descriptor instead.

func (*NewInvalidSelectorsExceptionRequest) GetArg0

func (*NewInvalidSelectorsExceptionRequest) GetArg1

func (*NewInvalidSelectorsExceptionRequest) ProtoMessage

func (*NewInvalidSelectorsExceptionRequest) ProtoMessage()

func (*NewInvalidSelectorsExceptionRequest) ProtoReflect

func (*NewInvalidSelectorsExceptionRequest) Reset

func (*NewInvalidSelectorsExceptionRequest) String

type NewInvalidSelectorsExceptionResponse

type NewInvalidSelectorsExceptionResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*NewInvalidSelectorsExceptionResponse) Descriptor deprecated

func (*NewInvalidSelectorsExceptionResponse) Descriptor() ([]byte, []int)

Deprecated: Use NewInvalidSelectorsExceptionResponse.ProtoReflect.Descriptor instead.

func (*NewInvalidSelectorsExceptionResponse) GetResult

func (*NewInvalidSelectorsExceptionResponse) ProtoMessage

func (*NewInvalidSelectorsExceptionResponse) ProtoMessage()

func (*NewInvalidSelectorsExceptionResponse) ProtoReflect

func (*NewInvalidSelectorsExceptionResponse) Reset

func (*NewInvalidSelectorsExceptionResponse) String

type UnimplementedAppSearchExceptionServiceServer

type UnimplementedAppSearchExceptionServiceServer struct{}

UnimplementedAppSearchExceptionServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedAppSearchExceptionServiceServer) GetResultCode

func (UnimplementedAppSearchExceptionServiceServer) NewAppSearchException

type UnimplementedIkeIOExceptionServiceServer

type UnimplementedIkeIOExceptionServiceServer struct{}

UnimplementedIkeIOExceptionServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedIkeIOExceptionServiceServer) GetCause0

func (UnimplementedIkeIOExceptionServiceServer) GetCause0_1

func (UnimplementedIkeIOExceptionServiceServer) NewIkeIOException

type UnimplementedIkeNetworkLostExceptionServiceServer

type UnimplementedIkeNetworkLostExceptionServiceServer struct{}

UnimplementedIkeNetworkLostExceptionServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedIkeNetworkLostExceptionServiceServer) GetNetwork

type UnimplementedIkeProtocolExceptionServiceServer

type UnimplementedIkeProtocolExceptionServiceServer struct{}

UnimplementedIkeProtocolExceptionServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedIkeProtocolExceptionServiceServer) GetErrorType

type UnimplementedInvalidKeExceptionServiceServer

type UnimplementedInvalidKeExceptionServiceServer struct{}

UnimplementedInvalidKeExceptionServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedInvalidKeExceptionServiceServer) GetDhGroup

func (UnimplementedInvalidKeExceptionServiceServer) NewInvalidKeException

type UnimplementedInvalidMajorVersionExceptionServiceServer

type UnimplementedInvalidMajorVersionExceptionServiceServer struct{}

UnimplementedInvalidMajorVersionExceptionServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedInvalidMajorVersionExceptionServiceServer) GetMajorVersion

type UnimplementedInvalidSelectorsExceptionServiceServer

type UnimplementedInvalidSelectorsExceptionServiceServer struct{}

UnimplementedInvalidSelectorsExceptionServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedInvalidSelectorsExceptionServiceServer) GetIpSecPacketInfo

func (UnimplementedInvalidSelectorsExceptionServiceServer) GetIpSecSpi

type UnsafeAppSearchExceptionServiceServer

type UnsafeAppSearchExceptionServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeAppSearchExceptionServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to AppSearchExceptionServiceServer will result in compilation errors.

type UnsafeIkeIOExceptionServiceServer

type UnsafeIkeIOExceptionServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeIkeIOExceptionServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to IkeIOExceptionServiceServer will result in compilation errors.

type UnsafeIkeNetworkLostExceptionServiceServer

type UnsafeIkeNetworkLostExceptionServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeIkeNetworkLostExceptionServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to IkeNetworkLostExceptionServiceServer will result in compilation errors.

type UnsafeIkeProtocolExceptionServiceServer

type UnsafeIkeProtocolExceptionServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeIkeProtocolExceptionServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to IkeProtocolExceptionServiceServer will result in compilation errors.

type UnsafeInvalidKeExceptionServiceServer

type UnsafeInvalidKeExceptionServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeInvalidKeExceptionServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to InvalidKeExceptionServiceServer will result in compilation errors.

type UnsafeInvalidMajorVersionExceptionServiceServer

type UnsafeInvalidMajorVersionExceptionServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeInvalidMajorVersionExceptionServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to InvalidMajorVersionExceptionServiceServer will result in compilation errors.

type UnsafeInvalidSelectorsExceptionServiceServer

type UnsafeInvalidSelectorsExceptionServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeInvalidSelectorsExceptionServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to InvalidSelectorsExceptionServiceServer will result in compilation errors.

Jump to