ext

package
v0.0.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 29, 2026 License: CC0-1.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

const (
	SdkExtensionsService_GetExtensionVersion_FullMethodName = "/ext.SdkExtensionsService/GetExtensionVersion"
)

Variables

var File_proto_ext_ext_proto protoreflect.FileDescriptor
var SdkExtensionsService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "ext.SdkExtensionsService",
	HandlerType: (*SdkExtensionsServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "GetExtensionVersion",
			Handler:    _SdkExtensionsService_GetExtensionVersion_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/ext/ext.proto",
}

SdkExtensionsService_ServiceDesc is the grpc.ServiceDesc for SdkExtensionsService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterSdkExtensionsServiceServer

func RegisterSdkExtensionsServiceServer(s grpc.ServiceRegistrar, srv SdkExtensionsServiceServer)

Types

type GetExtensionVersionRequest

type GetExtensionVersionRequest struct {
	Arg0 int32 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*GetExtensionVersionRequest) Descriptor deprecated

func (*GetExtensionVersionRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetExtensionVersionRequest.ProtoReflect.Descriptor instead.

func (*GetExtensionVersionRequest) GetArg0

func (x *GetExtensionVersionRequest) GetArg0() int32

func (*GetExtensionVersionRequest) ProtoMessage

func (*GetExtensionVersionRequest) ProtoMessage()

func (*GetExtensionVersionRequest) ProtoReflect

func (*GetExtensionVersionRequest) Reset

func (x *GetExtensionVersionRequest) Reset()

func (*GetExtensionVersionRequest) String

func (x *GetExtensionVersionRequest) String() string

type GetExtensionVersionResponse

type GetExtensionVersionResponse struct {
	Result int32 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetExtensionVersionResponse) Descriptor deprecated

func (*GetExtensionVersionResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetExtensionVersionResponse.ProtoReflect.Descriptor instead.

func (*GetExtensionVersionResponse) GetResult

func (x *GetExtensionVersionResponse) GetResult() int32

func (*GetExtensionVersionResponse) ProtoMessage

func (*GetExtensionVersionResponse) ProtoMessage()

func (*GetExtensionVersionResponse) ProtoReflect

func (*GetExtensionVersionResponse) Reset

func (x *GetExtensionVersionResponse) Reset()

func (*GetExtensionVersionResponse) String

func (x *GetExtensionVersionResponse) String() string

type SdkExtensionsServiceClient

type SdkExtensionsServiceClient interface {
	GetExtensionVersion(ctx context.Context, in *GetExtensionVersionRequest, opts ...grpc.CallOption) (*GetExtensionVersionResponse, error)
}

SdkExtensionsServiceClient is the client API for SdkExtensionsService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type SdkExtensionsServiceServer

type SdkExtensionsServiceServer interface {
	GetExtensionVersion(context.Context, *GetExtensionVersionRequest) (*GetExtensionVersionResponse, error)
	// contains filtered or unexported methods
}

SdkExtensionsServiceServer is the server API for SdkExtensionsService service. All implementations must embed UnimplementedSdkExtensionsServiceServer for forward compatibility.

type UnimplementedSdkExtensionsServiceServer

type UnimplementedSdkExtensionsServiceServer struct{}

UnimplementedSdkExtensionsServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedSdkExtensionsServiceServer) GetExtensionVersion

type UnsafeSdkExtensionsServiceServer

type UnsafeSdkExtensionsServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeSdkExtensionsServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to SdkExtensionsServiceServer will result in compilation errors.

Jump to