feature

package
v0.0.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 29, 2026 License: CC0-1.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

const (
	MmTelFeatureMmTelCapabilitiesService_Equals_FullMethodName    = "/feature.MmTelFeatureMmTelCapabilitiesService/Equals"
	MmTelFeatureMmTelCapabilitiesService_HashCode_FullMethodName  = "/feature.MmTelFeatureMmTelCapabilitiesService/HashCode"
	MmTelFeatureMmTelCapabilitiesService_IsCapable_FullMethodName = "/feature.MmTelFeatureMmTelCapabilitiesService/IsCapable"
	MmTelFeatureMmTelCapabilitiesService_ToString_FullMethodName  = "/feature.MmTelFeatureMmTelCapabilitiesService/ToString"
)

Variables

var File_proto_feature_feature_proto protoreflect.FileDescriptor
var MmTelFeatureMmTelCapabilitiesService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "feature.MmTelFeatureMmTelCapabilitiesService",
	HandlerType: (*MmTelFeatureMmTelCapabilitiesServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "Equals",
			Handler:    _MmTelFeatureMmTelCapabilitiesService_Equals_Handler,
		},
		{
			MethodName: "HashCode",
			Handler:    _MmTelFeatureMmTelCapabilitiesService_HashCode_Handler,
		},
		{
			MethodName: "IsCapable",
			Handler:    _MmTelFeatureMmTelCapabilitiesService_IsCapable_Handler,
		},
		{
			MethodName: "ToString",
			Handler:    _MmTelFeatureMmTelCapabilitiesService_ToString_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/feature/feature.proto",
}

MmTelFeatureMmTelCapabilitiesService_ServiceDesc is the grpc.ServiceDesc for MmTelFeatureMmTelCapabilitiesService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

Types

type EqualsRequest

type EqualsRequest struct {
	Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*EqualsRequest) Descriptor deprecated

func (*EqualsRequest) Descriptor() ([]byte, []int)

Deprecated: Use EqualsRequest.ProtoReflect.Descriptor instead.

func (*EqualsRequest) GetArg0

func (x *EqualsRequest) GetArg0() int64

func (*EqualsRequest) ProtoMessage

func (*EqualsRequest) ProtoMessage()

func (*EqualsRequest) ProtoReflect

func (x *EqualsRequest) ProtoReflect() protoreflect.Message

func (*EqualsRequest) Reset

func (x *EqualsRequest) Reset()

func (*EqualsRequest) String

func (x *EqualsRequest) String() string

type EqualsResponse

type EqualsResponse struct {
	Result bool `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*EqualsResponse) Descriptor deprecated

func (*EqualsResponse) Descriptor() ([]byte, []int)

Deprecated: Use EqualsResponse.ProtoReflect.Descriptor instead.

func (*EqualsResponse) GetResult

func (x *EqualsResponse) GetResult() bool

func (*EqualsResponse) ProtoMessage

func (*EqualsResponse) ProtoMessage()

func (*EqualsResponse) ProtoReflect

func (x *EqualsResponse) ProtoReflect() protoreflect.Message

func (*EqualsResponse) Reset

func (x *EqualsResponse) Reset()

func (*EqualsResponse) String

func (x *EqualsResponse) String() string

type HashCodeRequest

type HashCodeRequest struct {
	// contains filtered or unexported fields
}

func (*HashCodeRequest) Descriptor deprecated

func (*HashCodeRequest) Descriptor() ([]byte, []int)

Deprecated: Use HashCodeRequest.ProtoReflect.Descriptor instead.

func (*HashCodeRequest) ProtoMessage

func (*HashCodeRequest) ProtoMessage()

func (*HashCodeRequest) ProtoReflect

func (x *HashCodeRequest) ProtoReflect() protoreflect.Message

func (*HashCodeRequest) Reset

func (x *HashCodeRequest) Reset()

func (*HashCodeRequest) String

func (x *HashCodeRequest) String() string

type HashCodeResponse

type HashCodeResponse struct {
	Result int32 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*HashCodeResponse) Descriptor deprecated

func (*HashCodeResponse) Descriptor() ([]byte, []int)

Deprecated: Use HashCodeResponse.ProtoReflect.Descriptor instead.

func (*HashCodeResponse) GetResult

func (x *HashCodeResponse) GetResult() int32

func (*HashCodeResponse) ProtoMessage

func (*HashCodeResponse) ProtoMessage()

func (*HashCodeResponse) ProtoReflect

func (x *HashCodeResponse) ProtoReflect() protoreflect.Message

func (*HashCodeResponse) Reset

func (x *HashCodeResponse) Reset()

func (*HashCodeResponse) String

func (x *HashCodeResponse) String() string

type IsCapableRequest

type IsCapableRequest struct {
	Arg0 int32 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*IsCapableRequest) Descriptor deprecated

func (*IsCapableRequest) Descriptor() ([]byte, []int)

Deprecated: Use IsCapableRequest.ProtoReflect.Descriptor instead.

func (*IsCapableRequest) GetArg0

func (x *IsCapableRequest) GetArg0() int32

func (*IsCapableRequest) ProtoMessage

func (*IsCapableRequest) ProtoMessage()

func (*IsCapableRequest) ProtoReflect

func (x *IsCapableRequest) ProtoReflect() protoreflect.Message

func (*IsCapableRequest) Reset

func (x *IsCapableRequest) Reset()

func (*IsCapableRequest) String

func (x *IsCapableRequest) String() string

type IsCapableResponse

type IsCapableResponse struct {
	Result bool `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*IsCapableResponse) Descriptor deprecated

func (*IsCapableResponse) Descriptor() ([]byte, []int)

Deprecated: Use IsCapableResponse.ProtoReflect.Descriptor instead.

func (*IsCapableResponse) GetResult

func (x *IsCapableResponse) GetResult() bool

func (*IsCapableResponse) ProtoMessage

func (*IsCapableResponse) ProtoMessage()

func (*IsCapableResponse) ProtoReflect

func (x *IsCapableResponse) ProtoReflect() protoreflect.Message

func (*IsCapableResponse) Reset

func (x *IsCapableResponse) Reset()

func (*IsCapableResponse) String

func (x *IsCapableResponse) String() string

type MmTelFeatureMmTelCapabilitiesServiceClient

type MmTelFeatureMmTelCapabilitiesServiceClient interface {
	Equals(ctx context.Context, in *EqualsRequest, opts ...grpc.CallOption) (*EqualsResponse, error)
	HashCode(ctx context.Context, in *HashCodeRequest, opts ...grpc.CallOption) (*HashCodeResponse, error)
	IsCapable(ctx context.Context, in *IsCapableRequest, opts ...grpc.CallOption) (*IsCapableResponse, error)
	ToString(ctx context.Context, in *ToStringRequest, opts ...grpc.CallOption) (*ToStringResponse, error)
}

MmTelFeatureMmTelCapabilitiesServiceClient is the client API for MmTelFeatureMmTelCapabilitiesService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type MmTelFeatureMmTelCapabilitiesServiceServer

type MmTelFeatureMmTelCapabilitiesServiceServer interface {
	Equals(context.Context, *EqualsRequest) (*EqualsResponse, error)
	HashCode(context.Context, *HashCodeRequest) (*HashCodeResponse, error)
	IsCapable(context.Context, *IsCapableRequest) (*IsCapableResponse, error)
	ToString(context.Context, *ToStringRequest) (*ToStringResponse, error)
	// contains filtered or unexported methods
}

MmTelFeatureMmTelCapabilitiesServiceServer is the server API for MmTelFeatureMmTelCapabilitiesService service. All implementations must embed UnimplementedMmTelFeatureMmTelCapabilitiesServiceServer for forward compatibility.

type ToStringRequest

type ToStringRequest struct {
	// contains filtered or unexported fields
}

func (*ToStringRequest) Descriptor deprecated

func (*ToStringRequest) Descriptor() ([]byte, []int)

Deprecated: Use ToStringRequest.ProtoReflect.Descriptor instead.

func (*ToStringRequest) ProtoMessage

func (*ToStringRequest) ProtoMessage()

func (*ToStringRequest) ProtoReflect

func (x *ToStringRequest) ProtoReflect() protoreflect.Message

func (*ToStringRequest) Reset

func (x *ToStringRequest) Reset()

func (*ToStringRequest) String

func (x *ToStringRequest) String() string

type ToStringResponse

type ToStringResponse struct {
	Result string `protobuf:"bytes,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*ToStringResponse) Descriptor deprecated

func (*ToStringResponse) Descriptor() ([]byte, []int)

Deprecated: Use ToStringResponse.ProtoReflect.Descriptor instead.

func (*ToStringResponse) GetResult

func (x *ToStringResponse) GetResult() string

func (*ToStringResponse) ProtoMessage

func (*ToStringResponse) ProtoMessage()

func (*ToStringResponse) ProtoReflect

func (x *ToStringResponse) ProtoReflect() protoreflect.Message

func (*ToStringResponse) Reset

func (x *ToStringResponse) Reset()

func (*ToStringResponse) String

func (x *ToStringResponse) String() string

type UnimplementedMmTelFeatureMmTelCapabilitiesServiceServer

type UnimplementedMmTelFeatureMmTelCapabilitiesServiceServer struct{}

UnimplementedMmTelFeatureMmTelCapabilitiesServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedMmTelFeatureMmTelCapabilitiesServiceServer) Equals

func (UnimplementedMmTelFeatureMmTelCapabilitiesServiceServer) HashCode

func (UnimplementedMmTelFeatureMmTelCapabilitiesServiceServer) IsCapable

func (UnimplementedMmTelFeatureMmTelCapabilitiesServiceServer) ToString

type UnsafeMmTelFeatureMmTelCapabilitiesServiceServer

type UnsafeMmTelFeatureMmTelCapabilitiesServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeMmTelFeatureMmTelCapabilitiesServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to MmTelFeatureMmTelCapabilitiesServiceServer will result in compilation errors.

Jump to