Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterManagerServiceServer(s grpc.ServiceRegistrar, srv ManagerServiceServer)
- type AggregateRawRequest
- func (*AggregateRawRequest) Descriptor() ([]byte, []int)deprecated
- func (x *AggregateRawRequest) GetRequest() int64
- func (*AggregateRawRequest) ProtoMessage()
- func (x *AggregateRawRequest) ProtoReflect() protoreflect.Message
- func (x *AggregateRawRequest) Reset()
- func (x *AggregateRawRequest) String() string
- type AggregateRawResponse
- func (*AggregateRawResponse) Descriptor() ([]byte, []int)deprecated
- func (x *AggregateRawResponse) GetResult() int64
- func (*AggregateRawResponse) ProtoMessage()
- func (x *AggregateRawResponse) ProtoReflect() protoreflect.Message
- func (x *AggregateRawResponse) Reset()
- func (x *AggregateRawResponse) String() string
- type DeleteRecordsRawRequest
- func (*DeleteRecordsRawRequest) Descriptor() ([]byte, []int)deprecated
- func (x *DeleteRecordsRawRequest) GetRecordType() int64
- func (x *DeleteRecordsRawRequest) GetTimeRange() int64
- func (*DeleteRecordsRawRequest) ProtoMessage()
- func (x *DeleteRecordsRawRequest) ProtoReflect() protoreflect.Message
- func (x *DeleteRecordsRawRequest) Reset()
- func (x *DeleteRecordsRawRequest) String() string
- type DeleteRecordsRawResponse
- type GetOrCreateRawRequest
- func (*GetOrCreateRawRequest) Descriptor() ([]byte, []int)deprecated
- func (x *GetOrCreateRawRequest) GetCtx() int64
- func (*GetOrCreateRawRequest) ProtoMessage()
- func (x *GetOrCreateRawRequest) ProtoReflect() protoreflect.Message
- func (x *GetOrCreateRawRequest) Reset()
- func (x *GetOrCreateRawRequest) String() string
- type GetOrCreateRawResponse
- func (*GetOrCreateRawResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetOrCreateRawResponse) GetResult() int64
- func (*GetOrCreateRawResponse) ProtoMessage()
- func (x *GetOrCreateRawResponse) ProtoReflect() protoreflect.Message
- func (x *GetOrCreateRawResponse) Reset()
- func (x *GetOrCreateRawResponse) String() string
- type InsertRecordsRawRequest
- func (*InsertRecordsRawRequest) Descriptor() ([]byte, []int)deprecated
- func (x *InsertRecordsRawRequest) GetRecords() int64
- func (*InsertRecordsRawRequest) ProtoMessage()
- func (x *InsertRecordsRawRequest) ProtoReflect() protoreflect.Message
- func (x *InsertRecordsRawRequest) Reset()
- func (x *InsertRecordsRawRequest) String() string
- type InsertRecordsRawResponse
- func (*InsertRecordsRawResponse) Descriptor() ([]byte, []int)deprecated
- func (x *InsertRecordsRawResponse) GetResult() int64
- func (*InsertRecordsRawResponse) ProtoMessage()
- func (x *InsertRecordsRawResponse) ProtoReflect() protoreflect.Message
- func (x *InsertRecordsRawResponse) Reset()
- func (x *InsertRecordsRawResponse) String() string
- type ManagerServiceClient
- type ManagerServiceServer
- type ReadRecordsRawRequest
- func (*ReadRecordsRawRequest) Descriptor() ([]byte, []int)deprecated
- func (x *ReadRecordsRawRequest) GetRequest() int64
- func (*ReadRecordsRawRequest) ProtoMessage()
- func (x *ReadRecordsRawRequest) ProtoReflect() protoreflect.Message
- func (x *ReadRecordsRawRequest) Reset()
- func (x *ReadRecordsRawRequest) String() string
- type ReadRecordsRawResponse
- func (*ReadRecordsRawResponse) Descriptor() ([]byte, []int)deprecated
- func (x *ReadRecordsRawResponse) GetResult() int64
- func (*ReadRecordsRawResponse) ProtoMessage()
- func (x *ReadRecordsRawResponse) ProtoReflect() protoreflect.Message
- func (x *ReadRecordsRawResponse) Reset()
- func (x *ReadRecordsRawResponse) String() string
- type UnimplementedManagerServiceServer
- func (UnimplementedManagerServiceServer) AggregateRaw(context.Context, *AggregateRawRequest) (*AggregateRawResponse, error)
- func (UnimplementedManagerServiceServer) DeleteRecordsRaw(context.Context, *DeleteRecordsRawRequest) (*DeleteRecordsRawResponse, error)
- func (UnimplementedManagerServiceServer) GetOrCreateRaw(context.Context, *GetOrCreateRawRequest) (*GetOrCreateRawResponse, error)
- func (UnimplementedManagerServiceServer) InsertRecordsRaw(context.Context, *InsertRecordsRawRequest) (*InsertRecordsRawResponse, error)
- func (UnimplementedManagerServiceServer) ReadRecordsRaw(context.Context, *ReadRecordsRawRequest) (*ReadRecordsRawResponse, error)
- type UnsafeManagerServiceServer
Constants ¶
const ( ManagerService_GetOrCreateRaw_FullMethodName = "/health.ManagerService/GetOrCreateRaw" ManagerService_InsertRecordsRaw_FullMethodName = "/health.ManagerService/InsertRecordsRaw" ManagerService_ReadRecordsRaw_FullMethodName = "/health.ManagerService/ReadRecordsRaw" ManagerService_AggregateRaw_FullMethodName = "/health.ManagerService/AggregateRaw" ManagerService_DeleteRecordsRaw_FullMethodName = "/health.ManagerService/DeleteRecordsRaw" )
Variables ¶
var File_proto_health_health_proto protoreflect.FileDescriptor
var ManagerService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "health.ManagerService", HandlerType: (*ManagerServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "GetOrCreateRaw", Handler: _ManagerService_GetOrCreateRaw_Handler, }, { MethodName: "InsertRecordsRaw", Handler: _ManagerService_InsertRecordsRaw_Handler, }, { MethodName: "ReadRecordsRaw", Handler: _ManagerService_ReadRecordsRaw_Handler, }, { MethodName: "AggregateRaw", Handler: _ManagerService_AggregateRaw_Handler, }, { MethodName: "DeleteRecordsRaw", Handler: _ManagerService_DeleteRecordsRaw_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "proto/health/health.proto", }
ManagerService_ServiceDesc is the grpc.ServiceDesc for ManagerService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterManagerServiceServer ¶
func RegisterManagerServiceServer(s grpc.ServiceRegistrar, srv ManagerServiceServer)
Types ¶
type AggregateRawRequest ¶
type AggregateRawRequest struct {
Request int64 `protobuf:"varint,1,opt,name=request,proto3" json:"request,omitempty"`
// contains filtered or unexported fields
}
func (*AggregateRawRequest) Descriptor
deprecated
func (*AggregateRawRequest) Descriptor() ([]byte, []int)
Deprecated: Use AggregateRawRequest.ProtoReflect.Descriptor instead.
func (*AggregateRawRequest) GetRequest ¶
func (x *AggregateRawRequest) GetRequest() int64
func (*AggregateRawRequest) ProtoMessage ¶
func (*AggregateRawRequest) ProtoMessage()
func (*AggregateRawRequest) ProtoReflect ¶
func (x *AggregateRawRequest) ProtoReflect() protoreflect.Message
func (*AggregateRawRequest) Reset ¶
func (x *AggregateRawRequest) Reset()
func (*AggregateRawRequest) String ¶
func (x *AggregateRawRequest) String() string
type AggregateRawResponse ¶
type AggregateRawResponse struct {
Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*AggregateRawResponse) Descriptor
deprecated
func (*AggregateRawResponse) Descriptor() ([]byte, []int)
Deprecated: Use AggregateRawResponse.ProtoReflect.Descriptor instead.
func (*AggregateRawResponse) GetResult ¶
func (x *AggregateRawResponse) GetResult() int64
func (*AggregateRawResponse) ProtoMessage ¶
func (*AggregateRawResponse) ProtoMessage()
func (*AggregateRawResponse) ProtoReflect ¶
func (x *AggregateRawResponse) ProtoReflect() protoreflect.Message
func (*AggregateRawResponse) Reset ¶
func (x *AggregateRawResponse) Reset()
func (*AggregateRawResponse) String ¶
func (x *AggregateRawResponse) String() string
type DeleteRecordsRawRequest ¶
type DeleteRecordsRawRequest struct {
RecordType int64 `protobuf:"varint,1,opt,name=record_type,json=recordType,proto3" json:"record_type,omitempty"`
TimeRange int64 `protobuf:"varint,2,opt,name=time_range,json=timeRange,proto3" json:"time_range,omitempty"`
// contains filtered or unexported fields
}
func (*DeleteRecordsRawRequest) Descriptor
deprecated
func (*DeleteRecordsRawRequest) Descriptor() ([]byte, []int)
Deprecated: Use DeleteRecordsRawRequest.ProtoReflect.Descriptor instead.
func (*DeleteRecordsRawRequest) GetRecordType ¶
func (x *DeleteRecordsRawRequest) GetRecordType() int64
func (*DeleteRecordsRawRequest) GetTimeRange ¶
func (x *DeleteRecordsRawRequest) GetTimeRange() int64
func (*DeleteRecordsRawRequest) ProtoMessage ¶
func (*DeleteRecordsRawRequest) ProtoMessage()
func (*DeleteRecordsRawRequest) ProtoReflect ¶
func (x *DeleteRecordsRawRequest) ProtoReflect() protoreflect.Message
func (*DeleteRecordsRawRequest) Reset ¶
func (x *DeleteRecordsRawRequest) Reset()
func (*DeleteRecordsRawRequest) String ¶
func (x *DeleteRecordsRawRequest) String() string
type DeleteRecordsRawResponse ¶
type DeleteRecordsRawResponse struct {
// contains filtered or unexported fields
}
func (*DeleteRecordsRawResponse) Descriptor
deprecated
func (*DeleteRecordsRawResponse) Descriptor() ([]byte, []int)
Deprecated: Use DeleteRecordsRawResponse.ProtoReflect.Descriptor instead.
func (*DeleteRecordsRawResponse) ProtoMessage ¶
func (*DeleteRecordsRawResponse) ProtoMessage()
func (*DeleteRecordsRawResponse) ProtoReflect ¶
func (x *DeleteRecordsRawResponse) ProtoReflect() protoreflect.Message
func (*DeleteRecordsRawResponse) Reset ¶
func (x *DeleteRecordsRawResponse) Reset()
func (*DeleteRecordsRawResponse) String ¶
func (x *DeleteRecordsRawResponse) String() string
type GetOrCreateRawRequest ¶
type GetOrCreateRawRequest struct {
Ctx int64 `protobuf:"varint,1,opt,name=ctx,proto3" json:"ctx,omitempty"`
// contains filtered or unexported fields
}
func (*GetOrCreateRawRequest) Descriptor
deprecated
func (*GetOrCreateRawRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetOrCreateRawRequest.ProtoReflect.Descriptor instead.
func (*GetOrCreateRawRequest) GetCtx ¶
func (x *GetOrCreateRawRequest) GetCtx() int64
func (*GetOrCreateRawRequest) ProtoMessage ¶
func (*GetOrCreateRawRequest) ProtoMessage()
func (*GetOrCreateRawRequest) ProtoReflect ¶
func (x *GetOrCreateRawRequest) ProtoReflect() protoreflect.Message
func (*GetOrCreateRawRequest) Reset ¶
func (x *GetOrCreateRawRequest) Reset()
func (*GetOrCreateRawRequest) String ¶
func (x *GetOrCreateRawRequest) String() string
type GetOrCreateRawResponse ¶
type GetOrCreateRawResponse struct {
Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*GetOrCreateRawResponse) Descriptor
deprecated
func (*GetOrCreateRawResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetOrCreateRawResponse.ProtoReflect.Descriptor instead.
func (*GetOrCreateRawResponse) GetResult ¶
func (x *GetOrCreateRawResponse) GetResult() int64
func (*GetOrCreateRawResponse) ProtoMessage ¶
func (*GetOrCreateRawResponse) ProtoMessage()
func (*GetOrCreateRawResponse) ProtoReflect ¶
func (x *GetOrCreateRawResponse) ProtoReflect() protoreflect.Message
func (*GetOrCreateRawResponse) Reset ¶
func (x *GetOrCreateRawResponse) Reset()
func (*GetOrCreateRawResponse) String ¶
func (x *GetOrCreateRawResponse) String() string
type InsertRecordsRawRequest ¶
type InsertRecordsRawRequest struct {
Records int64 `protobuf:"varint,1,opt,name=records,proto3" json:"records,omitempty"`
// contains filtered or unexported fields
}
func (*InsertRecordsRawRequest) Descriptor
deprecated
func (*InsertRecordsRawRequest) Descriptor() ([]byte, []int)
Deprecated: Use InsertRecordsRawRequest.ProtoReflect.Descriptor instead.
func (*InsertRecordsRawRequest) GetRecords ¶
func (x *InsertRecordsRawRequest) GetRecords() int64
func (*InsertRecordsRawRequest) ProtoMessage ¶
func (*InsertRecordsRawRequest) ProtoMessage()
func (*InsertRecordsRawRequest) ProtoReflect ¶
func (x *InsertRecordsRawRequest) ProtoReflect() protoreflect.Message
func (*InsertRecordsRawRequest) Reset ¶
func (x *InsertRecordsRawRequest) Reset()
func (*InsertRecordsRawRequest) String ¶
func (x *InsertRecordsRawRequest) String() string
type InsertRecordsRawResponse ¶
type InsertRecordsRawResponse struct {
Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*InsertRecordsRawResponse) Descriptor
deprecated
func (*InsertRecordsRawResponse) Descriptor() ([]byte, []int)
Deprecated: Use InsertRecordsRawResponse.ProtoReflect.Descriptor instead.
func (*InsertRecordsRawResponse) GetResult ¶
func (x *InsertRecordsRawResponse) GetResult() int64
func (*InsertRecordsRawResponse) ProtoMessage ¶
func (*InsertRecordsRawResponse) ProtoMessage()
func (*InsertRecordsRawResponse) ProtoReflect ¶
func (x *InsertRecordsRawResponse) ProtoReflect() protoreflect.Message
func (*InsertRecordsRawResponse) Reset ¶
func (x *InsertRecordsRawResponse) Reset()
func (*InsertRecordsRawResponse) String ¶
func (x *InsertRecordsRawResponse) String() string
type ManagerServiceClient ¶
type ManagerServiceClient interface {
GetOrCreateRaw(ctx context.Context, in *GetOrCreateRawRequest, opts ...grpc.CallOption) (*GetOrCreateRawResponse, error)
InsertRecordsRaw(ctx context.Context, in *InsertRecordsRawRequest, opts ...grpc.CallOption) (*InsertRecordsRawResponse, error)
ReadRecordsRaw(ctx context.Context, in *ReadRecordsRawRequest, opts ...grpc.CallOption) (*ReadRecordsRawResponse, error)
AggregateRaw(ctx context.Context, in *AggregateRawRequest, opts ...grpc.CallOption) (*AggregateRawResponse, error)
DeleteRecordsRaw(ctx context.Context, in *DeleteRecordsRawRequest, opts ...grpc.CallOption) (*DeleteRecordsRawResponse, error)
}
ManagerServiceClient is the client API for ManagerService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewManagerServiceClient ¶
func NewManagerServiceClient(cc grpc.ClientConnInterface) ManagerServiceClient
type ManagerServiceServer ¶
type ManagerServiceServer interface {
GetOrCreateRaw(context.Context, *GetOrCreateRawRequest) (*GetOrCreateRawResponse, error)
InsertRecordsRaw(context.Context, *InsertRecordsRawRequest) (*InsertRecordsRawResponse, error)
ReadRecordsRaw(context.Context, *ReadRecordsRawRequest) (*ReadRecordsRawResponse, error)
AggregateRaw(context.Context, *AggregateRawRequest) (*AggregateRawResponse, error)
DeleteRecordsRaw(context.Context, *DeleteRecordsRawRequest) (*DeleteRecordsRawResponse, error)
// contains filtered or unexported methods
}
ManagerServiceServer is the server API for ManagerService service. All implementations must embed UnimplementedManagerServiceServer for forward compatibility.
type ReadRecordsRawRequest ¶
type ReadRecordsRawRequest struct {
Request int64 `protobuf:"varint,1,opt,name=request,proto3" json:"request,omitempty"`
// contains filtered or unexported fields
}
func (*ReadRecordsRawRequest) Descriptor
deprecated
func (*ReadRecordsRawRequest) Descriptor() ([]byte, []int)
Deprecated: Use ReadRecordsRawRequest.ProtoReflect.Descriptor instead.
func (*ReadRecordsRawRequest) GetRequest ¶
func (x *ReadRecordsRawRequest) GetRequest() int64
func (*ReadRecordsRawRequest) ProtoMessage ¶
func (*ReadRecordsRawRequest) ProtoMessage()
func (*ReadRecordsRawRequest) ProtoReflect ¶
func (x *ReadRecordsRawRequest) ProtoReflect() protoreflect.Message
func (*ReadRecordsRawRequest) Reset ¶
func (x *ReadRecordsRawRequest) Reset()
func (*ReadRecordsRawRequest) String ¶
func (x *ReadRecordsRawRequest) String() string
type ReadRecordsRawResponse ¶
type ReadRecordsRawResponse struct {
Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*ReadRecordsRawResponse) Descriptor
deprecated
func (*ReadRecordsRawResponse) Descriptor() ([]byte, []int)
Deprecated: Use ReadRecordsRawResponse.ProtoReflect.Descriptor instead.
func (*ReadRecordsRawResponse) GetResult ¶
func (x *ReadRecordsRawResponse) GetResult() int64
func (*ReadRecordsRawResponse) ProtoMessage ¶
func (*ReadRecordsRawResponse) ProtoMessage()
func (*ReadRecordsRawResponse) ProtoReflect ¶
func (x *ReadRecordsRawResponse) ProtoReflect() protoreflect.Message
func (*ReadRecordsRawResponse) Reset ¶
func (x *ReadRecordsRawResponse) Reset()
func (*ReadRecordsRawResponse) String ¶
func (x *ReadRecordsRawResponse) String() string
type UnimplementedManagerServiceServer ¶
type UnimplementedManagerServiceServer struct{}
UnimplementedManagerServiceServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedManagerServiceServer) AggregateRaw ¶
func (UnimplementedManagerServiceServer) AggregateRaw(context.Context, *AggregateRawRequest) (*AggregateRawResponse, error)
func (UnimplementedManagerServiceServer) DeleteRecordsRaw ¶
func (UnimplementedManagerServiceServer) DeleteRecordsRaw(context.Context, *DeleteRecordsRawRequest) (*DeleteRecordsRawResponse, error)
func (UnimplementedManagerServiceServer) GetOrCreateRaw ¶
func (UnimplementedManagerServiceServer) GetOrCreateRaw(context.Context, *GetOrCreateRawRequest) (*GetOrCreateRawResponse, error)
func (UnimplementedManagerServiceServer) InsertRecordsRaw ¶
func (UnimplementedManagerServiceServer) InsertRecordsRaw(context.Context, *InsertRecordsRawRequest) (*InsertRecordsRawResponse, error)
func (UnimplementedManagerServiceServer) ReadRecordsRaw ¶
func (UnimplementedManagerServiceServer) ReadRecordsRaw(context.Context, *ReadRecordsRawRequest) (*ReadRecordsRawResponse, error)
type UnsafeManagerServiceServer ¶
type UnsafeManagerServiceServer interface {
// contains filtered or unexported methods
}
UnsafeManagerServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ManagerServiceServer will result in compilation errors.