hpke

package
v0.0.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 29, 2026 License: CC0-1.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

const (
	XdhKeySpecService_NewXdhKeySpec_FullMethodName = "/hpke.XdhKeySpecService/NewXdhKeySpec"
	XdhKeySpecService_Equals_FullMethodName        = "/hpke.XdhKeySpecService/Equals"
	XdhKeySpecService_GetFormat_FullMethodName     = "/hpke.XdhKeySpecService/GetFormat"
	XdhKeySpecService_GetKey_FullMethodName        = "/hpke.XdhKeySpecService/GetKey"
	XdhKeySpecService_HashCode_FullMethodName      = "/hpke.XdhKeySpecService/HashCode"
)
const (
	SpiService_EngineExport_FullMethodName             = "/hpke.SpiService/EngineExport"
	SpiService_EngineInitRecipient_FullMethodName      = "/hpke.SpiService/EngineInitRecipient"
	SpiService_EngineInitSender_FullMethodName         = "/hpke.SpiService/EngineInitSender"
	SpiService_EngineInitSenderWithSeed_FullMethodName = "/hpke.SpiService/EngineInitSenderWithSeed"
	SpiService_EngineOpen_FullMethodName               = "/hpke.SpiService/EngineOpen"
	SpiService_EngineSeal_FullMethodName               = "/hpke.SpiService/EngineSeal"
	SpiService_GetEncapsulated_FullMethodName          = "/hpke.SpiService/GetEncapsulated"
)

Variables

var File_proto_hpke_hpke_proto protoreflect.FileDescriptor
var SpiService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "hpke.SpiService",
	HandlerType: (*SpiServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "EngineExport",
			Handler:    _SpiService_EngineExport_Handler,
		},
		{
			MethodName: "EngineInitRecipient",
			Handler:    _SpiService_EngineInitRecipient_Handler,
		},
		{
			MethodName: "EngineInitSender",
			Handler:    _SpiService_EngineInitSender_Handler,
		},
		{
			MethodName: "EngineInitSenderWithSeed",
			Handler:    _SpiService_EngineInitSenderWithSeed_Handler,
		},
		{
			MethodName: "EngineOpen",
			Handler:    _SpiService_EngineOpen_Handler,
		},
		{
			MethodName: "EngineSeal",
			Handler:    _SpiService_EngineSeal_Handler,
		},
		{
			MethodName: "GetEncapsulated",
			Handler:    _SpiService_GetEncapsulated_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/hpke/hpke.proto",
}

SpiService_ServiceDesc is the grpc.ServiceDesc for SpiService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var XdhKeySpecService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "hpke.XdhKeySpecService",
	HandlerType: (*XdhKeySpecServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "NewXdhKeySpec",
			Handler:    _XdhKeySpecService_NewXdhKeySpec_Handler,
		},
		{
			MethodName: "Equals",
			Handler:    _XdhKeySpecService_Equals_Handler,
		},
		{
			MethodName: "GetFormat",
			Handler:    _XdhKeySpecService_GetFormat_Handler,
		},
		{
			MethodName: "GetKey",
			Handler:    _XdhKeySpecService_GetKey_Handler,
		},
		{
			MethodName: "HashCode",
			Handler:    _XdhKeySpecService_HashCode_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/hpke/hpke.proto",
}

XdhKeySpecService_ServiceDesc is the grpc.ServiceDesc for XdhKeySpecService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterSpiServiceServer

func RegisterSpiServiceServer(s grpc.ServiceRegistrar, srv SpiServiceServer)

func RegisterXdhKeySpecServiceServer

func RegisterXdhKeySpecServiceServer(s grpc.ServiceRegistrar, srv XdhKeySpecServiceServer)

Types

type EngineExportRequest

type EngineExportRequest struct {
	Arg0 int32 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	Arg1 int64 `protobuf:"varint,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
	// contains filtered or unexported fields
}

func (*EngineExportRequest) Descriptor deprecated

func (*EngineExportRequest) Descriptor() ([]byte, []int)

Deprecated: Use EngineExportRequest.ProtoReflect.Descriptor instead.

func (*EngineExportRequest) GetArg0

func (x *EngineExportRequest) GetArg0() int32

func (*EngineExportRequest) GetArg1

func (x *EngineExportRequest) GetArg1() int64

func (*EngineExportRequest) ProtoMessage

func (*EngineExportRequest) ProtoMessage()

func (*EngineExportRequest) ProtoReflect

func (x *EngineExportRequest) ProtoReflect() protoreflect.Message

func (*EngineExportRequest) Reset

func (x *EngineExportRequest) Reset()

func (*EngineExportRequest) String

func (x *EngineExportRequest) String() string

type EngineExportResponse

type EngineExportResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*EngineExportResponse) Descriptor deprecated

func (*EngineExportResponse) Descriptor() ([]byte, []int)

Deprecated: Use EngineExportResponse.ProtoReflect.Descriptor instead.

func (*EngineExportResponse) GetResult

func (x *EngineExportResponse) GetResult() int64

func (*EngineExportResponse) ProtoMessage

func (*EngineExportResponse) ProtoMessage()

func (*EngineExportResponse) ProtoReflect

func (x *EngineExportResponse) ProtoReflect() protoreflect.Message

func (*EngineExportResponse) Reset

func (x *EngineExportResponse) Reset()

func (*EngineExportResponse) String

func (x *EngineExportResponse) String() string

type EngineInitRecipientRequest

type EngineInitRecipientRequest struct {
	Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	Arg1 int64 `protobuf:"varint,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
	Arg2 int64 `protobuf:"varint,3,opt,name=arg2,proto3" json:"arg2,omitempty"`
	Arg3 int64 `protobuf:"varint,4,opt,name=arg3,proto3" json:"arg3,omitempty"`
	Arg4 int64 `protobuf:"varint,5,opt,name=arg4,proto3" json:"arg4,omitempty"`
	Arg5 int64 `protobuf:"varint,6,opt,name=arg5,proto3" json:"arg5,omitempty"`
	// contains filtered or unexported fields
}

func (*EngineInitRecipientRequest) Descriptor deprecated

func (*EngineInitRecipientRequest) Descriptor() ([]byte, []int)

Deprecated: Use EngineInitRecipientRequest.ProtoReflect.Descriptor instead.

func (*EngineInitRecipientRequest) GetArg0

func (x *EngineInitRecipientRequest) GetArg0() int64

func (*EngineInitRecipientRequest) GetArg1

func (x *EngineInitRecipientRequest) GetArg1() int64

func (*EngineInitRecipientRequest) GetArg2

func (x *EngineInitRecipientRequest) GetArg2() int64

func (*EngineInitRecipientRequest) GetArg3

func (x *EngineInitRecipientRequest) GetArg3() int64

func (*EngineInitRecipientRequest) GetArg4

func (x *EngineInitRecipientRequest) GetArg4() int64

func (*EngineInitRecipientRequest) GetArg5

func (x *EngineInitRecipientRequest) GetArg5() int64

func (*EngineInitRecipientRequest) ProtoMessage

func (*EngineInitRecipientRequest) ProtoMessage()

func (*EngineInitRecipientRequest) ProtoReflect

func (*EngineInitRecipientRequest) Reset

func (x *EngineInitRecipientRequest) Reset()

func (*EngineInitRecipientRequest) String

func (x *EngineInitRecipientRequest) String() string

type EngineInitRecipientResponse

type EngineInitRecipientResponse struct {
	// contains filtered or unexported fields
}

func (*EngineInitRecipientResponse) Descriptor deprecated

func (*EngineInitRecipientResponse) Descriptor() ([]byte, []int)

Deprecated: Use EngineInitRecipientResponse.ProtoReflect.Descriptor instead.

func (*EngineInitRecipientResponse) ProtoMessage

func (*EngineInitRecipientResponse) ProtoMessage()

func (*EngineInitRecipientResponse) ProtoReflect

func (*EngineInitRecipientResponse) Reset

func (x *EngineInitRecipientResponse) Reset()

func (*EngineInitRecipientResponse) String

func (x *EngineInitRecipientResponse) String() string

type EngineInitSenderRequest

type EngineInitSenderRequest struct {
	Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	Arg1 int64 `protobuf:"varint,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
	Arg2 int64 `protobuf:"varint,3,opt,name=arg2,proto3" json:"arg2,omitempty"`
	Arg3 int64 `protobuf:"varint,4,opt,name=arg3,proto3" json:"arg3,omitempty"`
	Arg4 int64 `protobuf:"varint,5,opt,name=arg4,proto3" json:"arg4,omitempty"`
	// contains filtered or unexported fields
}

func (*EngineInitSenderRequest) Descriptor deprecated

func (*EngineInitSenderRequest) Descriptor() ([]byte, []int)

Deprecated: Use EngineInitSenderRequest.ProtoReflect.Descriptor instead.

func (*EngineInitSenderRequest) GetArg0

func (x *EngineInitSenderRequest) GetArg0() int64

func (*EngineInitSenderRequest) GetArg1

func (x *EngineInitSenderRequest) GetArg1() int64

func (*EngineInitSenderRequest) GetArg2

func (x *EngineInitSenderRequest) GetArg2() int64

func (*EngineInitSenderRequest) GetArg3

func (x *EngineInitSenderRequest) GetArg3() int64

func (*EngineInitSenderRequest) GetArg4

func (x *EngineInitSenderRequest) GetArg4() int64

func (*EngineInitSenderRequest) ProtoMessage

func (*EngineInitSenderRequest) ProtoMessage()

func (*EngineInitSenderRequest) ProtoReflect

func (x *EngineInitSenderRequest) ProtoReflect() protoreflect.Message

func (*EngineInitSenderRequest) Reset

func (x *EngineInitSenderRequest) Reset()

func (*EngineInitSenderRequest) String

func (x *EngineInitSenderRequest) String() string

type EngineInitSenderResponse

type EngineInitSenderResponse struct {
	// contains filtered or unexported fields
}

func (*EngineInitSenderResponse) Descriptor deprecated

func (*EngineInitSenderResponse) Descriptor() ([]byte, []int)

Deprecated: Use EngineInitSenderResponse.ProtoReflect.Descriptor instead.

func (*EngineInitSenderResponse) ProtoMessage

func (*EngineInitSenderResponse) ProtoMessage()

func (*EngineInitSenderResponse) ProtoReflect

func (x *EngineInitSenderResponse) ProtoReflect() protoreflect.Message

func (*EngineInitSenderResponse) Reset

func (x *EngineInitSenderResponse) Reset()

func (*EngineInitSenderResponse) String

func (x *EngineInitSenderResponse) String() string

type EngineInitSenderWithSeedRequest

type EngineInitSenderWithSeedRequest struct {
	Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	Arg1 int64 `protobuf:"varint,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
	Arg2 int64 `protobuf:"varint,3,opt,name=arg2,proto3" json:"arg2,omitempty"`
	Arg3 int64 `protobuf:"varint,4,opt,name=arg3,proto3" json:"arg3,omitempty"`
	Arg4 int64 `protobuf:"varint,5,opt,name=arg4,proto3" json:"arg4,omitempty"`
	Arg5 int64 `protobuf:"varint,6,opt,name=arg5,proto3" json:"arg5,omitempty"`
	// contains filtered or unexported fields
}

func (*EngineInitSenderWithSeedRequest) Descriptor deprecated

func (*EngineInitSenderWithSeedRequest) Descriptor() ([]byte, []int)

Deprecated: Use EngineInitSenderWithSeedRequest.ProtoReflect.Descriptor instead.

func (*EngineInitSenderWithSeedRequest) GetArg0

func (*EngineInitSenderWithSeedRequest) GetArg1

func (*EngineInitSenderWithSeedRequest) GetArg2

func (*EngineInitSenderWithSeedRequest) GetArg3

func (*EngineInitSenderWithSeedRequest) GetArg4

func (*EngineInitSenderWithSeedRequest) GetArg5

func (*EngineInitSenderWithSeedRequest) ProtoMessage

func (*EngineInitSenderWithSeedRequest) ProtoMessage()

func (*EngineInitSenderWithSeedRequest) ProtoReflect

func (*EngineInitSenderWithSeedRequest) Reset

func (*EngineInitSenderWithSeedRequest) String

type EngineInitSenderWithSeedResponse

type EngineInitSenderWithSeedResponse struct {
	// contains filtered or unexported fields
}

func (*EngineInitSenderWithSeedResponse) Descriptor deprecated

func (*EngineInitSenderWithSeedResponse) Descriptor() ([]byte, []int)

Deprecated: Use EngineInitSenderWithSeedResponse.ProtoReflect.Descriptor instead.

func (*EngineInitSenderWithSeedResponse) ProtoMessage

func (*EngineInitSenderWithSeedResponse) ProtoMessage()

func (*EngineInitSenderWithSeedResponse) ProtoReflect

func (*EngineInitSenderWithSeedResponse) Reset

func (*EngineInitSenderWithSeedResponse) String

type EngineOpenRequest

type EngineOpenRequest struct {
	Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	Arg1 int64 `protobuf:"varint,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
	// contains filtered or unexported fields
}

func (*EngineOpenRequest) Descriptor deprecated

func (*EngineOpenRequest) Descriptor() ([]byte, []int)

Deprecated: Use EngineOpenRequest.ProtoReflect.Descriptor instead.

func (*EngineOpenRequest) GetArg0

func (x *EngineOpenRequest) GetArg0() int64

func (*EngineOpenRequest) GetArg1

func (x *EngineOpenRequest) GetArg1() int64

func (*EngineOpenRequest) ProtoMessage

func (*EngineOpenRequest) ProtoMessage()

func (*EngineOpenRequest) ProtoReflect

func (x *EngineOpenRequest) ProtoReflect() protoreflect.Message

func (*EngineOpenRequest) Reset

func (x *EngineOpenRequest) Reset()

func (*EngineOpenRequest) String

func (x *EngineOpenRequest) String() string

type EngineOpenResponse

type EngineOpenResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*EngineOpenResponse) Descriptor deprecated

func (*EngineOpenResponse) Descriptor() ([]byte, []int)

Deprecated: Use EngineOpenResponse.ProtoReflect.Descriptor instead.

func (*EngineOpenResponse) GetResult

func (x *EngineOpenResponse) GetResult() int64

func (*EngineOpenResponse) ProtoMessage

func (*EngineOpenResponse) ProtoMessage()

func (*EngineOpenResponse) ProtoReflect

func (x *EngineOpenResponse) ProtoReflect() protoreflect.Message

func (*EngineOpenResponse) Reset

func (x *EngineOpenResponse) Reset()

func (*EngineOpenResponse) String

func (x *EngineOpenResponse) String() string

type EngineSealRequest

type EngineSealRequest struct {
	Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	Arg1 int64 `protobuf:"varint,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
	// contains filtered or unexported fields
}

func (*EngineSealRequest) Descriptor deprecated

func (*EngineSealRequest) Descriptor() ([]byte, []int)

Deprecated: Use EngineSealRequest.ProtoReflect.Descriptor instead.

func (*EngineSealRequest) GetArg0

func (x *EngineSealRequest) GetArg0() int64

func (*EngineSealRequest) GetArg1

func (x *EngineSealRequest) GetArg1() int64

func (*EngineSealRequest) ProtoMessage

func (*EngineSealRequest) ProtoMessage()

func (*EngineSealRequest) ProtoReflect

func (x *EngineSealRequest) ProtoReflect() protoreflect.Message

func (*EngineSealRequest) Reset

func (x *EngineSealRequest) Reset()

func (*EngineSealRequest) String

func (x *EngineSealRequest) String() string

type EngineSealResponse

type EngineSealResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*EngineSealResponse) Descriptor deprecated

func (*EngineSealResponse) Descriptor() ([]byte, []int)

Deprecated: Use EngineSealResponse.ProtoReflect.Descriptor instead.

func (*EngineSealResponse) GetResult

func (x *EngineSealResponse) GetResult() int64

func (*EngineSealResponse) ProtoMessage

func (*EngineSealResponse) ProtoMessage()

func (*EngineSealResponse) ProtoReflect

func (x *EngineSealResponse) ProtoReflect() protoreflect.Message

func (*EngineSealResponse) Reset

func (x *EngineSealResponse) Reset()

func (*EngineSealResponse) String

func (x *EngineSealResponse) String() string

type EqualsRequest

type EqualsRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	Arg0   int64 `protobuf:"varint,2,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*EqualsRequest) Descriptor deprecated

func (*EqualsRequest) Descriptor() ([]byte, []int)

Deprecated: Use EqualsRequest.ProtoReflect.Descriptor instead.

func (*EqualsRequest) GetArg0

func (x *EqualsRequest) GetArg0() int64

func (*EqualsRequest) GetHandle

func (x *EqualsRequest) GetHandle() int64

func (*EqualsRequest) ProtoMessage

func (*EqualsRequest) ProtoMessage()

func (*EqualsRequest) ProtoReflect

func (x *EqualsRequest) ProtoReflect() protoreflect.Message

func (*EqualsRequest) Reset

func (x *EqualsRequest) Reset()

func (*EqualsRequest) String

func (x *EqualsRequest) String() string

type EqualsResponse

type EqualsResponse struct {
	Result bool `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*EqualsResponse) Descriptor deprecated

func (*EqualsResponse) Descriptor() ([]byte, []int)

Deprecated: Use EqualsResponse.ProtoReflect.Descriptor instead.

func (*EqualsResponse) GetResult

func (x *EqualsResponse) GetResult() bool

func (*EqualsResponse) ProtoMessage

func (*EqualsResponse) ProtoMessage()

func (*EqualsResponse) ProtoReflect

func (x *EqualsResponse) ProtoReflect() protoreflect.Message

func (*EqualsResponse) Reset

func (x *EqualsResponse) Reset()

func (*EqualsResponse) String

func (x *EqualsResponse) String() string

type GetEncapsulatedRequest

type GetEncapsulatedRequest struct {
	// contains filtered or unexported fields
}

func (*GetEncapsulatedRequest) Descriptor deprecated

func (*GetEncapsulatedRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetEncapsulatedRequest.ProtoReflect.Descriptor instead.

func (*GetEncapsulatedRequest) ProtoMessage

func (*GetEncapsulatedRequest) ProtoMessage()

func (*GetEncapsulatedRequest) ProtoReflect

func (x *GetEncapsulatedRequest) ProtoReflect() protoreflect.Message

func (*GetEncapsulatedRequest) Reset

func (x *GetEncapsulatedRequest) Reset()

func (*GetEncapsulatedRequest) String

func (x *GetEncapsulatedRequest) String() string

type GetEncapsulatedResponse

type GetEncapsulatedResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetEncapsulatedResponse) Descriptor deprecated

func (*GetEncapsulatedResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetEncapsulatedResponse.ProtoReflect.Descriptor instead.

func (*GetEncapsulatedResponse) GetResult

func (x *GetEncapsulatedResponse) GetResult() int64

func (*GetEncapsulatedResponse) ProtoMessage

func (*GetEncapsulatedResponse) ProtoMessage()

func (*GetEncapsulatedResponse) ProtoReflect

func (x *GetEncapsulatedResponse) ProtoReflect() protoreflect.Message

func (*GetEncapsulatedResponse) Reset

func (x *GetEncapsulatedResponse) Reset()

func (*GetEncapsulatedResponse) String

func (x *GetEncapsulatedResponse) String() string

type GetFormatRequest

type GetFormatRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	// contains filtered or unexported fields
}

func (*GetFormatRequest) Descriptor deprecated

func (*GetFormatRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetFormatRequest.ProtoReflect.Descriptor instead.

func (*GetFormatRequest) GetHandle

func (x *GetFormatRequest) GetHandle() int64

func (*GetFormatRequest) ProtoMessage

func (*GetFormatRequest) ProtoMessage()

func (*GetFormatRequest) ProtoReflect

func (x *GetFormatRequest) ProtoReflect() protoreflect.Message

func (*GetFormatRequest) Reset

func (x *GetFormatRequest) Reset()

func (*GetFormatRequest) String

func (x *GetFormatRequest) String() string

type GetFormatResponse

type GetFormatResponse struct {
	Result string `protobuf:"bytes,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetFormatResponse) Descriptor deprecated

func (*GetFormatResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetFormatResponse.ProtoReflect.Descriptor instead.

func (*GetFormatResponse) GetResult

func (x *GetFormatResponse) GetResult() string

func (*GetFormatResponse) ProtoMessage

func (*GetFormatResponse) ProtoMessage()

func (*GetFormatResponse) ProtoReflect

func (x *GetFormatResponse) ProtoReflect() protoreflect.Message

func (*GetFormatResponse) Reset

func (x *GetFormatResponse) Reset()

func (*GetFormatResponse) String

func (x *GetFormatResponse) String() string

type GetKeyRequest

type GetKeyRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	// contains filtered or unexported fields
}

func (*GetKeyRequest) Descriptor deprecated

func (*GetKeyRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetKeyRequest.ProtoReflect.Descriptor instead.

func (*GetKeyRequest) GetHandle

func (x *GetKeyRequest) GetHandle() int64

func (*GetKeyRequest) ProtoMessage

func (*GetKeyRequest) ProtoMessage()

func (*GetKeyRequest) ProtoReflect

func (x *GetKeyRequest) ProtoReflect() protoreflect.Message

func (*GetKeyRequest) Reset

func (x *GetKeyRequest) Reset()

func (*GetKeyRequest) String

func (x *GetKeyRequest) String() string

type GetKeyResponse

type GetKeyResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetKeyResponse) Descriptor deprecated

func (*GetKeyResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetKeyResponse.ProtoReflect.Descriptor instead.

func (*GetKeyResponse) GetResult

func (x *GetKeyResponse) GetResult() int64

func (*GetKeyResponse) ProtoMessage

func (*GetKeyResponse) ProtoMessage()

func (*GetKeyResponse) ProtoReflect

func (x *GetKeyResponse) ProtoReflect() protoreflect.Message

func (*GetKeyResponse) Reset

func (x *GetKeyResponse) Reset()

func (*GetKeyResponse) String

func (x *GetKeyResponse) String() string

type HashCodeRequest

type HashCodeRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	// contains filtered or unexported fields
}

func (*HashCodeRequest) Descriptor deprecated

func (*HashCodeRequest) Descriptor() ([]byte, []int)

Deprecated: Use HashCodeRequest.ProtoReflect.Descriptor instead.

func (*HashCodeRequest) GetHandle

func (x *HashCodeRequest) GetHandle() int64

func (*HashCodeRequest) ProtoMessage

func (*HashCodeRequest) ProtoMessage()

func (*HashCodeRequest) ProtoReflect

func (x *HashCodeRequest) ProtoReflect() protoreflect.Message

func (*HashCodeRequest) Reset

func (x *HashCodeRequest) Reset()

func (*HashCodeRequest) String

func (x *HashCodeRequest) String() string

type HashCodeResponse

type HashCodeResponse struct {
	Result int32 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*HashCodeResponse) Descriptor deprecated

func (*HashCodeResponse) Descriptor() ([]byte, []int)

Deprecated: Use HashCodeResponse.ProtoReflect.Descriptor instead.

func (*HashCodeResponse) GetResult

func (x *HashCodeResponse) GetResult() int32

func (*HashCodeResponse) ProtoMessage

func (*HashCodeResponse) ProtoMessage()

func (*HashCodeResponse) ProtoReflect

func (x *HashCodeResponse) ProtoReflect() protoreflect.Message

func (*HashCodeResponse) Reset

func (x *HashCodeResponse) Reset()

func (*HashCodeResponse) String

func (x *HashCodeResponse) String() string

type NewXdhKeySpecRequest

type NewXdhKeySpecRequest struct {
	Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*NewXdhKeySpecRequest) Descriptor deprecated

func (*NewXdhKeySpecRequest) Descriptor() ([]byte, []int)

Deprecated: Use NewXdhKeySpecRequest.ProtoReflect.Descriptor instead.

func (*NewXdhKeySpecRequest) GetArg0

func (x *NewXdhKeySpecRequest) GetArg0() int64

func (*NewXdhKeySpecRequest) ProtoMessage

func (*NewXdhKeySpecRequest) ProtoMessage()

func (*NewXdhKeySpecRequest) ProtoReflect

func (x *NewXdhKeySpecRequest) ProtoReflect() protoreflect.Message

func (*NewXdhKeySpecRequest) Reset

func (x *NewXdhKeySpecRequest) Reset()

func (*NewXdhKeySpecRequest) String

func (x *NewXdhKeySpecRequest) String() string

type NewXdhKeySpecResponse

type NewXdhKeySpecResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*NewXdhKeySpecResponse) Descriptor deprecated

func (*NewXdhKeySpecResponse) Descriptor() ([]byte, []int)

Deprecated: Use NewXdhKeySpecResponse.ProtoReflect.Descriptor instead.

func (*NewXdhKeySpecResponse) GetResult

func (x *NewXdhKeySpecResponse) GetResult() int64

func (*NewXdhKeySpecResponse) ProtoMessage

func (*NewXdhKeySpecResponse) ProtoMessage()

func (*NewXdhKeySpecResponse) ProtoReflect

func (x *NewXdhKeySpecResponse) ProtoReflect() protoreflect.Message

func (*NewXdhKeySpecResponse) Reset

func (x *NewXdhKeySpecResponse) Reset()

func (*NewXdhKeySpecResponse) String

func (x *NewXdhKeySpecResponse) String() string

type SpiServiceClient

SpiServiceClient is the client API for SpiService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

func NewSpiServiceClient

func NewSpiServiceClient(cc grpc.ClientConnInterface) SpiServiceClient

type SpiServiceServer

SpiServiceServer is the server API for SpiService service. All implementations must embed UnimplementedSpiServiceServer for forward compatibility.

type UnimplementedSpiServiceServer

type UnimplementedSpiServiceServer struct{}

UnimplementedSpiServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedSpiServiceServer) EngineExport

func (UnimplementedSpiServiceServer) EngineInitSender

func (UnimplementedSpiServiceServer) EngineOpen

func (UnimplementedSpiServiceServer) EngineSeal

func (UnimplementedSpiServiceServer) GetEncapsulated

type UnimplementedXdhKeySpecServiceServer

type UnimplementedXdhKeySpecServiceServer struct{}

UnimplementedXdhKeySpecServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedXdhKeySpecServiceServer) Equals

func (UnimplementedXdhKeySpecServiceServer) GetFormat

func (UnimplementedXdhKeySpecServiceServer) GetKey

func (UnimplementedXdhKeySpecServiceServer) HashCode

func (UnimplementedXdhKeySpecServiceServer) NewXdhKeySpec

type UnsafeSpiServiceServer

type UnsafeSpiServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeSpiServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to SpiServiceServer will result in compilation errors.

type UnsafeXdhKeySpecServiceServer

type UnsafeXdhKeySpecServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeXdhKeySpecServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to XdhKeySpecServiceServer will result in compilation errors.

type XdhKeySpecServiceClient

type XdhKeySpecServiceClient interface {
	NewXdhKeySpec(ctx context.Context, in *NewXdhKeySpecRequest, opts ...grpc.CallOption) (*NewXdhKeySpecResponse, error)
	Equals(ctx context.Context, in *EqualsRequest, opts ...grpc.CallOption) (*EqualsResponse, error)
	GetFormat(ctx context.Context, in *GetFormatRequest, opts ...grpc.CallOption) (*GetFormatResponse, error)
	GetKey(ctx context.Context, in *GetKeyRequest, opts ...grpc.CallOption) (*GetKeyResponse, error)
	HashCode(ctx context.Context, in *HashCodeRequest, opts ...grpc.CallOption) (*HashCodeResponse, error)
}

XdhKeySpecServiceClient is the client API for XdhKeySpecService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type XdhKeySpecServiceServer

type XdhKeySpecServiceServer interface {
	NewXdhKeySpec(context.Context, *NewXdhKeySpecRequest) (*NewXdhKeySpecResponse, error)
	Equals(context.Context, *EqualsRequest) (*EqualsResponse, error)
	GetFormat(context.Context, *GetFormatRequest) (*GetFormatResponse, error)
	GetKey(context.Context, *GetKeyRequest) (*GetKeyResponse, error)
	HashCode(context.Context, *HashCodeRequest) (*HashCodeResponse, error)
	// contains filtered or unexported methods
}

XdhKeySpecServiceServer is the server API for XdhKeySpecService service. All implementations must embed UnimplementedXdhKeySpecServiceServer for forward compatibility.

Jump to