inline

package
v0.0.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 29, 2026 License: CC0-1.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

const (
	PresentationSpecService_DescribeContents_FullMethodName = "/inline.PresentationSpecService/DescribeContents"
	PresentationSpecService_Equals_FullMethodName           = "/inline.PresentationSpecService/Equals"
	PresentationSpecService_GetMaxSize_FullMethodName       = "/inline.PresentationSpecService/GetMaxSize"
	PresentationSpecService_GetMinSize_FullMethodName       = "/inline.PresentationSpecService/GetMinSize"
	PresentationSpecService_GetStyle_FullMethodName         = "/inline.PresentationSpecService/GetStyle"
	PresentationSpecService_HashCode_FullMethodName         = "/inline.PresentationSpecService/HashCode"
	PresentationSpecService_ToString_FullMethodName         = "/inline.PresentationSpecService/ToString"
	PresentationSpecService_WriteToParcel_FullMethodName    = "/inline.PresentationSpecService/WriteToParcel"
)
const (
	PresentationSpecBuilderService_Build_FullMethodName    = "/inline.PresentationSpecBuilderService/Build"
	PresentationSpecBuilderService_SetStyle_FullMethodName = "/inline.PresentationSpecBuilderService/SetStyle"
)
const (
	ContentViewService_GetSurfaceControl_FullMethodName         = "/inline.ContentViewService/GetSurfaceControl"
	ContentViewService_IsZOrderedOnTop_FullMethodName           = "/inline.ContentViewService/IsZOrderedOnTop"
	ContentViewService_OnLayout_FullMethodName                  = "/inline.ContentViewService/OnLayout"
	ContentViewService_SetClipBounds_FullMethodName             = "/inline.ContentViewService/SetClipBounds"
	ContentViewService_SetSurfaceControlCallback_FullMethodName = "/inline.ContentViewService/SetSurfaceControlCallback"
	ContentViewService_SetZOrderedOnTop_FullMethodName          = "/inline.ContentViewService/SetZOrderedOnTop"
)
const (
	ContentViewSurfaceControlCallbackService_OnCreated_FullMethodName   = "/inline.ContentViewSurfaceControlCallbackService/OnCreated"
	ContentViewSurfaceControlCallbackService_OnDestroyed_FullMethodName = "/inline.ContentViewSurfaceControlCallbackService/OnDestroyed"
)

Variables

var ContentViewService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "inline.ContentViewService",
	HandlerType: (*ContentViewServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "GetSurfaceControl",
			Handler:    _ContentViewService_GetSurfaceControl_Handler,
		},
		{
			MethodName: "IsZOrderedOnTop",
			Handler:    _ContentViewService_IsZOrderedOnTop_Handler,
		},
		{
			MethodName: "OnLayout",
			Handler:    _ContentViewService_OnLayout_Handler,
		},
		{
			MethodName: "SetClipBounds",
			Handler:    _ContentViewService_SetClipBounds_Handler,
		},
		{
			MethodName: "SetSurfaceControlCallback",
			Handler:    _ContentViewService_SetSurfaceControlCallback_Handler,
		},
		{
			MethodName: "SetZOrderedOnTop",
			Handler:    _ContentViewService_SetZOrderedOnTop_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/inline/inline.proto",
}

ContentViewService_ServiceDesc is the grpc.ServiceDesc for ContentViewService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var ContentViewSurfaceControlCallbackService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "inline.ContentViewSurfaceControlCallbackService",
	HandlerType: (*ContentViewSurfaceControlCallbackServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "OnCreated",
			Handler:    _ContentViewSurfaceControlCallbackService_OnCreated_Handler,
		},
		{
			MethodName: "OnDestroyed",
			Handler:    _ContentViewSurfaceControlCallbackService_OnDestroyed_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/inline/inline.proto",
}

ContentViewSurfaceControlCallbackService_ServiceDesc is the grpc.ServiceDesc for ContentViewSurfaceControlCallbackService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var File_proto_inline_inline_proto protoreflect.FileDescriptor
var PresentationSpecBuilderService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "inline.PresentationSpecBuilderService",
	HandlerType: (*PresentationSpecBuilderServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "Build",
			Handler:    _PresentationSpecBuilderService_Build_Handler,
		},
		{
			MethodName: "SetStyle",
			Handler:    _PresentationSpecBuilderService_SetStyle_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/inline/inline.proto",
}

PresentationSpecBuilderService_ServiceDesc is the grpc.ServiceDesc for PresentationSpecBuilderService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var PresentationSpecService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "inline.PresentationSpecService",
	HandlerType: (*PresentationSpecServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "DescribeContents",
			Handler:    _PresentationSpecService_DescribeContents_Handler,
		},
		{
			MethodName: "Equals",
			Handler:    _PresentationSpecService_Equals_Handler,
		},
		{
			MethodName: "GetMaxSize",
			Handler:    _PresentationSpecService_GetMaxSize_Handler,
		},
		{
			MethodName: "GetMinSize",
			Handler:    _PresentationSpecService_GetMinSize_Handler,
		},
		{
			MethodName: "GetStyle",
			Handler:    _PresentationSpecService_GetStyle_Handler,
		},
		{
			MethodName: "HashCode",
			Handler:    _PresentationSpecService_HashCode_Handler,
		},
		{
			MethodName: "ToString",
			Handler:    _PresentationSpecService_ToString_Handler,
		},
		{
			MethodName: "WriteToParcel",
			Handler:    _PresentationSpecService_WriteToParcel_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/inline/inline.proto",
}

PresentationSpecService_ServiceDesc is the grpc.ServiceDesc for PresentationSpecService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterContentViewServiceServer

func RegisterContentViewServiceServer(s grpc.ServiceRegistrar, srv ContentViewServiceServer)

func RegisterPresentationSpecBuilderServiceServer

func RegisterPresentationSpecBuilderServiceServer(s grpc.ServiceRegistrar, srv PresentationSpecBuilderServiceServer)

func RegisterPresentationSpecServiceServer

func RegisterPresentationSpecServiceServer(s grpc.ServiceRegistrar, srv PresentationSpecServiceServer)

Types

type BuildRequest

type BuildRequest struct {
	// contains filtered or unexported fields
}

func (*BuildRequest) Descriptor deprecated

func (*BuildRequest) Descriptor() ([]byte, []int)

Deprecated: Use BuildRequest.ProtoReflect.Descriptor instead.

func (*BuildRequest) ProtoMessage

func (*BuildRequest) ProtoMessage()

func (*BuildRequest) ProtoReflect

func (x *BuildRequest) ProtoReflect() protoreflect.Message

func (*BuildRequest) Reset

func (x *BuildRequest) Reset()

func (*BuildRequest) String

func (x *BuildRequest) String() string

type BuildResponse

type BuildResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*BuildResponse) Descriptor deprecated

func (*BuildResponse) Descriptor() ([]byte, []int)

Deprecated: Use BuildResponse.ProtoReflect.Descriptor instead.

func (*BuildResponse) GetResult

func (x *BuildResponse) GetResult() int64

func (*BuildResponse) ProtoMessage

func (*BuildResponse) ProtoMessage()

func (*BuildResponse) ProtoReflect

func (x *BuildResponse) ProtoReflect() protoreflect.Message

func (*BuildResponse) Reset

func (x *BuildResponse) Reset()

func (*BuildResponse) String

func (x *BuildResponse) String() string

type ContentViewServiceClient

type ContentViewServiceClient interface {
	GetSurfaceControl(ctx context.Context, in *GetSurfaceControlRequest, opts ...grpc.CallOption) (*GetSurfaceControlResponse, error)
	IsZOrderedOnTop(ctx context.Context, in *IsZOrderedOnTopRequest, opts ...grpc.CallOption) (*IsZOrderedOnTopResponse, error)
	OnLayout(ctx context.Context, in *OnLayoutRequest, opts ...grpc.CallOption) (*OnLayoutResponse, error)
	SetClipBounds(ctx context.Context, in *SetClipBoundsRequest, opts ...grpc.CallOption) (*SetClipBoundsResponse, error)
	SetSurfaceControlCallback(ctx context.Context, in *SetSurfaceControlCallbackRequest, opts ...grpc.CallOption) (*SetSurfaceControlCallbackResponse, error)
	SetZOrderedOnTop(ctx context.Context, in *SetZOrderedOnTopRequest, opts ...grpc.CallOption) (*SetZOrderedOnTopResponse, error)
}

ContentViewServiceClient is the client API for ContentViewService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type ContentViewServiceServer

ContentViewServiceServer is the server API for ContentViewService service. All implementations must embed UnimplementedContentViewServiceServer for forward compatibility.

type ContentViewSurfaceControlCallbackServiceClient

type ContentViewSurfaceControlCallbackServiceClient interface {
	OnCreated(ctx context.Context, in *OnCreatedRequest, opts ...grpc.CallOption) (*OnCreatedResponse, error)
	OnDestroyed(ctx context.Context, in *OnDestroyedRequest, opts ...grpc.CallOption) (*OnDestroyedResponse, error)
}

ContentViewSurfaceControlCallbackServiceClient is the client API for ContentViewSurfaceControlCallbackService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type ContentViewSurfaceControlCallbackServiceServer

type ContentViewSurfaceControlCallbackServiceServer interface {
	OnCreated(context.Context, *OnCreatedRequest) (*OnCreatedResponse, error)
	OnDestroyed(context.Context, *OnDestroyedRequest) (*OnDestroyedResponse, error)
	// contains filtered or unexported methods
}

ContentViewSurfaceControlCallbackServiceServer is the server API for ContentViewSurfaceControlCallbackService service. All implementations must embed UnimplementedContentViewSurfaceControlCallbackServiceServer for forward compatibility.

type DescribeContentsRequest

type DescribeContentsRequest struct {
	// contains filtered or unexported fields
}

func (*DescribeContentsRequest) Descriptor deprecated

func (*DescribeContentsRequest) Descriptor() ([]byte, []int)

Deprecated: Use DescribeContentsRequest.ProtoReflect.Descriptor instead.

func (*DescribeContentsRequest) ProtoMessage

func (*DescribeContentsRequest) ProtoMessage()

func (*DescribeContentsRequest) ProtoReflect

func (x *DescribeContentsRequest) ProtoReflect() protoreflect.Message

func (*DescribeContentsRequest) Reset

func (x *DescribeContentsRequest) Reset()

func (*DescribeContentsRequest) String

func (x *DescribeContentsRequest) String() string

type DescribeContentsResponse

type DescribeContentsResponse struct {
	Result int32 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*DescribeContentsResponse) Descriptor deprecated

func (*DescribeContentsResponse) Descriptor() ([]byte, []int)

Deprecated: Use DescribeContentsResponse.ProtoReflect.Descriptor instead.

func (*DescribeContentsResponse) GetResult

func (x *DescribeContentsResponse) GetResult() int32

func (*DescribeContentsResponse) ProtoMessage

func (*DescribeContentsResponse) ProtoMessage()

func (*DescribeContentsResponse) ProtoReflect

func (x *DescribeContentsResponse) ProtoReflect() protoreflect.Message

func (*DescribeContentsResponse) Reset

func (x *DescribeContentsResponse) Reset()

func (*DescribeContentsResponse) String

func (x *DescribeContentsResponse) String() string

type EqualsRequest

type EqualsRequest struct {
	Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*EqualsRequest) Descriptor deprecated

func (*EqualsRequest) Descriptor() ([]byte, []int)

Deprecated: Use EqualsRequest.ProtoReflect.Descriptor instead.

func (*EqualsRequest) GetArg0

func (x *EqualsRequest) GetArg0() int64

func (*EqualsRequest) ProtoMessage

func (*EqualsRequest) ProtoMessage()

func (*EqualsRequest) ProtoReflect

func (x *EqualsRequest) ProtoReflect() protoreflect.Message

func (*EqualsRequest) Reset

func (x *EqualsRequest) Reset()

func (*EqualsRequest) String

func (x *EqualsRequest) String() string

type EqualsResponse

type EqualsResponse struct {
	Result bool `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*EqualsResponse) Descriptor deprecated

func (*EqualsResponse) Descriptor() ([]byte, []int)

Deprecated: Use EqualsResponse.ProtoReflect.Descriptor instead.

func (*EqualsResponse) GetResult

func (x *EqualsResponse) GetResult() bool

func (*EqualsResponse) ProtoMessage

func (*EqualsResponse) ProtoMessage()

func (*EqualsResponse) ProtoReflect

func (x *EqualsResponse) ProtoReflect() protoreflect.Message

func (*EqualsResponse) Reset

func (x *EqualsResponse) Reset()

func (*EqualsResponse) String

func (x *EqualsResponse) String() string

type GetMaxSizeRequest

type GetMaxSizeRequest struct {
	// contains filtered or unexported fields
}

func (*GetMaxSizeRequest) Descriptor deprecated

func (*GetMaxSizeRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetMaxSizeRequest.ProtoReflect.Descriptor instead.

func (*GetMaxSizeRequest) ProtoMessage

func (*GetMaxSizeRequest) ProtoMessage()

func (*GetMaxSizeRequest) ProtoReflect

func (x *GetMaxSizeRequest) ProtoReflect() protoreflect.Message

func (*GetMaxSizeRequest) Reset

func (x *GetMaxSizeRequest) Reset()

func (*GetMaxSizeRequest) String

func (x *GetMaxSizeRequest) String() string

type GetMaxSizeResponse

type GetMaxSizeResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetMaxSizeResponse) Descriptor deprecated

func (*GetMaxSizeResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetMaxSizeResponse.ProtoReflect.Descriptor instead.

func (*GetMaxSizeResponse) GetResult

func (x *GetMaxSizeResponse) GetResult() int64

func (*GetMaxSizeResponse) ProtoMessage

func (*GetMaxSizeResponse) ProtoMessage()

func (*GetMaxSizeResponse) ProtoReflect

func (x *GetMaxSizeResponse) ProtoReflect() protoreflect.Message

func (*GetMaxSizeResponse) Reset

func (x *GetMaxSizeResponse) Reset()

func (*GetMaxSizeResponse) String

func (x *GetMaxSizeResponse) String() string

type GetMinSizeRequest

type GetMinSizeRequest struct {
	// contains filtered or unexported fields
}

func (*GetMinSizeRequest) Descriptor deprecated

func (*GetMinSizeRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetMinSizeRequest.ProtoReflect.Descriptor instead.

func (*GetMinSizeRequest) ProtoMessage

func (*GetMinSizeRequest) ProtoMessage()

func (*GetMinSizeRequest) ProtoReflect

func (x *GetMinSizeRequest) ProtoReflect() protoreflect.Message

func (*GetMinSizeRequest) Reset

func (x *GetMinSizeRequest) Reset()

func (*GetMinSizeRequest) String

func (x *GetMinSizeRequest) String() string

type GetMinSizeResponse

type GetMinSizeResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetMinSizeResponse) Descriptor deprecated

func (*GetMinSizeResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetMinSizeResponse.ProtoReflect.Descriptor instead.

func (*GetMinSizeResponse) GetResult

func (x *GetMinSizeResponse) GetResult() int64

func (*GetMinSizeResponse) ProtoMessage

func (*GetMinSizeResponse) ProtoMessage()

func (*GetMinSizeResponse) ProtoReflect

func (x *GetMinSizeResponse) ProtoReflect() protoreflect.Message

func (*GetMinSizeResponse) Reset

func (x *GetMinSizeResponse) Reset()

func (*GetMinSizeResponse) String

func (x *GetMinSizeResponse) String() string

type GetStyleRequest

type GetStyleRequest struct {
	// contains filtered or unexported fields
}

func (*GetStyleRequest) Descriptor deprecated

func (*GetStyleRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetStyleRequest.ProtoReflect.Descriptor instead.

func (*GetStyleRequest) ProtoMessage

func (*GetStyleRequest) ProtoMessage()

func (*GetStyleRequest) ProtoReflect

func (x *GetStyleRequest) ProtoReflect() protoreflect.Message

func (*GetStyleRequest) Reset

func (x *GetStyleRequest) Reset()

func (*GetStyleRequest) String

func (x *GetStyleRequest) String() string

type GetStyleResponse

type GetStyleResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetStyleResponse) Descriptor deprecated

func (*GetStyleResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetStyleResponse.ProtoReflect.Descriptor instead.

func (*GetStyleResponse) GetResult

func (x *GetStyleResponse) GetResult() int64

func (*GetStyleResponse) ProtoMessage

func (*GetStyleResponse) ProtoMessage()

func (*GetStyleResponse) ProtoReflect

func (x *GetStyleResponse) ProtoReflect() protoreflect.Message

func (*GetStyleResponse) Reset

func (x *GetStyleResponse) Reset()

func (*GetStyleResponse) String

func (x *GetStyleResponse) String() string

type GetSurfaceControlRequest

type GetSurfaceControlRequest struct {
	// contains filtered or unexported fields
}

func (*GetSurfaceControlRequest) Descriptor deprecated

func (*GetSurfaceControlRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetSurfaceControlRequest.ProtoReflect.Descriptor instead.

func (*GetSurfaceControlRequest) ProtoMessage

func (*GetSurfaceControlRequest) ProtoMessage()

func (*GetSurfaceControlRequest) ProtoReflect

func (x *GetSurfaceControlRequest) ProtoReflect() protoreflect.Message

func (*GetSurfaceControlRequest) Reset

func (x *GetSurfaceControlRequest) Reset()

func (*GetSurfaceControlRequest) String

func (x *GetSurfaceControlRequest) String() string

type GetSurfaceControlResponse

type GetSurfaceControlResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetSurfaceControlResponse) Descriptor deprecated

func (*GetSurfaceControlResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetSurfaceControlResponse.ProtoReflect.Descriptor instead.

func (*GetSurfaceControlResponse) GetResult

func (x *GetSurfaceControlResponse) GetResult() int64

func (*GetSurfaceControlResponse) ProtoMessage

func (*GetSurfaceControlResponse) ProtoMessage()

func (*GetSurfaceControlResponse) ProtoReflect

func (*GetSurfaceControlResponse) Reset

func (x *GetSurfaceControlResponse) Reset()

func (*GetSurfaceControlResponse) String

func (x *GetSurfaceControlResponse) String() string

type HashCodeRequest

type HashCodeRequest struct {
	// contains filtered or unexported fields
}

func (*HashCodeRequest) Descriptor deprecated

func (*HashCodeRequest) Descriptor() ([]byte, []int)

Deprecated: Use HashCodeRequest.ProtoReflect.Descriptor instead.

func (*HashCodeRequest) ProtoMessage

func (*HashCodeRequest) ProtoMessage()

func (*HashCodeRequest) ProtoReflect

func (x *HashCodeRequest) ProtoReflect() protoreflect.Message

func (*HashCodeRequest) Reset

func (x *HashCodeRequest) Reset()

func (*HashCodeRequest) String

func (x *HashCodeRequest) String() string

type HashCodeResponse

type HashCodeResponse struct {
	Result int32 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*HashCodeResponse) Descriptor deprecated

func (*HashCodeResponse) Descriptor() ([]byte, []int)

Deprecated: Use HashCodeResponse.ProtoReflect.Descriptor instead.

func (*HashCodeResponse) GetResult

func (x *HashCodeResponse) GetResult() int32

func (*HashCodeResponse) ProtoMessage

func (*HashCodeResponse) ProtoMessage()

func (*HashCodeResponse) ProtoReflect

func (x *HashCodeResponse) ProtoReflect() protoreflect.Message

func (*HashCodeResponse) Reset

func (x *HashCodeResponse) Reset()

func (*HashCodeResponse) String

func (x *HashCodeResponse) String() string

type IsZOrderedOnTopRequest

type IsZOrderedOnTopRequest struct {
	// contains filtered or unexported fields
}

func (*IsZOrderedOnTopRequest) Descriptor deprecated

func (*IsZOrderedOnTopRequest) Descriptor() ([]byte, []int)

Deprecated: Use IsZOrderedOnTopRequest.ProtoReflect.Descriptor instead.

func (*IsZOrderedOnTopRequest) ProtoMessage

func (*IsZOrderedOnTopRequest) ProtoMessage()

func (*IsZOrderedOnTopRequest) ProtoReflect

func (x *IsZOrderedOnTopRequest) ProtoReflect() protoreflect.Message

func (*IsZOrderedOnTopRequest) Reset

func (x *IsZOrderedOnTopRequest) Reset()

func (*IsZOrderedOnTopRequest) String

func (x *IsZOrderedOnTopRequest) String() string

type IsZOrderedOnTopResponse

type IsZOrderedOnTopResponse struct {
	Result bool `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*IsZOrderedOnTopResponse) Descriptor deprecated

func (*IsZOrderedOnTopResponse) Descriptor() ([]byte, []int)

Deprecated: Use IsZOrderedOnTopResponse.ProtoReflect.Descriptor instead.

func (*IsZOrderedOnTopResponse) GetResult

func (x *IsZOrderedOnTopResponse) GetResult() bool

func (*IsZOrderedOnTopResponse) ProtoMessage

func (*IsZOrderedOnTopResponse) ProtoMessage()

func (*IsZOrderedOnTopResponse) ProtoReflect

func (x *IsZOrderedOnTopResponse) ProtoReflect() protoreflect.Message

func (*IsZOrderedOnTopResponse) Reset

func (x *IsZOrderedOnTopResponse) Reset()

func (*IsZOrderedOnTopResponse) String

func (x *IsZOrderedOnTopResponse) String() string

type OnCreatedRequest

type OnCreatedRequest struct {
	Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*OnCreatedRequest) Descriptor deprecated

func (*OnCreatedRequest) Descriptor() ([]byte, []int)

Deprecated: Use OnCreatedRequest.ProtoReflect.Descriptor instead.

func (*OnCreatedRequest) GetArg0

func (x *OnCreatedRequest) GetArg0() int64

func (*OnCreatedRequest) ProtoMessage

func (*OnCreatedRequest) ProtoMessage()

func (*OnCreatedRequest) ProtoReflect

func (x *OnCreatedRequest) ProtoReflect() protoreflect.Message

func (*OnCreatedRequest) Reset

func (x *OnCreatedRequest) Reset()

func (*OnCreatedRequest) String

func (x *OnCreatedRequest) String() string

type OnCreatedResponse

type OnCreatedResponse struct {
	// contains filtered or unexported fields
}

func (*OnCreatedResponse) Descriptor deprecated

func (*OnCreatedResponse) Descriptor() ([]byte, []int)

Deprecated: Use OnCreatedResponse.ProtoReflect.Descriptor instead.

func (*OnCreatedResponse) ProtoMessage

func (*OnCreatedResponse) ProtoMessage()

func (*OnCreatedResponse) ProtoReflect

func (x *OnCreatedResponse) ProtoReflect() protoreflect.Message

func (*OnCreatedResponse) Reset

func (x *OnCreatedResponse) Reset()

func (*OnCreatedResponse) String

func (x *OnCreatedResponse) String() string

type OnDestroyedRequest

type OnDestroyedRequest struct {
	Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*OnDestroyedRequest) Descriptor deprecated

func (*OnDestroyedRequest) Descriptor() ([]byte, []int)

Deprecated: Use OnDestroyedRequest.ProtoReflect.Descriptor instead.

func (*OnDestroyedRequest) GetArg0

func (x *OnDestroyedRequest) GetArg0() int64

func (*OnDestroyedRequest) ProtoMessage

func (*OnDestroyedRequest) ProtoMessage()

func (*OnDestroyedRequest) ProtoReflect

func (x *OnDestroyedRequest) ProtoReflect() protoreflect.Message

func (*OnDestroyedRequest) Reset

func (x *OnDestroyedRequest) Reset()

func (*OnDestroyedRequest) String

func (x *OnDestroyedRequest) String() string

type OnDestroyedResponse

type OnDestroyedResponse struct {
	// contains filtered or unexported fields
}

func (*OnDestroyedResponse) Descriptor deprecated

func (*OnDestroyedResponse) Descriptor() ([]byte, []int)

Deprecated: Use OnDestroyedResponse.ProtoReflect.Descriptor instead.

func (*OnDestroyedResponse) ProtoMessage

func (*OnDestroyedResponse) ProtoMessage()

func (*OnDestroyedResponse) ProtoReflect

func (x *OnDestroyedResponse) ProtoReflect() protoreflect.Message

func (*OnDestroyedResponse) Reset

func (x *OnDestroyedResponse) Reset()

func (*OnDestroyedResponse) String

func (x *OnDestroyedResponse) String() string

type OnLayoutRequest

type OnLayoutRequest struct {
	Arg0 bool  `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	Arg1 int32 `protobuf:"varint,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
	Arg2 int32 `protobuf:"varint,3,opt,name=arg2,proto3" json:"arg2,omitempty"`
	Arg3 int32 `protobuf:"varint,4,opt,name=arg3,proto3" json:"arg3,omitempty"`
	Arg4 int32 `protobuf:"varint,5,opt,name=arg4,proto3" json:"arg4,omitempty"`
	// contains filtered or unexported fields
}

func (*OnLayoutRequest) Descriptor deprecated

func (*OnLayoutRequest) Descriptor() ([]byte, []int)

Deprecated: Use OnLayoutRequest.ProtoReflect.Descriptor instead.

func (*OnLayoutRequest) GetArg0

func (x *OnLayoutRequest) GetArg0() bool

func (*OnLayoutRequest) GetArg1

func (x *OnLayoutRequest) GetArg1() int32

func (*OnLayoutRequest) GetArg2

func (x *OnLayoutRequest) GetArg2() int32

func (*OnLayoutRequest) GetArg3

func (x *OnLayoutRequest) GetArg3() int32

func (*OnLayoutRequest) GetArg4

func (x *OnLayoutRequest) GetArg4() int32

func (*OnLayoutRequest) ProtoMessage

func (*OnLayoutRequest) ProtoMessage()

func (*OnLayoutRequest) ProtoReflect

func (x *OnLayoutRequest) ProtoReflect() protoreflect.Message

func (*OnLayoutRequest) Reset

func (x *OnLayoutRequest) Reset()

func (*OnLayoutRequest) String

func (x *OnLayoutRequest) String() string

type OnLayoutResponse

type OnLayoutResponse struct {
	// contains filtered or unexported fields
}

func (*OnLayoutResponse) Descriptor deprecated

func (*OnLayoutResponse) Descriptor() ([]byte, []int)

Deprecated: Use OnLayoutResponse.ProtoReflect.Descriptor instead.

func (*OnLayoutResponse) ProtoMessage

func (*OnLayoutResponse) ProtoMessage()

func (*OnLayoutResponse) ProtoReflect

func (x *OnLayoutResponse) ProtoReflect() protoreflect.Message

func (*OnLayoutResponse) Reset

func (x *OnLayoutResponse) Reset()

func (*OnLayoutResponse) String

func (x *OnLayoutResponse) String() string

type PresentationSpecBuilderServiceClient

type PresentationSpecBuilderServiceClient interface {
	Build(ctx context.Context, in *BuildRequest, opts ...grpc.CallOption) (*BuildResponse, error)
	SetStyle(ctx context.Context, in *SetStyleRequest, opts ...grpc.CallOption) (*SetStyleResponse, error)
}

PresentationSpecBuilderServiceClient is the client API for PresentationSpecBuilderService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type PresentationSpecBuilderServiceServer

type PresentationSpecBuilderServiceServer interface {
	Build(context.Context, *BuildRequest) (*BuildResponse, error)
	SetStyle(context.Context, *SetStyleRequest) (*SetStyleResponse, error)
	// contains filtered or unexported methods
}

PresentationSpecBuilderServiceServer is the server API for PresentationSpecBuilderService service. All implementations must embed UnimplementedPresentationSpecBuilderServiceServer for forward compatibility.

type PresentationSpecServiceClient

type PresentationSpecServiceClient interface {
	DescribeContents(ctx context.Context, in *DescribeContentsRequest, opts ...grpc.CallOption) (*DescribeContentsResponse, error)
	Equals(ctx context.Context, in *EqualsRequest, opts ...grpc.CallOption) (*EqualsResponse, error)
	GetMaxSize(ctx context.Context, in *GetMaxSizeRequest, opts ...grpc.CallOption) (*GetMaxSizeResponse, error)
	GetMinSize(ctx context.Context, in *GetMinSizeRequest, opts ...grpc.CallOption) (*GetMinSizeResponse, error)
	GetStyle(ctx context.Context, in *GetStyleRequest, opts ...grpc.CallOption) (*GetStyleResponse, error)
	HashCode(ctx context.Context, in *HashCodeRequest, opts ...grpc.CallOption) (*HashCodeResponse, error)
	ToString(ctx context.Context, in *ToStringRequest, opts ...grpc.CallOption) (*ToStringResponse, error)
	WriteToParcel(ctx context.Context, in *WriteToParcelRequest, opts ...grpc.CallOption) (*WriteToParcelResponse, error)
}

PresentationSpecServiceClient is the client API for PresentationSpecService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type PresentationSpecServiceServer

PresentationSpecServiceServer is the server API for PresentationSpecService service. All implementations must embed UnimplementedPresentationSpecServiceServer for forward compatibility.

type SetClipBoundsRequest

type SetClipBoundsRequest struct {
	Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*SetClipBoundsRequest) Descriptor deprecated

func (*SetClipBoundsRequest) Descriptor() ([]byte, []int)

Deprecated: Use SetClipBoundsRequest.ProtoReflect.Descriptor instead.

func (*SetClipBoundsRequest) GetArg0

func (x *SetClipBoundsRequest) GetArg0() int64

func (*SetClipBoundsRequest) ProtoMessage

func (*SetClipBoundsRequest) ProtoMessage()

func (*SetClipBoundsRequest) ProtoReflect

func (x *SetClipBoundsRequest) ProtoReflect() protoreflect.Message

func (*SetClipBoundsRequest) Reset

func (x *SetClipBoundsRequest) Reset()

func (*SetClipBoundsRequest) String

func (x *SetClipBoundsRequest) String() string

type SetClipBoundsResponse

type SetClipBoundsResponse struct {
	// contains filtered or unexported fields
}

func (*SetClipBoundsResponse) Descriptor deprecated

func (*SetClipBoundsResponse) Descriptor() ([]byte, []int)

Deprecated: Use SetClipBoundsResponse.ProtoReflect.Descriptor instead.

func (*SetClipBoundsResponse) ProtoMessage

func (*SetClipBoundsResponse) ProtoMessage()

func (*SetClipBoundsResponse) ProtoReflect

func (x *SetClipBoundsResponse) ProtoReflect() protoreflect.Message

func (*SetClipBoundsResponse) Reset

func (x *SetClipBoundsResponse) Reset()

func (*SetClipBoundsResponse) String

func (x *SetClipBoundsResponse) String() string

type SetStyleRequest

type SetStyleRequest struct {
	Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*SetStyleRequest) Descriptor deprecated

func (*SetStyleRequest) Descriptor() ([]byte, []int)

Deprecated: Use SetStyleRequest.ProtoReflect.Descriptor instead.

func (*SetStyleRequest) GetArg0

func (x *SetStyleRequest) GetArg0() int64

func (*SetStyleRequest) ProtoMessage

func (*SetStyleRequest) ProtoMessage()

func (*SetStyleRequest) ProtoReflect

func (x *SetStyleRequest) ProtoReflect() protoreflect.Message

func (*SetStyleRequest) Reset

func (x *SetStyleRequest) Reset()

func (*SetStyleRequest) String

func (x *SetStyleRequest) String() string

type SetStyleResponse

type SetStyleResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*SetStyleResponse) Descriptor deprecated

func (*SetStyleResponse) Descriptor() ([]byte, []int)

Deprecated: Use SetStyleResponse.ProtoReflect.Descriptor instead.

func (*SetStyleResponse) GetResult

func (x *SetStyleResponse) GetResult() int64

func (*SetStyleResponse) ProtoMessage

func (*SetStyleResponse) ProtoMessage()

func (*SetStyleResponse) ProtoReflect

func (x *SetStyleResponse) ProtoReflect() protoreflect.Message

func (*SetStyleResponse) Reset

func (x *SetStyleResponse) Reset()

func (*SetStyleResponse) String

func (x *SetStyleResponse) String() string

type SetSurfaceControlCallbackRequest

type SetSurfaceControlCallbackRequest struct {
	Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*SetSurfaceControlCallbackRequest) Descriptor deprecated

func (*SetSurfaceControlCallbackRequest) Descriptor() ([]byte, []int)

Deprecated: Use SetSurfaceControlCallbackRequest.ProtoReflect.Descriptor instead.

func (*SetSurfaceControlCallbackRequest) GetArg0

func (*SetSurfaceControlCallbackRequest) ProtoMessage

func (*SetSurfaceControlCallbackRequest) ProtoMessage()

func (*SetSurfaceControlCallbackRequest) ProtoReflect

func (*SetSurfaceControlCallbackRequest) Reset

func (*SetSurfaceControlCallbackRequest) String

type SetSurfaceControlCallbackResponse

type SetSurfaceControlCallbackResponse struct {
	// contains filtered or unexported fields
}

func (*SetSurfaceControlCallbackResponse) Descriptor deprecated

func (*SetSurfaceControlCallbackResponse) Descriptor() ([]byte, []int)

Deprecated: Use SetSurfaceControlCallbackResponse.ProtoReflect.Descriptor instead.

func (*SetSurfaceControlCallbackResponse) ProtoMessage

func (*SetSurfaceControlCallbackResponse) ProtoMessage()

func (*SetSurfaceControlCallbackResponse) ProtoReflect

func (*SetSurfaceControlCallbackResponse) Reset

func (*SetSurfaceControlCallbackResponse) String

type SetZOrderedOnTopRequest

type SetZOrderedOnTopRequest struct {
	Arg0 bool `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*SetZOrderedOnTopRequest) Descriptor deprecated

func (*SetZOrderedOnTopRequest) Descriptor() ([]byte, []int)

Deprecated: Use SetZOrderedOnTopRequest.ProtoReflect.Descriptor instead.

func (*SetZOrderedOnTopRequest) GetArg0

func (x *SetZOrderedOnTopRequest) GetArg0() bool

func (*SetZOrderedOnTopRequest) ProtoMessage

func (*SetZOrderedOnTopRequest) ProtoMessage()

func (*SetZOrderedOnTopRequest) ProtoReflect

func (x *SetZOrderedOnTopRequest) ProtoReflect() protoreflect.Message

func (*SetZOrderedOnTopRequest) Reset

func (x *SetZOrderedOnTopRequest) Reset()

func (*SetZOrderedOnTopRequest) String

func (x *SetZOrderedOnTopRequest) String() string

type SetZOrderedOnTopResponse

type SetZOrderedOnTopResponse struct {
	Result bool `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*SetZOrderedOnTopResponse) Descriptor deprecated

func (*SetZOrderedOnTopResponse) Descriptor() ([]byte, []int)

Deprecated: Use SetZOrderedOnTopResponse.ProtoReflect.Descriptor instead.

func (*SetZOrderedOnTopResponse) GetResult

func (x *SetZOrderedOnTopResponse) GetResult() bool

func (*SetZOrderedOnTopResponse) ProtoMessage

func (*SetZOrderedOnTopResponse) ProtoMessage()

func (*SetZOrderedOnTopResponse) ProtoReflect

func (x *SetZOrderedOnTopResponse) ProtoReflect() protoreflect.Message

func (*SetZOrderedOnTopResponse) Reset

func (x *SetZOrderedOnTopResponse) Reset()

func (*SetZOrderedOnTopResponse) String

func (x *SetZOrderedOnTopResponse) String() string

type ToStringRequest

type ToStringRequest struct {
	// contains filtered or unexported fields
}

func (*ToStringRequest) Descriptor deprecated

func (*ToStringRequest) Descriptor() ([]byte, []int)

Deprecated: Use ToStringRequest.ProtoReflect.Descriptor instead.

func (*ToStringRequest) ProtoMessage

func (*ToStringRequest) ProtoMessage()

func (*ToStringRequest) ProtoReflect

func (x *ToStringRequest) ProtoReflect() protoreflect.Message

func (*ToStringRequest) Reset

func (x *ToStringRequest) Reset()

func (*ToStringRequest) String

func (x *ToStringRequest) String() string

type ToStringResponse

type ToStringResponse struct {
	Result string `protobuf:"bytes,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*ToStringResponse) Descriptor deprecated

func (*ToStringResponse) Descriptor() ([]byte, []int)

Deprecated: Use ToStringResponse.ProtoReflect.Descriptor instead.

func (*ToStringResponse) GetResult

func (x *ToStringResponse) GetResult() string

func (*ToStringResponse) ProtoMessage

func (*ToStringResponse) ProtoMessage()

func (*ToStringResponse) ProtoReflect

func (x *ToStringResponse) ProtoReflect() protoreflect.Message

func (*ToStringResponse) Reset

func (x *ToStringResponse) Reset()

func (*ToStringResponse) String

func (x *ToStringResponse) String() string

type UnimplementedContentViewServiceServer

type UnimplementedContentViewServiceServer struct{}

UnimplementedContentViewServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedContentViewServiceServer) GetSurfaceControl

func (UnimplementedContentViewServiceServer) IsZOrderedOnTop

func (UnimplementedContentViewServiceServer) OnLayout

func (UnimplementedContentViewServiceServer) SetClipBounds

func (UnimplementedContentViewServiceServer) SetZOrderedOnTop

type UnimplementedContentViewSurfaceControlCallbackServiceServer

type UnimplementedContentViewSurfaceControlCallbackServiceServer struct{}

UnimplementedContentViewSurfaceControlCallbackServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedContentViewSurfaceControlCallbackServiceServer) OnCreated

func (UnimplementedContentViewSurfaceControlCallbackServiceServer) OnDestroyed

type UnimplementedPresentationSpecBuilderServiceServer

type UnimplementedPresentationSpecBuilderServiceServer struct{}

UnimplementedPresentationSpecBuilderServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedPresentationSpecBuilderServiceServer) Build

func (UnimplementedPresentationSpecBuilderServiceServer) SetStyle

type UnimplementedPresentationSpecServiceServer

type UnimplementedPresentationSpecServiceServer struct{}

UnimplementedPresentationSpecServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedPresentationSpecServiceServer) DescribeContents

func (UnimplementedPresentationSpecServiceServer) Equals

func (UnimplementedPresentationSpecServiceServer) GetMaxSize

func (UnimplementedPresentationSpecServiceServer) GetMinSize

func (UnimplementedPresentationSpecServiceServer) GetStyle

func (UnimplementedPresentationSpecServiceServer) HashCode

func (UnimplementedPresentationSpecServiceServer) ToString

func (UnimplementedPresentationSpecServiceServer) WriteToParcel

type UnsafeContentViewServiceServer

type UnsafeContentViewServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeContentViewServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ContentViewServiceServer will result in compilation errors.

type UnsafeContentViewSurfaceControlCallbackServiceServer

type UnsafeContentViewSurfaceControlCallbackServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeContentViewSurfaceControlCallbackServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ContentViewSurfaceControlCallbackServiceServer will result in compilation errors.

type UnsafePresentationSpecBuilderServiceServer

type UnsafePresentationSpecBuilderServiceServer interface {
	// contains filtered or unexported methods
}

UnsafePresentationSpecBuilderServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to PresentationSpecBuilderServiceServer will result in compilation errors.

type UnsafePresentationSpecServiceServer

type UnsafePresentationSpecServiceServer interface {
	// contains filtered or unexported methods
}

UnsafePresentationSpecServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to PresentationSpecServiceServer will result in compilation errors.

type WriteToParcelRequest

type WriteToParcelRequest struct {
	Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	Arg1 int32 `protobuf:"varint,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
	// contains filtered or unexported fields
}

func (*WriteToParcelRequest) Descriptor deprecated

func (*WriteToParcelRequest) Descriptor() ([]byte, []int)

Deprecated: Use WriteToParcelRequest.ProtoReflect.Descriptor instead.

func (*WriteToParcelRequest) GetArg0

func (x *WriteToParcelRequest) GetArg0() int64

func (*WriteToParcelRequest) GetArg1

func (x *WriteToParcelRequest) GetArg1() int32

func (*WriteToParcelRequest) ProtoMessage

func (*WriteToParcelRequest) ProtoMessage()

func (*WriteToParcelRequest) ProtoReflect

func (x *WriteToParcelRequest) ProtoReflect() protoreflect.Message

func (*WriteToParcelRequest) Reset

func (x *WriteToParcelRequest) Reset()

func (*WriteToParcelRequest) String

func (x *WriteToParcelRequest) String() string

type WriteToParcelResponse

type WriteToParcelResponse struct {
	// contains filtered or unexported fields
}

func (*WriteToParcelResponse) Descriptor deprecated

func (*WriteToParcelResponse) Descriptor() ([]byte, []int)

Deprecated: Use WriteToParcelResponse.ProtoReflect.Descriptor instead.

func (*WriteToParcelResponse) ProtoMessage

func (*WriteToParcelResponse) ProtoMessage()

func (*WriteToParcelResponse) ProtoReflect

func (x *WriteToParcelResponse) ProtoReflect() protoreflect.Message

func (*WriteToParcelResponse) Reset

func (x *WriteToParcelResponse) Reset()

func (*WriteToParcelResponse) String

func (x *WriteToParcelResponse) String() string

Jump to