jank

package
v0.0.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 29, 2026 License: CC0-1.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

const (
	AppJankStatsService_NewAppJankStats_FullMethodName               = "/jank.AppJankStatsService/NewAppJankStats"
	AppJankStatsService_GetJankyFrameCount_FullMethodName            = "/jank.AppJankStatsService/GetJankyFrameCount"
	AppJankStatsService_GetNavigationComponent_FullMethodName        = "/jank.AppJankStatsService/GetNavigationComponent"
	AppJankStatsService_GetRelativeFrameTimeHistogram_FullMethodName = "/jank.AppJankStatsService/GetRelativeFrameTimeHistogram"
	AppJankStatsService_GetTotalFrameCount_FullMethodName            = "/jank.AppJankStatsService/GetTotalFrameCount"
	AppJankStatsService_GetUid_FullMethodName                        = "/jank.AppJankStatsService/GetUid"
	AppJankStatsService_GetWidgetCategory_FullMethodName             = "/jank.AppJankStatsService/GetWidgetCategory"
	AppJankStatsService_GetWidgetId_FullMethodName                   = "/jank.AppJankStatsService/GetWidgetId"
	AppJankStatsService_GetWidgetState_FullMethodName                = "/jank.AppJankStatsService/GetWidgetState"
)
const (
	RelativeFrameTimeHistogramService_NewRelativeFrameTimeHistogram_FullMethodName = "/jank.RelativeFrameTimeHistogramService/NewRelativeFrameTimeHistogram"
	RelativeFrameTimeHistogramService_AddRelativeFrameTimeMillis_FullMethodName    = "/jank.RelativeFrameTimeHistogramService/AddRelativeFrameTimeMillis"
	RelativeFrameTimeHistogramService_GetBucketCounters_FullMethodName             = "/jank.RelativeFrameTimeHistogramService/GetBucketCounters"
	RelativeFrameTimeHistogramService_GetBucketEndpointsMillis_FullMethodName      = "/jank.RelativeFrameTimeHistogramService/GetBucketEndpointsMillis"
)

Variables

var AppJankStatsService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "jank.AppJankStatsService",
	HandlerType: (*AppJankStatsServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "NewAppJankStats",
			Handler:    _AppJankStatsService_NewAppJankStats_Handler,
		},
		{
			MethodName: "GetJankyFrameCount",
			Handler:    _AppJankStatsService_GetJankyFrameCount_Handler,
		},
		{
			MethodName: "GetNavigationComponent",
			Handler:    _AppJankStatsService_GetNavigationComponent_Handler,
		},
		{
			MethodName: "GetRelativeFrameTimeHistogram",
			Handler:    _AppJankStatsService_GetRelativeFrameTimeHistogram_Handler,
		},
		{
			MethodName: "GetTotalFrameCount",
			Handler:    _AppJankStatsService_GetTotalFrameCount_Handler,
		},
		{
			MethodName: "GetUid",
			Handler:    _AppJankStatsService_GetUid_Handler,
		},
		{
			MethodName: "GetWidgetCategory",
			Handler:    _AppJankStatsService_GetWidgetCategory_Handler,
		},
		{
			MethodName: "GetWidgetId",
			Handler:    _AppJankStatsService_GetWidgetId_Handler,
		},
		{
			MethodName: "GetWidgetState",
			Handler:    _AppJankStatsService_GetWidgetState_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/jank/jank.proto",
}

AppJankStatsService_ServiceDesc is the grpc.ServiceDesc for AppJankStatsService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var File_proto_jank_jank_proto protoreflect.FileDescriptor
var RelativeFrameTimeHistogramService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "jank.RelativeFrameTimeHistogramService",
	HandlerType: (*RelativeFrameTimeHistogramServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "NewRelativeFrameTimeHistogram",
			Handler:    _RelativeFrameTimeHistogramService_NewRelativeFrameTimeHistogram_Handler,
		},
		{
			MethodName: "AddRelativeFrameTimeMillis",
			Handler:    _RelativeFrameTimeHistogramService_AddRelativeFrameTimeMillis_Handler,
		},
		{
			MethodName: "GetBucketCounters",
			Handler:    _RelativeFrameTimeHistogramService_GetBucketCounters_Handler,
		},
		{
			MethodName: "GetBucketEndpointsMillis",
			Handler:    _RelativeFrameTimeHistogramService_GetBucketEndpointsMillis_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/jank/jank.proto",
}

RelativeFrameTimeHistogramService_ServiceDesc is the grpc.ServiceDesc for RelativeFrameTimeHistogramService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterAppJankStatsServiceServer

func RegisterAppJankStatsServiceServer(s grpc.ServiceRegistrar, srv AppJankStatsServiceServer)

func RegisterRelativeFrameTimeHistogramServiceServer

func RegisterRelativeFrameTimeHistogramServiceServer(s grpc.ServiceRegistrar, srv RelativeFrameTimeHistogramServiceServer)

Types

type AddRelativeFrameTimeMillisRequest

type AddRelativeFrameTimeMillisRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	Arg0   int32 `protobuf:"varint,2,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*AddRelativeFrameTimeMillisRequest) Descriptor deprecated

func (*AddRelativeFrameTimeMillisRequest) Descriptor() ([]byte, []int)

Deprecated: Use AddRelativeFrameTimeMillisRequest.ProtoReflect.Descriptor instead.

func (*AddRelativeFrameTimeMillisRequest) GetArg0

func (*AddRelativeFrameTimeMillisRequest) GetHandle

func (*AddRelativeFrameTimeMillisRequest) ProtoMessage

func (*AddRelativeFrameTimeMillisRequest) ProtoMessage()

func (*AddRelativeFrameTimeMillisRequest) ProtoReflect

func (*AddRelativeFrameTimeMillisRequest) Reset

func (*AddRelativeFrameTimeMillisRequest) String

type AddRelativeFrameTimeMillisResponse

type AddRelativeFrameTimeMillisResponse struct {
	// contains filtered or unexported fields
}

func (*AddRelativeFrameTimeMillisResponse) Descriptor deprecated

func (*AddRelativeFrameTimeMillisResponse) Descriptor() ([]byte, []int)

Deprecated: Use AddRelativeFrameTimeMillisResponse.ProtoReflect.Descriptor instead.

func (*AddRelativeFrameTimeMillisResponse) ProtoMessage

func (*AddRelativeFrameTimeMillisResponse) ProtoMessage()

func (*AddRelativeFrameTimeMillisResponse) ProtoReflect

func (*AddRelativeFrameTimeMillisResponse) Reset

func (*AddRelativeFrameTimeMillisResponse) String

type AppJankStatsServiceClient

AppJankStatsServiceClient is the client API for AppJankStatsService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type AppJankStatsServiceServer

AppJankStatsServiceServer is the server API for AppJankStatsService service. All implementations must embed UnimplementedAppJankStatsServiceServer for forward compatibility.

type GetBucketCountersRequest

type GetBucketCountersRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	// contains filtered or unexported fields
}

func (*GetBucketCountersRequest) Descriptor deprecated

func (*GetBucketCountersRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetBucketCountersRequest.ProtoReflect.Descriptor instead.

func (*GetBucketCountersRequest) GetHandle

func (x *GetBucketCountersRequest) GetHandle() int64

func (*GetBucketCountersRequest) ProtoMessage

func (*GetBucketCountersRequest) ProtoMessage()

func (*GetBucketCountersRequest) ProtoReflect

func (x *GetBucketCountersRequest) ProtoReflect() protoreflect.Message

func (*GetBucketCountersRequest) Reset

func (x *GetBucketCountersRequest) Reset()

func (*GetBucketCountersRequest) String

func (x *GetBucketCountersRequest) String() string

type GetBucketCountersResponse

type GetBucketCountersResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetBucketCountersResponse) Descriptor deprecated

func (*GetBucketCountersResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetBucketCountersResponse.ProtoReflect.Descriptor instead.

func (*GetBucketCountersResponse) GetResult

func (x *GetBucketCountersResponse) GetResult() int64

func (*GetBucketCountersResponse) ProtoMessage

func (*GetBucketCountersResponse) ProtoMessage()

func (*GetBucketCountersResponse) ProtoReflect

func (*GetBucketCountersResponse) Reset

func (x *GetBucketCountersResponse) Reset()

func (*GetBucketCountersResponse) String

func (x *GetBucketCountersResponse) String() string

type GetBucketEndpointsMillisRequest

type GetBucketEndpointsMillisRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	// contains filtered or unexported fields
}

func (*GetBucketEndpointsMillisRequest) Descriptor deprecated

func (*GetBucketEndpointsMillisRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetBucketEndpointsMillisRequest.ProtoReflect.Descriptor instead.

func (*GetBucketEndpointsMillisRequest) GetHandle

func (x *GetBucketEndpointsMillisRequest) GetHandle() int64

func (*GetBucketEndpointsMillisRequest) ProtoMessage

func (*GetBucketEndpointsMillisRequest) ProtoMessage()

func (*GetBucketEndpointsMillisRequest) ProtoReflect

func (*GetBucketEndpointsMillisRequest) Reset

func (*GetBucketEndpointsMillisRequest) String

type GetBucketEndpointsMillisResponse

type GetBucketEndpointsMillisResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetBucketEndpointsMillisResponse) Descriptor deprecated

func (*GetBucketEndpointsMillisResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetBucketEndpointsMillisResponse.ProtoReflect.Descriptor instead.

func (*GetBucketEndpointsMillisResponse) GetResult

func (x *GetBucketEndpointsMillisResponse) GetResult() int64

func (*GetBucketEndpointsMillisResponse) ProtoMessage

func (*GetBucketEndpointsMillisResponse) ProtoMessage()

func (*GetBucketEndpointsMillisResponse) ProtoReflect

func (*GetBucketEndpointsMillisResponse) Reset

func (*GetBucketEndpointsMillisResponse) String

type GetJankyFrameCountRequest

type GetJankyFrameCountRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	// contains filtered or unexported fields
}

func (*GetJankyFrameCountRequest) Descriptor deprecated

func (*GetJankyFrameCountRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetJankyFrameCountRequest.ProtoReflect.Descriptor instead.

func (*GetJankyFrameCountRequest) GetHandle

func (x *GetJankyFrameCountRequest) GetHandle() int64

func (*GetJankyFrameCountRequest) ProtoMessage

func (*GetJankyFrameCountRequest) ProtoMessage()

func (*GetJankyFrameCountRequest) ProtoReflect

func (*GetJankyFrameCountRequest) Reset

func (x *GetJankyFrameCountRequest) Reset()

func (*GetJankyFrameCountRequest) String

func (x *GetJankyFrameCountRequest) String() string

type GetJankyFrameCountResponse

type GetJankyFrameCountResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetJankyFrameCountResponse) Descriptor deprecated

func (*GetJankyFrameCountResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetJankyFrameCountResponse.ProtoReflect.Descriptor instead.

func (*GetJankyFrameCountResponse) GetResult

func (x *GetJankyFrameCountResponse) GetResult() int64

func (*GetJankyFrameCountResponse) ProtoMessage

func (*GetJankyFrameCountResponse) ProtoMessage()

func (*GetJankyFrameCountResponse) ProtoReflect

func (*GetJankyFrameCountResponse) Reset

func (x *GetJankyFrameCountResponse) Reset()

func (*GetJankyFrameCountResponse) String

func (x *GetJankyFrameCountResponse) String() string

type GetNavigationComponentRequest

type GetNavigationComponentRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	// contains filtered or unexported fields
}

func (*GetNavigationComponentRequest) Descriptor deprecated

func (*GetNavigationComponentRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetNavigationComponentRequest.ProtoReflect.Descriptor instead.

func (*GetNavigationComponentRequest) GetHandle

func (x *GetNavigationComponentRequest) GetHandle() int64

func (*GetNavigationComponentRequest) ProtoMessage

func (*GetNavigationComponentRequest) ProtoMessage()

func (*GetNavigationComponentRequest) ProtoReflect

func (*GetNavigationComponentRequest) Reset

func (x *GetNavigationComponentRequest) Reset()

func (*GetNavigationComponentRequest) String

type GetNavigationComponentResponse

type GetNavigationComponentResponse struct {
	Result string `protobuf:"bytes,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetNavigationComponentResponse) Descriptor deprecated

func (*GetNavigationComponentResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetNavigationComponentResponse.ProtoReflect.Descriptor instead.

func (*GetNavigationComponentResponse) GetResult

func (x *GetNavigationComponentResponse) GetResult() string

func (*GetNavigationComponentResponse) ProtoMessage

func (*GetNavigationComponentResponse) ProtoMessage()

func (*GetNavigationComponentResponse) ProtoReflect

func (*GetNavigationComponentResponse) Reset

func (x *GetNavigationComponentResponse) Reset()

func (*GetNavigationComponentResponse) String

type GetRelativeFrameTimeHistogramRequest

type GetRelativeFrameTimeHistogramRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	// contains filtered or unexported fields
}

func (*GetRelativeFrameTimeHistogramRequest) Descriptor deprecated

func (*GetRelativeFrameTimeHistogramRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetRelativeFrameTimeHistogramRequest.ProtoReflect.Descriptor instead.

func (*GetRelativeFrameTimeHistogramRequest) GetHandle

func (*GetRelativeFrameTimeHistogramRequest) ProtoMessage

func (*GetRelativeFrameTimeHistogramRequest) ProtoMessage()

func (*GetRelativeFrameTimeHistogramRequest) ProtoReflect

func (*GetRelativeFrameTimeHistogramRequest) Reset

func (*GetRelativeFrameTimeHistogramRequest) String

type GetRelativeFrameTimeHistogramResponse

type GetRelativeFrameTimeHistogramResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetRelativeFrameTimeHistogramResponse) Descriptor deprecated

func (*GetRelativeFrameTimeHistogramResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetRelativeFrameTimeHistogramResponse.ProtoReflect.Descriptor instead.

func (*GetRelativeFrameTimeHistogramResponse) GetResult

func (*GetRelativeFrameTimeHistogramResponse) ProtoMessage

func (*GetRelativeFrameTimeHistogramResponse) ProtoMessage()

func (*GetRelativeFrameTimeHistogramResponse) ProtoReflect

func (*GetRelativeFrameTimeHistogramResponse) Reset

func (*GetRelativeFrameTimeHistogramResponse) String

type GetTotalFrameCountRequest

type GetTotalFrameCountRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	// contains filtered or unexported fields
}

func (*GetTotalFrameCountRequest) Descriptor deprecated

func (*GetTotalFrameCountRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetTotalFrameCountRequest.ProtoReflect.Descriptor instead.

func (*GetTotalFrameCountRequest) GetHandle

func (x *GetTotalFrameCountRequest) GetHandle() int64

func (*GetTotalFrameCountRequest) ProtoMessage

func (*GetTotalFrameCountRequest) ProtoMessage()

func (*GetTotalFrameCountRequest) ProtoReflect

func (*GetTotalFrameCountRequest) Reset

func (x *GetTotalFrameCountRequest) Reset()

func (*GetTotalFrameCountRequest) String

func (x *GetTotalFrameCountRequest) String() string

type GetTotalFrameCountResponse

type GetTotalFrameCountResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetTotalFrameCountResponse) Descriptor deprecated

func (*GetTotalFrameCountResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetTotalFrameCountResponse.ProtoReflect.Descriptor instead.

func (*GetTotalFrameCountResponse) GetResult

func (x *GetTotalFrameCountResponse) GetResult() int64

func (*GetTotalFrameCountResponse) ProtoMessage

func (*GetTotalFrameCountResponse) ProtoMessage()

func (*GetTotalFrameCountResponse) ProtoReflect

func (*GetTotalFrameCountResponse) Reset

func (x *GetTotalFrameCountResponse) Reset()

func (*GetTotalFrameCountResponse) String

func (x *GetTotalFrameCountResponse) String() string

type GetUidRequest

type GetUidRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	// contains filtered or unexported fields
}

func (*GetUidRequest) Descriptor deprecated

func (*GetUidRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetUidRequest.ProtoReflect.Descriptor instead.

func (*GetUidRequest) GetHandle

func (x *GetUidRequest) GetHandle() int64

func (*GetUidRequest) ProtoMessage

func (*GetUidRequest) ProtoMessage()

func (*GetUidRequest) ProtoReflect

func (x *GetUidRequest) ProtoReflect() protoreflect.Message

func (*GetUidRequest) Reset

func (x *GetUidRequest) Reset()

func (*GetUidRequest) String

func (x *GetUidRequest) String() string

type GetUidResponse

type GetUidResponse struct {
	Result int32 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetUidResponse) Descriptor deprecated

func (*GetUidResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetUidResponse.ProtoReflect.Descriptor instead.

func (*GetUidResponse) GetResult

func (x *GetUidResponse) GetResult() int32

func (*GetUidResponse) ProtoMessage

func (*GetUidResponse) ProtoMessage()

func (*GetUidResponse) ProtoReflect

func (x *GetUidResponse) ProtoReflect() protoreflect.Message

func (*GetUidResponse) Reset

func (x *GetUidResponse) Reset()

func (*GetUidResponse) String

func (x *GetUidResponse) String() string

type GetWidgetCategoryRequest

type GetWidgetCategoryRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	// contains filtered or unexported fields
}

func (*GetWidgetCategoryRequest) Descriptor deprecated

func (*GetWidgetCategoryRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetWidgetCategoryRequest.ProtoReflect.Descriptor instead.

func (*GetWidgetCategoryRequest) GetHandle

func (x *GetWidgetCategoryRequest) GetHandle() int64

func (*GetWidgetCategoryRequest) ProtoMessage

func (*GetWidgetCategoryRequest) ProtoMessage()

func (*GetWidgetCategoryRequest) ProtoReflect

func (x *GetWidgetCategoryRequest) ProtoReflect() protoreflect.Message

func (*GetWidgetCategoryRequest) Reset

func (x *GetWidgetCategoryRequest) Reset()

func (*GetWidgetCategoryRequest) String

func (x *GetWidgetCategoryRequest) String() string

type GetWidgetCategoryResponse

type GetWidgetCategoryResponse struct {
	Result string `protobuf:"bytes,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetWidgetCategoryResponse) Descriptor deprecated

func (*GetWidgetCategoryResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetWidgetCategoryResponse.ProtoReflect.Descriptor instead.

func (*GetWidgetCategoryResponse) GetResult

func (x *GetWidgetCategoryResponse) GetResult() string

func (*GetWidgetCategoryResponse) ProtoMessage

func (*GetWidgetCategoryResponse) ProtoMessage()

func (*GetWidgetCategoryResponse) ProtoReflect

func (*GetWidgetCategoryResponse) Reset

func (x *GetWidgetCategoryResponse) Reset()

func (*GetWidgetCategoryResponse) String

func (x *GetWidgetCategoryResponse) String() string

type GetWidgetIdRequest

type GetWidgetIdRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	// contains filtered or unexported fields
}

func (*GetWidgetIdRequest) Descriptor deprecated

func (*GetWidgetIdRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetWidgetIdRequest.ProtoReflect.Descriptor instead.

func (*GetWidgetIdRequest) GetHandle

func (x *GetWidgetIdRequest) GetHandle() int64

func (*GetWidgetIdRequest) ProtoMessage

func (*GetWidgetIdRequest) ProtoMessage()

func (*GetWidgetIdRequest) ProtoReflect

func (x *GetWidgetIdRequest) ProtoReflect() protoreflect.Message

func (*GetWidgetIdRequest) Reset

func (x *GetWidgetIdRequest) Reset()

func (*GetWidgetIdRequest) String

func (x *GetWidgetIdRequest) String() string

type GetWidgetIdResponse

type GetWidgetIdResponse struct {
	Result string `protobuf:"bytes,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetWidgetIdResponse) Descriptor deprecated

func (*GetWidgetIdResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetWidgetIdResponse.ProtoReflect.Descriptor instead.

func (*GetWidgetIdResponse) GetResult

func (x *GetWidgetIdResponse) GetResult() string

func (*GetWidgetIdResponse) ProtoMessage

func (*GetWidgetIdResponse) ProtoMessage()

func (*GetWidgetIdResponse) ProtoReflect

func (x *GetWidgetIdResponse) ProtoReflect() protoreflect.Message

func (*GetWidgetIdResponse) Reset

func (x *GetWidgetIdResponse) Reset()

func (*GetWidgetIdResponse) String

func (x *GetWidgetIdResponse) String() string

type GetWidgetStateRequest

type GetWidgetStateRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	// contains filtered or unexported fields
}

func (*GetWidgetStateRequest) Descriptor deprecated

func (*GetWidgetStateRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetWidgetStateRequest.ProtoReflect.Descriptor instead.

func (*GetWidgetStateRequest) GetHandle

func (x *GetWidgetStateRequest) GetHandle() int64

func (*GetWidgetStateRequest) ProtoMessage

func (*GetWidgetStateRequest) ProtoMessage()

func (*GetWidgetStateRequest) ProtoReflect

func (x *GetWidgetStateRequest) ProtoReflect() protoreflect.Message

func (*GetWidgetStateRequest) Reset

func (x *GetWidgetStateRequest) Reset()

func (*GetWidgetStateRequest) String

func (x *GetWidgetStateRequest) String() string

type GetWidgetStateResponse

type GetWidgetStateResponse struct {
	Result string `protobuf:"bytes,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetWidgetStateResponse) Descriptor deprecated

func (*GetWidgetStateResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetWidgetStateResponse.ProtoReflect.Descriptor instead.

func (*GetWidgetStateResponse) GetResult

func (x *GetWidgetStateResponse) GetResult() string

func (*GetWidgetStateResponse) ProtoMessage

func (*GetWidgetStateResponse) ProtoMessage()

func (*GetWidgetStateResponse) ProtoReflect

func (x *GetWidgetStateResponse) ProtoReflect() protoreflect.Message

func (*GetWidgetStateResponse) Reset

func (x *GetWidgetStateResponse) Reset()

func (*GetWidgetStateResponse) String

func (x *GetWidgetStateResponse) String() string

type NewAppJankStatsRequest

type NewAppJankStatsRequest struct {
	Arg0 int32  `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	Arg1 string `protobuf:"bytes,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
	Arg2 string `protobuf:"bytes,3,opt,name=arg2,proto3" json:"arg2,omitempty"`
	Arg3 string `protobuf:"bytes,4,opt,name=arg3,proto3" json:"arg3,omitempty"`
	Arg4 string `protobuf:"bytes,5,opt,name=arg4,proto3" json:"arg4,omitempty"`
	Arg5 int64  `protobuf:"varint,6,opt,name=arg5,proto3" json:"arg5,omitempty"`
	Arg6 int64  `protobuf:"varint,7,opt,name=arg6,proto3" json:"arg6,omitempty"`
	Arg7 int64  `protobuf:"varint,8,opt,name=arg7,proto3" json:"arg7,omitempty"`
	// contains filtered or unexported fields
}

func (*NewAppJankStatsRequest) Descriptor deprecated

func (*NewAppJankStatsRequest) Descriptor() ([]byte, []int)

Deprecated: Use NewAppJankStatsRequest.ProtoReflect.Descriptor instead.

func (*NewAppJankStatsRequest) GetArg0

func (x *NewAppJankStatsRequest) GetArg0() int32

func (*NewAppJankStatsRequest) GetArg1

func (x *NewAppJankStatsRequest) GetArg1() string

func (*NewAppJankStatsRequest) GetArg2

func (x *NewAppJankStatsRequest) GetArg2() string

func (*NewAppJankStatsRequest) GetArg3

func (x *NewAppJankStatsRequest) GetArg3() string

func (*NewAppJankStatsRequest) GetArg4

func (x *NewAppJankStatsRequest) GetArg4() string

func (*NewAppJankStatsRequest) GetArg5

func (x *NewAppJankStatsRequest) GetArg5() int64

func (*NewAppJankStatsRequest) GetArg6

func (x *NewAppJankStatsRequest) GetArg6() int64

func (*NewAppJankStatsRequest) GetArg7

func (x *NewAppJankStatsRequest) GetArg7() int64

func (*NewAppJankStatsRequest) ProtoMessage

func (*NewAppJankStatsRequest) ProtoMessage()

func (*NewAppJankStatsRequest) ProtoReflect

func (x *NewAppJankStatsRequest) ProtoReflect() protoreflect.Message

func (*NewAppJankStatsRequest) Reset

func (x *NewAppJankStatsRequest) Reset()

func (*NewAppJankStatsRequest) String

func (x *NewAppJankStatsRequest) String() string

type NewAppJankStatsResponse

type NewAppJankStatsResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*NewAppJankStatsResponse) Descriptor deprecated

func (*NewAppJankStatsResponse) Descriptor() ([]byte, []int)

Deprecated: Use NewAppJankStatsResponse.ProtoReflect.Descriptor instead.

func (*NewAppJankStatsResponse) GetResult

func (x *NewAppJankStatsResponse) GetResult() int64

func (*NewAppJankStatsResponse) ProtoMessage

func (*NewAppJankStatsResponse) ProtoMessage()

func (*NewAppJankStatsResponse) ProtoReflect

func (x *NewAppJankStatsResponse) ProtoReflect() protoreflect.Message

func (*NewAppJankStatsResponse) Reset

func (x *NewAppJankStatsResponse) Reset()

func (*NewAppJankStatsResponse) String

func (x *NewAppJankStatsResponse) String() string

type NewRelativeFrameTimeHistogramRequest

type NewRelativeFrameTimeHistogramRequest struct {
	// contains filtered or unexported fields
}

func (*NewRelativeFrameTimeHistogramRequest) Descriptor deprecated

func (*NewRelativeFrameTimeHistogramRequest) Descriptor() ([]byte, []int)

Deprecated: Use NewRelativeFrameTimeHistogramRequest.ProtoReflect.Descriptor instead.

func (*NewRelativeFrameTimeHistogramRequest) ProtoMessage

func (*NewRelativeFrameTimeHistogramRequest) ProtoMessage()

func (*NewRelativeFrameTimeHistogramRequest) ProtoReflect

func (*NewRelativeFrameTimeHistogramRequest) Reset

func (*NewRelativeFrameTimeHistogramRequest) String

type NewRelativeFrameTimeHistogramResponse

type NewRelativeFrameTimeHistogramResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*NewRelativeFrameTimeHistogramResponse) Descriptor deprecated

func (*NewRelativeFrameTimeHistogramResponse) Descriptor() ([]byte, []int)

Deprecated: Use NewRelativeFrameTimeHistogramResponse.ProtoReflect.Descriptor instead.

func (*NewRelativeFrameTimeHistogramResponse) GetResult

func (*NewRelativeFrameTimeHistogramResponse) ProtoMessage

func (*NewRelativeFrameTimeHistogramResponse) ProtoMessage()

func (*NewRelativeFrameTimeHistogramResponse) ProtoReflect

func (*NewRelativeFrameTimeHistogramResponse) Reset

func (*NewRelativeFrameTimeHistogramResponse) String

type RelativeFrameTimeHistogramServiceClient

type RelativeFrameTimeHistogramServiceClient interface {
	NewRelativeFrameTimeHistogram(ctx context.Context, in *NewRelativeFrameTimeHistogramRequest, opts ...grpc.CallOption) (*NewRelativeFrameTimeHistogramResponse, error)
	AddRelativeFrameTimeMillis(ctx context.Context, in *AddRelativeFrameTimeMillisRequest, opts ...grpc.CallOption) (*AddRelativeFrameTimeMillisResponse, error)
	GetBucketCounters(ctx context.Context, in *GetBucketCountersRequest, opts ...grpc.CallOption) (*GetBucketCountersResponse, error)
	GetBucketEndpointsMillis(ctx context.Context, in *GetBucketEndpointsMillisRequest, opts ...grpc.CallOption) (*GetBucketEndpointsMillisResponse, error)
}

RelativeFrameTimeHistogramServiceClient is the client API for RelativeFrameTimeHistogramService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type RelativeFrameTimeHistogramServiceServer

type RelativeFrameTimeHistogramServiceServer interface {
	NewRelativeFrameTimeHistogram(context.Context, *NewRelativeFrameTimeHistogramRequest) (*NewRelativeFrameTimeHistogramResponse, error)
	AddRelativeFrameTimeMillis(context.Context, *AddRelativeFrameTimeMillisRequest) (*AddRelativeFrameTimeMillisResponse, error)
	GetBucketCounters(context.Context, *GetBucketCountersRequest) (*GetBucketCountersResponse, error)
	GetBucketEndpointsMillis(context.Context, *GetBucketEndpointsMillisRequest) (*GetBucketEndpointsMillisResponse, error)
	// contains filtered or unexported methods
}

RelativeFrameTimeHistogramServiceServer is the server API for RelativeFrameTimeHistogramService service. All implementations must embed UnimplementedRelativeFrameTimeHistogramServiceServer for forward compatibility.

type UnimplementedAppJankStatsServiceServer

type UnimplementedAppJankStatsServiceServer struct{}

UnimplementedAppJankStatsServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedAppJankStatsServiceServer) GetJankyFrameCount

func (UnimplementedAppJankStatsServiceServer) GetTotalFrameCount

func (UnimplementedAppJankStatsServiceServer) GetUid

func (UnimplementedAppJankStatsServiceServer) GetWidgetCategory

func (UnimplementedAppJankStatsServiceServer) GetWidgetId

func (UnimplementedAppJankStatsServiceServer) GetWidgetState

func (UnimplementedAppJankStatsServiceServer) NewAppJankStats

type UnimplementedRelativeFrameTimeHistogramServiceServer

type UnimplementedRelativeFrameTimeHistogramServiceServer struct{}

UnimplementedRelativeFrameTimeHistogramServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedRelativeFrameTimeHistogramServiceServer) GetBucketCounters

func (UnimplementedRelativeFrameTimeHistogramServiceServer) GetBucketEndpointsMillis

type UnsafeAppJankStatsServiceServer

type UnsafeAppJankStatsServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeAppJankStatsServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to AppJankStatsServiceServer will result in compilation errors.

type UnsafeRelativeFrameTimeHistogramServiceServer

type UnsafeRelativeFrameTimeHistogramServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeRelativeFrameTimeHistogramServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to RelativeFrameTimeHistogramServiceServer will result in compilation errors.

Jump to