print

package
v0.0.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 22, 2026 License: CC0-1.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

const (
	JobService_Cancel_FullMethodName      = "/print.JobService/Cancel"
	JobService_Equals_FullMethodName      = "/print.JobService/Equals"
	JobService_GetId_FullMethodName       = "/print.JobService/GetId"
	JobService_GetInfo_FullMethodName     = "/print.JobService/GetInfo"
	JobService_HashCode_FullMethodName    = "/print.JobService/HashCode"
	JobService_IsBlocked_FullMethodName   = "/print.JobService/IsBlocked"
	JobService_IsCancelled_FullMethodName = "/print.JobService/IsCancelled"
	JobService_IsCompleted_FullMethodName = "/print.JobService/IsCompleted"
	JobService_IsFailed_FullMethodName    = "/print.JobService/IsFailed"
	JobService_IsQueued_FullMethodName    = "/print.JobService/IsQueued"
	JobService_IsStarted_FullMethodName   = "/print.JobService/IsStarted"
	JobService_Restart_FullMethodName     = "/print.JobService/Restart"
)
const (
	JobInfoService_DescribeContents_FullMethodName        = "/print.JobInfoService/DescribeContents"
	JobInfoService_GetAdvancedIntOption_FullMethodName    = "/print.JobInfoService/GetAdvancedIntOption"
	JobInfoService_GetAdvancedStringOption_FullMethodName = "/print.JobInfoService/GetAdvancedStringOption"
	JobInfoService_GetAttributes_FullMethodName           = "/print.JobInfoService/GetAttributes"
	JobInfoService_GetCopies_FullMethodName               = "/print.JobInfoService/GetCopies"
	JobInfoService_GetCreationTime_FullMethodName         = "/print.JobInfoService/GetCreationTime"
	JobInfoService_GetId_FullMethodName                   = "/print.JobInfoService/GetId"
	JobInfoService_GetLabel_FullMethodName                = "/print.JobInfoService/GetLabel"
	JobInfoService_GetPages_FullMethodName                = "/print.JobInfoService/GetPages"
	JobInfoService_GetPrinterId_FullMethodName            = "/print.JobInfoService/GetPrinterId"
	JobInfoService_GetState_FullMethodName                = "/print.JobInfoService/GetState"
	JobInfoService_HasAdvancedOption_FullMethodName       = "/print.JobInfoService/HasAdvancedOption"
	JobInfoService_ToString_FullMethodName                = "/print.JobInfoService/ToString"
	JobInfoService_WriteToParcel_FullMethodName           = "/print.JobInfoService/WriteToParcel"
)
const (
	ManagerService_GetPrintJobs_FullMethodName          = "/print.ManagerService/GetPrintJobs"
	ManagerService_IsPrintServiceEnabled_FullMethodName = "/print.ManagerService/IsPrintServiceEnabled"
	ManagerService_Print_FullMethodName                 = "/print.ManagerService/Print"
)

Variables

var File_proto_print_print_proto protoreflect.FileDescriptor
var JobInfoService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "print.JobInfoService",
	HandlerType: (*JobInfoServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "DescribeContents",
			Handler:    _JobInfoService_DescribeContents_Handler,
		},
		{
			MethodName: "GetAdvancedIntOption",
			Handler:    _JobInfoService_GetAdvancedIntOption_Handler,
		},
		{
			MethodName: "GetAdvancedStringOption",
			Handler:    _JobInfoService_GetAdvancedStringOption_Handler,
		},
		{
			MethodName: "GetAttributes",
			Handler:    _JobInfoService_GetAttributes_Handler,
		},
		{
			MethodName: "GetCopies",
			Handler:    _JobInfoService_GetCopies_Handler,
		},
		{
			MethodName: "GetCreationTime",
			Handler:    _JobInfoService_GetCreationTime_Handler,
		},
		{
			MethodName: "GetId",
			Handler:    _JobInfoService_GetId_Handler,
		},
		{
			MethodName: "GetLabel",
			Handler:    _JobInfoService_GetLabel_Handler,
		},
		{
			MethodName: "GetPages",
			Handler:    _JobInfoService_GetPages_Handler,
		},
		{
			MethodName: "GetPrinterId",
			Handler:    _JobInfoService_GetPrinterId_Handler,
		},
		{
			MethodName: "GetState",
			Handler:    _JobInfoService_GetState_Handler,
		},
		{
			MethodName: "HasAdvancedOption",
			Handler:    _JobInfoService_HasAdvancedOption_Handler,
		},
		{
			MethodName: "ToString",
			Handler:    _JobInfoService_ToString_Handler,
		},
		{
			MethodName: "WriteToParcel",
			Handler:    _JobInfoService_WriteToParcel_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/print/print.proto",
}

JobInfoService_ServiceDesc is the grpc.ServiceDesc for JobInfoService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var JobService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "print.JobService",
	HandlerType: (*JobServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "Cancel",
			Handler:    _JobService_Cancel_Handler,
		},
		{
			MethodName: "Equals",
			Handler:    _JobService_Equals_Handler,
		},
		{
			MethodName: "GetId",
			Handler:    _JobService_GetId_Handler,
		},
		{
			MethodName: "GetInfo",
			Handler:    _JobService_GetInfo_Handler,
		},
		{
			MethodName: "HashCode",
			Handler:    _JobService_HashCode_Handler,
		},
		{
			MethodName: "IsBlocked",
			Handler:    _JobService_IsBlocked_Handler,
		},
		{
			MethodName: "IsCancelled",
			Handler:    _JobService_IsCancelled_Handler,
		},
		{
			MethodName: "IsCompleted",
			Handler:    _JobService_IsCompleted_Handler,
		},
		{
			MethodName: "IsFailed",
			Handler:    _JobService_IsFailed_Handler,
		},
		{
			MethodName: "IsQueued",
			Handler:    _JobService_IsQueued_Handler,
		},
		{
			MethodName: "IsStarted",
			Handler:    _JobService_IsStarted_Handler,
		},
		{
			MethodName: "Restart",
			Handler:    _JobService_Restart_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/print/print.proto",
}

JobService_ServiceDesc is the grpc.ServiceDesc for JobService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var ManagerService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "print.ManagerService",
	HandlerType: (*ManagerServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "GetPrintJobs",
			Handler:    _ManagerService_GetPrintJobs_Handler,
		},
		{
			MethodName: "IsPrintServiceEnabled",
			Handler:    _ManagerService_IsPrintServiceEnabled_Handler,
		},
		{
			MethodName: "Print",
			Handler:    _ManagerService_Print_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/print/print.proto",
}

ManagerService_ServiceDesc is the grpc.ServiceDesc for ManagerService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterJobInfoServiceServer added in v0.0.4

func RegisterJobInfoServiceServer(s grpc.ServiceRegistrar, srv JobInfoServiceServer)

func RegisterJobServiceServer added in v0.0.4

func RegisterJobServiceServer(s grpc.ServiceRegistrar, srv JobServiceServer)

func RegisterManagerServiceServer added in v0.0.4

func RegisterManagerServiceServer(s grpc.ServiceRegistrar, srv ManagerServiceServer)

Types

type CancelRequest

type CancelRequest struct {
	// contains filtered or unexported fields
}

func (*CancelRequest) Descriptor deprecated

func (*CancelRequest) Descriptor() ([]byte, []int)

Deprecated: Use CancelRequest.ProtoReflect.Descriptor instead.

func (*CancelRequest) ProtoMessage

func (*CancelRequest) ProtoMessage()

func (*CancelRequest) ProtoReflect

func (x *CancelRequest) ProtoReflect() protoreflect.Message

func (*CancelRequest) Reset

func (x *CancelRequest) Reset()

func (*CancelRequest) String

func (x *CancelRequest) String() string

type CancelResponse

type CancelResponse struct {
	// contains filtered or unexported fields
}

func (*CancelResponse) Descriptor deprecated

func (*CancelResponse) Descriptor() ([]byte, []int)

Deprecated: Use CancelResponse.ProtoReflect.Descriptor instead.

func (*CancelResponse) ProtoMessage

func (*CancelResponse) ProtoMessage()

func (*CancelResponse) ProtoReflect

func (x *CancelResponse) ProtoReflect() protoreflect.Message

func (*CancelResponse) Reset

func (x *CancelResponse) Reset()

func (*CancelResponse) String

func (x *CancelResponse) String() string

type DescribeContentsRequest

type DescribeContentsRequest struct {
	// contains filtered or unexported fields
}

func (*DescribeContentsRequest) Descriptor deprecated

func (*DescribeContentsRequest) Descriptor() ([]byte, []int)

Deprecated: Use DescribeContentsRequest.ProtoReflect.Descriptor instead.

func (*DescribeContentsRequest) ProtoMessage

func (*DescribeContentsRequest) ProtoMessage()

func (*DescribeContentsRequest) ProtoReflect

func (x *DescribeContentsRequest) ProtoReflect() protoreflect.Message

func (*DescribeContentsRequest) Reset

func (x *DescribeContentsRequest) Reset()

func (*DescribeContentsRequest) String

func (x *DescribeContentsRequest) String() string

type DescribeContentsResponse

type DescribeContentsResponse struct {
	Result int32 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*DescribeContentsResponse) Descriptor deprecated

func (*DescribeContentsResponse) Descriptor() ([]byte, []int)

Deprecated: Use DescribeContentsResponse.ProtoReflect.Descriptor instead.

func (*DescribeContentsResponse) GetResult

func (x *DescribeContentsResponse) GetResult() int32

func (*DescribeContentsResponse) ProtoMessage

func (*DescribeContentsResponse) ProtoMessage()

func (*DescribeContentsResponse) ProtoReflect

func (x *DescribeContentsResponse) ProtoReflect() protoreflect.Message

func (*DescribeContentsResponse) Reset

func (x *DescribeContentsResponse) Reset()

func (*DescribeContentsResponse) String

func (x *DescribeContentsResponse) String() string

type EqualsRequest

type EqualsRequest struct {
	Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*EqualsRequest) Descriptor deprecated

func (*EqualsRequest) Descriptor() ([]byte, []int)

Deprecated: Use EqualsRequest.ProtoReflect.Descriptor instead.

func (*EqualsRequest) GetArg0

func (x *EqualsRequest) GetArg0() int64

func (*EqualsRequest) ProtoMessage

func (*EqualsRequest) ProtoMessage()

func (*EqualsRequest) ProtoReflect

func (x *EqualsRequest) ProtoReflect() protoreflect.Message

func (*EqualsRequest) Reset

func (x *EqualsRequest) Reset()

func (*EqualsRequest) String

func (x *EqualsRequest) String() string

type EqualsResponse

type EqualsResponse struct {
	Result bool `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*EqualsResponse) Descriptor deprecated

func (*EqualsResponse) Descriptor() ([]byte, []int)

Deprecated: Use EqualsResponse.ProtoReflect.Descriptor instead.

func (*EqualsResponse) GetResult

func (x *EqualsResponse) GetResult() bool

func (*EqualsResponse) ProtoMessage

func (*EqualsResponse) ProtoMessage()

func (*EqualsResponse) ProtoReflect

func (x *EqualsResponse) ProtoReflect() protoreflect.Message

func (*EqualsResponse) Reset

func (x *EqualsResponse) Reset()

func (*EqualsResponse) String

func (x *EqualsResponse) String() string

type GetAdvancedIntOptionRequest

type GetAdvancedIntOptionRequest struct {
	Arg0 string `protobuf:"bytes,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*GetAdvancedIntOptionRequest) Descriptor deprecated

func (*GetAdvancedIntOptionRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetAdvancedIntOptionRequest.ProtoReflect.Descriptor instead.

func (*GetAdvancedIntOptionRequest) GetArg0

func (x *GetAdvancedIntOptionRequest) GetArg0() string

func (*GetAdvancedIntOptionRequest) ProtoMessage

func (*GetAdvancedIntOptionRequest) ProtoMessage()

func (*GetAdvancedIntOptionRequest) ProtoReflect

func (*GetAdvancedIntOptionRequest) Reset

func (x *GetAdvancedIntOptionRequest) Reset()

func (*GetAdvancedIntOptionRequest) String

func (x *GetAdvancedIntOptionRequest) String() string

type GetAdvancedIntOptionResponse

type GetAdvancedIntOptionResponse struct {
	Result int32 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetAdvancedIntOptionResponse) Descriptor deprecated

func (*GetAdvancedIntOptionResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetAdvancedIntOptionResponse.ProtoReflect.Descriptor instead.

func (*GetAdvancedIntOptionResponse) GetResult

func (x *GetAdvancedIntOptionResponse) GetResult() int32

func (*GetAdvancedIntOptionResponse) ProtoMessage

func (*GetAdvancedIntOptionResponse) ProtoMessage()

func (*GetAdvancedIntOptionResponse) ProtoReflect

func (*GetAdvancedIntOptionResponse) Reset

func (x *GetAdvancedIntOptionResponse) Reset()

func (*GetAdvancedIntOptionResponse) String

type GetAdvancedStringOptionRequest

type GetAdvancedStringOptionRequest struct {
	Arg0 string `protobuf:"bytes,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*GetAdvancedStringOptionRequest) Descriptor deprecated

func (*GetAdvancedStringOptionRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetAdvancedStringOptionRequest.ProtoReflect.Descriptor instead.

func (*GetAdvancedStringOptionRequest) GetArg0

func (*GetAdvancedStringOptionRequest) ProtoMessage

func (*GetAdvancedStringOptionRequest) ProtoMessage()

func (*GetAdvancedStringOptionRequest) ProtoReflect

func (*GetAdvancedStringOptionRequest) Reset

func (x *GetAdvancedStringOptionRequest) Reset()

func (*GetAdvancedStringOptionRequest) String

type GetAdvancedStringOptionResponse

type GetAdvancedStringOptionResponse struct {
	Result string `protobuf:"bytes,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetAdvancedStringOptionResponse) Descriptor deprecated

func (*GetAdvancedStringOptionResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetAdvancedStringOptionResponse.ProtoReflect.Descriptor instead.

func (*GetAdvancedStringOptionResponse) GetResult

func (x *GetAdvancedStringOptionResponse) GetResult() string

func (*GetAdvancedStringOptionResponse) ProtoMessage

func (*GetAdvancedStringOptionResponse) ProtoMessage()

func (*GetAdvancedStringOptionResponse) ProtoReflect

func (*GetAdvancedStringOptionResponse) Reset

func (*GetAdvancedStringOptionResponse) String

type GetAttributesRequest

type GetAttributesRequest struct {
	// contains filtered or unexported fields
}

func (*GetAttributesRequest) Descriptor deprecated

func (*GetAttributesRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetAttributesRequest.ProtoReflect.Descriptor instead.

func (*GetAttributesRequest) ProtoMessage

func (*GetAttributesRequest) ProtoMessage()

func (*GetAttributesRequest) ProtoReflect

func (x *GetAttributesRequest) ProtoReflect() protoreflect.Message

func (*GetAttributesRequest) Reset

func (x *GetAttributesRequest) Reset()

func (*GetAttributesRequest) String

func (x *GetAttributesRequest) String() string

type GetAttributesResponse

type GetAttributesResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetAttributesResponse) Descriptor deprecated

func (*GetAttributesResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetAttributesResponse.ProtoReflect.Descriptor instead.

func (*GetAttributesResponse) GetResult

func (x *GetAttributesResponse) GetResult() int64

func (*GetAttributesResponse) ProtoMessage

func (*GetAttributesResponse) ProtoMessage()

func (*GetAttributesResponse) ProtoReflect

func (x *GetAttributesResponse) ProtoReflect() protoreflect.Message

func (*GetAttributesResponse) Reset

func (x *GetAttributesResponse) Reset()

func (*GetAttributesResponse) String

func (x *GetAttributesResponse) String() string

type GetCopiesRequest

type GetCopiesRequest struct {
	// contains filtered or unexported fields
}

func (*GetCopiesRequest) Descriptor deprecated

func (*GetCopiesRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetCopiesRequest.ProtoReflect.Descriptor instead.

func (*GetCopiesRequest) ProtoMessage

func (*GetCopiesRequest) ProtoMessage()

func (*GetCopiesRequest) ProtoReflect

func (x *GetCopiesRequest) ProtoReflect() protoreflect.Message

func (*GetCopiesRequest) Reset

func (x *GetCopiesRequest) Reset()

func (*GetCopiesRequest) String

func (x *GetCopiesRequest) String() string

type GetCopiesResponse

type GetCopiesResponse struct {
	Result int32 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetCopiesResponse) Descriptor deprecated

func (*GetCopiesResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetCopiesResponse.ProtoReflect.Descriptor instead.

func (*GetCopiesResponse) GetResult

func (x *GetCopiesResponse) GetResult() int32

func (*GetCopiesResponse) ProtoMessage

func (*GetCopiesResponse) ProtoMessage()

func (*GetCopiesResponse) ProtoReflect

func (x *GetCopiesResponse) ProtoReflect() protoreflect.Message

func (*GetCopiesResponse) Reset

func (x *GetCopiesResponse) Reset()

func (*GetCopiesResponse) String

func (x *GetCopiesResponse) String() string

type GetCreationTimeRequest

type GetCreationTimeRequest struct {
	// contains filtered or unexported fields
}

func (*GetCreationTimeRequest) Descriptor deprecated

func (*GetCreationTimeRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetCreationTimeRequest.ProtoReflect.Descriptor instead.

func (*GetCreationTimeRequest) ProtoMessage

func (*GetCreationTimeRequest) ProtoMessage()

func (*GetCreationTimeRequest) ProtoReflect

func (x *GetCreationTimeRequest) ProtoReflect() protoreflect.Message

func (*GetCreationTimeRequest) Reset

func (x *GetCreationTimeRequest) Reset()

func (*GetCreationTimeRequest) String

func (x *GetCreationTimeRequest) String() string

type GetCreationTimeResponse

type GetCreationTimeResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetCreationTimeResponse) Descriptor deprecated

func (*GetCreationTimeResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetCreationTimeResponse.ProtoReflect.Descriptor instead.

func (*GetCreationTimeResponse) GetResult

func (x *GetCreationTimeResponse) GetResult() int64

func (*GetCreationTimeResponse) ProtoMessage

func (*GetCreationTimeResponse) ProtoMessage()

func (*GetCreationTimeResponse) ProtoReflect

func (x *GetCreationTimeResponse) ProtoReflect() protoreflect.Message

func (*GetCreationTimeResponse) Reset

func (x *GetCreationTimeResponse) Reset()

func (*GetCreationTimeResponse) String

func (x *GetCreationTimeResponse) String() string

type GetIdRequest

type GetIdRequest struct {
	// contains filtered or unexported fields
}

func (*GetIdRequest) Descriptor deprecated

func (*GetIdRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetIdRequest.ProtoReflect.Descriptor instead.

func (*GetIdRequest) ProtoMessage

func (*GetIdRequest) ProtoMessage()

func (*GetIdRequest) ProtoReflect

func (x *GetIdRequest) ProtoReflect() protoreflect.Message

func (*GetIdRequest) Reset

func (x *GetIdRequest) Reset()

func (*GetIdRequest) String

func (x *GetIdRequest) String() string

type GetIdResponse

type GetIdResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetIdResponse) Descriptor deprecated

func (*GetIdResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetIdResponse.ProtoReflect.Descriptor instead.

func (*GetIdResponse) GetResult

func (x *GetIdResponse) GetResult() int64

func (*GetIdResponse) ProtoMessage

func (*GetIdResponse) ProtoMessage()

func (*GetIdResponse) ProtoReflect

func (x *GetIdResponse) ProtoReflect() protoreflect.Message

func (*GetIdResponse) Reset

func (x *GetIdResponse) Reset()

func (*GetIdResponse) String

func (x *GetIdResponse) String() string

type GetInfoRequest

type GetInfoRequest struct {
	// contains filtered or unexported fields
}

func (*GetInfoRequest) Descriptor deprecated

func (*GetInfoRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetInfoRequest.ProtoReflect.Descriptor instead.

func (*GetInfoRequest) ProtoMessage

func (*GetInfoRequest) ProtoMessage()

func (*GetInfoRequest) ProtoReflect

func (x *GetInfoRequest) ProtoReflect() protoreflect.Message

func (*GetInfoRequest) Reset

func (x *GetInfoRequest) Reset()

func (*GetInfoRequest) String

func (x *GetInfoRequest) String() string

type GetInfoResponse

type GetInfoResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetInfoResponse) Descriptor deprecated

func (*GetInfoResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetInfoResponse.ProtoReflect.Descriptor instead.

func (*GetInfoResponse) GetResult

func (x *GetInfoResponse) GetResult() int64

func (*GetInfoResponse) ProtoMessage

func (*GetInfoResponse) ProtoMessage()

func (*GetInfoResponse) ProtoReflect

func (x *GetInfoResponse) ProtoReflect() protoreflect.Message

func (*GetInfoResponse) Reset

func (x *GetInfoResponse) Reset()

func (*GetInfoResponse) String

func (x *GetInfoResponse) String() string

type GetLabelRequest

type GetLabelRequest struct {
	// contains filtered or unexported fields
}

func (*GetLabelRequest) Descriptor deprecated

func (*GetLabelRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetLabelRequest.ProtoReflect.Descriptor instead.

func (*GetLabelRequest) ProtoMessage

func (*GetLabelRequest) ProtoMessage()

func (*GetLabelRequest) ProtoReflect

func (x *GetLabelRequest) ProtoReflect() protoreflect.Message

func (*GetLabelRequest) Reset

func (x *GetLabelRequest) Reset()

func (*GetLabelRequest) String

func (x *GetLabelRequest) String() string

type GetLabelResponse

type GetLabelResponse struct {
	Result string `protobuf:"bytes,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetLabelResponse) Descriptor deprecated

func (*GetLabelResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetLabelResponse.ProtoReflect.Descriptor instead.

func (*GetLabelResponse) GetResult

func (x *GetLabelResponse) GetResult() string

func (*GetLabelResponse) ProtoMessage

func (*GetLabelResponse) ProtoMessage()

func (*GetLabelResponse) ProtoReflect

func (x *GetLabelResponse) ProtoReflect() protoreflect.Message

func (*GetLabelResponse) Reset

func (x *GetLabelResponse) Reset()

func (*GetLabelResponse) String

func (x *GetLabelResponse) String() string

type GetPagesRequest

type GetPagesRequest struct {
	// contains filtered or unexported fields
}

func (*GetPagesRequest) Descriptor deprecated

func (*GetPagesRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetPagesRequest.ProtoReflect.Descriptor instead.

func (*GetPagesRequest) ProtoMessage

func (*GetPagesRequest) ProtoMessage()

func (*GetPagesRequest) ProtoReflect

func (x *GetPagesRequest) ProtoReflect() protoreflect.Message

func (*GetPagesRequest) Reset

func (x *GetPagesRequest) Reset()

func (*GetPagesRequest) String

func (x *GetPagesRequest) String() string

type GetPagesResponse

type GetPagesResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetPagesResponse) Descriptor deprecated

func (*GetPagesResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetPagesResponse.ProtoReflect.Descriptor instead.

func (*GetPagesResponse) GetResult

func (x *GetPagesResponse) GetResult() int64

func (*GetPagesResponse) ProtoMessage

func (*GetPagesResponse) ProtoMessage()

func (*GetPagesResponse) ProtoReflect

func (x *GetPagesResponse) ProtoReflect() protoreflect.Message

func (*GetPagesResponse) Reset

func (x *GetPagesResponse) Reset()

func (*GetPagesResponse) String

func (x *GetPagesResponse) String() string

type GetPrintJobsRequest

type GetPrintJobsRequest struct {
	// contains filtered or unexported fields
}

func (*GetPrintJobsRequest) Descriptor deprecated

func (*GetPrintJobsRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetPrintJobsRequest.ProtoReflect.Descriptor instead.

func (*GetPrintJobsRequest) ProtoMessage

func (*GetPrintJobsRequest) ProtoMessage()

func (*GetPrintJobsRequest) ProtoReflect

func (x *GetPrintJobsRequest) ProtoReflect() protoreflect.Message

func (*GetPrintJobsRequest) Reset

func (x *GetPrintJobsRequest) Reset()

func (*GetPrintJobsRequest) String

func (x *GetPrintJobsRequest) String() string

type GetPrintJobsResponse

type GetPrintJobsResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetPrintJobsResponse) Descriptor deprecated

func (*GetPrintJobsResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetPrintJobsResponse.ProtoReflect.Descriptor instead.

func (*GetPrintJobsResponse) GetResult

func (x *GetPrintJobsResponse) GetResult() int64

func (*GetPrintJobsResponse) ProtoMessage

func (*GetPrintJobsResponse) ProtoMessage()

func (*GetPrintJobsResponse) ProtoReflect

func (x *GetPrintJobsResponse) ProtoReflect() protoreflect.Message

func (*GetPrintJobsResponse) Reset

func (x *GetPrintJobsResponse) Reset()

func (*GetPrintJobsResponse) String

func (x *GetPrintJobsResponse) String() string

type GetPrinterIdRequest

type GetPrinterIdRequest struct {
	// contains filtered or unexported fields
}

func (*GetPrinterIdRequest) Descriptor deprecated

func (*GetPrinterIdRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetPrinterIdRequest.ProtoReflect.Descriptor instead.

func (*GetPrinterIdRequest) ProtoMessage

func (*GetPrinterIdRequest) ProtoMessage()

func (*GetPrinterIdRequest) ProtoReflect

func (x *GetPrinterIdRequest) ProtoReflect() protoreflect.Message

func (*GetPrinterIdRequest) Reset

func (x *GetPrinterIdRequest) Reset()

func (*GetPrinterIdRequest) String

func (x *GetPrinterIdRequest) String() string

type GetPrinterIdResponse

type GetPrinterIdResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetPrinterIdResponse) Descriptor deprecated

func (*GetPrinterIdResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetPrinterIdResponse.ProtoReflect.Descriptor instead.

func (*GetPrinterIdResponse) GetResult

func (x *GetPrinterIdResponse) GetResult() int64

func (*GetPrinterIdResponse) ProtoMessage

func (*GetPrinterIdResponse) ProtoMessage()

func (*GetPrinterIdResponse) ProtoReflect

func (x *GetPrinterIdResponse) ProtoReflect() protoreflect.Message

func (*GetPrinterIdResponse) Reset

func (x *GetPrinterIdResponse) Reset()

func (*GetPrinterIdResponse) String

func (x *GetPrinterIdResponse) String() string

type GetStateRequest

type GetStateRequest struct {
	// contains filtered or unexported fields
}

func (*GetStateRequest) Descriptor deprecated

func (*GetStateRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetStateRequest.ProtoReflect.Descriptor instead.

func (*GetStateRequest) ProtoMessage

func (*GetStateRequest) ProtoMessage()

func (*GetStateRequest) ProtoReflect

func (x *GetStateRequest) ProtoReflect() protoreflect.Message

func (*GetStateRequest) Reset

func (x *GetStateRequest) Reset()

func (*GetStateRequest) String

func (x *GetStateRequest) String() string

type GetStateResponse

type GetStateResponse struct {
	Result int32 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetStateResponse) Descriptor deprecated

func (*GetStateResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetStateResponse.ProtoReflect.Descriptor instead.

func (*GetStateResponse) GetResult

func (x *GetStateResponse) GetResult() int32

func (*GetStateResponse) ProtoMessage

func (*GetStateResponse) ProtoMessage()

func (*GetStateResponse) ProtoReflect

func (x *GetStateResponse) ProtoReflect() protoreflect.Message

func (*GetStateResponse) Reset

func (x *GetStateResponse) Reset()

func (*GetStateResponse) String

func (x *GetStateResponse) String() string

type HasAdvancedOptionRequest

type HasAdvancedOptionRequest struct {
	Arg0 string `protobuf:"bytes,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*HasAdvancedOptionRequest) Descriptor deprecated

func (*HasAdvancedOptionRequest) Descriptor() ([]byte, []int)

Deprecated: Use HasAdvancedOptionRequest.ProtoReflect.Descriptor instead.

func (*HasAdvancedOptionRequest) GetArg0

func (x *HasAdvancedOptionRequest) GetArg0() string

func (*HasAdvancedOptionRequest) ProtoMessage

func (*HasAdvancedOptionRequest) ProtoMessage()

func (*HasAdvancedOptionRequest) ProtoReflect

func (x *HasAdvancedOptionRequest) ProtoReflect() protoreflect.Message

func (*HasAdvancedOptionRequest) Reset

func (x *HasAdvancedOptionRequest) Reset()

func (*HasAdvancedOptionRequest) String

func (x *HasAdvancedOptionRequest) String() string

type HasAdvancedOptionResponse

type HasAdvancedOptionResponse struct {
	Result bool `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*HasAdvancedOptionResponse) Descriptor deprecated

func (*HasAdvancedOptionResponse) Descriptor() ([]byte, []int)

Deprecated: Use HasAdvancedOptionResponse.ProtoReflect.Descriptor instead.

func (*HasAdvancedOptionResponse) GetResult

func (x *HasAdvancedOptionResponse) GetResult() bool

func (*HasAdvancedOptionResponse) ProtoMessage

func (*HasAdvancedOptionResponse) ProtoMessage()

func (*HasAdvancedOptionResponse) ProtoReflect

func (*HasAdvancedOptionResponse) Reset

func (x *HasAdvancedOptionResponse) Reset()

func (*HasAdvancedOptionResponse) String

func (x *HasAdvancedOptionResponse) String() string

type HashCodeRequest

type HashCodeRequest struct {
	// contains filtered or unexported fields
}

func (*HashCodeRequest) Descriptor deprecated

func (*HashCodeRequest) Descriptor() ([]byte, []int)

Deprecated: Use HashCodeRequest.ProtoReflect.Descriptor instead.

func (*HashCodeRequest) ProtoMessage

func (*HashCodeRequest) ProtoMessage()

func (*HashCodeRequest) ProtoReflect

func (x *HashCodeRequest) ProtoReflect() protoreflect.Message

func (*HashCodeRequest) Reset

func (x *HashCodeRequest) Reset()

func (*HashCodeRequest) String

func (x *HashCodeRequest) String() string

type HashCodeResponse

type HashCodeResponse struct {
	Result int32 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*HashCodeResponse) Descriptor deprecated

func (*HashCodeResponse) Descriptor() ([]byte, []int)

Deprecated: Use HashCodeResponse.ProtoReflect.Descriptor instead.

func (*HashCodeResponse) GetResult

func (x *HashCodeResponse) GetResult() int32

func (*HashCodeResponse) ProtoMessage

func (*HashCodeResponse) ProtoMessage()

func (*HashCodeResponse) ProtoReflect

func (x *HashCodeResponse) ProtoReflect() protoreflect.Message

func (*HashCodeResponse) Reset

func (x *HashCodeResponse) Reset()

func (*HashCodeResponse) String

func (x *HashCodeResponse) String() string

type IsBlockedRequest

type IsBlockedRequest struct {
	// contains filtered or unexported fields
}

func (*IsBlockedRequest) Descriptor deprecated

func (*IsBlockedRequest) Descriptor() ([]byte, []int)

Deprecated: Use IsBlockedRequest.ProtoReflect.Descriptor instead.

func (*IsBlockedRequest) ProtoMessage

func (*IsBlockedRequest) ProtoMessage()

func (*IsBlockedRequest) ProtoReflect

func (x *IsBlockedRequest) ProtoReflect() protoreflect.Message

func (*IsBlockedRequest) Reset

func (x *IsBlockedRequest) Reset()

func (*IsBlockedRequest) String

func (x *IsBlockedRequest) String() string

type IsBlockedResponse

type IsBlockedResponse struct {
	Result bool `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*IsBlockedResponse) Descriptor deprecated

func (*IsBlockedResponse) Descriptor() ([]byte, []int)

Deprecated: Use IsBlockedResponse.ProtoReflect.Descriptor instead.

func (*IsBlockedResponse) GetResult

func (x *IsBlockedResponse) GetResult() bool

func (*IsBlockedResponse) ProtoMessage

func (*IsBlockedResponse) ProtoMessage()

func (*IsBlockedResponse) ProtoReflect

func (x *IsBlockedResponse) ProtoReflect() protoreflect.Message

func (*IsBlockedResponse) Reset

func (x *IsBlockedResponse) Reset()

func (*IsBlockedResponse) String

func (x *IsBlockedResponse) String() string

type IsCancelledRequest

type IsCancelledRequest struct {
	// contains filtered or unexported fields
}

func (*IsCancelledRequest) Descriptor deprecated

func (*IsCancelledRequest) Descriptor() ([]byte, []int)

Deprecated: Use IsCancelledRequest.ProtoReflect.Descriptor instead.

func (*IsCancelledRequest) ProtoMessage

func (*IsCancelledRequest) ProtoMessage()

func (*IsCancelledRequest) ProtoReflect

func (x *IsCancelledRequest) ProtoReflect() protoreflect.Message

func (*IsCancelledRequest) Reset

func (x *IsCancelledRequest) Reset()

func (*IsCancelledRequest) String

func (x *IsCancelledRequest) String() string

type IsCancelledResponse

type IsCancelledResponse struct {
	Result bool `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*IsCancelledResponse) Descriptor deprecated

func (*IsCancelledResponse) Descriptor() ([]byte, []int)

Deprecated: Use IsCancelledResponse.ProtoReflect.Descriptor instead.

func (*IsCancelledResponse) GetResult

func (x *IsCancelledResponse) GetResult() bool

func (*IsCancelledResponse) ProtoMessage

func (*IsCancelledResponse) ProtoMessage()

func (*IsCancelledResponse) ProtoReflect

func (x *IsCancelledResponse) ProtoReflect() protoreflect.Message

func (*IsCancelledResponse) Reset

func (x *IsCancelledResponse) Reset()

func (*IsCancelledResponse) String

func (x *IsCancelledResponse) String() string

type IsCompletedRequest

type IsCompletedRequest struct {
	// contains filtered or unexported fields
}

func (*IsCompletedRequest) Descriptor deprecated

func (*IsCompletedRequest) Descriptor() ([]byte, []int)

Deprecated: Use IsCompletedRequest.ProtoReflect.Descriptor instead.

func (*IsCompletedRequest) ProtoMessage

func (*IsCompletedRequest) ProtoMessage()

func (*IsCompletedRequest) ProtoReflect

func (x *IsCompletedRequest) ProtoReflect() protoreflect.Message

func (*IsCompletedRequest) Reset

func (x *IsCompletedRequest) Reset()

func (*IsCompletedRequest) String

func (x *IsCompletedRequest) String() string

type IsCompletedResponse

type IsCompletedResponse struct {
	Result bool `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*IsCompletedResponse) Descriptor deprecated

func (*IsCompletedResponse) Descriptor() ([]byte, []int)

Deprecated: Use IsCompletedResponse.ProtoReflect.Descriptor instead.

func (*IsCompletedResponse) GetResult

func (x *IsCompletedResponse) GetResult() bool

func (*IsCompletedResponse) ProtoMessage

func (*IsCompletedResponse) ProtoMessage()

func (*IsCompletedResponse) ProtoReflect

func (x *IsCompletedResponse) ProtoReflect() protoreflect.Message

func (*IsCompletedResponse) Reset

func (x *IsCompletedResponse) Reset()

func (*IsCompletedResponse) String

func (x *IsCompletedResponse) String() string

type IsFailedRequest

type IsFailedRequest struct {
	// contains filtered or unexported fields
}

func (*IsFailedRequest) Descriptor deprecated

func (*IsFailedRequest) Descriptor() ([]byte, []int)

Deprecated: Use IsFailedRequest.ProtoReflect.Descriptor instead.

func (*IsFailedRequest) ProtoMessage

func (*IsFailedRequest) ProtoMessage()

func (*IsFailedRequest) ProtoReflect

func (x *IsFailedRequest) ProtoReflect() protoreflect.Message

func (*IsFailedRequest) Reset

func (x *IsFailedRequest) Reset()

func (*IsFailedRequest) String

func (x *IsFailedRequest) String() string

type IsFailedResponse

type IsFailedResponse struct {
	Result bool `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*IsFailedResponse) Descriptor deprecated

func (*IsFailedResponse) Descriptor() ([]byte, []int)

Deprecated: Use IsFailedResponse.ProtoReflect.Descriptor instead.

func (*IsFailedResponse) GetResult

func (x *IsFailedResponse) GetResult() bool

func (*IsFailedResponse) ProtoMessage

func (*IsFailedResponse) ProtoMessage()

func (*IsFailedResponse) ProtoReflect

func (x *IsFailedResponse) ProtoReflect() protoreflect.Message

func (*IsFailedResponse) Reset

func (x *IsFailedResponse) Reset()

func (*IsFailedResponse) String

func (x *IsFailedResponse) String() string

type IsPrintServiceEnabledRequest

type IsPrintServiceEnabledRequest struct {
	Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*IsPrintServiceEnabledRequest) Descriptor deprecated

func (*IsPrintServiceEnabledRequest) Descriptor() ([]byte, []int)

Deprecated: Use IsPrintServiceEnabledRequest.ProtoReflect.Descriptor instead.

func (*IsPrintServiceEnabledRequest) GetArg0

func (x *IsPrintServiceEnabledRequest) GetArg0() int64

func (*IsPrintServiceEnabledRequest) ProtoMessage

func (*IsPrintServiceEnabledRequest) ProtoMessage()

func (*IsPrintServiceEnabledRequest) ProtoReflect

func (*IsPrintServiceEnabledRequest) Reset

func (x *IsPrintServiceEnabledRequest) Reset()

func (*IsPrintServiceEnabledRequest) String

type IsPrintServiceEnabledResponse

type IsPrintServiceEnabledResponse struct {
	Result bool `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*IsPrintServiceEnabledResponse) Descriptor deprecated

func (*IsPrintServiceEnabledResponse) Descriptor() ([]byte, []int)

Deprecated: Use IsPrintServiceEnabledResponse.ProtoReflect.Descriptor instead.

func (*IsPrintServiceEnabledResponse) GetResult

func (x *IsPrintServiceEnabledResponse) GetResult() bool

func (*IsPrintServiceEnabledResponse) ProtoMessage

func (*IsPrintServiceEnabledResponse) ProtoMessage()

func (*IsPrintServiceEnabledResponse) ProtoReflect

func (*IsPrintServiceEnabledResponse) Reset

func (x *IsPrintServiceEnabledResponse) Reset()

func (*IsPrintServiceEnabledResponse) String

type IsQueuedRequest

type IsQueuedRequest struct {
	// contains filtered or unexported fields
}

func (*IsQueuedRequest) Descriptor deprecated

func (*IsQueuedRequest) Descriptor() ([]byte, []int)

Deprecated: Use IsQueuedRequest.ProtoReflect.Descriptor instead.

func (*IsQueuedRequest) ProtoMessage

func (*IsQueuedRequest) ProtoMessage()

func (*IsQueuedRequest) ProtoReflect

func (x *IsQueuedRequest) ProtoReflect() protoreflect.Message

func (*IsQueuedRequest) Reset

func (x *IsQueuedRequest) Reset()

func (*IsQueuedRequest) String

func (x *IsQueuedRequest) String() string

type IsQueuedResponse

type IsQueuedResponse struct {
	Result bool `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*IsQueuedResponse) Descriptor deprecated

func (*IsQueuedResponse) Descriptor() ([]byte, []int)

Deprecated: Use IsQueuedResponse.ProtoReflect.Descriptor instead.

func (*IsQueuedResponse) GetResult

func (x *IsQueuedResponse) GetResult() bool

func (*IsQueuedResponse) ProtoMessage

func (*IsQueuedResponse) ProtoMessage()

func (*IsQueuedResponse) ProtoReflect

func (x *IsQueuedResponse) ProtoReflect() protoreflect.Message

func (*IsQueuedResponse) Reset

func (x *IsQueuedResponse) Reset()

func (*IsQueuedResponse) String

func (x *IsQueuedResponse) String() string

type IsStartedRequest

type IsStartedRequest struct {
	// contains filtered or unexported fields
}

func (*IsStartedRequest) Descriptor deprecated

func (*IsStartedRequest) Descriptor() ([]byte, []int)

Deprecated: Use IsStartedRequest.ProtoReflect.Descriptor instead.

func (*IsStartedRequest) ProtoMessage

func (*IsStartedRequest) ProtoMessage()

func (*IsStartedRequest) ProtoReflect

func (x *IsStartedRequest) ProtoReflect() protoreflect.Message

func (*IsStartedRequest) Reset

func (x *IsStartedRequest) Reset()

func (*IsStartedRequest) String

func (x *IsStartedRequest) String() string

type IsStartedResponse

type IsStartedResponse struct {
	Result bool `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*IsStartedResponse) Descriptor deprecated

func (*IsStartedResponse) Descriptor() ([]byte, []int)

Deprecated: Use IsStartedResponse.ProtoReflect.Descriptor instead.

func (*IsStartedResponse) GetResult

func (x *IsStartedResponse) GetResult() bool

func (*IsStartedResponse) ProtoMessage

func (*IsStartedResponse) ProtoMessage()

func (*IsStartedResponse) ProtoReflect

func (x *IsStartedResponse) ProtoReflect() protoreflect.Message

func (*IsStartedResponse) Reset

func (x *IsStartedResponse) Reset()

func (*IsStartedResponse) String

func (x *IsStartedResponse) String() string

type JobInfoServiceClient added in v0.0.4

type JobInfoServiceClient interface {
	DescribeContents(ctx context.Context, in *DescribeContentsRequest, opts ...grpc.CallOption) (*DescribeContentsResponse, error)
	GetAdvancedIntOption(ctx context.Context, in *GetAdvancedIntOptionRequest, opts ...grpc.CallOption) (*GetAdvancedIntOptionResponse, error)
	GetAdvancedStringOption(ctx context.Context, in *GetAdvancedStringOptionRequest, opts ...grpc.CallOption) (*GetAdvancedStringOptionResponse, error)
	GetAttributes(ctx context.Context, in *GetAttributesRequest, opts ...grpc.CallOption) (*GetAttributesResponse, error)
	GetCopies(ctx context.Context, in *GetCopiesRequest, opts ...grpc.CallOption) (*GetCopiesResponse, error)
	GetCreationTime(ctx context.Context, in *GetCreationTimeRequest, opts ...grpc.CallOption) (*GetCreationTimeResponse, error)
	GetId(ctx context.Context, in *GetIdRequest, opts ...grpc.CallOption) (*GetIdResponse, error)
	GetLabel(ctx context.Context, in *GetLabelRequest, opts ...grpc.CallOption) (*GetLabelResponse, error)
	GetPages(ctx context.Context, in *GetPagesRequest, opts ...grpc.CallOption) (*GetPagesResponse, error)
	GetPrinterId(ctx context.Context, in *GetPrinterIdRequest, opts ...grpc.CallOption) (*GetPrinterIdResponse, error)
	GetState(ctx context.Context, in *GetStateRequest, opts ...grpc.CallOption) (*GetStateResponse, error)
	HasAdvancedOption(ctx context.Context, in *HasAdvancedOptionRequest, opts ...grpc.CallOption) (*HasAdvancedOptionResponse, error)
	ToString(ctx context.Context, in *ToStringRequest, opts ...grpc.CallOption) (*ToStringResponse, error)
	WriteToParcel(ctx context.Context, in *WriteToParcelRequest, opts ...grpc.CallOption) (*WriteToParcelResponse, error)
}

JobInfoServiceClient is the client API for JobInfoService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

func NewJobInfoServiceClient added in v0.0.4

func NewJobInfoServiceClient(cc grpc.ClientConnInterface) JobInfoServiceClient

type JobInfoServiceServer added in v0.0.4

JobInfoServiceServer is the server API for JobInfoService service. All implementations must embed UnimplementedJobInfoServiceServer for forward compatibility.

type JobServiceClient added in v0.0.4

JobServiceClient is the client API for JobService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

func NewJobServiceClient added in v0.0.4

func NewJobServiceClient(cc grpc.ClientConnInterface) JobServiceClient

type JobServiceServer added in v0.0.4

JobServiceServer is the server API for JobService service. All implementations must embed UnimplementedJobServiceServer for forward compatibility.

type ManagerServiceClient added in v0.0.4

type ManagerServiceClient interface {
	GetPrintJobs(ctx context.Context, in *GetPrintJobsRequest, opts ...grpc.CallOption) (*GetPrintJobsResponse, error)
	IsPrintServiceEnabled(ctx context.Context, in *IsPrintServiceEnabledRequest, opts ...grpc.CallOption) (*IsPrintServiceEnabledResponse, error)
	Print(ctx context.Context, in *PrintRequest, opts ...grpc.CallOption) (*PrintResponse, error)
}

ManagerServiceClient is the client API for ManagerService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

func NewManagerServiceClient added in v0.0.4

func NewManagerServiceClient(cc grpc.ClientConnInterface) ManagerServiceClient

type ManagerServiceServer added in v0.0.4

type ManagerServiceServer interface {
	GetPrintJobs(context.Context, *GetPrintJobsRequest) (*GetPrintJobsResponse, error)
	IsPrintServiceEnabled(context.Context, *IsPrintServiceEnabledRequest) (*IsPrintServiceEnabledResponse, error)
	Print(context.Context, *PrintRequest) (*PrintResponse, error)
	// contains filtered or unexported methods
}

ManagerServiceServer is the server API for ManagerService service. All implementations must embed UnimplementedManagerServiceServer for forward compatibility.

type PrintRequest

type PrintRequest struct {
	Arg0 string `protobuf:"bytes,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	Arg1 int64  `protobuf:"varint,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
	Arg2 int64  `protobuf:"varint,3,opt,name=arg2,proto3" json:"arg2,omitempty"`
	// contains filtered or unexported fields
}

func (*PrintRequest) Descriptor deprecated

func (*PrintRequest) Descriptor() ([]byte, []int)

Deprecated: Use PrintRequest.ProtoReflect.Descriptor instead.

func (*PrintRequest) GetArg0

func (x *PrintRequest) GetArg0() string

func (*PrintRequest) GetArg1

func (x *PrintRequest) GetArg1() int64

func (*PrintRequest) GetArg2

func (x *PrintRequest) GetArg2() int64

func (*PrintRequest) ProtoMessage

func (*PrintRequest) ProtoMessage()

func (*PrintRequest) ProtoReflect

func (x *PrintRequest) ProtoReflect() protoreflect.Message

func (*PrintRequest) Reset

func (x *PrintRequest) Reset()

func (*PrintRequest) String

func (x *PrintRequest) String() string

type PrintResponse

type PrintResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*PrintResponse) Descriptor deprecated

func (*PrintResponse) Descriptor() ([]byte, []int)

Deprecated: Use PrintResponse.ProtoReflect.Descriptor instead.

func (*PrintResponse) GetResult

func (x *PrintResponse) GetResult() int64

func (*PrintResponse) ProtoMessage

func (*PrintResponse) ProtoMessage()

func (*PrintResponse) ProtoReflect

func (x *PrintResponse) ProtoReflect() protoreflect.Message

func (*PrintResponse) Reset

func (x *PrintResponse) Reset()

func (*PrintResponse) String

func (x *PrintResponse) String() string

type RestartRequest

type RestartRequest struct {
	// contains filtered or unexported fields
}

func (*RestartRequest) Descriptor deprecated

func (*RestartRequest) Descriptor() ([]byte, []int)

Deprecated: Use RestartRequest.ProtoReflect.Descriptor instead.

func (*RestartRequest) ProtoMessage

func (*RestartRequest) ProtoMessage()

func (*RestartRequest) ProtoReflect

func (x *RestartRequest) ProtoReflect() protoreflect.Message

func (*RestartRequest) Reset

func (x *RestartRequest) Reset()

func (*RestartRequest) String

func (x *RestartRequest) String() string

type RestartResponse

type RestartResponse struct {
	// contains filtered or unexported fields
}

func (*RestartResponse) Descriptor deprecated

func (*RestartResponse) Descriptor() ([]byte, []int)

Deprecated: Use RestartResponse.ProtoReflect.Descriptor instead.

func (*RestartResponse) ProtoMessage

func (*RestartResponse) ProtoMessage()

func (*RestartResponse) ProtoReflect

func (x *RestartResponse) ProtoReflect() protoreflect.Message

func (*RestartResponse) Reset

func (x *RestartResponse) Reset()

func (*RestartResponse) String

func (x *RestartResponse) String() string

type ToStringRequest

type ToStringRequest struct {
	// contains filtered or unexported fields
}

func (*ToStringRequest) Descriptor deprecated

func (*ToStringRequest) Descriptor() ([]byte, []int)

Deprecated: Use ToStringRequest.ProtoReflect.Descriptor instead.

func (*ToStringRequest) ProtoMessage

func (*ToStringRequest) ProtoMessage()

func (*ToStringRequest) ProtoReflect

func (x *ToStringRequest) ProtoReflect() protoreflect.Message

func (*ToStringRequest) Reset

func (x *ToStringRequest) Reset()

func (*ToStringRequest) String

func (x *ToStringRequest) String() string

type ToStringResponse

type ToStringResponse struct {
	Result string `protobuf:"bytes,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*ToStringResponse) Descriptor deprecated

func (*ToStringResponse) Descriptor() ([]byte, []int)

Deprecated: Use ToStringResponse.ProtoReflect.Descriptor instead.

func (*ToStringResponse) GetResult

func (x *ToStringResponse) GetResult() string

func (*ToStringResponse) ProtoMessage

func (*ToStringResponse) ProtoMessage()

func (*ToStringResponse) ProtoReflect

func (x *ToStringResponse) ProtoReflect() protoreflect.Message

func (*ToStringResponse) Reset

func (x *ToStringResponse) Reset()

func (*ToStringResponse) String

func (x *ToStringResponse) String() string

type UnimplementedJobInfoServiceServer added in v0.0.4

type UnimplementedJobInfoServiceServer struct{}

UnimplementedJobInfoServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedJobInfoServiceServer) DescribeContents added in v0.0.4

func (UnimplementedJobInfoServiceServer) GetAdvancedIntOption added in v0.0.4

func (UnimplementedJobInfoServiceServer) GetAdvancedStringOption added in v0.0.4

func (UnimplementedJobInfoServiceServer) GetAttributes added in v0.0.4

func (UnimplementedJobInfoServiceServer) GetCopies added in v0.0.4

func (UnimplementedJobInfoServiceServer) GetCreationTime added in v0.0.4

func (UnimplementedJobInfoServiceServer) GetId added in v0.0.4

func (UnimplementedJobInfoServiceServer) GetLabel added in v0.0.4

func (UnimplementedJobInfoServiceServer) GetPages added in v0.0.4

func (UnimplementedJobInfoServiceServer) GetPrinterId added in v0.0.4

func (UnimplementedJobInfoServiceServer) GetState added in v0.0.4

func (UnimplementedJobInfoServiceServer) HasAdvancedOption added in v0.0.4

func (UnimplementedJobInfoServiceServer) ToString added in v0.0.4

func (UnimplementedJobInfoServiceServer) WriteToParcel added in v0.0.4

type UnimplementedJobServiceServer added in v0.0.4

type UnimplementedJobServiceServer struct{}

UnimplementedJobServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedJobServiceServer) Cancel added in v0.0.4

func (UnimplementedJobServiceServer) Equals added in v0.0.4

func (UnimplementedJobServiceServer) GetId added in v0.0.4

func (UnimplementedJobServiceServer) GetInfo added in v0.0.4

func (UnimplementedJobServiceServer) HashCode added in v0.0.4

func (UnimplementedJobServiceServer) IsBlocked added in v0.0.4

func (UnimplementedJobServiceServer) IsCancelled added in v0.0.4

func (UnimplementedJobServiceServer) IsCompleted added in v0.0.4

func (UnimplementedJobServiceServer) IsFailed added in v0.0.4

func (UnimplementedJobServiceServer) IsQueued added in v0.0.4

func (UnimplementedJobServiceServer) IsStarted added in v0.0.4

func (UnimplementedJobServiceServer) Restart added in v0.0.4

type UnimplementedManagerServiceServer added in v0.0.4

type UnimplementedManagerServiceServer struct{}

UnimplementedManagerServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedManagerServiceServer) GetPrintJobs added in v0.0.4

func (UnimplementedManagerServiceServer) IsPrintServiceEnabled added in v0.0.4

func (UnimplementedManagerServiceServer) Print added in v0.0.4

type UnsafeJobInfoServiceServer added in v0.0.4

type UnsafeJobInfoServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeJobInfoServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to JobInfoServiceServer will result in compilation errors.

type UnsafeJobServiceServer added in v0.0.4

type UnsafeJobServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeJobServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to JobServiceServer will result in compilation errors.

type UnsafeManagerServiceServer added in v0.0.4

type UnsafeManagerServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeManagerServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ManagerServiceServer will result in compilation errors.

type WriteToParcelRequest

type WriteToParcelRequest struct {
	Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	Arg1 int32 `protobuf:"varint,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
	// contains filtered or unexported fields
}

func (*WriteToParcelRequest) Descriptor deprecated

func (*WriteToParcelRequest) Descriptor() ([]byte, []int)

Deprecated: Use WriteToParcelRequest.ProtoReflect.Descriptor instead.

func (*WriteToParcelRequest) GetArg0

func (x *WriteToParcelRequest) GetArg0() int64

func (*WriteToParcelRequest) GetArg1

func (x *WriteToParcelRequest) GetArg1() int32

func (*WriteToParcelRequest) ProtoMessage

func (*WriteToParcelRequest) ProtoMessage()

func (*WriteToParcelRequest) ProtoReflect

func (x *WriteToParcelRequest) ProtoReflect() protoreflect.Message

func (*WriteToParcelRequest) Reset

func (x *WriteToParcelRequest) Reset()

func (*WriteToParcelRequest) String

func (x *WriteToParcelRequest) String() string

type WriteToParcelResponse

type WriteToParcelResponse struct {
	// contains filtered or unexported fields
}

func (*WriteToParcelResponse) Descriptor deprecated

func (*WriteToParcelResponse) Descriptor() ([]byte, []int)

Deprecated: Use WriteToParcelResponse.ProtoReflect.Descriptor instead.

func (*WriteToParcelResponse) ProtoMessage

func (*WriteToParcelResponse) ProtoMessage()

func (*WriteToParcelResponse) ProtoReflect

func (x *WriteToParcelResponse) ProtoReflect() protoreflect.Message

func (*WriteToParcelResponse) Reset

func (x *WriteToParcelResponse) Reset()

func (*WriteToParcelResponse) String

func (x *WriteToParcelResponse) String() string

Jump to