projection

package
v0.0.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 22, 2026 License: CC0-1.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

const (
	VirtualDisplayService_GetDisplay_FullMethodName  = "/projection.VirtualDisplayService/GetDisplay"
	VirtualDisplayService_GetSurface_FullMethodName  = "/projection.VirtualDisplayService/GetSurface"
	VirtualDisplayService_Release_FullMethodName     = "/projection.VirtualDisplayService/Release"
	VirtualDisplayService_Resize_FullMethodName      = "/projection.VirtualDisplayService/Resize"
	VirtualDisplayService_SetRotation_FullMethodName = "/projection.VirtualDisplayService/SetRotation"
	VirtualDisplayService_SetSurface_FullMethodName  = "/projection.VirtualDisplayService/SetSurface"
	VirtualDisplayService_ToString_FullMethodName    = "/projection.VirtualDisplayService/ToString"
)
const (
	MediaProjectionService_Stop_FullMethodName               = "/projection.MediaProjectionService/Stop"
	MediaProjectionService_UnregisterCallback_FullMethodName = "/projection.MediaProjectionService/UnregisterCallback"
)
const (
	MediaProjectionManagerService_CreateScreenCaptureIntent0_FullMethodName   = "/projection.MediaProjectionManagerService/CreateScreenCaptureIntent0"
	MediaProjectionManagerService_CreateScreenCaptureIntent1_1_FullMethodName = "/projection.MediaProjectionManagerService/CreateScreenCaptureIntent1_1"
	MediaProjectionManagerService_GetMediaProjection_FullMethodName           = "/projection.MediaProjectionManagerService/GetMediaProjection"
)

Variables

var File_proto_projection_projection_proto protoreflect.FileDescriptor
var MediaProjectionManagerService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "projection.MediaProjectionManagerService",
	HandlerType: (*MediaProjectionManagerServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "CreateScreenCaptureIntent0",
			Handler:    _MediaProjectionManagerService_CreateScreenCaptureIntent0_Handler,
		},
		{
			MethodName: "CreateScreenCaptureIntent1_1",
			Handler:    _MediaProjectionManagerService_CreateScreenCaptureIntent1_1_Handler,
		},
		{
			MethodName: "GetMediaProjection",
			Handler:    _MediaProjectionManagerService_GetMediaProjection_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/projection/projection.proto",
}

MediaProjectionManagerService_ServiceDesc is the grpc.ServiceDesc for MediaProjectionManagerService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var MediaProjectionService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "projection.MediaProjectionService",
	HandlerType: (*MediaProjectionServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "Stop",
			Handler:    _MediaProjectionService_Stop_Handler,
		},
		{
			MethodName: "UnregisterCallback",
			Handler:    _MediaProjectionService_UnregisterCallback_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/projection/projection.proto",
}

MediaProjectionService_ServiceDesc is the grpc.ServiceDesc for MediaProjectionService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var VirtualDisplayService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "projection.VirtualDisplayService",
	HandlerType: (*VirtualDisplayServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "GetDisplay",
			Handler:    _VirtualDisplayService_GetDisplay_Handler,
		},
		{
			MethodName: "GetSurface",
			Handler:    _VirtualDisplayService_GetSurface_Handler,
		},
		{
			MethodName: "Release",
			Handler:    _VirtualDisplayService_Release_Handler,
		},
		{
			MethodName: "Resize",
			Handler:    _VirtualDisplayService_Resize_Handler,
		},
		{
			MethodName: "SetRotation",
			Handler:    _VirtualDisplayService_SetRotation_Handler,
		},
		{
			MethodName: "SetSurface",
			Handler:    _VirtualDisplayService_SetSurface_Handler,
		},
		{
			MethodName: "ToString",
			Handler:    _VirtualDisplayService_ToString_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/projection/projection.proto",
}

VirtualDisplayService_ServiceDesc is the grpc.ServiceDesc for VirtualDisplayService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterMediaProjectionManagerServiceServer

func RegisterMediaProjectionManagerServiceServer(s grpc.ServiceRegistrar, srv MediaProjectionManagerServiceServer)

func RegisterMediaProjectionServiceServer

func RegisterMediaProjectionServiceServer(s grpc.ServiceRegistrar, srv MediaProjectionServiceServer)

func RegisterVirtualDisplayServiceServer

func RegisterVirtualDisplayServiceServer(s grpc.ServiceRegistrar, srv VirtualDisplayServiceServer)

Types

type CreateScreenCaptureIntent0Request

type CreateScreenCaptureIntent0Request struct {
	// contains filtered or unexported fields
}

func (*CreateScreenCaptureIntent0Request) Descriptor deprecated

func (*CreateScreenCaptureIntent0Request) Descriptor() ([]byte, []int)

Deprecated: Use CreateScreenCaptureIntent0Request.ProtoReflect.Descriptor instead.

func (*CreateScreenCaptureIntent0Request) ProtoMessage

func (*CreateScreenCaptureIntent0Request) ProtoMessage()

func (*CreateScreenCaptureIntent0Request) ProtoReflect

func (*CreateScreenCaptureIntent0Request) Reset

func (*CreateScreenCaptureIntent0Request) String

type CreateScreenCaptureIntent0Response

type CreateScreenCaptureIntent0Response struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*CreateScreenCaptureIntent0Response) Descriptor deprecated

func (*CreateScreenCaptureIntent0Response) Descriptor() ([]byte, []int)

Deprecated: Use CreateScreenCaptureIntent0Response.ProtoReflect.Descriptor instead.

func (*CreateScreenCaptureIntent0Response) GetResult

func (*CreateScreenCaptureIntent0Response) ProtoMessage

func (*CreateScreenCaptureIntent0Response) ProtoMessage()

func (*CreateScreenCaptureIntent0Response) ProtoReflect

func (*CreateScreenCaptureIntent0Response) Reset

func (*CreateScreenCaptureIntent0Response) String

type CreateScreenCaptureIntent1_1Request

type CreateScreenCaptureIntent1_1Request struct {
	Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*CreateScreenCaptureIntent1_1Request) Descriptor deprecated

func (*CreateScreenCaptureIntent1_1Request) Descriptor() ([]byte, []int)

Deprecated: Use CreateScreenCaptureIntent1_1Request.ProtoReflect.Descriptor instead.

func (*CreateScreenCaptureIntent1_1Request) GetArg0

func (*CreateScreenCaptureIntent1_1Request) ProtoMessage

func (*CreateScreenCaptureIntent1_1Request) ProtoMessage()

func (*CreateScreenCaptureIntent1_1Request) ProtoReflect

func (*CreateScreenCaptureIntent1_1Request) Reset

func (*CreateScreenCaptureIntent1_1Request) String

type CreateScreenCaptureIntent1_1Response

type CreateScreenCaptureIntent1_1Response struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*CreateScreenCaptureIntent1_1Response) Descriptor deprecated

func (*CreateScreenCaptureIntent1_1Response) Descriptor() ([]byte, []int)

Deprecated: Use CreateScreenCaptureIntent1_1Response.ProtoReflect.Descriptor instead.

func (*CreateScreenCaptureIntent1_1Response) GetResult

func (*CreateScreenCaptureIntent1_1Response) ProtoMessage

func (*CreateScreenCaptureIntent1_1Response) ProtoMessage()

func (*CreateScreenCaptureIntent1_1Response) ProtoReflect

func (*CreateScreenCaptureIntent1_1Response) Reset

func (*CreateScreenCaptureIntent1_1Response) String

type GetDisplayRequest

type GetDisplayRequest struct {
	// contains filtered or unexported fields
}

func (*GetDisplayRequest) Descriptor deprecated

func (*GetDisplayRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetDisplayRequest.ProtoReflect.Descriptor instead.

func (*GetDisplayRequest) ProtoMessage

func (*GetDisplayRequest) ProtoMessage()

func (*GetDisplayRequest) ProtoReflect

func (x *GetDisplayRequest) ProtoReflect() protoreflect.Message

func (*GetDisplayRequest) Reset

func (x *GetDisplayRequest) Reset()

func (*GetDisplayRequest) String

func (x *GetDisplayRequest) String() string

type GetDisplayResponse

type GetDisplayResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetDisplayResponse) Descriptor deprecated

func (*GetDisplayResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetDisplayResponse.ProtoReflect.Descriptor instead.

func (*GetDisplayResponse) GetResult

func (x *GetDisplayResponse) GetResult() int64

func (*GetDisplayResponse) ProtoMessage

func (*GetDisplayResponse) ProtoMessage()

func (*GetDisplayResponse) ProtoReflect

func (x *GetDisplayResponse) ProtoReflect() protoreflect.Message

func (*GetDisplayResponse) Reset

func (x *GetDisplayResponse) Reset()

func (*GetDisplayResponse) String

func (x *GetDisplayResponse) String() string

type GetMediaProjectionRequest

type GetMediaProjectionRequest struct {
	Arg0 int32 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	Arg1 int64 `protobuf:"varint,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
	// contains filtered or unexported fields
}

func (*GetMediaProjectionRequest) Descriptor deprecated

func (*GetMediaProjectionRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetMediaProjectionRequest.ProtoReflect.Descriptor instead.

func (*GetMediaProjectionRequest) GetArg0

func (x *GetMediaProjectionRequest) GetArg0() int32

func (*GetMediaProjectionRequest) GetArg1

func (x *GetMediaProjectionRequest) GetArg1() int64

func (*GetMediaProjectionRequest) ProtoMessage

func (*GetMediaProjectionRequest) ProtoMessage()

func (*GetMediaProjectionRequest) ProtoReflect

func (*GetMediaProjectionRequest) Reset

func (x *GetMediaProjectionRequest) Reset()

func (*GetMediaProjectionRequest) String

func (x *GetMediaProjectionRequest) String() string

type GetMediaProjectionResponse

type GetMediaProjectionResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetMediaProjectionResponse) Descriptor deprecated

func (*GetMediaProjectionResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetMediaProjectionResponse.ProtoReflect.Descriptor instead.

func (*GetMediaProjectionResponse) GetResult

func (x *GetMediaProjectionResponse) GetResult() int64

func (*GetMediaProjectionResponse) ProtoMessage

func (*GetMediaProjectionResponse) ProtoMessage()

func (*GetMediaProjectionResponse) ProtoReflect

func (*GetMediaProjectionResponse) Reset

func (x *GetMediaProjectionResponse) Reset()

func (*GetMediaProjectionResponse) String

func (x *GetMediaProjectionResponse) String() string

type GetSurfaceRequest

type GetSurfaceRequest struct {
	// contains filtered or unexported fields
}

func (*GetSurfaceRequest) Descriptor deprecated

func (*GetSurfaceRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetSurfaceRequest.ProtoReflect.Descriptor instead.

func (*GetSurfaceRequest) ProtoMessage

func (*GetSurfaceRequest) ProtoMessage()

func (*GetSurfaceRequest) ProtoReflect

func (x *GetSurfaceRequest) ProtoReflect() protoreflect.Message

func (*GetSurfaceRequest) Reset

func (x *GetSurfaceRequest) Reset()

func (*GetSurfaceRequest) String

func (x *GetSurfaceRequest) String() string

type GetSurfaceResponse

type GetSurfaceResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetSurfaceResponse) Descriptor deprecated

func (*GetSurfaceResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetSurfaceResponse.ProtoReflect.Descriptor instead.

func (*GetSurfaceResponse) GetResult

func (x *GetSurfaceResponse) GetResult() int64

func (*GetSurfaceResponse) ProtoMessage

func (*GetSurfaceResponse) ProtoMessage()

func (*GetSurfaceResponse) ProtoReflect

func (x *GetSurfaceResponse) ProtoReflect() protoreflect.Message

func (*GetSurfaceResponse) Reset

func (x *GetSurfaceResponse) Reset()

func (*GetSurfaceResponse) String

func (x *GetSurfaceResponse) String() string

type MediaProjectionManagerServiceClient

type MediaProjectionManagerServiceClient interface {
	CreateScreenCaptureIntent0(ctx context.Context, in *CreateScreenCaptureIntent0Request, opts ...grpc.CallOption) (*CreateScreenCaptureIntent0Response, error)
	CreateScreenCaptureIntent1_1(ctx context.Context, in *CreateScreenCaptureIntent1_1Request, opts ...grpc.CallOption) (*CreateScreenCaptureIntent1_1Response, error)
	GetMediaProjection(ctx context.Context, in *GetMediaProjectionRequest, opts ...grpc.CallOption) (*GetMediaProjectionResponse, error)
}

MediaProjectionManagerServiceClient is the client API for MediaProjectionManagerService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type MediaProjectionManagerServiceServer

type MediaProjectionManagerServiceServer interface {
	CreateScreenCaptureIntent0(context.Context, *CreateScreenCaptureIntent0Request) (*CreateScreenCaptureIntent0Response, error)
	CreateScreenCaptureIntent1_1(context.Context, *CreateScreenCaptureIntent1_1Request) (*CreateScreenCaptureIntent1_1Response, error)
	GetMediaProjection(context.Context, *GetMediaProjectionRequest) (*GetMediaProjectionResponse, error)
	// contains filtered or unexported methods
}

MediaProjectionManagerServiceServer is the server API for MediaProjectionManagerService service. All implementations must embed UnimplementedMediaProjectionManagerServiceServer for forward compatibility.

type MediaProjectionServiceClient

type MediaProjectionServiceClient interface {
	Stop(ctx context.Context, in *StopRequest, opts ...grpc.CallOption) (*StopResponse, error)
	UnregisterCallback(ctx context.Context, in *UnregisterCallbackRequest, opts ...grpc.CallOption) (*UnregisterCallbackResponse, error)
}

MediaProjectionServiceClient is the client API for MediaProjectionService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type MediaProjectionServiceServer

type MediaProjectionServiceServer interface {
	Stop(context.Context, *StopRequest) (*StopResponse, error)
	UnregisterCallback(context.Context, *UnregisterCallbackRequest) (*UnregisterCallbackResponse, error)
	// contains filtered or unexported methods
}

MediaProjectionServiceServer is the server API for MediaProjectionService service. All implementations must embed UnimplementedMediaProjectionServiceServer for forward compatibility.

type ReleaseRequest

type ReleaseRequest struct {
	// contains filtered or unexported fields
}

func (*ReleaseRequest) Descriptor deprecated

func (*ReleaseRequest) Descriptor() ([]byte, []int)

Deprecated: Use ReleaseRequest.ProtoReflect.Descriptor instead.

func (*ReleaseRequest) ProtoMessage

func (*ReleaseRequest) ProtoMessage()

func (*ReleaseRequest) ProtoReflect

func (x *ReleaseRequest) ProtoReflect() protoreflect.Message

func (*ReleaseRequest) Reset

func (x *ReleaseRequest) Reset()

func (*ReleaseRequest) String

func (x *ReleaseRequest) String() string

type ReleaseResponse

type ReleaseResponse struct {
	// contains filtered or unexported fields
}

func (*ReleaseResponse) Descriptor deprecated

func (*ReleaseResponse) Descriptor() ([]byte, []int)

Deprecated: Use ReleaseResponse.ProtoReflect.Descriptor instead.

func (*ReleaseResponse) ProtoMessage

func (*ReleaseResponse) ProtoMessage()

func (*ReleaseResponse) ProtoReflect

func (x *ReleaseResponse) ProtoReflect() protoreflect.Message

func (*ReleaseResponse) Reset

func (x *ReleaseResponse) Reset()

func (*ReleaseResponse) String

func (x *ReleaseResponse) String() string

type ResizeRequest

type ResizeRequest struct {
	Arg0 int32 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	Arg1 int32 `protobuf:"varint,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
	Arg2 int32 `protobuf:"varint,3,opt,name=arg2,proto3" json:"arg2,omitempty"`
	// contains filtered or unexported fields
}

func (*ResizeRequest) Descriptor deprecated

func (*ResizeRequest) Descriptor() ([]byte, []int)

Deprecated: Use ResizeRequest.ProtoReflect.Descriptor instead.

func (*ResizeRequest) GetArg0

func (x *ResizeRequest) GetArg0() int32

func (*ResizeRequest) GetArg1

func (x *ResizeRequest) GetArg1() int32

func (*ResizeRequest) GetArg2

func (x *ResizeRequest) GetArg2() int32

func (*ResizeRequest) ProtoMessage

func (*ResizeRequest) ProtoMessage()

func (*ResizeRequest) ProtoReflect

func (x *ResizeRequest) ProtoReflect() protoreflect.Message

func (*ResizeRequest) Reset

func (x *ResizeRequest) Reset()

func (*ResizeRequest) String

func (x *ResizeRequest) String() string

type ResizeResponse

type ResizeResponse struct {
	// contains filtered or unexported fields
}

func (*ResizeResponse) Descriptor deprecated

func (*ResizeResponse) Descriptor() ([]byte, []int)

Deprecated: Use ResizeResponse.ProtoReflect.Descriptor instead.

func (*ResizeResponse) ProtoMessage

func (*ResizeResponse) ProtoMessage()

func (*ResizeResponse) ProtoReflect

func (x *ResizeResponse) ProtoReflect() protoreflect.Message

func (*ResizeResponse) Reset

func (x *ResizeResponse) Reset()

func (*ResizeResponse) String

func (x *ResizeResponse) String() string

type SetRotationRequest

type SetRotationRequest struct {
	Arg0 int32 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*SetRotationRequest) Descriptor deprecated

func (*SetRotationRequest) Descriptor() ([]byte, []int)

Deprecated: Use SetRotationRequest.ProtoReflect.Descriptor instead.

func (*SetRotationRequest) GetArg0

func (x *SetRotationRequest) GetArg0() int32

func (*SetRotationRequest) ProtoMessage

func (*SetRotationRequest) ProtoMessage()

func (*SetRotationRequest) ProtoReflect

func (x *SetRotationRequest) ProtoReflect() protoreflect.Message

func (*SetRotationRequest) Reset

func (x *SetRotationRequest) Reset()

func (*SetRotationRequest) String

func (x *SetRotationRequest) String() string

type SetRotationResponse

type SetRotationResponse struct {
	// contains filtered or unexported fields
}

func (*SetRotationResponse) Descriptor deprecated

func (*SetRotationResponse) Descriptor() ([]byte, []int)

Deprecated: Use SetRotationResponse.ProtoReflect.Descriptor instead.

func (*SetRotationResponse) ProtoMessage

func (*SetRotationResponse) ProtoMessage()

func (*SetRotationResponse) ProtoReflect

func (x *SetRotationResponse) ProtoReflect() protoreflect.Message

func (*SetRotationResponse) Reset

func (x *SetRotationResponse) Reset()

func (*SetRotationResponse) String

func (x *SetRotationResponse) String() string

type SetSurfaceRequest

type SetSurfaceRequest struct {
	Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*SetSurfaceRequest) Descriptor deprecated

func (*SetSurfaceRequest) Descriptor() ([]byte, []int)

Deprecated: Use SetSurfaceRequest.ProtoReflect.Descriptor instead.

func (*SetSurfaceRequest) GetArg0

func (x *SetSurfaceRequest) GetArg0() int64

func (*SetSurfaceRequest) ProtoMessage

func (*SetSurfaceRequest) ProtoMessage()

func (*SetSurfaceRequest) ProtoReflect

func (x *SetSurfaceRequest) ProtoReflect() protoreflect.Message

func (*SetSurfaceRequest) Reset

func (x *SetSurfaceRequest) Reset()

func (*SetSurfaceRequest) String

func (x *SetSurfaceRequest) String() string

type SetSurfaceResponse

type SetSurfaceResponse struct {
	// contains filtered or unexported fields
}

func (*SetSurfaceResponse) Descriptor deprecated

func (*SetSurfaceResponse) Descriptor() ([]byte, []int)

Deprecated: Use SetSurfaceResponse.ProtoReflect.Descriptor instead.

func (*SetSurfaceResponse) ProtoMessage

func (*SetSurfaceResponse) ProtoMessage()

func (*SetSurfaceResponse) ProtoReflect

func (x *SetSurfaceResponse) ProtoReflect() protoreflect.Message

func (*SetSurfaceResponse) Reset

func (x *SetSurfaceResponse) Reset()

func (*SetSurfaceResponse) String

func (x *SetSurfaceResponse) String() string

type StopRequest

type StopRequest struct {
	// contains filtered or unexported fields
}

func (*StopRequest) Descriptor deprecated

func (*StopRequest) Descriptor() ([]byte, []int)

Deprecated: Use StopRequest.ProtoReflect.Descriptor instead.

func (*StopRequest) ProtoMessage

func (*StopRequest) ProtoMessage()

func (*StopRequest) ProtoReflect

func (x *StopRequest) ProtoReflect() protoreflect.Message

func (*StopRequest) Reset

func (x *StopRequest) Reset()

func (*StopRequest) String

func (x *StopRequest) String() string

type StopResponse

type StopResponse struct {
	// contains filtered or unexported fields
}

func (*StopResponse) Descriptor deprecated

func (*StopResponse) Descriptor() ([]byte, []int)

Deprecated: Use StopResponse.ProtoReflect.Descriptor instead.

func (*StopResponse) ProtoMessage

func (*StopResponse) ProtoMessage()

func (*StopResponse) ProtoReflect

func (x *StopResponse) ProtoReflect() protoreflect.Message

func (*StopResponse) Reset

func (x *StopResponse) Reset()

func (*StopResponse) String

func (x *StopResponse) String() string

type ToStringRequest

type ToStringRequest struct {
	// contains filtered or unexported fields
}

func (*ToStringRequest) Descriptor deprecated

func (*ToStringRequest) Descriptor() ([]byte, []int)

Deprecated: Use ToStringRequest.ProtoReflect.Descriptor instead.

func (*ToStringRequest) ProtoMessage

func (*ToStringRequest) ProtoMessage()

func (*ToStringRequest) ProtoReflect

func (x *ToStringRequest) ProtoReflect() protoreflect.Message

func (*ToStringRequest) Reset

func (x *ToStringRequest) Reset()

func (*ToStringRequest) String

func (x *ToStringRequest) String() string

type ToStringResponse

type ToStringResponse struct {
	Result string `protobuf:"bytes,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*ToStringResponse) Descriptor deprecated

func (*ToStringResponse) Descriptor() ([]byte, []int)

Deprecated: Use ToStringResponse.ProtoReflect.Descriptor instead.

func (*ToStringResponse) GetResult

func (x *ToStringResponse) GetResult() string

func (*ToStringResponse) ProtoMessage

func (*ToStringResponse) ProtoMessage()

func (*ToStringResponse) ProtoReflect

func (x *ToStringResponse) ProtoReflect() protoreflect.Message

func (*ToStringResponse) Reset

func (x *ToStringResponse) Reset()

func (*ToStringResponse) String

func (x *ToStringResponse) String() string

type UnimplementedMediaProjectionManagerServiceServer

type UnimplementedMediaProjectionManagerServiceServer struct{}

UnimplementedMediaProjectionManagerServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedMediaProjectionManagerServiceServer) GetMediaProjection

type UnimplementedMediaProjectionServiceServer

type UnimplementedMediaProjectionServiceServer struct{}

UnimplementedMediaProjectionServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedMediaProjectionServiceServer) Stop

func (UnimplementedMediaProjectionServiceServer) UnregisterCallback

type UnimplementedVirtualDisplayServiceServer

type UnimplementedVirtualDisplayServiceServer struct{}

UnimplementedVirtualDisplayServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedVirtualDisplayServiceServer) GetDisplay

func (UnimplementedVirtualDisplayServiceServer) GetSurface

func (UnimplementedVirtualDisplayServiceServer) Release

func (UnimplementedVirtualDisplayServiceServer) Resize

func (UnimplementedVirtualDisplayServiceServer) SetRotation

func (UnimplementedVirtualDisplayServiceServer) SetSurface

func (UnimplementedVirtualDisplayServiceServer) ToString

type UnregisterCallbackRequest

type UnregisterCallbackRequest struct {
	Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*UnregisterCallbackRequest) Descriptor deprecated

func (*UnregisterCallbackRequest) Descriptor() ([]byte, []int)

Deprecated: Use UnregisterCallbackRequest.ProtoReflect.Descriptor instead.

func (*UnregisterCallbackRequest) GetArg0

func (x *UnregisterCallbackRequest) GetArg0() int64

func (*UnregisterCallbackRequest) ProtoMessage

func (*UnregisterCallbackRequest) ProtoMessage()

func (*UnregisterCallbackRequest) ProtoReflect

func (*UnregisterCallbackRequest) Reset

func (x *UnregisterCallbackRequest) Reset()

func (*UnregisterCallbackRequest) String

func (x *UnregisterCallbackRequest) String() string

type UnregisterCallbackResponse

type UnregisterCallbackResponse struct {
	// contains filtered or unexported fields
}

func (*UnregisterCallbackResponse) Descriptor deprecated

func (*UnregisterCallbackResponse) Descriptor() ([]byte, []int)

Deprecated: Use UnregisterCallbackResponse.ProtoReflect.Descriptor instead.

func (*UnregisterCallbackResponse) ProtoMessage

func (*UnregisterCallbackResponse) ProtoMessage()

func (*UnregisterCallbackResponse) ProtoReflect

func (*UnregisterCallbackResponse) Reset

func (x *UnregisterCallbackResponse) Reset()

func (*UnregisterCallbackResponse) String

func (x *UnregisterCallbackResponse) String() string

type UnsafeMediaProjectionManagerServiceServer

type UnsafeMediaProjectionManagerServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeMediaProjectionManagerServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to MediaProjectionManagerServiceServer will result in compilation errors.

type UnsafeMediaProjectionServiceServer

type UnsafeMediaProjectionServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeMediaProjectionServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to MediaProjectionServiceServer will result in compilation errors.

type UnsafeVirtualDisplayServiceServer

type UnsafeVirtualDisplayServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeVirtualDisplayServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to VirtualDisplayServiceServer will result in compilation errors.

type VirtualDisplayServiceClient

type VirtualDisplayServiceClient interface {
	GetDisplay(ctx context.Context, in *GetDisplayRequest, opts ...grpc.CallOption) (*GetDisplayResponse, error)
	GetSurface(ctx context.Context, in *GetSurfaceRequest, opts ...grpc.CallOption) (*GetSurfaceResponse, error)
	Release(ctx context.Context, in *ReleaseRequest, opts ...grpc.CallOption) (*ReleaseResponse, error)
	Resize(ctx context.Context, in *ResizeRequest, opts ...grpc.CallOption) (*ResizeResponse, error)
	SetRotation(ctx context.Context, in *SetRotationRequest, opts ...grpc.CallOption) (*SetRotationResponse, error)
	SetSurface(ctx context.Context, in *SetSurfaceRequest, opts ...grpc.CallOption) (*SetSurfaceResponse, error)
	ToString(ctx context.Context, in *ToStringRequest, opts ...grpc.CallOption) (*ToStringResponse, error)
}

VirtualDisplayServiceClient is the client API for VirtualDisplayService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type VirtualDisplayServiceServer

type VirtualDisplayServiceServer interface {
	GetDisplay(context.Context, *GetDisplayRequest) (*GetDisplayResponse, error)
	GetSurface(context.Context, *GetSurfaceRequest) (*GetSurfaceResponse, error)
	Release(context.Context, *ReleaseRequest) (*ReleaseResponse, error)
	Resize(context.Context, *ResizeRequest) (*ResizeResponse, error)
	SetRotation(context.Context, *SetRotationRequest) (*SetRotationResponse, error)
	SetSurface(context.Context, *SetSurfaceRequest) (*SetSurfaceResponse, error)
	ToString(context.Context, *ToStringRequest) (*ToStringResponse, error)
	// contains filtered or unexported methods
}

VirtualDisplayServiceServer is the server API for VirtualDisplayService service. All implementations must embed UnimplementedVirtualDisplayServiceServer for forward compatibility.

Jump to