Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterManagerServiceServer(s grpc.ServiceRegistrar, srv ManagerServiceServer)
- type CreateRequestRoleIntentRequest
- func (*CreateRequestRoleIntentRequest) Descriptor() ([]byte, []int)deprecated
- func (x *CreateRequestRoleIntentRequest) GetArg0() string
- func (*CreateRequestRoleIntentRequest) ProtoMessage()
- func (x *CreateRequestRoleIntentRequest) ProtoReflect() protoreflect.Message
- func (x *CreateRequestRoleIntentRequest) Reset()
- func (x *CreateRequestRoleIntentRequest) String() string
- type CreateRequestRoleIntentResponse
- func (*CreateRequestRoleIntentResponse) Descriptor() ([]byte, []int)deprecated
- func (x *CreateRequestRoleIntentResponse) GetResult() int64
- func (*CreateRequestRoleIntentResponse) ProtoMessage()
- func (x *CreateRequestRoleIntentResponse) ProtoReflect() protoreflect.Message
- func (x *CreateRequestRoleIntentResponse) Reset()
- func (x *CreateRequestRoleIntentResponse) String() string
- type IsRoleAvailableRequest
- func (*IsRoleAvailableRequest) Descriptor() ([]byte, []int)deprecated
- func (x *IsRoleAvailableRequest) GetArg0() string
- func (*IsRoleAvailableRequest) ProtoMessage()
- func (x *IsRoleAvailableRequest) ProtoReflect() protoreflect.Message
- func (x *IsRoleAvailableRequest) Reset()
- func (x *IsRoleAvailableRequest) String() string
- type IsRoleAvailableResponse
- func (*IsRoleAvailableResponse) Descriptor() ([]byte, []int)deprecated
- func (x *IsRoleAvailableResponse) GetResult() bool
- func (*IsRoleAvailableResponse) ProtoMessage()
- func (x *IsRoleAvailableResponse) ProtoReflect() protoreflect.Message
- func (x *IsRoleAvailableResponse) Reset()
- func (x *IsRoleAvailableResponse) String() string
- type IsRoleHeldRequest
- type IsRoleHeldResponse
- func (*IsRoleHeldResponse) Descriptor() ([]byte, []int)deprecated
- func (x *IsRoleHeldResponse) GetResult() bool
- func (*IsRoleHeldResponse) ProtoMessage()
- func (x *IsRoleHeldResponse) ProtoReflect() protoreflect.Message
- func (x *IsRoleHeldResponse) Reset()
- func (x *IsRoleHeldResponse) String() string
- type ManagerServiceClient
- type ManagerServiceServer
- type UnimplementedManagerServiceServer
- func (UnimplementedManagerServiceServer) CreateRequestRoleIntent(context.Context, *CreateRequestRoleIntentRequest) (*CreateRequestRoleIntentResponse, error)
- func (UnimplementedManagerServiceServer) IsRoleAvailable(context.Context, *IsRoleAvailableRequest) (*IsRoleAvailableResponse, error)
- func (UnimplementedManagerServiceServer) IsRoleHeld(context.Context, *IsRoleHeldRequest) (*IsRoleHeldResponse, error)
- type UnsafeManagerServiceServer
Constants ¶
const ( ManagerService_CreateRequestRoleIntent_FullMethodName = "/role.ManagerService/CreateRequestRoleIntent" ManagerService_IsRoleAvailable_FullMethodName = "/role.ManagerService/IsRoleAvailable" ManagerService_IsRoleHeld_FullMethodName = "/role.ManagerService/IsRoleHeld" )
Variables ¶
var File_proto_role_role_proto protoreflect.FileDescriptor
var ManagerService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "role.ManagerService", HandlerType: (*ManagerServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "CreateRequestRoleIntent", Handler: _ManagerService_CreateRequestRoleIntent_Handler, }, { MethodName: "IsRoleAvailable", Handler: _ManagerService_IsRoleAvailable_Handler, }, { MethodName: "IsRoleHeld", Handler: _ManagerService_IsRoleHeld_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "proto/role/role.proto", }
ManagerService_ServiceDesc is the grpc.ServiceDesc for ManagerService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterManagerServiceServer ¶ added in v0.0.4
func RegisterManagerServiceServer(s grpc.ServiceRegistrar, srv ManagerServiceServer)
Types ¶
type CreateRequestRoleIntentRequest ¶
type CreateRequestRoleIntentRequest struct {
Arg0 string `protobuf:"bytes,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
// contains filtered or unexported fields
}
func (*CreateRequestRoleIntentRequest) Descriptor
deprecated
func (*CreateRequestRoleIntentRequest) Descriptor() ([]byte, []int)
Deprecated: Use CreateRequestRoleIntentRequest.ProtoReflect.Descriptor instead.
func (*CreateRequestRoleIntentRequest) GetArg0 ¶
func (x *CreateRequestRoleIntentRequest) GetArg0() string
func (*CreateRequestRoleIntentRequest) ProtoMessage ¶
func (*CreateRequestRoleIntentRequest) ProtoMessage()
func (*CreateRequestRoleIntentRequest) ProtoReflect ¶
func (x *CreateRequestRoleIntentRequest) ProtoReflect() protoreflect.Message
func (*CreateRequestRoleIntentRequest) Reset ¶
func (x *CreateRequestRoleIntentRequest) Reset()
func (*CreateRequestRoleIntentRequest) String ¶
func (x *CreateRequestRoleIntentRequest) String() string
type CreateRequestRoleIntentResponse ¶
type CreateRequestRoleIntentResponse struct {
Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*CreateRequestRoleIntentResponse) Descriptor
deprecated
func (*CreateRequestRoleIntentResponse) Descriptor() ([]byte, []int)
Deprecated: Use CreateRequestRoleIntentResponse.ProtoReflect.Descriptor instead.
func (*CreateRequestRoleIntentResponse) GetResult ¶
func (x *CreateRequestRoleIntentResponse) GetResult() int64
func (*CreateRequestRoleIntentResponse) ProtoMessage ¶
func (*CreateRequestRoleIntentResponse) ProtoMessage()
func (*CreateRequestRoleIntentResponse) ProtoReflect ¶
func (x *CreateRequestRoleIntentResponse) ProtoReflect() protoreflect.Message
func (*CreateRequestRoleIntentResponse) Reset ¶
func (x *CreateRequestRoleIntentResponse) Reset()
func (*CreateRequestRoleIntentResponse) String ¶
func (x *CreateRequestRoleIntentResponse) String() string
type IsRoleAvailableRequest ¶
type IsRoleAvailableRequest struct {
Arg0 string `protobuf:"bytes,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
// contains filtered or unexported fields
}
func (*IsRoleAvailableRequest) Descriptor
deprecated
func (*IsRoleAvailableRequest) Descriptor() ([]byte, []int)
Deprecated: Use IsRoleAvailableRequest.ProtoReflect.Descriptor instead.
func (*IsRoleAvailableRequest) GetArg0 ¶
func (x *IsRoleAvailableRequest) GetArg0() string
func (*IsRoleAvailableRequest) ProtoMessage ¶
func (*IsRoleAvailableRequest) ProtoMessage()
func (*IsRoleAvailableRequest) ProtoReflect ¶
func (x *IsRoleAvailableRequest) ProtoReflect() protoreflect.Message
func (*IsRoleAvailableRequest) Reset ¶
func (x *IsRoleAvailableRequest) Reset()
func (*IsRoleAvailableRequest) String ¶
func (x *IsRoleAvailableRequest) String() string
type IsRoleAvailableResponse ¶
type IsRoleAvailableResponse struct {
Result bool `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*IsRoleAvailableResponse) Descriptor
deprecated
func (*IsRoleAvailableResponse) Descriptor() ([]byte, []int)
Deprecated: Use IsRoleAvailableResponse.ProtoReflect.Descriptor instead.
func (*IsRoleAvailableResponse) GetResult ¶
func (x *IsRoleAvailableResponse) GetResult() bool
func (*IsRoleAvailableResponse) ProtoMessage ¶
func (*IsRoleAvailableResponse) ProtoMessage()
func (*IsRoleAvailableResponse) ProtoReflect ¶
func (x *IsRoleAvailableResponse) ProtoReflect() protoreflect.Message
func (*IsRoleAvailableResponse) Reset ¶
func (x *IsRoleAvailableResponse) Reset()
func (*IsRoleAvailableResponse) String ¶
func (x *IsRoleAvailableResponse) String() string
type IsRoleHeldRequest ¶
type IsRoleHeldRequest struct {
Arg0 string `protobuf:"bytes,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
// contains filtered or unexported fields
}
func (*IsRoleHeldRequest) Descriptor
deprecated
func (*IsRoleHeldRequest) Descriptor() ([]byte, []int)
Deprecated: Use IsRoleHeldRequest.ProtoReflect.Descriptor instead.
func (*IsRoleHeldRequest) GetArg0 ¶
func (x *IsRoleHeldRequest) GetArg0() string
func (*IsRoleHeldRequest) ProtoMessage ¶
func (*IsRoleHeldRequest) ProtoMessage()
func (*IsRoleHeldRequest) ProtoReflect ¶
func (x *IsRoleHeldRequest) ProtoReflect() protoreflect.Message
func (*IsRoleHeldRequest) Reset ¶
func (x *IsRoleHeldRequest) Reset()
func (*IsRoleHeldRequest) String ¶
func (x *IsRoleHeldRequest) String() string
type IsRoleHeldResponse ¶
type IsRoleHeldResponse struct {
Result bool `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*IsRoleHeldResponse) Descriptor
deprecated
func (*IsRoleHeldResponse) Descriptor() ([]byte, []int)
Deprecated: Use IsRoleHeldResponse.ProtoReflect.Descriptor instead.
func (*IsRoleHeldResponse) GetResult ¶
func (x *IsRoleHeldResponse) GetResult() bool
func (*IsRoleHeldResponse) ProtoMessage ¶
func (*IsRoleHeldResponse) ProtoMessage()
func (*IsRoleHeldResponse) ProtoReflect ¶
func (x *IsRoleHeldResponse) ProtoReflect() protoreflect.Message
func (*IsRoleHeldResponse) Reset ¶
func (x *IsRoleHeldResponse) Reset()
func (*IsRoleHeldResponse) String ¶
func (x *IsRoleHeldResponse) String() string
type ManagerServiceClient ¶ added in v0.0.4
type ManagerServiceClient interface {
CreateRequestRoleIntent(ctx context.Context, in *CreateRequestRoleIntentRequest, opts ...grpc.CallOption) (*CreateRequestRoleIntentResponse, error)
IsRoleAvailable(ctx context.Context, in *IsRoleAvailableRequest, opts ...grpc.CallOption) (*IsRoleAvailableResponse, error)
IsRoleHeld(ctx context.Context, in *IsRoleHeldRequest, opts ...grpc.CallOption) (*IsRoleHeldResponse, error)
}
ManagerServiceClient is the client API for ManagerService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewManagerServiceClient ¶ added in v0.0.4
func NewManagerServiceClient(cc grpc.ClientConnInterface) ManagerServiceClient
type ManagerServiceServer ¶ added in v0.0.4
type ManagerServiceServer interface {
CreateRequestRoleIntent(context.Context, *CreateRequestRoleIntentRequest) (*CreateRequestRoleIntentResponse, error)
IsRoleAvailable(context.Context, *IsRoleAvailableRequest) (*IsRoleAvailableResponse, error)
IsRoleHeld(context.Context, *IsRoleHeldRequest) (*IsRoleHeldResponse, error)
// contains filtered or unexported methods
}
ManagerServiceServer is the server API for ManagerService service. All implementations must embed UnimplementedManagerServiceServer for forward compatibility.
type UnimplementedManagerServiceServer ¶ added in v0.0.4
type UnimplementedManagerServiceServer struct{}
UnimplementedManagerServiceServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedManagerServiceServer) CreateRequestRoleIntent ¶ added in v0.0.4
func (UnimplementedManagerServiceServer) CreateRequestRoleIntent(context.Context, *CreateRequestRoleIntentRequest) (*CreateRequestRoleIntentResponse, error)
func (UnimplementedManagerServiceServer) IsRoleAvailable ¶ added in v0.0.4
func (UnimplementedManagerServiceServer) IsRoleAvailable(context.Context, *IsRoleAvailableRequest) (*IsRoleAvailableResponse, error)
func (UnimplementedManagerServiceServer) IsRoleHeld ¶ added in v0.0.4
func (UnimplementedManagerServiceServer) IsRoleHeld(context.Context, *IsRoleHeldRequest) (*IsRoleHeldResponse, error)
type UnsafeManagerServiceServer ¶ added in v0.0.4
type UnsafeManagerServiceServer interface {
// contains filtered or unexported methods
}
UnsafeManagerServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ManagerServiceServer will result in compilation errors.