rtp

package
v0.0.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 29, 2026 License: CC0-1.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

const (
	AudioCodecService_GetCodec_FullMethodName  = "/rtp.AudioCodecService/GetCodec"
	AudioCodecService_GetCodecs_FullMethodName = "/rtp.AudioCodecService/GetCodecs"
)
const (
	AudioGroupService_NewAudioGroup_FullMethodName = "/rtp.AudioGroupService/NewAudioGroup"
	AudioGroupService_Clear_FullMethodName         = "/rtp.AudioGroupService/Clear"
	AudioGroupService_GetMode_FullMethodName       = "/rtp.AudioGroupService/GetMode"
	AudioGroupService_GetStreams_FullMethodName    = "/rtp.AudioGroupService/GetStreams"
	AudioGroupService_SendDtmf_FullMethodName      = "/rtp.AudioGroupService/SendDtmf"
	AudioGroupService_SetMode_FullMethodName       = "/rtp.AudioGroupService/SetMode"
)
const (
	AudioStreamService_NewAudioStream_FullMethodName = "/rtp.AudioStreamService/NewAudioStream"
	AudioStreamService_GetCodec_FullMethodName       = "/rtp.AudioStreamService/GetCodec"
	AudioStreamService_GetDtmfType_FullMethodName    = "/rtp.AudioStreamService/GetDtmfType"
	AudioStreamService_GetGroup_FullMethodName       = "/rtp.AudioStreamService/GetGroup"
	AudioStreamService_IsBusy_FullMethodName         = "/rtp.AudioStreamService/IsBusy"
	AudioStreamService_Join_FullMethodName           = "/rtp.AudioStreamService/Join"
	AudioStreamService_SetCodec_FullMethodName       = "/rtp.AudioStreamService/SetCodec"
	AudioStreamService_SetDtmfType_FullMethodName    = "/rtp.AudioStreamService/SetDtmfType"
)
const (
	StreamService_Associate_FullMethodName        = "/rtp.StreamService/Associate"
	StreamService_GetLocalAddress_FullMethodName  = "/rtp.StreamService/GetLocalAddress"
	StreamService_GetLocalPort_FullMethodName     = "/rtp.StreamService/GetLocalPort"
	StreamService_GetMode_FullMethodName          = "/rtp.StreamService/GetMode"
	StreamService_GetRemoteAddress_FullMethodName = "/rtp.StreamService/GetRemoteAddress"
	StreamService_GetRemotePort_FullMethodName    = "/rtp.StreamService/GetRemotePort"
	StreamService_IsBusy_FullMethodName           = "/rtp.StreamService/IsBusy"
	StreamService_Release_FullMethodName          = "/rtp.StreamService/Release"
	StreamService_SetMode_FullMethodName          = "/rtp.StreamService/SetMode"
)

Variables

var AudioCodecService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "rtp.AudioCodecService",
	HandlerType: (*AudioCodecServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "GetCodec",
			Handler:    _AudioCodecService_GetCodec_Handler,
		},
		{
			MethodName: "GetCodecs",
			Handler:    _AudioCodecService_GetCodecs_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/rtp/rtp.proto",
}

AudioCodecService_ServiceDesc is the grpc.ServiceDesc for AudioCodecService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var AudioGroupService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "rtp.AudioGroupService",
	HandlerType: (*AudioGroupServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "NewAudioGroup",
			Handler:    _AudioGroupService_NewAudioGroup_Handler,
		},
		{
			MethodName: "Clear",
			Handler:    _AudioGroupService_Clear_Handler,
		},
		{
			MethodName: "GetMode",
			Handler:    _AudioGroupService_GetMode_Handler,
		},
		{
			MethodName: "GetStreams",
			Handler:    _AudioGroupService_GetStreams_Handler,
		},
		{
			MethodName: "SendDtmf",
			Handler:    _AudioGroupService_SendDtmf_Handler,
		},
		{
			MethodName: "SetMode",
			Handler:    _AudioGroupService_SetMode_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/rtp/rtp.proto",
}

AudioGroupService_ServiceDesc is the grpc.ServiceDesc for AudioGroupService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var AudioStreamService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "rtp.AudioStreamService",
	HandlerType: (*AudioStreamServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "NewAudioStream",
			Handler:    _AudioStreamService_NewAudioStream_Handler,
		},
		{
			MethodName: "GetCodec",
			Handler:    _AudioStreamService_GetCodec_Handler,
		},
		{
			MethodName: "GetDtmfType",
			Handler:    _AudioStreamService_GetDtmfType_Handler,
		},
		{
			MethodName: "GetGroup",
			Handler:    _AudioStreamService_GetGroup_Handler,
		},
		{
			MethodName: "IsBusy",
			Handler:    _AudioStreamService_IsBusy_Handler,
		},
		{
			MethodName: "Join",
			Handler:    _AudioStreamService_Join_Handler,
		},
		{
			MethodName: "SetCodec",
			Handler:    _AudioStreamService_SetCodec_Handler,
		},
		{
			MethodName: "SetDtmfType",
			Handler:    _AudioStreamService_SetDtmfType_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/rtp/rtp.proto",
}

AudioStreamService_ServiceDesc is the grpc.ServiceDesc for AudioStreamService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var File_proto_rtp_rtp_proto protoreflect.FileDescriptor
var StreamService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "rtp.StreamService",
	HandlerType: (*StreamServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "Associate",
			Handler:    _StreamService_Associate_Handler,
		},
		{
			MethodName: "GetLocalAddress",
			Handler:    _StreamService_GetLocalAddress_Handler,
		},
		{
			MethodName: "GetLocalPort",
			Handler:    _StreamService_GetLocalPort_Handler,
		},
		{
			MethodName: "GetMode",
			Handler:    _StreamService_GetMode_Handler,
		},
		{
			MethodName: "GetRemoteAddress",
			Handler:    _StreamService_GetRemoteAddress_Handler,
		},
		{
			MethodName: "GetRemotePort",
			Handler:    _StreamService_GetRemotePort_Handler,
		},
		{
			MethodName: "IsBusy",
			Handler:    _StreamService_IsBusy_Handler,
		},
		{
			MethodName: "Release",
			Handler:    _StreamService_Release_Handler,
		},
		{
			MethodName: "SetMode",
			Handler:    _StreamService_SetMode_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/rtp/rtp.proto",
}

StreamService_ServiceDesc is the grpc.ServiceDesc for StreamService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterAudioCodecServiceServer

func RegisterAudioCodecServiceServer(s grpc.ServiceRegistrar, srv AudioCodecServiceServer)

func RegisterAudioGroupServiceServer

func RegisterAudioGroupServiceServer(s grpc.ServiceRegistrar, srv AudioGroupServiceServer)

func RegisterAudioStreamServiceServer

func RegisterAudioStreamServiceServer(s grpc.ServiceRegistrar, srv AudioStreamServiceServer)

func RegisterStreamServiceServer

func RegisterStreamServiceServer(s grpc.ServiceRegistrar, srv StreamServiceServer)

Types

type AssociateRequest

type AssociateRequest struct {
	Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	Arg1 int32 `protobuf:"varint,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
	// contains filtered or unexported fields
}

func (*AssociateRequest) Descriptor deprecated

func (*AssociateRequest) Descriptor() ([]byte, []int)

Deprecated: Use AssociateRequest.ProtoReflect.Descriptor instead.

func (*AssociateRequest) GetArg0

func (x *AssociateRequest) GetArg0() int64

func (*AssociateRequest) GetArg1

func (x *AssociateRequest) GetArg1() int32

func (*AssociateRequest) ProtoMessage

func (*AssociateRequest) ProtoMessage()

func (*AssociateRequest) ProtoReflect

func (x *AssociateRequest) ProtoReflect() protoreflect.Message

func (*AssociateRequest) Reset

func (x *AssociateRequest) Reset()

func (*AssociateRequest) String

func (x *AssociateRequest) String() string

type AssociateResponse

type AssociateResponse struct {
	// contains filtered or unexported fields
}

func (*AssociateResponse) Descriptor deprecated

func (*AssociateResponse) Descriptor() ([]byte, []int)

Deprecated: Use AssociateResponse.ProtoReflect.Descriptor instead.

func (*AssociateResponse) ProtoMessage

func (*AssociateResponse) ProtoMessage()

func (*AssociateResponse) ProtoReflect

func (x *AssociateResponse) ProtoReflect() protoreflect.Message

func (*AssociateResponse) Reset

func (x *AssociateResponse) Reset()

func (*AssociateResponse) String

func (x *AssociateResponse) String() string

type AudioCodecServiceClient

type AudioCodecServiceClient interface {
	GetCodec(ctx context.Context, in *GetCodecRequest, opts ...grpc.CallOption) (*GetCodecResponse, error)
	GetCodecs(ctx context.Context, in *GetCodecsRequest, opts ...grpc.CallOption) (*GetCodecsResponse, error)
}

AudioCodecServiceClient is the client API for AudioCodecService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type AudioCodecServiceServer

type AudioCodecServiceServer interface {
	GetCodec(context.Context, *GetCodecRequest) (*GetCodecResponse, error)
	GetCodecs(context.Context, *GetCodecsRequest) (*GetCodecsResponse, error)
	// contains filtered or unexported methods
}

AudioCodecServiceServer is the server API for AudioCodecService service. All implementations must embed UnimplementedAudioCodecServiceServer for forward compatibility.

type AudioGroupServiceClient

type AudioGroupServiceClient interface {
	NewAudioGroup(ctx context.Context, in *NewAudioGroupRequest, opts ...grpc.CallOption) (*NewAudioGroupResponse, error)
	Clear(ctx context.Context, in *ClearRequest, opts ...grpc.CallOption) (*ClearResponse, error)
	GetMode(ctx context.Context, in *GetModeRequest, opts ...grpc.CallOption) (*GetModeResponse, error)
	GetStreams(ctx context.Context, in *GetStreamsRequest, opts ...grpc.CallOption) (*GetStreamsResponse, error)
	SendDtmf(ctx context.Context, in *SendDtmfRequest, opts ...grpc.CallOption) (*SendDtmfResponse, error)
	SetMode(ctx context.Context, in *SetModeRequest, opts ...grpc.CallOption) (*SetModeResponse, error)
}

AudioGroupServiceClient is the client API for AudioGroupService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type AudioGroupServiceServer

type AudioGroupServiceServer interface {
	NewAudioGroup(context.Context, *NewAudioGroupRequest) (*NewAudioGroupResponse, error)
	Clear(context.Context, *ClearRequest) (*ClearResponse, error)
	GetMode(context.Context, *GetModeRequest) (*GetModeResponse, error)
	GetStreams(context.Context, *GetStreamsRequest) (*GetStreamsResponse, error)
	SendDtmf(context.Context, *SendDtmfRequest) (*SendDtmfResponse, error)
	SetMode(context.Context, *SetModeRequest) (*SetModeResponse, error)
	// contains filtered or unexported methods
}

AudioGroupServiceServer is the server API for AudioGroupService service. All implementations must embed UnimplementedAudioGroupServiceServer for forward compatibility.

type AudioStreamGetCodecRequest

type AudioStreamGetCodecRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	// contains filtered or unexported fields
}

func (*AudioStreamGetCodecRequest) Descriptor deprecated

func (*AudioStreamGetCodecRequest) Descriptor() ([]byte, []int)

Deprecated: Use AudioStreamGetCodecRequest.ProtoReflect.Descriptor instead.

func (*AudioStreamGetCodecRequest) GetHandle

func (x *AudioStreamGetCodecRequest) GetHandle() int64

func (*AudioStreamGetCodecRequest) ProtoMessage

func (*AudioStreamGetCodecRequest) ProtoMessage()

func (*AudioStreamGetCodecRequest) ProtoReflect

func (*AudioStreamGetCodecRequest) Reset

func (x *AudioStreamGetCodecRequest) Reset()

func (*AudioStreamGetCodecRequest) String

func (x *AudioStreamGetCodecRequest) String() string

type AudioStreamServiceClient

type AudioStreamServiceClient interface {
	NewAudioStream(ctx context.Context, in *NewAudioStreamRequest, opts ...grpc.CallOption) (*NewAudioStreamResponse, error)
	GetCodec(ctx context.Context, in *AudioStreamGetCodecRequest, opts ...grpc.CallOption) (*GetCodecResponse, error)
	GetDtmfType(ctx context.Context, in *GetDtmfTypeRequest, opts ...grpc.CallOption) (*GetDtmfTypeResponse, error)
	GetGroup(ctx context.Context, in *GetGroupRequest, opts ...grpc.CallOption) (*GetGroupResponse, error)
	IsBusy(ctx context.Context, in *IsBusyRequest, opts ...grpc.CallOption) (*IsBusyResponse, error)
	Join(ctx context.Context, in *JoinRequest, opts ...grpc.CallOption) (*JoinResponse, error)
	SetCodec(ctx context.Context, in *SetCodecRequest, opts ...grpc.CallOption) (*SetCodecResponse, error)
	SetDtmfType(ctx context.Context, in *SetDtmfTypeRequest, opts ...grpc.CallOption) (*SetDtmfTypeResponse, error)
}

AudioStreamServiceClient is the client API for AudioStreamService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type AudioStreamServiceServer

AudioStreamServiceServer is the server API for AudioStreamService service. All implementations must embed UnimplementedAudioStreamServiceServer for forward compatibility.

type ClearRequest

type ClearRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	// contains filtered or unexported fields
}

func (*ClearRequest) Descriptor deprecated

func (*ClearRequest) Descriptor() ([]byte, []int)

Deprecated: Use ClearRequest.ProtoReflect.Descriptor instead.

func (*ClearRequest) GetHandle

func (x *ClearRequest) GetHandle() int64

func (*ClearRequest) ProtoMessage

func (*ClearRequest) ProtoMessage()

func (*ClearRequest) ProtoReflect

func (x *ClearRequest) ProtoReflect() protoreflect.Message

func (*ClearRequest) Reset

func (x *ClearRequest) Reset()

func (*ClearRequest) String

func (x *ClearRequest) String() string

type ClearResponse

type ClearResponse struct {
	// contains filtered or unexported fields
}

func (*ClearResponse) Descriptor deprecated

func (*ClearResponse) Descriptor() ([]byte, []int)

Deprecated: Use ClearResponse.ProtoReflect.Descriptor instead.

func (*ClearResponse) ProtoMessage

func (*ClearResponse) ProtoMessage()

func (*ClearResponse) ProtoReflect

func (x *ClearResponse) ProtoReflect() protoreflect.Message

func (*ClearResponse) Reset

func (x *ClearResponse) Reset()

func (*ClearResponse) String

func (x *ClearResponse) String() string

type GetCodecRequest

type GetCodecRequest struct {
	Arg0 int32  `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	Arg1 string `protobuf:"bytes,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
	Arg2 string `protobuf:"bytes,3,opt,name=arg2,proto3" json:"arg2,omitempty"`
	// contains filtered or unexported fields
}

func (*GetCodecRequest) Descriptor deprecated

func (*GetCodecRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetCodecRequest.ProtoReflect.Descriptor instead.

func (*GetCodecRequest) GetArg0

func (x *GetCodecRequest) GetArg0() int32

func (*GetCodecRequest) GetArg1

func (x *GetCodecRequest) GetArg1() string

func (*GetCodecRequest) GetArg2

func (x *GetCodecRequest) GetArg2() string

func (*GetCodecRequest) ProtoMessage

func (*GetCodecRequest) ProtoMessage()

func (*GetCodecRequest) ProtoReflect

func (x *GetCodecRequest) ProtoReflect() protoreflect.Message

func (*GetCodecRequest) Reset

func (x *GetCodecRequest) Reset()

func (*GetCodecRequest) String

func (x *GetCodecRequest) String() string

type GetCodecResponse

type GetCodecResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetCodecResponse) Descriptor deprecated

func (*GetCodecResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetCodecResponse.ProtoReflect.Descriptor instead.

func (*GetCodecResponse) GetResult

func (x *GetCodecResponse) GetResult() int64

func (*GetCodecResponse) ProtoMessage

func (*GetCodecResponse) ProtoMessage()

func (*GetCodecResponse) ProtoReflect

func (x *GetCodecResponse) ProtoReflect() protoreflect.Message

func (*GetCodecResponse) Reset

func (x *GetCodecResponse) Reset()

func (*GetCodecResponse) String

func (x *GetCodecResponse) String() string

type GetCodecsRequest

type GetCodecsRequest struct {
	// contains filtered or unexported fields
}

func (*GetCodecsRequest) Descriptor deprecated

func (*GetCodecsRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetCodecsRequest.ProtoReflect.Descriptor instead.

func (*GetCodecsRequest) ProtoMessage

func (*GetCodecsRequest) ProtoMessage()

func (*GetCodecsRequest) ProtoReflect

func (x *GetCodecsRequest) ProtoReflect() protoreflect.Message

func (*GetCodecsRequest) Reset

func (x *GetCodecsRequest) Reset()

func (*GetCodecsRequest) String

func (x *GetCodecsRequest) String() string

type GetCodecsResponse

type GetCodecsResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetCodecsResponse) Descriptor deprecated

func (*GetCodecsResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetCodecsResponse.ProtoReflect.Descriptor instead.

func (*GetCodecsResponse) GetResult

func (x *GetCodecsResponse) GetResult() int64

func (*GetCodecsResponse) ProtoMessage

func (*GetCodecsResponse) ProtoMessage()

func (*GetCodecsResponse) ProtoReflect

func (x *GetCodecsResponse) ProtoReflect() protoreflect.Message

func (*GetCodecsResponse) Reset

func (x *GetCodecsResponse) Reset()

func (*GetCodecsResponse) String

func (x *GetCodecsResponse) String() string

type GetDtmfTypeRequest

type GetDtmfTypeRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	// contains filtered or unexported fields
}

func (*GetDtmfTypeRequest) Descriptor deprecated

func (*GetDtmfTypeRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetDtmfTypeRequest.ProtoReflect.Descriptor instead.

func (*GetDtmfTypeRequest) GetHandle

func (x *GetDtmfTypeRequest) GetHandle() int64

func (*GetDtmfTypeRequest) ProtoMessage

func (*GetDtmfTypeRequest) ProtoMessage()

func (*GetDtmfTypeRequest) ProtoReflect

func (x *GetDtmfTypeRequest) ProtoReflect() protoreflect.Message

func (*GetDtmfTypeRequest) Reset

func (x *GetDtmfTypeRequest) Reset()

func (*GetDtmfTypeRequest) String

func (x *GetDtmfTypeRequest) String() string

type GetDtmfTypeResponse

type GetDtmfTypeResponse struct {
	Result int32 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetDtmfTypeResponse) Descriptor deprecated

func (*GetDtmfTypeResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetDtmfTypeResponse.ProtoReflect.Descriptor instead.

func (*GetDtmfTypeResponse) GetResult

func (x *GetDtmfTypeResponse) GetResult() int32

func (*GetDtmfTypeResponse) ProtoMessage

func (*GetDtmfTypeResponse) ProtoMessage()

func (*GetDtmfTypeResponse) ProtoReflect

func (x *GetDtmfTypeResponse) ProtoReflect() protoreflect.Message

func (*GetDtmfTypeResponse) Reset

func (x *GetDtmfTypeResponse) Reset()

func (*GetDtmfTypeResponse) String

func (x *GetDtmfTypeResponse) String() string

type GetGroupRequest

type GetGroupRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	// contains filtered or unexported fields
}

func (*GetGroupRequest) Descriptor deprecated

func (*GetGroupRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetGroupRequest.ProtoReflect.Descriptor instead.

func (*GetGroupRequest) GetHandle

func (x *GetGroupRequest) GetHandle() int64

func (*GetGroupRequest) ProtoMessage

func (*GetGroupRequest) ProtoMessage()

func (*GetGroupRequest) ProtoReflect

func (x *GetGroupRequest) ProtoReflect() protoreflect.Message

func (*GetGroupRequest) Reset

func (x *GetGroupRequest) Reset()

func (*GetGroupRequest) String

func (x *GetGroupRequest) String() string

type GetGroupResponse

type GetGroupResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetGroupResponse) Descriptor deprecated

func (*GetGroupResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetGroupResponse.ProtoReflect.Descriptor instead.

func (*GetGroupResponse) GetResult

func (x *GetGroupResponse) GetResult() int64

func (*GetGroupResponse) ProtoMessage

func (*GetGroupResponse) ProtoMessage()

func (*GetGroupResponse) ProtoReflect

func (x *GetGroupResponse) ProtoReflect() protoreflect.Message

func (*GetGroupResponse) Reset

func (x *GetGroupResponse) Reset()

func (*GetGroupResponse) String

func (x *GetGroupResponse) String() string

type GetLocalAddressRequest

type GetLocalAddressRequest struct {
	// contains filtered or unexported fields
}

func (*GetLocalAddressRequest) Descriptor deprecated

func (*GetLocalAddressRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetLocalAddressRequest.ProtoReflect.Descriptor instead.

func (*GetLocalAddressRequest) ProtoMessage

func (*GetLocalAddressRequest) ProtoMessage()

func (*GetLocalAddressRequest) ProtoReflect

func (x *GetLocalAddressRequest) ProtoReflect() protoreflect.Message

func (*GetLocalAddressRequest) Reset

func (x *GetLocalAddressRequest) Reset()

func (*GetLocalAddressRequest) String

func (x *GetLocalAddressRequest) String() string

type GetLocalAddressResponse

type GetLocalAddressResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetLocalAddressResponse) Descriptor deprecated

func (*GetLocalAddressResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetLocalAddressResponse.ProtoReflect.Descriptor instead.

func (*GetLocalAddressResponse) GetResult

func (x *GetLocalAddressResponse) GetResult() int64

func (*GetLocalAddressResponse) ProtoMessage

func (*GetLocalAddressResponse) ProtoMessage()

func (*GetLocalAddressResponse) ProtoReflect

func (x *GetLocalAddressResponse) ProtoReflect() protoreflect.Message

func (*GetLocalAddressResponse) Reset

func (x *GetLocalAddressResponse) Reset()

func (*GetLocalAddressResponse) String

func (x *GetLocalAddressResponse) String() string

type GetLocalPortRequest

type GetLocalPortRequest struct {
	// contains filtered or unexported fields
}

func (*GetLocalPortRequest) Descriptor deprecated

func (*GetLocalPortRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetLocalPortRequest.ProtoReflect.Descriptor instead.

func (*GetLocalPortRequest) ProtoMessage

func (*GetLocalPortRequest) ProtoMessage()

func (*GetLocalPortRequest) ProtoReflect

func (x *GetLocalPortRequest) ProtoReflect() protoreflect.Message

func (*GetLocalPortRequest) Reset

func (x *GetLocalPortRequest) Reset()

func (*GetLocalPortRequest) String

func (x *GetLocalPortRequest) String() string

type GetLocalPortResponse

type GetLocalPortResponse struct {
	Result int32 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetLocalPortResponse) Descriptor deprecated

func (*GetLocalPortResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetLocalPortResponse.ProtoReflect.Descriptor instead.

func (*GetLocalPortResponse) GetResult

func (x *GetLocalPortResponse) GetResult() int32

func (*GetLocalPortResponse) ProtoMessage

func (*GetLocalPortResponse) ProtoMessage()

func (*GetLocalPortResponse) ProtoReflect

func (x *GetLocalPortResponse) ProtoReflect() protoreflect.Message

func (*GetLocalPortResponse) Reset

func (x *GetLocalPortResponse) Reset()

func (*GetLocalPortResponse) String

func (x *GetLocalPortResponse) String() string

type GetModeRequest

type GetModeRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	// contains filtered or unexported fields
}

func (*GetModeRequest) Descriptor deprecated

func (*GetModeRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetModeRequest.ProtoReflect.Descriptor instead.

func (*GetModeRequest) GetHandle

func (x *GetModeRequest) GetHandle() int64

func (*GetModeRequest) ProtoMessage

func (*GetModeRequest) ProtoMessage()

func (*GetModeRequest) ProtoReflect

func (x *GetModeRequest) ProtoReflect() protoreflect.Message

func (*GetModeRequest) Reset

func (x *GetModeRequest) Reset()

func (*GetModeRequest) String

func (x *GetModeRequest) String() string

type GetModeResponse

type GetModeResponse struct {
	Result int32 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetModeResponse) Descriptor deprecated

func (*GetModeResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetModeResponse.ProtoReflect.Descriptor instead.

func (*GetModeResponse) GetResult

func (x *GetModeResponse) GetResult() int32

func (*GetModeResponse) ProtoMessage

func (*GetModeResponse) ProtoMessage()

func (*GetModeResponse) ProtoReflect

func (x *GetModeResponse) ProtoReflect() protoreflect.Message

func (*GetModeResponse) Reset

func (x *GetModeResponse) Reset()

func (*GetModeResponse) String

func (x *GetModeResponse) String() string

type GetRemoteAddressRequest

type GetRemoteAddressRequest struct {
	// contains filtered or unexported fields
}

func (*GetRemoteAddressRequest) Descriptor deprecated

func (*GetRemoteAddressRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetRemoteAddressRequest.ProtoReflect.Descriptor instead.

func (*GetRemoteAddressRequest) ProtoMessage

func (*GetRemoteAddressRequest) ProtoMessage()

func (*GetRemoteAddressRequest) ProtoReflect

func (x *GetRemoteAddressRequest) ProtoReflect() protoreflect.Message

func (*GetRemoteAddressRequest) Reset

func (x *GetRemoteAddressRequest) Reset()

func (*GetRemoteAddressRequest) String

func (x *GetRemoteAddressRequest) String() string

type GetRemoteAddressResponse

type GetRemoteAddressResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetRemoteAddressResponse) Descriptor deprecated

func (*GetRemoteAddressResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetRemoteAddressResponse.ProtoReflect.Descriptor instead.

func (*GetRemoteAddressResponse) GetResult

func (x *GetRemoteAddressResponse) GetResult() int64

func (*GetRemoteAddressResponse) ProtoMessage

func (*GetRemoteAddressResponse) ProtoMessage()

func (*GetRemoteAddressResponse) ProtoReflect

func (x *GetRemoteAddressResponse) ProtoReflect() protoreflect.Message

func (*GetRemoteAddressResponse) Reset

func (x *GetRemoteAddressResponse) Reset()

func (*GetRemoteAddressResponse) String

func (x *GetRemoteAddressResponse) String() string

type GetRemotePortRequest

type GetRemotePortRequest struct {
	// contains filtered or unexported fields
}

func (*GetRemotePortRequest) Descriptor deprecated

func (*GetRemotePortRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetRemotePortRequest.ProtoReflect.Descriptor instead.

func (*GetRemotePortRequest) ProtoMessage

func (*GetRemotePortRequest) ProtoMessage()

func (*GetRemotePortRequest) ProtoReflect

func (x *GetRemotePortRequest) ProtoReflect() protoreflect.Message

func (*GetRemotePortRequest) Reset

func (x *GetRemotePortRequest) Reset()

func (*GetRemotePortRequest) String

func (x *GetRemotePortRequest) String() string

type GetRemotePortResponse

type GetRemotePortResponse struct {
	Result int32 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetRemotePortResponse) Descriptor deprecated

func (*GetRemotePortResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetRemotePortResponse.ProtoReflect.Descriptor instead.

func (*GetRemotePortResponse) GetResult

func (x *GetRemotePortResponse) GetResult() int32

func (*GetRemotePortResponse) ProtoMessage

func (*GetRemotePortResponse) ProtoMessage()

func (*GetRemotePortResponse) ProtoReflect

func (x *GetRemotePortResponse) ProtoReflect() protoreflect.Message

func (*GetRemotePortResponse) Reset

func (x *GetRemotePortResponse) Reset()

func (*GetRemotePortResponse) String

func (x *GetRemotePortResponse) String() string

type GetStreamsRequest

type GetStreamsRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	// contains filtered or unexported fields
}

func (*GetStreamsRequest) Descriptor deprecated

func (*GetStreamsRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetStreamsRequest.ProtoReflect.Descriptor instead.

func (*GetStreamsRequest) GetHandle

func (x *GetStreamsRequest) GetHandle() int64

func (*GetStreamsRequest) ProtoMessage

func (*GetStreamsRequest) ProtoMessage()

func (*GetStreamsRequest) ProtoReflect

func (x *GetStreamsRequest) ProtoReflect() protoreflect.Message

func (*GetStreamsRequest) Reset

func (x *GetStreamsRequest) Reset()

func (*GetStreamsRequest) String

func (x *GetStreamsRequest) String() string

type GetStreamsResponse

type GetStreamsResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetStreamsResponse) Descriptor deprecated

func (*GetStreamsResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetStreamsResponse.ProtoReflect.Descriptor instead.

func (*GetStreamsResponse) GetResult

func (x *GetStreamsResponse) GetResult() int64

func (*GetStreamsResponse) ProtoMessage

func (*GetStreamsResponse) ProtoMessage()

func (*GetStreamsResponse) ProtoReflect

func (x *GetStreamsResponse) ProtoReflect() protoreflect.Message

func (*GetStreamsResponse) Reset

func (x *GetStreamsResponse) Reset()

func (*GetStreamsResponse) String

func (x *GetStreamsResponse) String() string

type IsBusyRequest

type IsBusyRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	// contains filtered or unexported fields
}

func (*IsBusyRequest) Descriptor deprecated

func (*IsBusyRequest) Descriptor() ([]byte, []int)

Deprecated: Use IsBusyRequest.ProtoReflect.Descriptor instead.

func (*IsBusyRequest) GetHandle

func (x *IsBusyRequest) GetHandle() int64

func (*IsBusyRequest) ProtoMessage

func (*IsBusyRequest) ProtoMessage()

func (*IsBusyRequest) ProtoReflect

func (x *IsBusyRequest) ProtoReflect() protoreflect.Message

func (*IsBusyRequest) Reset

func (x *IsBusyRequest) Reset()

func (*IsBusyRequest) String

func (x *IsBusyRequest) String() string

type IsBusyResponse

type IsBusyResponse struct {
	Result bool `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*IsBusyResponse) Descriptor deprecated

func (*IsBusyResponse) Descriptor() ([]byte, []int)

Deprecated: Use IsBusyResponse.ProtoReflect.Descriptor instead.

func (*IsBusyResponse) GetResult

func (x *IsBusyResponse) GetResult() bool

func (*IsBusyResponse) ProtoMessage

func (*IsBusyResponse) ProtoMessage()

func (*IsBusyResponse) ProtoReflect

func (x *IsBusyResponse) ProtoReflect() protoreflect.Message

func (*IsBusyResponse) Reset

func (x *IsBusyResponse) Reset()

func (*IsBusyResponse) String

func (x *IsBusyResponse) String() string

type JoinRequest

type JoinRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	Arg0   int64 `protobuf:"varint,2,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*JoinRequest) Descriptor deprecated

func (*JoinRequest) Descriptor() ([]byte, []int)

Deprecated: Use JoinRequest.ProtoReflect.Descriptor instead.

func (*JoinRequest) GetArg0

func (x *JoinRequest) GetArg0() int64

func (*JoinRequest) GetHandle

func (x *JoinRequest) GetHandle() int64

func (*JoinRequest) ProtoMessage

func (*JoinRequest) ProtoMessage()

func (*JoinRequest) ProtoReflect

func (x *JoinRequest) ProtoReflect() protoreflect.Message

func (*JoinRequest) Reset

func (x *JoinRequest) Reset()

func (*JoinRequest) String

func (x *JoinRequest) String() string

type JoinResponse

type JoinResponse struct {
	// contains filtered or unexported fields
}

func (*JoinResponse) Descriptor deprecated

func (*JoinResponse) Descriptor() ([]byte, []int)

Deprecated: Use JoinResponse.ProtoReflect.Descriptor instead.

func (*JoinResponse) ProtoMessage

func (*JoinResponse) ProtoMessage()

func (*JoinResponse) ProtoReflect

func (x *JoinResponse) ProtoReflect() protoreflect.Message

func (*JoinResponse) Reset

func (x *JoinResponse) Reset()

func (*JoinResponse) String

func (x *JoinResponse) String() string

type NewAudioGroupRequest

type NewAudioGroupRequest struct {
	Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*NewAudioGroupRequest) Descriptor deprecated

func (*NewAudioGroupRequest) Descriptor() ([]byte, []int)

Deprecated: Use NewAudioGroupRequest.ProtoReflect.Descriptor instead.

func (*NewAudioGroupRequest) GetArg0

func (x *NewAudioGroupRequest) GetArg0() int64

func (*NewAudioGroupRequest) ProtoMessage

func (*NewAudioGroupRequest) ProtoMessage()

func (*NewAudioGroupRequest) ProtoReflect

func (x *NewAudioGroupRequest) ProtoReflect() protoreflect.Message

func (*NewAudioGroupRequest) Reset

func (x *NewAudioGroupRequest) Reset()

func (*NewAudioGroupRequest) String

func (x *NewAudioGroupRequest) String() string

type NewAudioGroupResponse

type NewAudioGroupResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*NewAudioGroupResponse) Descriptor deprecated

func (*NewAudioGroupResponse) Descriptor() ([]byte, []int)

Deprecated: Use NewAudioGroupResponse.ProtoReflect.Descriptor instead.

func (*NewAudioGroupResponse) GetResult

func (x *NewAudioGroupResponse) GetResult() int64

func (*NewAudioGroupResponse) ProtoMessage

func (*NewAudioGroupResponse) ProtoMessage()

func (*NewAudioGroupResponse) ProtoReflect

func (x *NewAudioGroupResponse) ProtoReflect() protoreflect.Message

func (*NewAudioGroupResponse) Reset

func (x *NewAudioGroupResponse) Reset()

func (*NewAudioGroupResponse) String

func (x *NewAudioGroupResponse) String() string

type NewAudioStreamRequest

type NewAudioStreamRequest struct {
	Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*NewAudioStreamRequest) Descriptor deprecated

func (*NewAudioStreamRequest) Descriptor() ([]byte, []int)

Deprecated: Use NewAudioStreamRequest.ProtoReflect.Descriptor instead.

func (*NewAudioStreamRequest) GetArg0

func (x *NewAudioStreamRequest) GetArg0() int64

func (*NewAudioStreamRequest) ProtoMessage

func (*NewAudioStreamRequest) ProtoMessage()

func (*NewAudioStreamRequest) ProtoReflect

func (x *NewAudioStreamRequest) ProtoReflect() protoreflect.Message

func (*NewAudioStreamRequest) Reset

func (x *NewAudioStreamRequest) Reset()

func (*NewAudioStreamRequest) String

func (x *NewAudioStreamRequest) String() string

type NewAudioStreamResponse

type NewAudioStreamResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*NewAudioStreamResponse) Descriptor deprecated

func (*NewAudioStreamResponse) Descriptor() ([]byte, []int)

Deprecated: Use NewAudioStreamResponse.ProtoReflect.Descriptor instead.

func (*NewAudioStreamResponse) GetResult

func (x *NewAudioStreamResponse) GetResult() int64

func (*NewAudioStreamResponse) ProtoMessage

func (*NewAudioStreamResponse) ProtoMessage()

func (*NewAudioStreamResponse) ProtoReflect

func (x *NewAudioStreamResponse) ProtoReflect() protoreflect.Message

func (*NewAudioStreamResponse) Reset

func (x *NewAudioStreamResponse) Reset()

func (*NewAudioStreamResponse) String

func (x *NewAudioStreamResponse) String() string

type ReleaseRequest

type ReleaseRequest struct {
	// contains filtered or unexported fields
}

func (*ReleaseRequest) Descriptor deprecated

func (*ReleaseRequest) Descriptor() ([]byte, []int)

Deprecated: Use ReleaseRequest.ProtoReflect.Descriptor instead.

func (*ReleaseRequest) ProtoMessage

func (*ReleaseRequest) ProtoMessage()

func (*ReleaseRequest) ProtoReflect

func (x *ReleaseRequest) ProtoReflect() protoreflect.Message

func (*ReleaseRequest) Reset

func (x *ReleaseRequest) Reset()

func (*ReleaseRequest) String

func (x *ReleaseRequest) String() string

type ReleaseResponse

type ReleaseResponse struct {
	// contains filtered or unexported fields
}

func (*ReleaseResponse) Descriptor deprecated

func (*ReleaseResponse) Descriptor() ([]byte, []int)

Deprecated: Use ReleaseResponse.ProtoReflect.Descriptor instead.

func (*ReleaseResponse) ProtoMessage

func (*ReleaseResponse) ProtoMessage()

func (*ReleaseResponse) ProtoReflect

func (x *ReleaseResponse) ProtoReflect() protoreflect.Message

func (*ReleaseResponse) Reset

func (x *ReleaseResponse) Reset()

func (*ReleaseResponse) String

func (x *ReleaseResponse) String() string

type SendDtmfRequest

type SendDtmfRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	Arg0   int32 `protobuf:"varint,2,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*SendDtmfRequest) Descriptor deprecated

func (*SendDtmfRequest) Descriptor() ([]byte, []int)

Deprecated: Use SendDtmfRequest.ProtoReflect.Descriptor instead.

func (*SendDtmfRequest) GetArg0

func (x *SendDtmfRequest) GetArg0() int32

func (*SendDtmfRequest) GetHandle

func (x *SendDtmfRequest) GetHandle() int64

func (*SendDtmfRequest) ProtoMessage

func (*SendDtmfRequest) ProtoMessage()

func (*SendDtmfRequest) ProtoReflect

func (x *SendDtmfRequest) ProtoReflect() protoreflect.Message

func (*SendDtmfRequest) Reset

func (x *SendDtmfRequest) Reset()

func (*SendDtmfRequest) String

func (x *SendDtmfRequest) String() string

type SendDtmfResponse

type SendDtmfResponse struct {
	// contains filtered or unexported fields
}

func (*SendDtmfResponse) Descriptor deprecated

func (*SendDtmfResponse) Descriptor() ([]byte, []int)

Deprecated: Use SendDtmfResponse.ProtoReflect.Descriptor instead.

func (*SendDtmfResponse) ProtoMessage

func (*SendDtmfResponse) ProtoMessage()

func (*SendDtmfResponse) ProtoReflect

func (x *SendDtmfResponse) ProtoReflect() protoreflect.Message

func (*SendDtmfResponse) Reset

func (x *SendDtmfResponse) Reset()

func (*SendDtmfResponse) String

func (x *SendDtmfResponse) String() string

type SetCodecRequest

type SetCodecRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	Arg0   int64 `protobuf:"varint,2,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*SetCodecRequest) Descriptor deprecated

func (*SetCodecRequest) Descriptor() ([]byte, []int)

Deprecated: Use SetCodecRequest.ProtoReflect.Descriptor instead.

func (*SetCodecRequest) GetArg0

func (x *SetCodecRequest) GetArg0() int64

func (*SetCodecRequest) GetHandle

func (x *SetCodecRequest) GetHandle() int64

func (*SetCodecRequest) ProtoMessage

func (*SetCodecRequest) ProtoMessage()

func (*SetCodecRequest) ProtoReflect

func (x *SetCodecRequest) ProtoReflect() protoreflect.Message

func (*SetCodecRequest) Reset

func (x *SetCodecRequest) Reset()

func (*SetCodecRequest) String

func (x *SetCodecRequest) String() string

type SetCodecResponse

type SetCodecResponse struct {
	// contains filtered or unexported fields
}

func (*SetCodecResponse) Descriptor deprecated

func (*SetCodecResponse) Descriptor() ([]byte, []int)

Deprecated: Use SetCodecResponse.ProtoReflect.Descriptor instead.

func (*SetCodecResponse) ProtoMessage

func (*SetCodecResponse) ProtoMessage()

func (*SetCodecResponse) ProtoReflect

func (x *SetCodecResponse) ProtoReflect() protoreflect.Message

func (*SetCodecResponse) Reset

func (x *SetCodecResponse) Reset()

func (*SetCodecResponse) String

func (x *SetCodecResponse) String() string

type SetDtmfTypeRequest

type SetDtmfTypeRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	Arg0   int32 `protobuf:"varint,2,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*SetDtmfTypeRequest) Descriptor deprecated

func (*SetDtmfTypeRequest) Descriptor() ([]byte, []int)

Deprecated: Use SetDtmfTypeRequest.ProtoReflect.Descriptor instead.

func (*SetDtmfTypeRequest) GetArg0

func (x *SetDtmfTypeRequest) GetArg0() int32

func (*SetDtmfTypeRequest) GetHandle

func (x *SetDtmfTypeRequest) GetHandle() int64

func (*SetDtmfTypeRequest) ProtoMessage

func (*SetDtmfTypeRequest) ProtoMessage()

func (*SetDtmfTypeRequest) ProtoReflect

func (x *SetDtmfTypeRequest) ProtoReflect() protoreflect.Message

func (*SetDtmfTypeRequest) Reset

func (x *SetDtmfTypeRequest) Reset()

func (*SetDtmfTypeRequest) String

func (x *SetDtmfTypeRequest) String() string

type SetDtmfTypeResponse

type SetDtmfTypeResponse struct {
	// contains filtered or unexported fields
}

func (*SetDtmfTypeResponse) Descriptor deprecated

func (*SetDtmfTypeResponse) Descriptor() ([]byte, []int)

Deprecated: Use SetDtmfTypeResponse.ProtoReflect.Descriptor instead.

func (*SetDtmfTypeResponse) ProtoMessage

func (*SetDtmfTypeResponse) ProtoMessage()

func (*SetDtmfTypeResponse) ProtoReflect

func (x *SetDtmfTypeResponse) ProtoReflect() protoreflect.Message

func (*SetDtmfTypeResponse) Reset

func (x *SetDtmfTypeResponse) Reset()

func (*SetDtmfTypeResponse) String

func (x *SetDtmfTypeResponse) String() string

type SetModeRequest

type SetModeRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	Arg0   int32 `protobuf:"varint,2,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*SetModeRequest) Descriptor deprecated

func (*SetModeRequest) Descriptor() ([]byte, []int)

Deprecated: Use SetModeRequest.ProtoReflect.Descriptor instead.

func (*SetModeRequest) GetArg0

func (x *SetModeRequest) GetArg0() int32

func (*SetModeRequest) GetHandle

func (x *SetModeRequest) GetHandle() int64

func (*SetModeRequest) ProtoMessage

func (*SetModeRequest) ProtoMessage()

func (*SetModeRequest) ProtoReflect

func (x *SetModeRequest) ProtoReflect() protoreflect.Message

func (*SetModeRequest) Reset

func (x *SetModeRequest) Reset()

func (*SetModeRequest) String

func (x *SetModeRequest) String() string

type SetModeResponse

type SetModeResponse struct {
	// contains filtered or unexported fields
}

func (*SetModeResponse) Descriptor deprecated

func (*SetModeResponse) Descriptor() ([]byte, []int)

Deprecated: Use SetModeResponse.ProtoReflect.Descriptor instead.

func (*SetModeResponse) ProtoMessage

func (*SetModeResponse) ProtoMessage()

func (*SetModeResponse) ProtoReflect

func (x *SetModeResponse) ProtoReflect() protoreflect.Message

func (*SetModeResponse) Reset

func (x *SetModeResponse) Reset()

func (*SetModeResponse) String

func (x *SetModeResponse) String() string

type StreamGetModeRequest

type StreamGetModeRequest struct {
	// contains filtered or unexported fields
}

func (*StreamGetModeRequest) Descriptor deprecated

func (*StreamGetModeRequest) Descriptor() ([]byte, []int)

Deprecated: Use StreamGetModeRequest.ProtoReflect.Descriptor instead.

func (*StreamGetModeRequest) ProtoMessage

func (*StreamGetModeRequest) ProtoMessage()

func (*StreamGetModeRequest) ProtoReflect

func (x *StreamGetModeRequest) ProtoReflect() protoreflect.Message

func (*StreamGetModeRequest) Reset

func (x *StreamGetModeRequest) Reset()

func (*StreamGetModeRequest) String

func (x *StreamGetModeRequest) String() string

type StreamIsBusyRequest

type StreamIsBusyRequest struct {
	// contains filtered or unexported fields
}

func (*StreamIsBusyRequest) Descriptor deprecated

func (*StreamIsBusyRequest) Descriptor() ([]byte, []int)

Deprecated: Use StreamIsBusyRequest.ProtoReflect.Descriptor instead.

func (*StreamIsBusyRequest) ProtoMessage

func (*StreamIsBusyRequest) ProtoMessage()

func (*StreamIsBusyRequest) ProtoReflect

func (x *StreamIsBusyRequest) ProtoReflect() protoreflect.Message

func (*StreamIsBusyRequest) Reset

func (x *StreamIsBusyRequest) Reset()

func (*StreamIsBusyRequest) String

func (x *StreamIsBusyRequest) String() string

type StreamServiceClient

StreamServiceClient is the client API for StreamService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type StreamServiceServer

StreamServiceServer is the server API for StreamService service. All implementations must embed UnimplementedStreamServiceServer for forward compatibility.

type StreamSetModeRequest

type StreamSetModeRequest struct {
	Arg0 int32 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*StreamSetModeRequest) Descriptor deprecated

func (*StreamSetModeRequest) Descriptor() ([]byte, []int)

Deprecated: Use StreamSetModeRequest.ProtoReflect.Descriptor instead.

func (*StreamSetModeRequest) GetArg0

func (x *StreamSetModeRequest) GetArg0() int32

func (*StreamSetModeRequest) ProtoMessage

func (*StreamSetModeRequest) ProtoMessage()

func (*StreamSetModeRequest) ProtoReflect

func (x *StreamSetModeRequest) ProtoReflect() protoreflect.Message

func (*StreamSetModeRequest) Reset

func (x *StreamSetModeRequest) Reset()

func (*StreamSetModeRequest) String

func (x *StreamSetModeRequest) String() string

type UnimplementedAudioCodecServiceServer

type UnimplementedAudioCodecServiceServer struct{}

UnimplementedAudioCodecServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedAudioCodecServiceServer) GetCodec

func (UnimplementedAudioCodecServiceServer) GetCodecs

type UnimplementedAudioGroupServiceServer

type UnimplementedAudioGroupServiceServer struct{}

UnimplementedAudioGroupServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedAudioGroupServiceServer) Clear

func (UnimplementedAudioGroupServiceServer) GetMode

func (UnimplementedAudioGroupServiceServer) GetStreams

func (UnimplementedAudioGroupServiceServer) NewAudioGroup

func (UnimplementedAudioGroupServiceServer) SendDtmf

func (UnimplementedAudioGroupServiceServer) SetMode

type UnimplementedAudioStreamServiceServer

type UnimplementedAudioStreamServiceServer struct{}

UnimplementedAudioStreamServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedAudioStreamServiceServer) GetCodec

func (UnimplementedAudioStreamServiceServer) GetDtmfType

func (UnimplementedAudioStreamServiceServer) GetGroup

func (UnimplementedAudioStreamServiceServer) IsBusy

func (UnimplementedAudioStreamServiceServer) Join

func (UnimplementedAudioStreamServiceServer) NewAudioStream

func (UnimplementedAudioStreamServiceServer) SetCodec

func (UnimplementedAudioStreamServiceServer) SetDtmfType

type UnimplementedStreamServiceServer

type UnimplementedStreamServiceServer struct{}

UnimplementedStreamServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedStreamServiceServer) Associate

func (UnimplementedStreamServiceServer) GetLocalAddress

func (UnimplementedStreamServiceServer) GetLocalPort

func (UnimplementedStreamServiceServer) GetMode

func (UnimplementedStreamServiceServer) GetRemoteAddress

func (UnimplementedStreamServiceServer) GetRemotePort

func (UnimplementedStreamServiceServer) IsBusy

func (UnimplementedStreamServiceServer) Release

func (UnimplementedStreamServiceServer) SetMode

type UnsafeAudioCodecServiceServer

type UnsafeAudioCodecServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeAudioCodecServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to AudioCodecServiceServer will result in compilation errors.

type UnsafeAudioGroupServiceServer

type UnsafeAudioGroupServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeAudioGroupServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to AudioGroupServiceServer will result in compilation errors.

type UnsafeAudioStreamServiceServer

type UnsafeAudioStreamServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeAudioStreamServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to AudioStreamServiceServer will result in compilation errors.

type UnsafeStreamServiceServer

type UnsafeStreamServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeStreamServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to StreamServiceServer will result in compilation errors.

Jump to