rtt

package
v0.0.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 29, 2026 License: CC0-1.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

const (
	RangingCapabilitiesService_DescribeContents_FullMethodName                  = "/rtt.RangingCapabilitiesService/DescribeContents"
	RangingCapabilitiesService_HasPeriodicRangingHardwareFeature_FullMethodName = "/rtt.RangingCapabilitiesService/HasPeriodicRangingHardwareFeature"
	RangingCapabilitiesService_ToString_FullMethodName                          = "/rtt.RangingCapabilitiesService/ToString"
	RangingCapabilitiesService_WriteToParcel_FullMethodName                     = "/rtt.RangingCapabilitiesService/WriteToParcel"
)
const (
	RangingParamsService_DescribeContents_FullMethodName                  = "/rtt.RangingParamsService/DescribeContents"
	RangingParamsService_Equals_FullMethodName                            = "/rtt.RangingParamsService/Equals"
	RangingParamsService_GetMatchFilter_FullMethodName                    = "/rtt.RangingParamsService/GetMatchFilter"
	RangingParamsService_GetRangingUpdateRate_FullMethodName              = "/rtt.RangingParamsService/GetRangingUpdateRate"
	RangingParamsService_GetServiceName_FullMethodName                    = "/rtt.RangingParamsService/GetServiceName"
	RangingParamsService_HashCode_FullMethodName                          = "/rtt.RangingParamsService/HashCode"
	RangingParamsService_IsPeriodicRangingHwFeatureEnabled_FullMethodName = "/rtt.RangingParamsService/IsPeriodicRangingHwFeatureEnabled"
	RangingParamsService_ToString_FullMethodName                          = "/rtt.RangingParamsService/ToString"
	RangingParamsService_WriteToParcel_FullMethodName                     = "/rtt.RangingParamsService/WriteToParcel"
)
const (
	RangingParamsBuilderService_Build_FullMethodName                              = "/rtt.RangingParamsBuilderService/Build"
	RangingParamsBuilderService_SetMatchFilter_FullMethodName                     = "/rtt.RangingParamsBuilderService/SetMatchFilter"
	RangingParamsBuilderService_SetPeriodicRangingHwFeatureEnabled_FullMethodName = "/rtt.RangingParamsBuilderService/SetPeriodicRangingHwFeatureEnabled"
	RangingParamsBuilderService_SetRangingUpdateRate_FullMethodName               = "/rtt.RangingParamsBuilderService/SetRangingUpdateRate"
)

Variables

var File_proto_rtt_rtt_proto protoreflect.FileDescriptor
var RangingCapabilitiesService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "rtt.RangingCapabilitiesService",
	HandlerType: (*RangingCapabilitiesServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "DescribeContents",
			Handler:    _RangingCapabilitiesService_DescribeContents_Handler,
		},
		{
			MethodName: "HasPeriodicRangingHardwareFeature",
			Handler:    _RangingCapabilitiesService_HasPeriodicRangingHardwareFeature_Handler,
		},
		{
			MethodName: "ToString",
			Handler:    _RangingCapabilitiesService_ToString_Handler,
		},
		{
			MethodName: "WriteToParcel",
			Handler:    _RangingCapabilitiesService_WriteToParcel_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/rtt/rtt.proto",
}

RangingCapabilitiesService_ServiceDesc is the grpc.ServiceDesc for RangingCapabilitiesService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var RangingParamsBuilderService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "rtt.RangingParamsBuilderService",
	HandlerType: (*RangingParamsBuilderServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "Build",
			Handler:    _RangingParamsBuilderService_Build_Handler,
		},
		{
			MethodName: "SetMatchFilter",
			Handler:    _RangingParamsBuilderService_SetMatchFilter_Handler,
		},
		{
			MethodName: "SetPeriodicRangingHwFeatureEnabled",
			Handler:    _RangingParamsBuilderService_SetPeriodicRangingHwFeatureEnabled_Handler,
		},
		{
			MethodName: "SetRangingUpdateRate",
			Handler:    _RangingParamsBuilderService_SetRangingUpdateRate_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/rtt/rtt.proto",
}

RangingParamsBuilderService_ServiceDesc is the grpc.ServiceDesc for RangingParamsBuilderService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var RangingParamsService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "rtt.RangingParamsService",
	HandlerType: (*RangingParamsServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "DescribeContents",
			Handler:    _RangingParamsService_DescribeContents_Handler,
		},
		{
			MethodName: "Equals",
			Handler:    _RangingParamsService_Equals_Handler,
		},
		{
			MethodName: "GetMatchFilter",
			Handler:    _RangingParamsService_GetMatchFilter_Handler,
		},
		{
			MethodName: "GetRangingUpdateRate",
			Handler:    _RangingParamsService_GetRangingUpdateRate_Handler,
		},
		{
			MethodName: "GetServiceName",
			Handler:    _RangingParamsService_GetServiceName_Handler,
		},
		{
			MethodName: "HashCode",
			Handler:    _RangingParamsService_HashCode_Handler,
		},
		{
			MethodName: "IsPeriodicRangingHwFeatureEnabled",
			Handler:    _RangingParamsService_IsPeriodicRangingHwFeatureEnabled_Handler,
		},
		{
			MethodName: "ToString",
			Handler:    _RangingParamsService_ToString_Handler,
		},
		{
			MethodName: "WriteToParcel",
			Handler:    _RangingParamsService_WriteToParcel_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/rtt/rtt.proto",
}

RangingParamsService_ServiceDesc is the grpc.ServiceDesc for RangingParamsService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterRangingCapabilitiesServiceServer

func RegisterRangingCapabilitiesServiceServer(s grpc.ServiceRegistrar, srv RangingCapabilitiesServiceServer)

func RegisterRangingParamsBuilderServiceServer

func RegisterRangingParamsBuilderServiceServer(s grpc.ServiceRegistrar, srv RangingParamsBuilderServiceServer)

func RegisterRangingParamsServiceServer

func RegisterRangingParamsServiceServer(s grpc.ServiceRegistrar, srv RangingParamsServiceServer)

Types

type BuildRequest

type BuildRequest struct {
	// contains filtered or unexported fields
}

func (*BuildRequest) Descriptor deprecated

func (*BuildRequest) Descriptor() ([]byte, []int)

Deprecated: Use BuildRequest.ProtoReflect.Descriptor instead.

func (*BuildRequest) ProtoMessage

func (*BuildRequest) ProtoMessage()

func (*BuildRequest) ProtoReflect

func (x *BuildRequest) ProtoReflect() protoreflect.Message

func (*BuildRequest) Reset

func (x *BuildRequest) Reset()

func (*BuildRequest) String

func (x *BuildRequest) String() string

type BuildResponse

type BuildResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*BuildResponse) Descriptor deprecated

func (*BuildResponse) Descriptor() ([]byte, []int)

Deprecated: Use BuildResponse.ProtoReflect.Descriptor instead.

func (*BuildResponse) GetResult

func (x *BuildResponse) GetResult() int64

func (*BuildResponse) ProtoMessage

func (*BuildResponse) ProtoMessage()

func (*BuildResponse) ProtoReflect

func (x *BuildResponse) ProtoReflect() protoreflect.Message

func (*BuildResponse) Reset

func (x *BuildResponse) Reset()

func (*BuildResponse) String

func (x *BuildResponse) String() string

type DescribeContentsRequest

type DescribeContentsRequest struct {
	// contains filtered or unexported fields
}

func (*DescribeContentsRequest) Descriptor deprecated

func (*DescribeContentsRequest) Descriptor() ([]byte, []int)

Deprecated: Use DescribeContentsRequest.ProtoReflect.Descriptor instead.

func (*DescribeContentsRequest) ProtoMessage

func (*DescribeContentsRequest) ProtoMessage()

func (*DescribeContentsRequest) ProtoReflect

func (x *DescribeContentsRequest) ProtoReflect() protoreflect.Message

func (*DescribeContentsRequest) Reset

func (x *DescribeContentsRequest) Reset()

func (*DescribeContentsRequest) String

func (x *DescribeContentsRequest) String() string

type DescribeContentsResponse

type DescribeContentsResponse struct {
	Result int32 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*DescribeContentsResponse) Descriptor deprecated

func (*DescribeContentsResponse) Descriptor() ([]byte, []int)

Deprecated: Use DescribeContentsResponse.ProtoReflect.Descriptor instead.

func (*DescribeContentsResponse) GetResult

func (x *DescribeContentsResponse) GetResult() int32

func (*DescribeContentsResponse) ProtoMessage

func (*DescribeContentsResponse) ProtoMessage()

func (*DescribeContentsResponse) ProtoReflect

func (x *DescribeContentsResponse) ProtoReflect() protoreflect.Message

func (*DescribeContentsResponse) Reset

func (x *DescribeContentsResponse) Reset()

func (*DescribeContentsResponse) String

func (x *DescribeContentsResponse) String() string

type EqualsRequest

type EqualsRequest struct {
	Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*EqualsRequest) Descriptor deprecated

func (*EqualsRequest) Descriptor() ([]byte, []int)

Deprecated: Use EqualsRequest.ProtoReflect.Descriptor instead.

func (*EqualsRequest) GetArg0

func (x *EqualsRequest) GetArg0() int64

func (*EqualsRequest) ProtoMessage

func (*EqualsRequest) ProtoMessage()

func (*EqualsRequest) ProtoReflect

func (x *EqualsRequest) ProtoReflect() protoreflect.Message

func (*EqualsRequest) Reset

func (x *EqualsRequest) Reset()

func (*EqualsRequest) String

func (x *EqualsRequest) String() string

type EqualsResponse

type EqualsResponse struct {
	Result bool `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*EqualsResponse) Descriptor deprecated

func (*EqualsResponse) Descriptor() ([]byte, []int)

Deprecated: Use EqualsResponse.ProtoReflect.Descriptor instead.

func (*EqualsResponse) GetResult

func (x *EqualsResponse) GetResult() bool

func (*EqualsResponse) ProtoMessage

func (*EqualsResponse) ProtoMessage()

func (*EqualsResponse) ProtoReflect

func (x *EqualsResponse) ProtoReflect() protoreflect.Message

func (*EqualsResponse) Reset

func (x *EqualsResponse) Reset()

func (*EqualsResponse) String

func (x *EqualsResponse) String() string

type GetMatchFilterRequest

type GetMatchFilterRequest struct {
	// contains filtered or unexported fields
}

func (*GetMatchFilterRequest) Descriptor deprecated

func (*GetMatchFilterRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetMatchFilterRequest.ProtoReflect.Descriptor instead.

func (*GetMatchFilterRequest) ProtoMessage

func (*GetMatchFilterRequest) ProtoMessage()

func (*GetMatchFilterRequest) ProtoReflect

func (x *GetMatchFilterRequest) ProtoReflect() protoreflect.Message

func (*GetMatchFilterRequest) Reset

func (x *GetMatchFilterRequest) Reset()

func (*GetMatchFilterRequest) String

func (x *GetMatchFilterRequest) String() string

type GetMatchFilterResponse

type GetMatchFilterResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetMatchFilterResponse) Descriptor deprecated

func (*GetMatchFilterResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetMatchFilterResponse.ProtoReflect.Descriptor instead.

func (*GetMatchFilterResponse) GetResult

func (x *GetMatchFilterResponse) GetResult() int64

func (*GetMatchFilterResponse) ProtoMessage

func (*GetMatchFilterResponse) ProtoMessage()

func (*GetMatchFilterResponse) ProtoReflect

func (x *GetMatchFilterResponse) ProtoReflect() protoreflect.Message

func (*GetMatchFilterResponse) Reset

func (x *GetMatchFilterResponse) Reset()

func (*GetMatchFilterResponse) String

func (x *GetMatchFilterResponse) String() string

type GetRangingUpdateRateRequest

type GetRangingUpdateRateRequest struct {
	// contains filtered or unexported fields
}

func (*GetRangingUpdateRateRequest) Descriptor deprecated

func (*GetRangingUpdateRateRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetRangingUpdateRateRequest.ProtoReflect.Descriptor instead.

func (*GetRangingUpdateRateRequest) ProtoMessage

func (*GetRangingUpdateRateRequest) ProtoMessage()

func (*GetRangingUpdateRateRequest) ProtoReflect

func (*GetRangingUpdateRateRequest) Reset

func (x *GetRangingUpdateRateRequest) Reset()

func (*GetRangingUpdateRateRequest) String

func (x *GetRangingUpdateRateRequest) String() string

type GetRangingUpdateRateResponse

type GetRangingUpdateRateResponse struct {
	Result int32 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetRangingUpdateRateResponse) Descriptor deprecated

func (*GetRangingUpdateRateResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetRangingUpdateRateResponse.ProtoReflect.Descriptor instead.

func (*GetRangingUpdateRateResponse) GetResult

func (x *GetRangingUpdateRateResponse) GetResult() int32

func (*GetRangingUpdateRateResponse) ProtoMessage

func (*GetRangingUpdateRateResponse) ProtoMessage()

func (*GetRangingUpdateRateResponse) ProtoReflect

func (*GetRangingUpdateRateResponse) Reset

func (x *GetRangingUpdateRateResponse) Reset()

func (*GetRangingUpdateRateResponse) String

type GetServiceNameRequest

type GetServiceNameRequest struct {
	// contains filtered or unexported fields
}

func (*GetServiceNameRequest) Descriptor deprecated

func (*GetServiceNameRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetServiceNameRequest.ProtoReflect.Descriptor instead.

func (*GetServiceNameRequest) ProtoMessage

func (*GetServiceNameRequest) ProtoMessage()

func (*GetServiceNameRequest) ProtoReflect

func (x *GetServiceNameRequest) ProtoReflect() protoreflect.Message

func (*GetServiceNameRequest) Reset

func (x *GetServiceNameRequest) Reset()

func (*GetServiceNameRequest) String

func (x *GetServiceNameRequest) String() string

type GetServiceNameResponse

type GetServiceNameResponse struct {
	Result string `protobuf:"bytes,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetServiceNameResponse) Descriptor deprecated

func (*GetServiceNameResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetServiceNameResponse.ProtoReflect.Descriptor instead.

func (*GetServiceNameResponse) GetResult

func (x *GetServiceNameResponse) GetResult() string

func (*GetServiceNameResponse) ProtoMessage

func (*GetServiceNameResponse) ProtoMessage()

func (*GetServiceNameResponse) ProtoReflect

func (x *GetServiceNameResponse) ProtoReflect() protoreflect.Message

func (*GetServiceNameResponse) Reset

func (x *GetServiceNameResponse) Reset()

func (*GetServiceNameResponse) String

func (x *GetServiceNameResponse) String() string

type HasPeriodicRangingHardwareFeatureRequest

type HasPeriodicRangingHardwareFeatureRequest struct {
	// contains filtered or unexported fields
}

func (*HasPeriodicRangingHardwareFeatureRequest) Descriptor deprecated

func (*HasPeriodicRangingHardwareFeatureRequest) Descriptor() ([]byte, []int)

Deprecated: Use HasPeriodicRangingHardwareFeatureRequest.ProtoReflect.Descriptor instead.

func (*HasPeriodicRangingHardwareFeatureRequest) ProtoMessage

func (*HasPeriodicRangingHardwareFeatureRequest) ProtoReflect

func (*HasPeriodicRangingHardwareFeatureRequest) Reset

func (*HasPeriodicRangingHardwareFeatureRequest) String

type HasPeriodicRangingHardwareFeatureResponse

type HasPeriodicRangingHardwareFeatureResponse struct {
	Result bool `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*HasPeriodicRangingHardwareFeatureResponse) Descriptor deprecated

func (*HasPeriodicRangingHardwareFeatureResponse) Descriptor() ([]byte, []int)

Deprecated: Use HasPeriodicRangingHardwareFeatureResponse.ProtoReflect.Descriptor instead.

func (*HasPeriodicRangingHardwareFeatureResponse) GetResult

func (*HasPeriodicRangingHardwareFeatureResponse) ProtoMessage

func (*HasPeriodicRangingHardwareFeatureResponse) ProtoReflect

func (*HasPeriodicRangingHardwareFeatureResponse) Reset

func (*HasPeriodicRangingHardwareFeatureResponse) String

type HashCodeRequest

type HashCodeRequest struct {
	// contains filtered or unexported fields
}

func (*HashCodeRequest) Descriptor deprecated

func (*HashCodeRequest) Descriptor() ([]byte, []int)

Deprecated: Use HashCodeRequest.ProtoReflect.Descriptor instead.

func (*HashCodeRequest) ProtoMessage

func (*HashCodeRequest) ProtoMessage()

func (*HashCodeRequest) ProtoReflect

func (x *HashCodeRequest) ProtoReflect() protoreflect.Message

func (*HashCodeRequest) Reset

func (x *HashCodeRequest) Reset()

func (*HashCodeRequest) String

func (x *HashCodeRequest) String() string

type HashCodeResponse

type HashCodeResponse struct {
	Result int32 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*HashCodeResponse) Descriptor deprecated

func (*HashCodeResponse) Descriptor() ([]byte, []int)

Deprecated: Use HashCodeResponse.ProtoReflect.Descriptor instead.

func (*HashCodeResponse) GetResult

func (x *HashCodeResponse) GetResult() int32

func (*HashCodeResponse) ProtoMessage

func (*HashCodeResponse) ProtoMessage()

func (*HashCodeResponse) ProtoReflect

func (x *HashCodeResponse) ProtoReflect() protoreflect.Message

func (*HashCodeResponse) Reset

func (x *HashCodeResponse) Reset()

func (*HashCodeResponse) String

func (x *HashCodeResponse) String() string

type IsPeriodicRangingHwFeatureEnabledRequest

type IsPeriodicRangingHwFeatureEnabledRequest struct {
	// contains filtered or unexported fields
}

func (*IsPeriodicRangingHwFeatureEnabledRequest) Descriptor deprecated

func (*IsPeriodicRangingHwFeatureEnabledRequest) Descriptor() ([]byte, []int)

Deprecated: Use IsPeriodicRangingHwFeatureEnabledRequest.ProtoReflect.Descriptor instead.

func (*IsPeriodicRangingHwFeatureEnabledRequest) ProtoMessage

func (*IsPeriodicRangingHwFeatureEnabledRequest) ProtoReflect

func (*IsPeriodicRangingHwFeatureEnabledRequest) Reset

func (*IsPeriodicRangingHwFeatureEnabledRequest) String

type IsPeriodicRangingHwFeatureEnabledResponse

type IsPeriodicRangingHwFeatureEnabledResponse struct {
	Result bool `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*IsPeriodicRangingHwFeatureEnabledResponse) Descriptor deprecated

func (*IsPeriodicRangingHwFeatureEnabledResponse) Descriptor() ([]byte, []int)

Deprecated: Use IsPeriodicRangingHwFeatureEnabledResponse.ProtoReflect.Descriptor instead.

func (*IsPeriodicRangingHwFeatureEnabledResponse) GetResult

func (*IsPeriodicRangingHwFeatureEnabledResponse) ProtoMessage

func (*IsPeriodicRangingHwFeatureEnabledResponse) ProtoReflect

func (*IsPeriodicRangingHwFeatureEnabledResponse) Reset

func (*IsPeriodicRangingHwFeatureEnabledResponse) String

type RangingCapabilitiesServiceClient

type RangingCapabilitiesServiceClient interface {
	DescribeContents(ctx context.Context, in *DescribeContentsRequest, opts ...grpc.CallOption) (*DescribeContentsResponse, error)
	HasPeriodicRangingHardwareFeature(ctx context.Context, in *HasPeriodicRangingHardwareFeatureRequest, opts ...grpc.CallOption) (*HasPeriodicRangingHardwareFeatureResponse, error)
	ToString(ctx context.Context, in *ToStringRequest, opts ...grpc.CallOption) (*ToStringResponse, error)
	WriteToParcel(ctx context.Context, in *WriteToParcelRequest, opts ...grpc.CallOption) (*WriteToParcelResponse, error)
}

RangingCapabilitiesServiceClient is the client API for RangingCapabilitiesService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type RangingCapabilitiesServiceServer

type RangingCapabilitiesServiceServer interface {
	DescribeContents(context.Context, *DescribeContentsRequest) (*DescribeContentsResponse, error)
	HasPeriodicRangingHardwareFeature(context.Context, *HasPeriodicRangingHardwareFeatureRequest) (*HasPeriodicRangingHardwareFeatureResponse, error)
	ToString(context.Context, *ToStringRequest) (*ToStringResponse, error)
	WriteToParcel(context.Context, *WriteToParcelRequest) (*WriteToParcelResponse, error)
	// contains filtered or unexported methods
}

RangingCapabilitiesServiceServer is the server API for RangingCapabilitiesService service. All implementations must embed UnimplementedRangingCapabilitiesServiceServer for forward compatibility.

type RangingParamsBuilderServiceClient

type RangingParamsBuilderServiceClient interface {
	Build(ctx context.Context, in *BuildRequest, opts ...grpc.CallOption) (*BuildResponse, error)
	SetMatchFilter(ctx context.Context, in *SetMatchFilterRequest, opts ...grpc.CallOption) (*SetMatchFilterResponse, error)
	SetPeriodicRangingHwFeatureEnabled(ctx context.Context, in *SetPeriodicRangingHwFeatureEnabledRequest, opts ...grpc.CallOption) (*SetPeriodicRangingHwFeatureEnabledResponse, error)
	SetRangingUpdateRate(ctx context.Context, in *SetRangingUpdateRateRequest, opts ...grpc.CallOption) (*SetRangingUpdateRateResponse, error)
}

RangingParamsBuilderServiceClient is the client API for RangingParamsBuilderService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type RangingParamsBuilderServiceServer

type RangingParamsBuilderServiceServer interface {
	Build(context.Context, *BuildRequest) (*BuildResponse, error)
	SetMatchFilter(context.Context, *SetMatchFilterRequest) (*SetMatchFilterResponse, error)
	SetPeriodicRangingHwFeatureEnabled(context.Context, *SetPeriodicRangingHwFeatureEnabledRequest) (*SetPeriodicRangingHwFeatureEnabledResponse, error)
	SetRangingUpdateRate(context.Context, *SetRangingUpdateRateRequest) (*SetRangingUpdateRateResponse, error)
	// contains filtered or unexported methods
}

RangingParamsBuilderServiceServer is the server API for RangingParamsBuilderService service. All implementations must embed UnimplementedRangingParamsBuilderServiceServer for forward compatibility.

type RangingParamsServiceClient

RangingParamsServiceClient is the client API for RangingParamsService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type RangingParamsServiceServer

RangingParamsServiceServer is the server API for RangingParamsService service. All implementations must embed UnimplementedRangingParamsServiceServer for forward compatibility.

type SetMatchFilterRequest

type SetMatchFilterRequest struct {
	Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*SetMatchFilterRequest) Descriptor deprecated

func (*SetMatchFilterRequest) Descriptor() ([]byte, []int)

Deprecated: Use SetMatchFilterRequest.ProtoReflect.Descriptor instead.

func (*SetMatchFilterRequest) GetArg0

func (x *SetMatchFilterRequest) GetArg0() int64

func (*SetMatchFilterRequest) ProtoMessage

func (*SetMatchFilterRequest) ProtoMessage()

func (*SetMatchFilterRequest) ProtoReflect

func (x *SetMatchFilterRequest) ProtoReflect() protoreflect.Message

func (*SetMatchFilterRequest) Reset

func (x *SetMatchFilterRequest) Reset()

func (*SetMatchFilterRequest) String

func (x *SetMatchFilterRequest) String() string

type SetMatchFilterResponse

type SetMatchFilterResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*SetMatchFilterResponse) Descriptor deprecated

func (*SetMatchFilterResponse) Descriptor() ([]byte, []int)

Deprecated: Use SetMatchFilterResponse.ProtoReflect.Descriptor instead.

func (*SetMatchFilterResponse) GetResult

func (x *SetMatchFilterResponse) GetResult() int64

func (*SetMatchFilterResponse) ProtoMessage

func (*SetMatchFilterResponse) ProtoMessage()

func (*SetMatchFilterResponse) ProtoReflect

func (x *SetMatchFilterResponse) ProtoReflect() protoreflect.Message

func (*SetMatchFilterResponse) Reset

func (x *SetMatchFilterResponse) Reset()

func (*SetMatchFilterResponse) String

func (x *SetMatchFilterResponse) String() string

type SetPeriodicRangingHwFeatureEnabledRequest

type SetPeriodicRangingHwFeatureEnabledRequest struct {
	Arg0 bool `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*SetPeriodicRangingHwFeatureEnabledRequest) Descriptor deprecated

func (*SetPeriodicRangingHwFeatureEnabledRequest) Descriptor() ([]byte, []int)

Deprecated: Use SetPeriodicRangingHwFeatureEnabledRequest.ProtoReflect.Descriptor instead.

func (*SetPeriodicRangingHwFeatureEnabledRequest) GetArg0

func (*SetPeriodicRangingHwFeatureEnabledRequest) ProtoMessage

func (*SetPeriodicRangingHwFeatureEnabledRequest) ProtoReflect

func (*SetPeriodicRangingHwFeatureEnabledRequest) Reset

func (*SetPeriodicRangingHwFeatureEnabledRequest) String

type SetPeriodicRangingHwFeatureEnabledResponse

type SetPeriodicRangingHwFeatureEnabledResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*SetPeriodicRangingHwFeatureEnabledResponse) Descriptor deprecated

Deprecated: Use SetPeriodicRangingHwFeatureEnabledResponse.ProtoReflect.Descriptor instead.

func (*SetPeriodicRangingHwFeatureEnabledResponse) GetResult

func (*SetPeriodicRangingHwFeatureEnabledResponse) ProtoMessage

func (*SetPeriodicRangingHwFeatureEnabledResponse) ProtoReflect

func (*SetPeriodicRangingHwFeatureEnabledResponse) Reset

func (*SetPeriodicRangingHwFeatureEnabledResponse) String

type SetRangingUpdateRateRequest

type SetRangingUpdateRateRequest struct {
	Arg0 int32 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*SetRangingUpdateRateRequest) Descriptor deprecated

func (*SetRangingUpdateRateRequest) Descriptor() ([]byte, []int)

Deprecated: Use SetRangingUpdateRateRequest.ProtoReflect.Descriptor instead.

func (*SetRangingUpdateRateRequest) GetArg0

func (x *SetRangingUpdateRateRequest) GetArg0() int32

func (*SetRangingUpdateRateRequest) ProtoMessage

func (*SetRangingUpdateRateRequest) ProtoMessage()

func (*SetRangingUpdateRateRequest) ProtoReflect

func (*SetRangingUpdateRateRequest) Reset

func (x *SetRangingUpdateRateRequest) Reset()

func (*SetRangingUpdateRateRequest) String

func (x *SetRangingUpdateRateRequest) String() string

type SetRangingUpdateRateResponse

type SetRangingUpdateRateResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*SetRangingUpdateRateResponse) Descriptor deprecated

func (*SetRangingUpdateRateResponse) Descriptor() ([]byte, []int)

Deprecated: Use SetRangingUpdateRateResponse.ProtoReflect.Descriptor instead.

func (*SetRangingUpdateRateResponse) GetResult

func (x *SetRangingUpdateRateResponse) GetResult() int64

func (*SetRangingUpdateRateResponse) ProtoMessage

func (*SetRangingUpdateRateResponse) ProtoMessage()

func (*SetRangingUpdateRateResponse) ProtoReflect

func (*SetRangingUpdateRateResponse) Reset

func (x *SetRangingUpdateRateResponse) Reset()

func (*SetRangingUpdateRateResponse) String

type ToStringRequest

type ToStringRequest struct {
	// contains filtered or unexported fields
}

func (*ToStringRequest) Descriptor deprecated

func (*ToStringRequest) Descriptor() ([]byte, []int)

Deprecated: Use ToStringRequest.ProtoReflect.Descriptor instead.

func (*ToStringRequest) ProtoMessage

func (*ToStringRequest) ProtoMessage()

func (*ToStringRequest) ProtoReflect

func (x *ToStringRequest) ProtoReflect() protoreflect.Message

func (*ToStringRequest) Reset

func (x *ToStringRequest) Reset()

func (*ToStringRequest) String

func (x *ToStringRequest) String() string

type ToStringResponse

type ToStringResponse struct {
	Result string `protobuf:"bytes,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*ToStringResponse) Descriptor deprecated

func (*ToStringResponse) Descriptor() ([]byte, []int)

Deprecated: Use ToStringResponse.ProtoReflect.Descriptor instead.

func (*ToStringResponse) GetResult

func (x *ToStringResponse) GetResult() string

func (*ToStringResponse) ProtoMessage

func (*ToStringResponse) ProtoMessage()

func (*ToStringResponse) ProtoReflect

func (x *ToStringResponse) ProtoReflect() protoreflect.Message

func (*ToStringResponse) Reset

func (x *ToStringResponse) Reset()

func (*ToStringResponse) String

func (x *ToStringResponse) String() string

type UnimplementedRangingCapabilitiesServiceServer

type UnimplementedRangingCapabilitiesServiceServer struct{}

UnimplementedRangingCapabilitiesServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedRangingCapabilitiesServiceServer) DescribeContents

func (UnimplementedRangingCapabilitiesServiceServer) ToString

func (UnimplementedRangingCapabilitiesServiceServer) WriteToParcel

type UnimplementedRangingParamsBuilderServiceServer

type UnimplementedRangingParamsBuilderServiceServer struct{}

UnimplementedRangingParamsBuilderServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedRangingParamsBuilderServiceServer) Build

func (UnimplementedRangingParamsBuilderServiceServer) SetMatchFilter

func (UnimplementedRangingParamsBuilderServiceServer) SetRangingUpdateRate

type UnimplementedRangingParamsServiceServer

type UnimplementedRangingParamsServiceServer struct{}

UnimplementedRangingParamsServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedRangingParamsServiceServer) DescribeContents

func (UnimplementedRangingParamsServiceServer) Equals

func (UnimplementedRangingParamsServiceServer) GetMatchFilter

func (UnimplementedRangingParamsServiceServer) GetRangingUpdateRate

func (UnimplementedRangingParamsServiceServer) GetServiceName

func (UnimplementedRangingParamsServiceServer) HashCode

func (UnimplementedRangingParamsServiceServer) ToString

func (UnimplementedRangingParamsServiceServer) WriteToParcel

type UnsafeRangingCapabilitiesServiceServer

type UnsafeRangingCapabilitiesServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeRangingCapabilitiesServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to RangingCapabilitiesServiceServer will result in compilation errors.

type UnsafeRangingParamsBuilderServiceServer

type UnsafeRangingParamsBuilderServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeRangingParamsBuilderServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to RangingParamsBuilderServiceServer will result in compilation errors.

type UnsafeRangingParamsServiceServer

type UnsafeRangingParamsServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeRangingParamsServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to RangingParamsServiceServer will result in compilation errors.

type WriteToParcelRequest

type WriteToParcelRequest struct {
	Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	Arg1 int32 `protobuf:"varint,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
	// contains filtered or unexported fields
}

func (*WriteToParcelRequest) Descriptor deprecated

func (*WriteToParcelRequest) Descriptor() ([]byte, []int)

Deprecated: Use WriteToParcelRequest.ProtoReflect.Descriptor instead.

func (*WriteToParcelRequest) GetArg0

func (x *WriteToParcelRequest) GetArg0() int64

func (*WriteToParcelRequest) GetArg1

func (x *WriteToParcelRequest) GetArg1() int32

func (*WriteToParcelRequest) ProtoMessage

func (*WriteToParcelRequest) ProtoMessage()

func (*WriteToParcelRequest) ProtoReflect

func (x *WriteToParcelRequest) ProtoReflect() protoreflect.Message

func (*WriteToParcelRequest) Reset

func (x *WriteToParcelRequest) Reset()

func (*WriteToParcelRequest) String

func (x *WriteToParcelRequest) String() string

type WriteToParcelResponse

type WriteToParcelResponse struct {
	// contains filtered or unexported fields
}

func (*WriteToParcelResponse) Descriptor deprecated

func (*WriteToParcelResponse) Descriptor() ([]byte, []int)

Deprecated: Use WriteToParcelResponse.ProtoReflect.Descriptor instead.

func (*WriteToParcelResponse) ProtoMessage

func (*WriteToParcelResponse) ProtoMessage()

func (*WriteToParcelResponse) ProtoReflect

func (x *WriteToParcelResponse) ProtoReflect() protoreflect.Message

func (*WriteToParcelResponse) Reset

func (x *WriteToParcelResponse) Reset()

func (*WriteToParcelResponse) String

func (x *WriteToParcelResponse) String() string

Jump to