sax

package
v0.0.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 29, 2026 License: CC0-1.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

const (
	ElementService_GetChild1_FullMethodName                 = "/sax.ElementService/GetChild1"
	ElementService_GetChild2_1_FullMethodName               = "/sax.ElementService/GetChild2_1"
	ElementService_RequireChild1_FullMethodName             = "/sax.ElementService/RequireChild1"
	ElementService_RequireChild2_1_FullMethodName           = "/sax.ElementService/RequireChild2_1"
	ElementService_SetElementListener_FullMethodName        = "/sax.ElementService/SetElementListener"
	ElementService_SetEndElementListener_FullMethodName     = "/sax.ElementService/SetEndElementListener"
	ElementService_SetEndTextElementListener_FullMethodName = "/sax.ElementService/SetEndTextElementListener"
	ElementService_SetStartElementListener_FullMethodName   = "/sax.ElementService/SetStartElementListener"
	ElementService_SetTextElementListener_FullMethodName    = "/sax.ElementService/SetTextElementListener"
	ElementService_ToString_FullMethodName                  = "/sax.ElementService/ToString"
)
const (
	RootElementService_NewRootElement_FullMethodName    = "/sax.RootElementService/NewRootElement"
	RootElementService_GetContentHandler_FullMethodName = "/sax.RootElementService/GetContentHandler"
)
const (
	EndElementListenerService_End_FullMethodName = "/sax.EndElementListenerService/End"
)
const (
	EndTextElementListenerService_End_FullMethodName = "/sax.EndTextElementListenerService/End"
)
const (
	StartElementListenerService_Start_FullMethodName = "/sax.StartElementListenerService/Start"
)

Variables

var ElementService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "sax.ElementService",
	HandlerType: (*ElementServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "GetChild1",
			Handler:    _ElementService_GetChild1_Handler,
		},
		{
			MethodName: "GetChild2_1",
			Handler:    _ElementService_GetChild2_1_Handler,
		},
		{
			MethodName: "RequireChild1",
			Handler:    _ElementService_RequireChild1_Handler,
		},
		{
			MethodName: "RequireChild2_1",
			Handler:    _ElementService_RequireChild2_1_Handler,
		},
		{
			MethodName: "SetElementListener",
			Handler:    _ElementService_SetElementListener_Handler,
		},
		{
			MethodName: "SetEndElementListener",
			Handler:    _ElementService_SetEndElementListener_Handler,
		},
		{
			MethodName: "SetEndTextElementListener",
			Handler:    _ElementService_SetEndTextElementListener_Handler,
		},
		{
			MethodName: "SetStartElementListener",
			Handler:    _ElementService_SetStartElementListener_Handler,
		},
		{
			MethodName: "SetTextElementListener",
			Handler:    _ElementService_SetTextElementListener_Handler,
		},
		{
			MethodName: "ToString",
			Handler:    _ElementService_ToString_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/sax/sax.proto",
}

ElementService_ServiceDesc is the grpc.ServiceDesc for ElementService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var EndElementListenerService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "sax.EndElementListenerService",
	HandlerType: (*EndElementListenerServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "End",
			Handler:    _EndElementListenerService_End_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/sax/sax.proto",
}

EndElementListenerService_ServiceDesc is the grpc.ServiceDesc for EndElementListenerService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var EndTextElementListenerService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "sax.EndTextElementListenerService",
	HandlerType: (*EndTextElementListenerServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "End",
			Handler:    _EndTextElementListenerService_End_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/sax/sax.proto",
}

EndTextElementListenerService_ServiceDesc is the grpc.ServiceDesc for EndTextElementListenerService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var File_proto_sax_sax_proto protoreflect.FileDescriptor
var RootElementService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "sax.RootElementService",
	HandlerType: (*RootElementServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "NewRootElement",
			Handler:    _RootElementService_NewRootElement_Handler,
		},
		{
			MethodName: "GetContentHandler",
			Handler:    _RootElementService_GetContentHandler_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/sax/sax.proto",
}

RootElementService_ServiceDesc is the grpc.ServiceDesc for RootElementService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var StartElementListenerService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "sax.StartElementListenerService",
	HandlerType: (*StartElementListenerServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "Start",
			Handler:    _StartElementListenerService_Start_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/sax/sax.proto",
}

StartElementListenerService_ServiceDesc is the grpc.ServiceDesc for StartElementListenerService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterElementServiceServer

func RegisterElementServiceServer(s grpc.ServiceRegistrar, srv ElementServiceServer)

func RegisterEndElementListenerServiceServer

func RegisterEndElementListenerServiceServer(s grpc.ServiceRegistrar, srv EndElementListenerServiceServer)

func RegisterEndTextElementListenerServiceServer

func RegisterEndTextElementListenerServiceServer(s grpc.ServiceRegistrar, srv EndTextElementListenerServiceServer)

func RegisterRootElementServiceServer

func RegisterRootElementServiceServer(s grpc.ServiceRegistrar, srv RootElementServiceServer)

func RegisterStartElementListenerServiceServer

func RegisterStartElementListenerServiceServer(s grpc.ServiceRegistrar, srv StartElementListenerServiceServer)

Types

type ElementServiceClient

ElementServiceClient is the client API for ElementService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type ElementServiceServer

ElementServiceServer is the server API for ElementService service. All implementations must embed UnimplementedElementServiceServer for forward compatibility.

type EndElementListenerServiceClient

type EndElementListenerServiceClient interface {
	End(ctx context.Context, in *EndRequest, opts ...grpc.CallOption) (*EndResponse, error)
}

EndElementListenerServiceClient is the client API for EndElementListenerService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type EndElementListenerServiceServer

type EndElementListenerServiceServer interface {
	End(context.Context, *EndRequest) (*EndResponse, error)
	// contains filtered or unexported methods
}

EndElementListenerServiceServer is the server API for EndElementListenerService service. All implementations must embed UnimplementedEndElementListenerServiceServer for forward compatibility.

type EndRequest

type EndRequest struct {
	// contains filtered or unexported fields
}

func (*EndRequest) Descriptor deprecated

func (*EndRequest) Descriptor() ([]byte, []int)

Deprecated: Use EndRequest.ProtoReflect.Descriptor instead.

func (*EndRequest) ProtoMessage

func (*EndRequest) ProtoMessage()

func (*EndRequest) ProtoReflect

func (x *EndRequest) ProtoReflect() protoreflect.Message

func (*EndRequest) Reset

func (x *EndRequest) Reset()

func (*EndRequest) String

func (x *EndRequest) String() string

type EndResponse

type EndResponse struct {
	// contains filtered or unexported fields
}

func (*EndResponse) Descriptor deprecated

func (*EndResponse) Descriptor() ([]byte, []int)

Deprecated: Use EndResponse.ProtoReflect.Descriptor instead.

func (*EndResponse) ProtoMessage

func (*EndResponse) ProtoMessage()

func (*EndResponse) ProtoReflect

func (x *EndResponse) ProtoReflect() protoreflect.Message

func (*EndResponse) Reset

func (x *EndResponse) Reset()

func (*EndResponse) String

func (x *EndResponse) String() string

type EndTextElementListenerEndRequest

type EndTextElementListenerEndRequest struct {
	Arg0 string `protobuf:"bytes,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*EndTextElementListenerEndRequest) Descriptor deprecated

func (*EndTextElementListenerEndRequest) Descriptor() ([]byte, []int)

Deprecated: Use EndTextElementListenerEndRequest.ProtoReflect.Descriptor instead.

func (*EndTextElementListenerEndRequest) GetArg0

func (*EndTextElementListenerEndRequest) ProtoMessage

func (*EndTextElementListenerEndRequest) ProtoMessage()

func (*EndTextElementListenerEndRequest) ProtoReflect

func (*EndTextElementListenerEndRequest) Reset

func (*EndTextElementListenerEndRequest) String

type EndTextElementListenerServiceClient

type EndTextElementListenerServiceClient interface {
	End(ctx context.Context, in *EndTextElementListenerEndRequest, opts ...grpc.CallOption) (*EndResponse, error)
}

EndTextElementListenerServiceClient is the client API for EndTextElementListenerService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type EndTextElementListenerServiceServer

type EndTextElementListenerServiceServer interface {
	End(context.Context, *EndTextElementListenerEndRequest) (*EndResponse, error)
	// contains filtered or unexported methods
}

EndTextElementListenerServiceServer is the server API for EndTextElementListenerService service. All implementations must embed UnimplementedEndTextElementListenerServiceServer for forward compatibility.

type GetChild1Request

type GetChild1Request struct {
	Arg0 string `protobuf:"bytes,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*GetChild1Request) Descriptor deprecated

func (*GetChild1Request) Descriptor() ([]byte, []int)

Deprecated: Use GetChild1Request.ProtoReflect.Descriptor instead.

func (*GetChild1Request) GetArg0

func (x *GetChild1Request) GetArg0() string

func (*GetChild1Request) ProtoMessage

func (*GetChild1Request) ProtoMessage()

func (*GetChild1Request) ProtoReflect

func (x *GetChild1Request) ProtoReflect() protoreflect.Message

func (*GetChild1Request) Reset

func (x *GetChild1Request) Reset()

func (*GetChild1Request) String

func (x *GetChild1Request) String() string

type GetChild1Response

type GetChild1Response struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetChild1Response) Descriptor deprecated

func (*GetChild1Response) Descriptor() ([]byte, []int)

Deprecated: Use GetChild1Response.ProtoReflect.Descriptor instead.

func (*GetChild1Response) GetResult

func (x *GetChild1Response) GetResult() int64

func (*GetChild1Response) ProtoMessage

func (*GetChild1Response) ProtoMessage()

func (*GetChild1Response) ProtoReflect

func (x *GetChild1Response) ProtoReflect() protoreflect.Message

func (*GetChild1Response) Reset

func (x *GetChild1Response) Reset()

func (*GetChild1Response) String

func (x *GetChild1Response) String() string

type GetChild2_1Request

type GetChild2_1Request struct {
	Arg0 string `protobuf:"bytes,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	Arg1 string `protobuf:"bytes,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
	// contains filtered or unexported fields
}

func (*GetChild2_1Request) Descriptor deprecated

func (*GetChild2_1Request) Descriptor() ([]byte, []int)

Deprecated: Use GetChild2_1Request.ProtoReflect.Descriptor instead.

func (*GetChild2_1Request) GetArg0

func (x *GetChild2_1Request) GetArg0() string

func (*GetChild2_1Request) GetArg1

func (x *GetChild2_1Request) GetArg1() string

func (*GetChild2_1Request) ProtoMessage

func (*GetChild2_1Request) ProtoMessage()

func (*GetChild2_1Request) ProtoReflect

func (x *GetChild2_1Request) ProtoReflect() protoreflect.Message

func (*GetChild2_1Request) Reset

func (x *GetChild2_1Request) Reset()

func (*GetChild2_1Request) String

func (x *GetChild2_1Request) String() string

type GetChild2_1Response

type GetChild2_1Response struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetChild2_1Response) Descriptor deprecated

func (*GetChild2_1Response) Descriptor() ([]byte, []int)

Deprecated: Use GetChild2_1Response.ProtoReflect.Descriptor instead.

func (*GetChild2_1Response) GetResult

func (x *GetChild2_1Response) GetResult() int64

func (*GetChild2_1Response) ProtoMessage

func (*GetChild2_1Response) ProtoMessage()

func (*GetChild2_1Response) ProtoReflect

func (x *GetChild2_1Response) ProtoReflect() protoreflect.Message

func (*GetChild2_1Response) Reset

func (x *GetChild2_1Response) Reset()

func (*GetChild2_1Response) String

func (x *GetChild2_1Response) String() string

type GetContentHandlerRequest

type GetContentHandlerRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	// contains filtered or unexported fields
}

func (*GetContentHandlerRequest) Descriptor deprecated

func (*GetContentHandlerRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetContentHandlerRequest.ProtoReflect.Descriptor instead.

func (*GetContentHandlerRequest) GetHandle

func (x *GetContentHandlerRequest) GetHandle() int64

func (*GetContentHandlerRequest) ProtoMessage

func (*GetContentHandlerRequest) ProtoMessage()

func (*GetContentHandlerRequest) ProtoReflect

func (x *GetContentHandlerRequest) ProtoReflect() protoreflect.Message

func (*GetContentHandlerRequest) Reset

func (x *GetContentHandlerRequest) Reset()

func (*GetContentHandlerRequest) String

func (x *GetContentHandlerRequest) String() string

type GetContentHandlerResponse

type GetContentHandlerResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetContentHandlerResponse) Descriptor deprecated

func (*GetContentHandlerResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetContentHandlerResponse.ProtoReflect.Descriptor instead.

func (*GetContentHandlerResponse) GetResult

func (x *GetContentHandlerResponse) GetResult() int64

func (*GetContentHandlerResponse) ProtoMessage

func (*GetContentHandlerResponse) ProtoMessage()

func (*GetContentHandlerResponse) ProtoReflect

func (*GetContentHandlerResponse) Reset

func (x *GetContentHandlerResponse) Reset()

func (*GetContentHandlerResponse) String

func (x *GetContentHandlerResponse) String() string

type NewRootElementRequest

type NewRootElementRequest struct {
	Arg0 string `protobuf:"bytes,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*NewRootElementRequest) Descriptor deprecated

func (*NewRootElementRequest) Descriptor() ([]byte, []int)

Deprecated: Use NewRootElementRequest.ProtoReflect.Descriptor instead.

func (*NewRootElementRequest) GetArg0

func (x *NewRootElementRequest) GetArg0() string

func (*NewRootElementRequest) ProtoMessage

func (*NewRootElementRequest) ProtoMessage()

func (*NewRootElementRequest) ProtoReflect

func (x *NewRootElementRequest) ProtoReflect() protoreflect.Message

func (*NewRootElementRequest) Reset

func (x *NewRootElementRequest) Reset()

func (*NewRootElementRequest) String

func (x *NewRootElementRequest) String() string

type NewRootElementResponse

type NewRootElementResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*NewRootElementResponse) Descriptor deprecated

func (*NewRootElementResponse) Descriptor() ([]byte, []int)

Deprecated: Use NewRootElementResponse.ProtoReflect.Descriptor instead.

func (*NewRootElementResponse) GetResult

func (x *NewRootElementResponse) GetResult() int64

func (*NewRootElementResponse) ProtoMessage

func (*NewRootElementResponse) ProtoMessage()

func (*NewRootElementResponse) ProtoReflect

func (x *NewRootElementResponse) ProtoReflect() protoreflect.Message

func (*NewRootElementResponse) Reset

func (x *NewRootElementResponse) Reset()

func (*NewRootElementResponse) String

func (x *NewRootElementResponse) String() string

type RequireChild1Request

type RequireChild1Request struct {
	Arg0 string `protobuf:"bytes,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*RequireChild1Request) Descriptor deprecated

func (*RequireChild1Request) Descriptor() ([]byte, []int)

Deprecated: Use RequireChild1Request.ProtoReflect.Descriptor instead.

func (*RequireChild1Request) GetArg0

func (x *RequireChild1Request) GetArg0() string

func (*RequireChild1Request) ProtoMessage

func (*RequireChild1Request) ProtoMessage()

func (*RequireChild1Request) ProtoReflect

func (x *RequireChild1Request) ProtoReflect() protoreflect.Message

func (*RequireChild1Request) Reset

func (x *RequireChild1Request) Reset()

func (*RequireChild1Request) String

func (x *RequireChild1Request) String() string

type RequireChild1Response

type RequireChild1Response struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*RequireChild1Response) Descriptor deprecated

func (*RequireChild1Response) Descriptor() ([]byte, []int)

Deprecated: Use RequireChild1Response.ProtoReflect.Descriptor instead.

func (*RequireChild1Response) GetResult

func (x *RequireChild1Response) GetResult() int64

func (*RequireChild1Response) ProtoMessage

func (*RequireChild1Response) ProtoMessage()

func (*RequireChild1Response) ProtoReflect

func (x *RequireChild1Response) ProtoReflect() protoreflect.Message

func (*RequireChild1Response) Reset

func (x *RequireChild1Response) Reset()

func (*RequireChild1Response) String

func (x *RequireChild1Response) String() string

type RequireChild2_1Request

type RequireChild2_1Request struct {
	Arg0 string `protobuf:"bytes,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	Arg1 string `protobuf:"bytes,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
	// contains filtered or unexported fields
}

func (*RequireChild2_1Request) Descriptor deprecated

func (*RequireChild2_1Request) Descriptor() ([]byte, []int)

Deprecated: Use RequireChild2_1Request.ProtoReflect.Descriptor instead.

func (*RequireChild2_1Request) GetArg0

func (x *RequireChild2_1Request) GetArg0() string

func (*RequireChild2_1Request) GetArg1

func (x *RequireChild2_1Request) GetArg1() string

func (*RequireChild2_1Request) ProtoMessage

func (*RequireChild2_1Request) ProtoMessage()

func (*RequireChild2_1Request) ProtoReflect

func (x *RequireChild2_1Request) ProtoReflect() protoreflect.Message

func (*RequireChild2_1Request) Reset

func (x *RequireChild2_1Request) Reset()

func (*RequireChild2_1Request) String

func (x *RequireChild2_1Request) String() string

type RequireChild2_1Response

type RequireChild2_1Response struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*RequireChild2_1Response) Descriptor deprecated

func (*RequireChild2_1Response) Descriptor() ([]byte, []int)

Deprecated: Use RequireChild2_1Response.ProtoReflect.Descriptor instead.

func (*RequireChild2_1Response) GetResult

func (x *RequireChild2_1Response) GetResult() int64

func (*RequireChild2_1Response) ProtoMessage

func (*RequireChild2_1Response) ProtoMessage()

func (*RequireChild2_1Response) ProtoReflect

func (x *RequireChild2_1Response) ProtoReflect() protoreflect.Message

func (*RequireChild2_1Response) Reset

func (x *RequireChild2_1Response) Reset()

func (*RequireChild2_1Response) String

func (x *RequireChild2_1Response) String() string

type RootElementServiceClient

type RootElementServiceClient interface {
	NewRootElement(ctx context.Context, in *NewRootElementRequest, opts ...grpc.CallOption) (*NewRootElementResponse, error)
	GetContentHandler(ctx context.Context, in *GetContentHandlerRequest, opts ...grpc.CallOption) (*GetContentHandlerResponse, error)
}

RootElementServiceClient is the client API for RootElementService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type RootElementServiceServer

type RootElementServiceServer interface {
	NewRootElement(context.Context, *NewRootElementRequest) (*NewRootElementResponse, error)
	GetContentHandler(context.Context, *GetContentHandlerRequest) (*GetContentHandlerResponse, error)
	// contains filtered or unexported methods
}

RootElementServiceServer is the server API for RootElementService service. All implementations must embed UnimplementedRootElementServiceServer for forward compatibility.

type SetElementListenerRequest

type SetElementListenerRequest struct {
	Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*SetElementListenerRequest) Descriptor deprecated

func (*SetElementListenerRequest) Descriptor() ([]byte, []int)

Deprecated: Use SetElementListenerRequest.ProtoReflect.Descriptor instead.

func (*SetElementListenerRequest) GetArg0

func (x *SetElementListenerRequest) GetArg0() int64

func (*SetElementListenerRequest) ProtoMessage

func (*SetElementListenerRequest) ProtoMessage()

func (*SetElementListenerRequest) ProtoReflect

func (*SetElementListenerRequest) Reset

func (x *SetElementListenerRequest) Reset()

func (*SetElementListenerRequest) String

func (x *SetElementListenerRequest) String() string

type SetElementListenerResponse

type SetElementListenerResponse struct {
	// contains filtered or unexported fields
}

func (*SetElementListenerResponse) Descriptor deprecated

func (*SetElementListenerResponse) Descriptor() ([]byte, []int)

Deprecated: Use SetElementListenerResponse.ProtoReflect.Descriptor instead.

func (*SetElementListenerResponse) ProtoMessage

func (*SetElementListenerResponse) ProtoMessage()

func (*SetElementListenerResponse) ProtoReflect

func (*SetElementListenerResponse) Reset

func (x *SetElementListenerResponse) Reset()

func (*SetElementListenerResponse) String

func (x *SetElementListenerResponse) String() string

type SetEndElementListenerRequest

type SetEndElementListenerRequest struct {
	Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*SetEndElementListenerRequest) Descriptor deprecated

func (*SetEndElementListenerRequest) Descriptor() ([]byte, []int)

Deprecated: Use SetEndElementListenerRequest.ProtoReflect.Descriptor instead.

func (*SetEndElementListenerRequest) GetArg0

func (x *SetEndElementListenerRequest) GetArg0() int64

func (*SetEndElementListenerRequest) ProtoMessage

func (*SetEndElementListenerRequest) ProtoMessage()

func (*SetEndElementListenerRequest) ProtoReflect

func (*SetEndElementListenerRequest) Reset

func (x *SetEndElementListenerRequest) Reset()

func (*SetEndElementListenerRequest) String

type SetEndElementListenerResponse

type SetEndElementListenerResponse struct {
	// contains filtered or unexported fields
}

func (*SetEndElementListenerResponse) Descriptor deprecated

func (*SetEndElementListenerResponse) Descriptor() ([]byte, []int)

Deprecated: Use SetEndElementListenerResponse.ProtoReflect.Descriptor instead.

func (*SetEndElementListenerResponse) ProtoMessage

func (*SetEndElementListenerResponse) ProtoMessage()

func (*SetEndElementListenerResponse) ProtoReflect

func (*SetEndElementListenerResponse) Reset

func (x *SetEndElementListenerResponse) Reset()

func (*SetEndElementListenerResponse) String

type SetEndTextElementListenerRequest

type SetEndTextElementListenerRequest struct {
	Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*SetEndTextElementListenerRequest) Descriptor deprecated

func (*SetEndTextElementListenerRequest) Descriptor() ([]byte, []int)

Deprecated: Use SetEndTextElementListenerRequest.ProtoReflect.Descriptor instead.

func (*SetEndTextElementListenerRequest) GetArg0

func (*SetEndTextElementListenerRequest) ProtoMessage

func (*SetEndTextElementListenerRequest) ProtoMessage()

func (*SetEndTextElementListenerRequest) ProtoReflect

func (*SetEndTextElementListenerRequest) Reset

func (*SetEndTextElementListenerRequest) String

type SetEndTextElementListenerResponse

type SetEndTextElementListenerResponse struct {
	// contains filtered or unexported fields
}

func (*SetEndTextElementListenerResponse) Descriptor deprecated

func (*SetEndTextElementListenerResponse) Descriptor() ([]byte, []int)

Deprecated: Use SetEndTextElementListenerResponse.ProtoReflect.Descriptor instead.

func (*SetEndTextElementListenerResponse) ProtoMessage

func (*SetEndTextElementListenerResponse) ProtoMessage()

func (*SetEndTextElementListenerResponse) ProtoReflect

func (*SetEndTextElementListenerResponse) Reset

func (*SetEndTextElementListenerResponse) String

type SetStartElementListenerRequest

type SetStartElementListenerRequest struct {
	Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*SetStartElementListenerRequest) Descriptor deprecated

func (*SetStartElementListenerRequest) Descriptor() ([]byte, []int)

Deprecated: Use SetStartElementListenerRequest.ProtoReflect.Descriptor instead.

func (*SetStartElementListenerRequest) GetArg0

func (*SetStartElementListenerRequest) ProtoMessage

func (*SetStartElementListenerRequest) ProtoMessage()

func (*SetStartElementListenerRequest) ProtoReflect

func (*SetStartElementListenerRequest) Reset

func (x *SetStartElementListenerRequest) Reset()

func (*SetStartElementListenerRequest) String

type SetStartElementListenerResponse

type SetStartElementListenerResponse struct {
	// contains filtered or unexported fields
}

func (*SetStartElementListenerResponse) Descriptor deprecated

func (*SetStartElementListenerResponse) Descriptor() ([]byte, []int)

Deprecated: Use SetStartElementListenerResponse.ProtoReflect.Descriptor instead.

func (*SetStartElementListenerResponse) ProtoMessage

func (*SetStartElementListenerResponse) ProtoMessage()

func (*SetStartElementListenerResponse) ProtoReflect

func (*SetStartElementListenerResponse) Reset

func (*SetStartElementListenerResponse) String

type SetTextElementListenerRequest

type SetTextElementListenerRequest struct {
	Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*SetTextElementListenerRequest) Descriptor deprecated

func (*SetTextElementListenerRequest) Descriptor() ([]byte, []int)

Deprecated: Use SetTextElementListenerRequest.ProtoReflect.Descriptor instead.

func (*SetTextElementListenerRequest) GetArg0

func (x *SetTextElementListenerRequest) GetArg0() int64

func (*SetTextElementListenerRequest) ProtoMessage

func (*SetTextElementListenerRequest) ProtoMessage()

func (*SetTextElementListenerRequest) ProtoReflect

func (*SetTextElementListenerRequest) Reset

func (x *SetTextElementListenerRequest) Reset()

func (*SetTextElementListenerRequest) String

type SetTextElementListenerResponse

type SetTextElementListenerResponse struct {
	// contains filtered or unexported fields
}

func (*SetTextElementListenerResponse) Descriptor deprecated

func (*SetTextElementListenerResponse) Descriptor() ([]byte, []int)

Deprecated: Use SetTextElementListenerResponse.ProtoReflect.Descriptor instead.

func (*SetTextElementListenerResponse) ProtoMessage

func (*SetTextElementListenerResponse) ProtoMessage()

func (*SetTextElementListenerResponse) ProtoReflect

func (*SetTextElementListenerResponse) Reset

func (x *SetTextElementListenerResponse) Reset()

func (*SetTextElementListenerResponse) String

type StartElementListenerServiceClient

type StartElementListenerServiceClient interface {
	Start(ctx context.Context, in *StartRequest, opts ...grpc.CallOption) (*StartResponse, error)
}

StartElementListenerServiceClient is the client API for StartElementListenerService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type StartElementListenerServiceServer

type StartElementListenerServiceServer interface {
	Start(context.Context, *StartRequest) (*StartResponse, error)
	// contains filtered or unexported methods
}

StartElementListenerServiceServer is the server API for StartElementListenerService service. All implementations must embed UnimplementedStartElementListenerServiceServer for forward compatibility.

type StartRequest

type StartRequest struct {
	Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*StartRequest) Descriptor deprecated

func (*StartRequest) Descriptor() ([]byte, []int)

Deprecated: Use StartRequest.ProtoReflect.Descriptor instead.

func (*StartRequest) GetArg0

func (x *StartRequest) GetArg0() int64

func (*StartRequest) ProtoMessage

func (*StartRequest) ProtoMessage()

func (*StartRequest) ProtoReflect

func (x *StartRequest) ProtoReflect() protoreflect.Message

func (*StartRequest) Reset

func (x *StartRequest) Reset()

func (*StartRequest) String

func (x *StartRequest) String() string

type StartResponse

type StartResponse struct {
	// contains filtered or unexported fields
}

func (*StartResponse) Descriptor deprecated

func (*StartResponse) Descriptor() ([]byte, []int)

Deprecated: Use StartResponse.ProtoReflect.Descriptor instead.

func (*StartResponse) ProtoMessage

func (*StartResponse) ProtoMessage()

func (*StartResponse) ProtoReflect

func (x *StartResponse) ProtoReflect() protoreflect.Message

func (*StartResponse) Reset

func (x *StartResponse) Reset()

func (*StartResponse) String

func (x *StartResponse) String() string

type ToStringRequest

type ToStringRequest struct {
	// contains filtered or unexported fields
}

func (*ToStringRequest) Descriptor deprecated

func (*ToStringRequest) Descriptor() ([]byte, []int)

Deprecated: Use ToStringRequest.ProtoReflect.Descriptor instead.

func (*ToStringRequest) ProtoMessage

func (*ToStringRequest) ProtoMessage()

func (*ToStringRequest) ProtoReflect

func (x *ToStringRequest) ProtoReflect() protoreflect.Message

func (*ToStringRequest) Reset

func (x *ToStringRequest) Reset()

func (*ToStringRequest) String

func (x *ToStringRequest) String() string

type ToStringResponse

type ToStringResponse struct {
	Result string `protobuf:"bytes,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*ToStringResponse) Descriptor deprecated

func (*ToStringResponse) Descriptor() ([]byte, []int)

Deprecated: Use ToStringResponse.ProtoReflect.Descriptor instead.

func (*ToStringResponse) GetResult

func (x *ToStringResponse) GetResult() string

func (*ToStringResponse) ProtoMessage

func (*ToStringResponse) ProtoMessage()

func (*ToStringResponse) ProtoReflect

func (x *ToStringResponse) ProtoReflect() protoreflect.Message

func (*ToStringResponse) Reset

func (x *ToStringResponse) Reset()

func (*ToStringResponse) String

func (x *ToStringResponse) String() string

type UnimplementedElementServiceServer

type UnimplementedElementServiceServer struct{}

UnimplementedElementServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedElementServiceServer) GetChild1

func (UnimplementedElementServiceServer) GetChild2_1

func (UnimplementedElementServiceServer) RequireChild1

func (UnimplementedElementServiceServer) RequireChild2_1

func (UnimplementedElementServiceServer) SetElementListener

func (UnimplementedElementServiceServer) ToString

type UnimplementedEndElementListenerServiceServer

type UnimplementedEndElementListenerServiceServer struct{}

UnimplementedEndElementListenerServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedEndElementListenerServiceServer) End

type UnimplementedEndTextElementListenerServiceServer

type UnimplementedEndTextElementListenerServiceServer struct{}

UnimplementedEndTextElementListenerServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedEndTextElementListenerServiceServer) End

type UnimplementedRootElementServiceServer

type UnimplementedRootElementServiceServer struct{}

UnimplementedRootElementServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedRootElementServiceServer) GetContentHandler

func (UnimplementedRootElementServiceServer) NewRootElement

type UnimplementedStartElementListenerServiceServer

type UnimplementedStartElementListenerServiceServer struct{}

UnimplementedStartElementListenerServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedStartElementListenerServiceServer) Start

type UnsafeElementServiceServer

type UnsafeElementServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeElementServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ElementServiceServer will result in compilation errors.

type UnsafeEndElementListenerServiceServer

type UnsafeEndElementListenerServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeEndElementListenerServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to EndElementListenerServiceServer will result in compilation errors.

type UnsafeEndTextElementListenerServiceServer

type UnsafeEndTextElementListenerServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeEndTextElementListenerServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to EndTextElementListenerServiceServer will result in compilation errors.

type UnsafeRootElementServiceServer

type UnsafeRootElementServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeRootElementServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to RootElementServiceServer will result in compilation errors.

type UnsafeStartElementListenerServiceServer

type UnsafeStartElementListenerServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeStartElementListenerServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to StartElementListenerServiceServer will result in compilation errors.

Jump to