selection

package
v0.0.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 29, 2026 License: CC0-1.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

const (
	PageSelectionService_NewPageSelection_FullMethodName        = "/selection.PageSelectionService/NewPageSelection"
	PageSelectionService_DescribeContents_FullMethodName        = "/selection.PageSelectionService/DescribeContents"
	PageSelectionService_GetPage_FullMethodName                 = "/selection.PageSelectionService/GetPage"
	PageSelectionService_GetSelectedTextContents_FullMethodName = "/selection.PageSelectionService/GetSelectedTextContents"
	PageSelectionService_GetStart_FullMethodName                = "/selection.PageSelectionService/GetStart"
	PageSelectionService_GetStop_FullMethodName                 = "/selection.PageSelectionService/GetStop"
	PageSelectionService_WriteToParcel_FullMethodName           = "/selection.PageSelectionService/WriteToParcel"
)
const (
	BoundaryService_NewBoundary_FullMethodName      = "/selection.BoundaryService/NewBoundary"
	BoundaryService_DescribeContents_FullMethodName = "/selection.BoundaryService/DescribeContents"
	BoundaryService_GetIndex_FullMethodName         = "/selection.BoundaryService/GetIndex"
	BoundaryService_GetIsRtl_FullMethodName         = "/selection.BoundaryService/GetIsRtl"
	BoundaryService_GetPoint_FullMethodName         = "/selection.BoundaryService/GetPoint"
	BoundaryService_WriteToParcel_FullMethodName    = "/selection.BoundaryService/WriteToParcel"
)

Variables

var BoundaryService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "selection.BoundaryService",
	HandlerType: (*BoundaryServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "NewBoundary",
			Handler:    _BoundaryService_NewBoundary_Handler,
		},
		{
			MethodName: "DescribeContents",
			Handler:    _BoundaryService_DescribeContents_Handler,
		},
		{
			MethodName: "GetIndex",
			Handler:    _BoundaryService_GetIndex_Handler,
		},
		{
			MethodName: "GetIsRtl",
			Handler:    _BoundaryService_GetIsRtl_Handler,
		},
		{
			MethodName: "GetPoint",
			Handler:    _BoundaryService_GetPoint_Handler,
		},
		{
			MethodName: "WriteToParcel",
			Handler:    _BoundaryService_WriteToParcel_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/selection/selection.proto",
}

BoundaryService_ServiceDesc is the grpc.ServiceDesc for BoundaryService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var File_proto_selection_selection_proto protoreflect.FileDescriptor
var PageSelectionService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "selection.PageSelectionService",
	HandlerType: (*PageSelectionServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "NewPageSelection",
			Handler:    _PageSelectionService_NewPageSelection_Handler,
		},
		{
			MethodName: "DescribeContents",
			Handler:    _PageSelectionService_DescribeContents_Handler,
		},
		{
			MethodName: "GetPage",
			Handler:    _PageSelectionService_GetPage_Handler,
		},
		{
			MethodName: "GetSelectedTextContents",
			Handler:    _PageSelectionService_GetSelectedTextContents_Handler,
		},
		{
			MethodName: "GetStart",
			Handler:    _PageSelectionService_GetStart_Handler,
		},
		{
			MethodName: "GetStop",
			Handler:    _PageSelectionService_GetStop_Handler,
		},
		{
			MethodName: "WriteToParcel",
			Handler:    _PageSelectionService_WriteToParcel_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/selection/selection.proto",
}

PageSelectionService_ServiceDesc is the grpc.ServiceDesc for PageSelectionService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterBoundaryServiceServer

func RegisterBoundaryServiceServer(s grpc.ServiceRegistrar, srv BoundaryServiceServer)

func RegisterPageSelectionServiceServer

func RegisterPageSelectionServiceServer(s grpc.ServiceRegistrar, srv PageSelectionServiceServer)

Types

type BoundaryServiceClient

type BoundaryServiceClient interface {
	NewBoundary(ctx context.Context, in *NewBoundaryRequest, opts ...grpc.CallOption) (*NewBoundaryResponse, error)
	DescribeContents(ctx context.Context, in *DescribeContentsRequest, opts ...grpc.CallOption) (*DescribeContentsResponse, error)
	GetIndex(ctx context.Context, in *GetIndexRequest, opts ...grpc.CallOption) (*GetIndexResponse, error)
	GetIsRtl(ctx context.Context, in *GetIsRtlRequest, opts ...grpc.CallOption) (*GetIsRtlResponse, error)
	GetPoint(ctx context.Context, in *GetPointRequest, opts ...grpc.CallOption) (*GetPointResponse, error)
	WriteToParcel(ctx context.Context, in *WriteToParcelRequest, opts ...grpc.CallOption) (*WriteToParcelResponse, error)
}

BoundaryServiceClient is the client API for BoundaryService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type BoundaryServiceServer

type BoundaryServiceServer interface {
	NewBoundary(context.Context, *NewBoundaryRequest) (*NewBoundaryResponse, error)
	DescribeContents(context.Context, *DescribeContentsRequest) (*DescribeContentsResponse, error)
	GetIndex(context.Context, *GetIndexRequest) (*GetIndexResponse, error)
	GetIsRtl(context.Context, *GetIsRtlRequest) (*GetIsRtlResponse, error)
	GetPoint(context.Context, *GetPointRequest) (*GetPointResponse, error)
	WriteToParcel(context.Context, *WriteToParcelRequest) (*WriteToParcelResponse, error)
	// contains filtered or unexported methods
}

BoundaryServiceServer is the server API for BoundaryService service. All implementations must embed UnimplementedBoundaryServiceServer for forward compatibility.

type DescribeContentsRequest

type DescribeContentsRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	// contains filtered or unexported fields
}

func (*DescribeContentsRequest) Descriptor deprecated

func (*DescribeContentsRequest) Descriptor() ([]byte, []int)

Deprecated: Use DescribeContentsRequest.ProtoReflect.Descriptor instead.

func (*DescribeContentsRequest) GetHandle

func (x *DescribeContentsRequest) GetHandle() int64

func (*DescribeContentsRequest) ProtoMessage

func (*DescribeContentsRequest) ProtoMessage()

func (*DescribeContentsRequest) ProtoReflect

func (x *DescribeContentsRequest) ProtoReflect() protoreflect.Message

func (*DescribeContentsRequest) Reset

func (x *DescribeContentsRequest) Reset()

func (*DescribeContentsRequest) String

func (x *DescribeContentsRequest) String() string

type DescribeContentsResponse

type DescribeContentsResponse struct {
	Result int32 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*DescribeContentsResponse) Descriptor deprecated

func (*DescribeContentsResponse) Descriptor() ([]byte, []int)

Deprecated: Use DescribeContentsResponse.ProtoReflect.Descriptor instead.

func (*DescribeContentsResponse) GetResult

func (x *DescribeContentsResponse) GetResult() int32

func (*DescribeContentsResponse) ProtoMessage

func (*DescribeContentsResponse) ProtoMessage()

func (*DescribeContentsResponse) ProtoReflect

func (x *DescribeContentsResponse) ProtoReflect() protoreflect.Message

func (*DescribeContentsResponse) Reset

func (x *DescribeContentsResponse) Reset()

func (*DescribeContentsResponse) String

func (x *DescribeContentsResponse) String() string

type GetIndexRequest

type GetIndexRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	// contains filtered or unexported fields
}

func (*GetIndexRequest) Descriptor deprecated

func (*GetIndexRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetIndexRequest.ProtoReflect.Descriptor instead.

func (*GetIndexRequest) GetHandle

func (x *GetIndexRequest) GetHandle() int64

func (*GetIndexRequest) ProtoMessage

func (*GetIndexRequest) ProtoMessage()

func (*GetIndexRequest) ProtoReflect

func (x *GetIndexRequest) ProtoReflect() protoreflect.Message

func (*GetIndexRequest) Reset

func (x *GetIndexRequest) Reset()

func (*GetIndexRequest) String

func (x *GetIndexRequest) String() string

type GetIndexResponse

type GetIndexResponse struct {
	Result int32 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetIndexResponse) Descriptor deprecated

func (*GetIndexResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetIndexResponse.ProtoReflect.Descriptor instead.

func (*GetIndexResponse) GetResult

func (x *GetIndexResponse) GetResult() int32

func (*GetIndexResponse) ProtoMessage

func (*GetIndexResponse) ProtoMessage()

func (*GetIndexResponse) ProtoReflect

func (x *GetIndexResponse) ProtoReflect() protoreflect.Message

func (*GetIndexResponse) Reset

func (x *GetIndexResponse) Reset()

func (*GetIndexResponse) String

func (x *GetIndexResponse) String() string

type GetIsRtlRequest

type GetIsRtlRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	// contains filtered or unexported fields
}

func (*GetIsRtlRequest) Descriptor deprecated

func (*GetIsRtlRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetIsRtlRequest.ProtoReflect.Descriptor instead.

func (*GetIsRtlRequest) GetHandle

func (x *GetIsRtlRequest) GetHandle() int64

func (*GetIsRtlRequest) ProtoMessage

func (*GetIsRtlRequest) ProtoMessage()

func (*GetIsRtlRequest) ProtoReflect

func (x *GetIsRtlRequest) ProtoReflect() protoreflect.Message

func (*GetIsRtlRequest) Reset

func (x *GetIsRtlRequest) Reset()

func (*GetIsRtlRequest) String

func (x *GetIsRtlRequest) String() string

type GetIsRtlResponse

type GetIsRtlResponse struct {
	Result bool `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetIsRtlResponse) Descriptor deprecated

func (*GetIsRtlResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetIsRtlResponse.ProtoReflect.Descriptor instead.

func (*GetIsRtlResponse) GetResult

func (x *GetIsRtlResponse) GetResult() bool

func (*GetIsRtlResponse) ProtoMessage

func (*GetIsRtlResponse) ProtoMessage()

func (*GetIsRtlResponse) ProtoReflect

func (x *GetIsRtlResponse) ProtoReflect() protoreflect.Message

func (*GetIsRtlResponse) Reset

func (x *GetIsRtlResponse) Reset()

func (*GetIsRtlResponse) String

func (x *GetIsRtlResponse) String() string

type GetPageRequest

type GetPageRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	// contains filtered or unexported fields
}

func (*GetPageRequest) Descriptor deprecated

func (*GetPageRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetPageRequest.ProtoReflect.Descriptor instead.

func (*GetPageRequest) GetHandle

func (x *GetPageRequest) GetHandle() int64

func (*GetPageRequest) ProtoMessage

func (*GetPageRequest) ProtoMessage()

func (*GetPageRequest) ProtoReflect

func (x *GetPageRequest) ProtoReflect() protoreflect.Message

func (*GetPageRequest) Reset

func (x *GetPageRequest) Reset()

func (*GetPageRequest) String

func (x *GetPageRequest) String() string

type GetPageResponse

type GetPageResponse struct {
	Result int32 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetPageResponse) Descriptor deprecated

func (*GetPageResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetPageResponse.ProtoReflect.Descriptor instead.

func (*GetPageResponse) GetResult

func (x *GetPageResponse) GetResult() int32

func (*GetPageResponse) ProtoMessage

func (*GetPageResponse) ProtoMessage()

func (*GetPageResponse) ProtoReflect

func (x *GetPageResponse) ProtoReflect() protoreflect.Message

func (*GetPageResponse) Reset

func (x *GetPageResponse) Reset()

func (*GetPageResponse) String

func (x *GetPageResponse) String() string

type GetPointRequest

type GetPointRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	// contains filtered or unexported fields
}

func (*GetPointRequest) Descriptor deprecated

func (*GetPointRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetPointRequest.ProtoReflect.Descriptor instead.

func (*GetPointRequest) GetHandle

func (x *GetPointRequest) GetHandle() int64

func (*GetPointRequest) ProtoMessage

func (*GetPointRequest) ProtoMessage()

func (*GetPointRequest) ProtoReflect

func (x *GetPointRequest) ProtoReflect() protoreflect.Message

func (*GetPointRequest) Reset

func (x *GetPointRequest) Reset()

func (*GetPointRequest) String

func (x *GetPointRequest) String() string

type GetPointResponse

type GetPointResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetPointResponse) Descriptor deprecated

func (*GetPointResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetPointResponse.ProtoReflect.Descriptor instead.

func (*GetPointResponse) GetResult

func (x *GetPointResponse) GetResult() int64

func (*GetPointResponse) ProtoMessage

func (*GetPointResponse) ProtoMessage()

func (*GetPointResponse) ProtoReflect

func (x *GetPointResponse) ProtoReflect() protoreflect.Message

func (*GetPointResponse) Reset

func (x *GetPointResponse) Reset()

func (*GetPointResponse) String

func (x *GetPointResponse) String() string

type GetSelectedTextContentsRequest

type GetSelectedTextContentsRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	// contains filtered or unexported fields
}

func (*GetSelectedTextContentsRequest) Descriptor deprecated

func (*GetSelectedTextContentsRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetSelectedTextContentsRequest.ProtoReflect.Descriptor instead.

func (*GetSelectedTextContentsRequest) GetHandle

func (x *GetSelectedTextContentsRequest) GetHandle() int64

func (*GetSelectedTextContentsRequest) ProtoMessage

func (*GetSelectedTextContentsRequest) ProtoMessage()

func (*GetSelectedTextContentsRequest) ProtoReflect

func (*GetSelectedTextContentsRequest) Reset

func (x *GetSelectedTextContentsRequest) Reset()

func (*GetSelectedTextContentsRequest) String

type GetSelectedTextContentsResponse

type GetSelectedTextContentsResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetSelectedTextContentsResponse) Descriptor deprecated

func (*GetSelectedTextContentsResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetSelectedTextContentsResponse.ProtoReflect.Descriptor instead.

func (*GetSelectedTextContentsResponse) GetResult

func (x *GetSelectedTextContentsResponse) GetResult() int64

func (*GetSelectedTextContentsResponse) ProtoMessage

func (*GetSelectedTextContentsResponse) ProtoMessage()

func (*GetSelectedTextContentsResponse) ProtoReflect

func (*GetSelectedTextContentsResponse) Reset

func (*GetSelectedTextContentsResponse) String

type GetStartRequest

type GetStartRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	// contains filtered or unexported fields
}

func (*GetStartRequest) Descriptor deprecated

func (*GetStartRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetStartRequest.ProtoReflect.Descriptor instead.

func (*GetStartRequest) GetHandle

func (x *GetStartRequest) GetHandle() int64

func (*GetStartRequest) ProtoMessage

func (*GetStartRequest) ProtoMessage()

func (*GetStartRequest) ProtoReflect

func (x *GetStartRequest) ProtoReflect() protoreflect.Message

func (*GetStartRequest) Reset

func (x *GetStartRequest) Reset()

func (*GetStartRequest) String

func (x *GetStartRequest) String() string

type GetStartResponse

type GetStartResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetStartResponse) Descriptor deprecated

func (*GetStartResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetStartResponse.ProtoReflect.Descriptor instead.

func (*GetStartResponse) GetResult

func (x *GetStartResponse) GetResult() int64

func (*GetStartResponse) ProtoMessage

func (*GetStartResponse) ProtoMessage()

func (*GetStartResponse) ProtoReflect

func (x *GetStartResponse) ProtoReflect() protoreflect.Message

func (*GetStartResponse) Reset

func (x *GetStartResponse) Reset()

func (*GetStartResponse) String

func (x *GetStartResponse) String() string

type GetStopRequest

type GetStopRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	// contains filtered or unexported fields
}

func (*GetStopRequest) Descriptor deprecated

func (*GetStopRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetStopRequest.ProtoReflect.Descriptor instead.

func (*GetStopRequest) GetHandle

func (x *GetStopRequest) GetHandle() int64

func (*GetStopRequest) ProtoMessage

func (*GetStopRequest) ProtoMessage()

func (*GetStopRequest) ProtoReflect

func (x *GetStopRequest) ProtoReflect() protoreflect.Message

func (*GetStopRequest) Reset

func (x *GetStopRequest) Reset()

func (*GetStopRequest) String

func (x *GetStopRequest) String() string

type GetStopResponse

type GetStopResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetStopResponse) Descriptor deprecated

func (*GetStopResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetStopResponse.ProtoReflect.Descriptor instead.

func (*GetStopResponse) GetResult

func (x *GetStopResponse) GetResult() int64

func (*GetStopResponse) ProtoMessage

func (*GetStopResponse) ProtoMessage()

func (*GetStopResponse) ProtoReflect

func (x *GetStopResponse) ProtoReflect() protoreflect.Message

func (*GetStopResponse) Reset

func (x *GetStopResponse) Reset()

func (*GetStopResponse) String

func (x *GetStopResponse) String() string

type NewBoundaryRequest

type NewBoundaryRequest struct {
	Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*NewBoundaryRequest) Descriptor deprecated

func (*NewBoundaryRequest) Descriptor() ([]byte, []int)

Deprecated: Use NewBoundaryRequest.ProtoReflect.Descriptor instead.

func (*NewBoundaryRequest) GetArg0

func (x *NewBoundaryRequest) GetArg0() int64

func (*NewBoundaryRequest) ProtoMessage

func (*NewBoundaryRequest) ProtoMessage()

func (*NewBoundaryRequest) ProtoReflect

func (x *NewBoundaryRequest) ProtoReflect() protoreflect.Message

func (*NewBoundaryRequest) Reset

func (x *NewBoundaryRequest) Reset()

func (*NewBoundaryRequest) String

func (x *NewBoundaryRequest) String() string

type NewBoundaryResponse

type NewBoundaryResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*NewBoundaryResponse) Descriptor deprecated

func (*NewBoundaryResponse) Descriptor() ([]byte, []int)

Deprecated: Use NewBoundaryResponse.ProtoReflect.Descriptor instead.

func (*NewBoundaryResponse) GetResult

func (x *NewBoundaryResponse) GetResult() int64

func (*NewBoundaryResponse) ProtoMessage

func (*NewBoundaryResponse) ProtoMessage()

func (*NewBoundaryResponse) ProtoReflect

func (x *NewBoundaryResponse) ProtoReflect() protoreflect.Message

func (*NewBoundaryResponse) Reset

func (x *NewBoundaryResponse) Reset()

func (*NewBoundaryResponse) String

func (x *NewBoundaryResponse) String() string

type NewPageSelectionRequest

type NewPageSelectionRequest struct {
	Arg0 int32 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	Arg1 int64 `protobuf:"varint,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
	Arg2 int64 `protobuf:"varint,3,opt,name=arg2,proto3" json:"arg2,omitempty"`
	Arg3 int64 `protobuf:"varint,4,opt,name=arg3,proto3" json:"arg3,omitempty"`
	// contains filtered or unexported fields
}

func (*NewPageSelectionRequest) Descriptor deprecated

func (*NewPageSelectionRequest) Descriptor() ([]byte, []int)

Deprecated: Use NewPageSelectionRequest.ProtoReflect.Descriptor instead.

func (*NewPageSelectionRequest) GetArg0

func (x *NewPageSelectionRequest) GetArg0() int32

func (*NewPageSelectionRequest) GetArg1

func (x *NewPageSelectionRequest) GetArg1() int64

func (*NewPageSelectionRequest) GetArg2

func (x *NewPageSelectionRequest) GetArg2() int64

func (*NewPageSelectionRequest) GetArg3

func (x *NewPageSelectionRequest) GetArg3() int64

func (*NewPageSelectionRequest) ProtoMessage

func (*NewPageSelectionRequest) ProtoMessage()

func (*NewPageSelectionRequest) ProtoReflect

func (x *NewPageSelectionRequest) ProtoReflect() protoreflect.Message

func (*NewPageSelectionRequest) Reset

func (x *NewPageSelectionRequest) Reset()

func (*NewPageSelectionRequest) String

func (x *NewPageSelectionRequest) String() string

type NewPageSelectionResponse

type NewPageSelectionResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*NewPageSelectionResponse) Descriptor deprecated

func (*NewPageSelectionResponse) Descriptor() ([]byte, []int)

Deprecated: Use NewPageSelectionResponse.ProtoReflect.Descriptor instead.

func (*NewPageSelectionResponse) GetResult

func (x *NewPageSelectionResponse) GetResult() int64

func (*NewPageSelectionResponse) ProtoMessage

func (*NewPageSelectionResponse) ProtoMessage()

func (*NewPageSelectionResponse) ProtoReflect

func (x *NewPageSelectionResponse) ProtoReflect() protoreflect.Message

func (*NewPageSelectionResponse) Reset

func (x *NewPageSelectionResponse) Reset()

func (*NewPageSelectionResponse) String

func (x *NewPageSelectionResponse) String() string

type PageSelectionServiceClient

type PageSelectionServiceClient interface {
	NewPageSelection(ctx context.Context, in *NewPageSelectionRequest, opts ...grpc.CallOption) (*NewPageSelectionResponse, error)
	DescribeContents(ctx context.Context, in *DescribeContentsRequest, opts ...grpc.CallOption) (*DescribeContentsResponse, error)
	GetPage(ctx context.Context, in *GetPageRequest, opts ...grpc.CallOption) (*GetPageResponse, error)
	GetSelectedTextContents(ctx context.Context, in *GetSelectedTextContentsRequest, opts ...grpc.CallOption) (*GetSelectedTextContentsResponse, error)
	GetStart(ctx context.Context, in *GetStartRequest, opts ...grpc.CallOption) (*GetStartResponse, error)
	GetStop(ctx context.Context, in *GetStopRequest, opts ...grpc.CallOption) (*GetStopResponse, error)
	WriteToParcel(ctx context.Context, in *WriteToParcelRequest, opts ...grpc.CallOption) (*WriteToParcelResponse, error)
}

PageSelectionServiceClient is the client API for PageSelectionService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type PageSelectionServiceServer

PageSelectionServiceServer is the server API for PageSelectionService service. All implementations must embed UnimplementedPageSelectionServiceServer for forward compatibility.

type UnimplementedBoundaryServiceServer

type UnimplementedBoundaryServiceServer struct{}

UnimplementedBoundaryServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedBoundaryServiceServer) DescribeContents

func (UnimplementedBoundaryServiceServer) GetIndex

func (UnimplementedBoundaryServiceServer) GetIsRtl

func (UnimplementedBoundaryServiceServer) GetPoint

func (UnimplementedBoundaryServiceServer) NewBoundary

func (UnimplementedBoundaryServiceServer) WriteToParcel

type UnimplementedPageSelectionServiceServer

type UnimplementedPageSelectionServiceServer struct{}

UnimplementedPageSelectionServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedPageSelectionServiceServer) DescribeContents

func (UnimplementedPageSelectionServiceServer) GetPage

func (UnimplementedPageSelectionServiceServer) GetStart

func (UnimplementedPageSelectionServiceServer) GetStop

func (UnimplementedPageSelectionServiceServer) NewPageSelection

func (UnimplementedPageSelectionServiceServer) WriteToParcel

type UnsafeBoundaryServiceServer

type UnsafeBoundaryServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeBoundaryServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to BoundaryServiceServer will result in compilation errors.

type UnsafePageSelectionServiceServer

type UnsafePageSelectionServiceServer interface {
	// contains filtered or unexported methods
}

UnsafePageSelectionServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to PageSelectionServiceServer will result in compilation errors.

type WriteToParcelRequest

type WriteToParcelRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	Arg0   int64 `protobuf:"varint,2,opt,name=arg0,proto3" json:"arg0,omitempty"`
	Arg1   int32 `protobuf:"varint,3,opt,name=arg1,proto3" json:"arg1,omitempty"`
	// contains filtered or unexported fields
}

func (*WriteToParcelRequest) Descriptor deprecated

func (*WriteToParcelRequest) Descriptor() ([]byte, []int)

Deprecated: Use WriteToParcelRequest.ProtoReflect.Descriptor instead.

func (*WriteToParcelRequest) GetArg0

func (x *WriteToParcelRequest) GetArg0() int64

func (*WriteToParcelRequest) GetArg1

func (x *WriteToParcelRequest) GetArg1() int32

func (*WriteToParcelRequest) GetHandle

func (x *WriteToParcelRequest) GetHandle() int64

func (*WriteToParcelRequest) ProtoMessage

func (*WriteToParcelRequest) ProtoMessage()

func (*WriteToParcelRequest) ProtoReflect

func (x *WriteToParcelRequest) ProtoReflect() protoreflect.Message

func (*WriteToParcelRequest) Reset

func (x *WriteToParcelRequest) Reset()

func (*WriteToParcelRequest) String

func (x *WriteToParcelRequest) String() string

type WriteToParcelResponse

type WriteToParcelResponse struct {
	// contains filtered or unexported fields
}

func (*WriteToParcelResponse) Descriptor deprecated

func (*WriteToParcelResponse) Descriptor() ([]byte, []int)

Deprecated: Use WriteToParcelResponse.ProtoReflect.Descriptor instead.

func (*WriteToParcelResponse) ProtoMessage

func (*WriteToParcelResponse) ProtoMessage()

func (*WriteToParcelResponse) ProtoReflect

func (x *WriteToParcelResponse) ProtoReflect() protoreflect.Message

func (*WriteToParcelResponse) Reset

func (x *WriteToParcelResponse) Reset()

func (*WriteToParcelResponse) String

func (x *WriteToParcelResponse) String() string

Jump to