Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterSSLEnginesServiceServer(s grpc.ServiceRegistrar, srv SSLEnginesServiceServer)
- func RegisterSSLSocketsServiceServer(s grpc.ServiceRegistrar, srv SSLSocketsServiceServer)
- type ExportKeyingMaterialRequest
- func (*ExportKeyingMaterialRequest) Descriptor() ([]byte, []int)deprecated
- func (x *ExportKeyingMaterialRequest) GetArg0() int64
- func (x *ExportKeyingMaterialRequest) GetArg1() string
- func (x *ExportKeyingMaterialRequest) GetArg2() int64
- func (x *ExportKeyingMaterialRequest) GetArg3() int32
- func (*ExportKeyingMaterialRequest) ProtoMessage()
- func (x *ExportKeyingMaterialRequest) ProtoReflect() protoreflect.Message
- func (x *ExportKeyingMaterialRequest) Reset()
- func (x *ExportKeyingMaterialRequest) String() string
- type ExportKeyingMaterialResponse
- func (*ExportKeyingMaterialResponse) Descriptor() ([]byte, []int)deprecated
- func (x *ExportKeyingMaterialResponse) GetResult() int64
- func (*ExportKeyingMaterialResponse) ProtoMessage()
- func (x *ExportKeyingMaterialResponse) ProtoReflect() protoreflect.Message
- func (x *ExportKeyingMaterialResponse) Reset()
- func (x *ExportKeyingMaterialResponse) String() string
- type IsSupportedEngineRequest
- func (*IsSupportedEngineRequest) Descriptor() ([]byte, []int)deprecated
- func (x *IsSupportedEngineRequest) GetArg0() int64
- func (*IsSupportedEngineRequest) ProtoMessage()
- func (x *IsSupportedEngineRequest) ProtoReflect() protoreflect.Message
- func (x *IsSupportedEngineRequest) Reset()
- func (x *IsSupportedEngineRequest) String() string
- type IsSupportedEngineResponse
- func (*IsSupportedEngineResponse) Descriptor() ([]byte, []int)deprecated
- func (x *IsSupportedEngineResponse) GetResult() bool
- func (*IsSupportedEngineResponse) ProtoMessage()
- func (x *IsSupportedEngineResponse) ProtoReflect() protoreflect.Message
- func (x *IsSupportedEngineResponse) Reset()
- func (x *IsSupportedEngineResponse) String() string
- type IsSupportedSocketRequest
- func (*IsSupportedSocketRequest) Descriptor() ([]byte, []int)deprecated
- func (x *IsSupportedSocketRequest) GetArg0() int64
- func (*IsSupportedSocketRequest) ProtoMessage()
- func (x *IsSupportedSocketRequest) ProtoReflect() protoreflect.Message
- func (x *IsSupportedSocketRequest) Reset()
- func (x *IsSupportedSocketRequest) String() string
- type IsSupportedSocketResponse
- func (*IsSupportedSocketResponse) Descriptor() ([]byte, []int)deprecated
- func (x *IsSupportedSocketResponse) GetResult() bool
- func (*IsSupportedSocketResponse) ProtoMessage()
- func (x *IsSupportedSocketResponse) ProtoReflect() protoreflect.Message
- func (x *IsSupportedSocketResponse) Reset()
- func (x *IsSupportedSocketResponse) String() string
- type SSLEnginesServiceClient
- type SSLEnginesServiceServer
- type SSLSocketsServiceClient
- type SSLSocketsServiceServer
- type SetUseSessionTicketsRequest
- func (*SetUseSessionTicketsRequest) Descriptor() ([]byte, []int)deprecated
- func (x *SetUseSessionTicketsRequest) GetArg0() int64
- func (x *SetUseSessionTicketsRequest) GetArg1() bool
- func (*SetUseSessionTicketsRequest) ProtoMessage()
- func (x *SetUseSessionTicketsRequest) ProtoReflect() protoreflect.Message
- func (x *SetUseSessionTicketsRequest) Reset()
- func (x *SetUseSessionTicketsRequest) String() string
- type SetUseSessionTicketsResponse
- func (*SetUseSessionTicketsResponse) Descriptor() ([]byte, []int)deprecated
- func (*SetUseSessionTicketsResponse) ProtoMessage()
- func (x *SetUseSessionTicketsResponse) ProtoReflect() protoreflect.Message
- func (x *SetUseSessionTicketsResponse) Reset()
- func (x *SetUseSessionTicketsResponse) String() string
- type UnimplementedSSLEnginesServiceServer
- func (UnimplementedSSLEnginesServiceServer) ExportKeyingMaterial(context.Context, *ExportKeyingMaterialRequest) (*ExportKeyingMaterialResponse, error)
- func (UnimplementedSSLEnginesServiceServer) IsSupportedEngine(context.Context, *IsSupportedEngineRequest) (*IsSupportedEngineResponse, error)
- func (UnimplementedSSLEnginesServiceServer) SetUseSessionTickets(context.Context, *SetUseSessionTicketsRequest) (*SetUseSessionTicketsResponse, error)
- type UnimplementedSSLSocketsServiceServer
- func (UnimplementedSSLSocketsServiceServer) ExportKeyingMaterial(context.Context, *ExportKeyingMaterialRequest) (*ExportKeyingMaterialResponse, error)
- func (UnimplementedSSLSocketsServiceServer) IsSupportedSocket(context.Context, *IsSupportedSocketRequest) (*IsSupportedSocketResponse, error)
- func (UnimplementedSSLSocketsServiceServer) SetUseSessionTickets(context.Context, *SetUseSessionTicketsRequest) (*SetUseSessionTicketsResponse, error)
- type UnsafeSSLEnginesServiceServer
- type UnsafeSSLSocketsServiceServer
Constants ¶
const ( SSLEnginesService_ExportKeyingMaterial_FullMethodName = "/ssl.SSLEnginesService/ExportKeyingMaterial" SSLEnginesService_IsSupportedEngine_FullMethodName = "/ssl.SSLEnginesService/IsSupportedEngine" SSLEnginesService_SetUseSessionTickets_FullMethodName = "/ssl.SSLEnginesService/SetUseSessionTickets" )
const ( SSLSocketsService_ExportKeyingMaterial_FullMethodName = "/ssl.SSLSocketsService/ExportKeyingMaterial" SSLSocketsService_IsSupportedSocket_FullMethodName = "/ssl.SSLSocketsService/IsSupportedSocket" SSLSocketsService_SetUseSessionTickets_FullMethodName = "/ssl.SSLSocketsService/SetUseSessionTickets" )
Variables ¶
var File_proto_ssl_ssl_proto protoreflect.FileDescriptor
var SSLEnginesService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "ssl.SSLEnginesService", HandlerType: (*SSLEnginesServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "ExportKeyingMaterial", Handler: _SSLEnginesService_ExportKeyingMaterial_Handler, }, { MethodName: "IsSupportedEngine", Handler: _SSLEnginesService_IsSupportedEngine_Handler, }, { MethodName: "SetUseSessionTickets", Handler: _SSLEnginesService_SetUseSessionTickets_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "proto/ssl/ssl.proto", }
SSLEnginesService_ServiceDesc is the grpc.ServiceDesc for SSLEnginesService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var SSLSocketsService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "ssl.SSLSocketsService", HandlerType: (*SSLSocketsServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "ExportKeyingMaterial", Handler: _SSLSocketsService_ExportKeyingMaterial_Handler, }, { MethodName: "IsSupportedSocket", Handler: _SSLSocketsService_IsSupportedSocket_Handler, }, { MethodName: "SetUseSessionTickets", Handler: _SSLSocketsService_SetUseSessionTickets_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "proto/ssl/ssl.proto", }
SSLSocketsService_ServiceDesc is the grpc.ServiceDesc for SSLSocketsService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterSSLEnginesServiceServer ¶
func RegisterSSLEnginesServiceServer(s grpc.ServiceRegistrar, srv SSLEnginesServiceServer)
func RegisterSSLSocketsServiceServer ¶
func RegisterSSLSocketsServiceServer(s grpc.ServiceRegistrar, srv SSLSocketsServiceServer)
Types ¶
type ExportKeyingMaterialRequest ¶
type ExportKeyingMaterialRequest struct {
Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
Arg1 string `protobuf:"bytes,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
Arg2 int64 `protobuf:"varint,3,opt,name=arg2,proto3" json:"arg2,omitempty"`
Arg3 int32 `protobuf:"varint,4,opt,name=arg3,proto3" json:"arg3,omitempty"`
// contains filtered or unexported fields
}
func (*ExportKeyingMaterialRequest) Descriptor
deprecated
func (*ExportKeyingMaterialRequest) Descriptor() ([]byte, []int)
Deprecated: Use ExportKeyingMaterialRequest.ProtoReflect.Descriptor instead.
func (*ExportKeyingMaterialRequest) GetArg0 ¶
func (x *ExportKeyingMaterialRequest) GetArg0() int64
func (*ExportKeyingMaterialRequest) GetArg1 ¶
func (x *ExportKeyingMaterialRequest) GetArg1() string
func (*ExportKeyingMaterialRequest) GetArg2 ¶
func (x *ExportKeyingMaterialRequest) GetArg2() int64
func (*ExportKeyingMaterialRequest) GetArg3 ¶
func (x *ExportKeyingMaterialRequest) GetArg3() int32
func (*ExportKeyingMaterialRequest) ProtoMessage ¶
func (*ExportKeyingMaterialRequest) ProtoMessage()
func (*ExportKeyingMaterialRequest) ProtoReflect ¶
func (x *ExportKeyingMaterialRequest) ProtoReflect() protoreflect.Message
func (*ExportKeyingMaterialRequest) Reset ¶
func (x *ExportKeyingMaterialRequest) Reset()
func (*ExportKeyingMaterialRequest) String ¶
func (x *ExportKeyingMaterialRequest) String() string
type ExportKeyingMaterialResponse ¶
type ExportKeyingMaterialResponse struct {
Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*ExportKeyingMaterialResponse) Descriptor
deprecated
func (*ExportKeyingMaterialResponse) Descriptor() ([]byte, []int)
Deprecated: Use ExportKeyingMaterialResponse.ProtoReflect.Descriptor instead.
func (*ExportKeyingMaterialResponse) GetResult ¶
func (x *ExportKeyingMaterialResponse) GetResult() int64
func (*ExportKeyingMaterialResponse) ProtoMessage ¶
func (*ExportKeyingMaterialResponse) ProtoMessage()
func (*ExportKeyingMaterialResponse) ProtoReflect ¶
func (x *ExportKeyingMaterialResponse) ProtoReflect() protoreflect.Message
func (*ExportKeyingMaterialResponse) Reset ¶
func (x *ExportKeyingMaterialResponse) Reset()
func (*ExportKeyingMaterialResponse) String ¶
func (x *ExportKeyingMaterialResponse) String() string
type IsSupportedEngineRequest ¶
type IsSupportedEngineRequest struct {
Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
// contains filtered or unexported fields
}
func (*IsSupportedEngineRequest) Descriptor
deprecated
func (*IsSupportedEngineRequest) Descriptor() ([]byte, []int)
Deprecated: Use IsSupportedEngineRequest.ProtoReflect.Descriptor instead.
func (*IsSupportedEngineRequest) GetArg0 ¶
func (x *IsSupportedEngineRequest) GetArg0() int64
func (*IsSupportedEngineRequest) ProtoMessage ¶
func (*IsSupportedEngineRequest) ProtoMessage()
func (*IsSupportedEngineRequest) ProtoReflect ¶
func (x *IsSupportedEngineRequest) ProtoReflect() protoreflect.Message
func (*IsSupportedEngineRequest) Reset ¶
func (x *IsSupportedEngineRequest) Reset()
func (*IsSupportedEngineRequest) String ¶
func (x *IsSupportedEngineRequest) String() string
type IsSupportedEngineResponse ¶
type IsSupportedEngineResponse struct {
Result bool `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*IsSupportedEngineResponse) Descriptor
deprecated
func (*IsSupportedEngineResponse) Descriptor() ([]byte, []int)
Deprecated: Use IsSupportedEngineResponse.ProtoReflect.Descriptor instead.
func (*IsSupportedEngineResponse) GetResult ¶
func (x *IsSupportedEngineResponse) GetResult() bool
func (*IsSupportedEngineResponse) ProtoMessage ¶
func (*IsSupportedEngineResponse) ProtoMessage()
func (*IsSupportedEngineResponse) ProtoReflect ¶
func (x *IsSupportedEngineResponse) ProtoReflect() protoreflect.Message
func (*IsSupportedEngineResponse) Reset ¶
func (x *IsSupportedEngineResponse) Reset()
func (*IsSupportedEngineResponse) String ¶
func (x *IsSupportedEngineResponse) String() string
type IsSupportedSocketRequest ¶
type IsSupportedSocketRequest struct {
Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
// contains filtered or unexported fields
}
func (*IsSupportedSocketRequest) Descriptor
deprecated
func (*IsSupportedSocketRequest) Descriptor() ([]byte, []int)
Deprecated: Use IsSupportedSocketRequest.ProtoReflect.Descriptor instead.
func (*IsSupportedSocketRequest) GetArg0 ¶
func (x *IsSupportedSocketRequest) GetArg0() int64
func (*IsSupportedSocketRequest) ProtoMessage ¶
func (*IsSupportedSocketRequest) ProtoMessage()
func (*IsSupportedSocketRequest) ProtoReflect ¶
func (x *IsSupportedSocketRequest) ProtoReflect() protoreflect.Message
func (*IsSupportedSocketRequest) Reset ¶
func (x *IsSupportedSocketRequest) Reset()
func (*IsSupportedSocketRequest) String ¶
func (x *IsSupportedSocketRequest) String() string
type IsSupportedSocketResponse ¶
type IsSupportedSocketResponse struct {
Result bool `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*IsSupportedSocketResponse) Descriptor
deprecated
func (*IsSupportedSocketResponse) Descriptor() ([]byte, []int)
Deprecated: Use IsSupportedSocketResponse.ProtoReflect.Descriptor instead.
func (*IsSupportedSocketResponse) GetResult ¶
func (x *IsSupportedSocketResponse) GetResult() bool
func (*IsSupportedSocketResponse) ProtoMessage ¶
func (*IsSupportedSocketResponse) ProtoMessage()
func (*IsSupportedSocketResponse) ProtoReflect ¶
func (x *IsSupportedSocketResponse) ProtoReflect() protoreflect.Message
func (*IsSupportedSocketResponse) Reset ¶
func (x *IsSupportedSocketResponse) Reset()
func (*IsSupportedSocketResponse) String ¶
func (x *IsSupportedSocketResponse) String() string
type SSLEnginesServiceClient ¶
type SSLEnginesServiceClient interface {
ExportKeyingMaterial(ctx context.Context, in *ExportKeyingMaterialRequest, opts ...grpc.CallOption) (*ExportKeyingMaterialResponse, error)
IsSupportedEngine(ctx context.Context, in *IsSupportedEngineRequest, opts ...grpc.CallOption) (*IsSupportedEngineResponse, error)
SetUseSessionTickets(ctx context.Context, in *SetUseSessionTicketsRequest, opts ...grpc.CallOption) (*SetUseSessionTicketsResponse, error)
}
SSLEnginesServiceClient is the client API for SSLEnginesService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewSSLEnginesServiceClient ¶
func NewSSLEnginesServiceClient(cc grpc.ClientConnInterface) SSLEnginesServiceClient
type SSLEnginesServiceServer ¶
type SSLEnginesServiceServer interface {
ExportKeyingMaterial(context.Context, *ExportKeyingMaterialRequest) (*ExportKeyingMaterialResponse, error)
IsSupportedEngine(context.Context, *IsSupportedEngineRequest) (*IsSupportedEngineResponse, error)
SetUseSessionTickets(context.Context, *SetUseSessionTicketsRequest) (*SetUseSessionTicketsResponse, error)
// contains filtered or unexported methods
}
SSLEnginesServiceServer is the server API for SSLEnginesService service. All implementations must embed UnimplementedSSLEnginesServiceServer for forward compatibility.
type SSLSocketsServiceClient ¶
type SSLSocketsServiceClient interface {
ExportKeyingMaterial(ctx context.Context, in *ExportKeyingMaterialRequest, opts ...grpc.CallOption) (*ExportKeyingMaterialResponse, error)
IsSupportedSocket(ctx context.Context, in *IsSupportedSocketRequest, opts ...grpc.CallOption) (*IsSupportedSocketResponse, error)
SetUseSessionTickets(ctx context.Context, in *SetUseSessionTicketsRequest, opts ...grpc.CallOption) (*SetUseSessionTicketsResponse, error)
}
SSLSocketsServiceClient is the client API for SSLSocketsService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewSSLSocketsServiceClient ¶
func NewSSLSocketsServiceClient(cc grpc.ClientConnInterface) SSLSocketsServiceClient
type SSLSocketsServiceServer ¶
type SSLSocketsServiceServer interface {
ExportKeyingMaterial(context.Context, *ExportKeyingMaterialRequest) (*ExportKeyingMaterialResponse, error)
IsSupportedSocket(context.Context, *IsSupportedSocketRequest) (*IsSupportedSocketResponse, error)
SetUseSessionTickets(context.Context, *SetUseSessionTicketsRequest) (*SetUseSessionTicketsResponse, error)
// contains filtered or unexported methods
}
SSLSocketsServiceServer is the server API for SSLSocketsService service. All implementations must embed UnimplementedSSLSocketsServiceServer for forward compatibility.
type SetUseSessionTicketsRequest ¶
type SetUseSessionTicketsRequest struct {
Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
Arg1 bool `protobuf:"varint,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
// contains filtered or unexported fields
}
func (*SetUseSessionTicketsRequest) Descriptor
deprecated
func (*SetUseSessionTicketsRequest) Descriptor() ([]byte, []int)
Deprecated: Use SetUseSessionTicketsRequest.ProtoReflect.Descriptor instead.
func (*SetUseSessionTicketsRequest) GetArg0 ¶
func (x *SetUseSessionTicketsRequest) GetArg0() int64
func (*SetUseSessionTicketsRequest) GetArg1 ¶
func (x *SetUseSessionTicketsRequest) GetArg1() bool
func (*SetUseSessionTicketsRequest) ProtoMessage ¶
func (*SetUseSessionTicketsRequest) ProtoMessage()
func (*SetUseSessionTicketsRequest) ProtoReflect ¶
func (x *SetUseSessionTicketsRequest) ProtoReflect() protoreflect.Message
func (*SetUseSessionTicketsRequest) Reset ¶
func (x *SetUseSessionTicketsRequest) Reset()
func (*SetUseSessionTicketsRequest) String ¶
func (x *SetUseSessionTicketsRequest) String() string
type SetUseSessionTicketsResponse ¶
type SetUseSessionTicketsResponse struct {
// contains filtered or unexported fields
}
func (*SetUseSessionTicketsResponse) Descriptor
deprecated
func (*SetUseSessionTicketsResponse) Descriptor() ([]byte, []int)
Deprecated: Use SetUseSessionTicketsResponse.ProtoReflect.Descriptor instead.
func (*SetUseSessionTicketsResponse) ProtoMessage ¶
func (*SetUseSessionTicketsResponse) ProtoMessage()
func (*SetUseSessionTicketsResponse) ProtoReflect ¶
func (x *SetUseSessionTicketsResponse) ProtoReflect() protoreflect.Message
func (*SetUseSessionTicketsResponse) Reset ¶
func (x *SetUseSessionTicketsResponse) Reset()
func (*SetUseSessionTicketsResponse) String ¶
func (x *SetUseSessionTicketsResponse) String() string
type UnimplementedSSLEnginesServiceServer ¶
type UnimplementedSSLEnginesServiceServer struct{}
UnimplementedSSLEnginesServiceServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedSSLEnginesServiceServer) ExportKeyingMaterial ¶
func (UnimplementedSSLEnginesServiceServer) ExportKeyingMaterial(context.Context, *ExportKeyingMaterialRequest) (*ExportKeyingMaterialResponse, error)
func (UnimplementedSSLEnginesServiceServer) IsSupportedEngine ¶
func (UnimplementedSSLEnginesServiceServer) IsSupportedEngine(context.Context, *IsSupportedEngineRequest) (*IsSupportedEngineResponse, error)
func (UnimplementedSSLEnginesServiceServer) SetUseSessionTickets ¶
func (UnimplementedSSLEnginesServiceServer) SetUseSessionTickets(context.Context, *SetUseSessionTicketsRequest) (*SetUseSessionTicketsResponse, error)
type UnimplementedSSLSocketsServiceServer ¶
type UnimplementedSSLSocketsServiceServer struct{}
UnimplementedSSLSocketsServiceServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedSSLSocketsServiceServer) ExportKeyingMaterial ¶
func (UnimplementedSSLSocketsServiceServer) ExportKeyingMaterial(context.Context, *ExportKeyingMaterialRequest) (*ExportKeyingMaterialResponse, error)
func (UnimplementedSSLSocketsServiceServer) IsSupportedSocket ¶
func (UnimplementedSSLSocketsServiceServer) IsSupportedSocket(context.Context, *IsSupportedSocketRequest) (*IsSupportedSocketResponse, error)
func (UnimplementedSSLSocketsServiceServer) SetUseSessionTickets ¶
func (UnimplementedSSLSocketsServiceServer) SetUseSessionTickets(context.Context, *SetUseSessionTicketsRequest) (*SetUseSessionTicketsResponse, error)
type UnsafeSSLEnginesServiceServer ¶
type UnsafeSSLEnginesServiceServer interface {
// contains filtered or unexported methods
}
UnsafeSSLEnginesServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to SSLEnginesServiceServer will result in compilation errors.
type UnsafeSSLSocketsServiceServer ¶
type UnsafeSSLSocketsServiceServer interface {
// contains filtered or unexported methods
}
UnsafeSSLSocketsServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to SSLSocketsServiceServer will result in compilation errors.