strictmode

package
v0.0.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 29, 2026 License: CC0-1.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

const (
	ViolationService_HashCode_FullMethodName      = "/strictmode.ViolationService/HashCode"
	ViolationService_SetStackTrace_FullMethodName = "/strictmode.ViolationService/SetStackTrace"
)
const (
	UnsafeIntentLaunchViolationService_NewUnsafeIntentLaunchViolation_FullMethodName = "/strictmode.UnsafeIntentLaunchViolationService/NewUnsafeIntentLaunchViolation"
	UnsafeIntentLaunchViolationService_GetIntent_FullMethodName                      = "/strictmode.UnsafeIntentLaunchViolationService/GetIntent"
)
const (
	InstanceCountViolationService_GetNumberOfInstances_FullMethodName = "/strictmode.InstanceCountViolationService/GetNumberOfInstances"
)

Variables

var File_proto_strictmode_strictmode_proto protoreflect.FileDescriptor
var InstanceCountViolationService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "strictmode.InstanceCountViolationService",
	HandlerType: (*InstanceCountViolationServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "GetNumberOfInstances",
			Handler:    _InstanceCountViolationService_GetNumberOfInstances_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/strictmode/strictmode.proto",
}

InstanceCountViolationService_ServiceDesc is the grpc.ServiceDesc for InstanceCountViolationService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var UnsafeIntentLaunchViolationService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "strictmode.UnsafeIntentLaunchViolationService",
	HandlerType: (*UnsafeIntentLaunchViolationServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "NewUnsafeIntentLaunchViolation",
			Handler:    _UnsafeIntentLaunchViolationService_NewUnsafeIntentLaunchViolation_Handler,
		},
		{
			MethodName: "GetIntent",
			Handler:    _UnsafeIntentLaunchViolationService_GetIntent_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/strictmode/strictmode.proto",
}

UnsafeIntentLaunchViolationService_ServiceDesc is the grpc.ServiceDesc for UnsafeIntentLaunchViolationService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var ViolationService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "strictmode.ViolationService",
	HandlerType: (*ViolationServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "HashCode",
			Handler:    _ViolationService_HashCode_Handler,
		},
		{
			MethodName: "SetStackTrace",
			Handler:    _ViolationService_SetStackTrace_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/strictmode/strictmode.proto",
}

ViolationService_ServiceDesc is the grpc.ServiceDesc for ViolationService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterInstanceCountViolationServiceServer

func RegisterInstanceCountViolationServiceServer(s grpc.ServiceRegistrar, srv InstanceCountViolationServiceServer)

func RegisterViolationServiceServer

func RegisterViolationServiceServer(s grpc.ServiceRegistrar, srv ViolationServiceServer)

Types

type GetIntentRequest

type GetIntentRequest struct {
	Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
	// contains filtered or unexported fields
}

func (*GetIntentRequest) Descriptor deprecated

func (*GetIntentRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetIntentRequest.ProtoReflect.Descriptor instead.

func (*GetIntentRequest) GetHandle

func (x *GetIntentRequest) GetHandle() int64

func (*GetIntentRequest) ProtoMessage

func (*GetIntentRequest) ProtoMessage()

func (*GetIntentRequest) ProtoReflect

func (x *GetIntentRequest) ProtoReflect() protoreflect.Message

func (*GetIntentRequest) Reset

func (x *GetIntentRequest) Reset()

func (*GetIntentRequest) String

func (x *GetIntentRequest) String() string

type GetIntentResponse

type GetIntentResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetIntentResponse) Descriptor deprecated

func (*GetIntentResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetIntentResponse.ProtoReflect.Descriptor instead.

func (*GetIntentResponse) GetResult

func (x *GetIntentResponse) GetResult() int64

func (*GetIntentResponse) ProtoMessage

func (*GetIntentResponse) ProtoMessage()

func (*GetIntentResponse) ProtoReflect

func (x *GetIntentResponse) ProtoReflect() protoreflect.Message

func (*GetIntentResponse) Reset

func (x *GetIntentResponse) Reset()

func (*GetIntentResponse) String

func (x *GetIntentResponse) String() string

type GetNumberOfInstancesRequest

type GetNumberOfInstancesRequest struct {
	// contains filtered or unexported fields
}

func (*GetNumberOfInstancesRequest) Descriptor deprecated

func (*GetNumberOfInstancesRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetNumberOfInstancesRequest.ProtoReflect.Descriptor instead.

func (*GetNumberOfInstancesRequest) ProtoMessage

func (*GetNumberOfInstancesRequest) ProtoMessage()

func (*GetNumberOfInstancesRequest) ProtoReflect

func (*GetNumberOfInstancesRequest) Reset

func (x *GetNumberOfInstancesRequest) Reset()

func (*GetNumberOfInstancesRequest) String

func (x *GetNumberOfInstancesRequest) String() string

type GetNumberOfInstancesResponse

type GetNumberOfInstancesResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetNumberOfInstancesResponse) Descriptor deprecated

func (*GetNumberOfInstancesResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetNumberOfInstancesResponse.ProtoReflect.Descriptor instead.

func (*GetNumberOfInstancesResponse) GetResult

func (x *GetNumberOfInstancesResponse) GetResult() int64

func (*GetNumberOfInstancesResponse) ProtoMessage

func (*GetNumberOfInstancesResponse) ProtoMessage()

func (*GetNumberOfInstancesResponse) ProtoReflect

func (*GetNumberOfInstancesResponse) Reset

func (x *GetNumberOfInstancesResponse) Reset()

func (*GetNumberOfInstancesResponse) String

type HashCodeRequest

type HashCodeRequest struct {
	// contains filtered or unexported fields
}

func (*HashCodeRequest) Descriptor deprecated

func (*HashCodeRequest) Descriptor() ([]byte, []int)

Deprecated: Use HashCodeRequest.ProtoReflect.Descriptor instead.

func (*HashCodeRequest) ProtoMessage

func (*HashCodeRequest) ProtoMessage()

func (*HashCodeRequest) ProtoReflect

func (x *HashCodeRequest) ProtoReflect() protoreflect.Message

func (*HashCodeRequest) Reset

func (x *HashCodeRequest) Reset()

func (*HashCodeRequest) String

func (x *HashCodeRequest) String() string

type HashCodeResponse

type HashCodeResponse struct {
	Result int32 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*HashCodeResponse) Descriptor deprecated

func (*HashCodeResponse) Descriptor() ([]byte, []int)

Deprecated: Use HashCodeResponse.ProtoReflect.Descriptor instead.

func (*HashCodeResponse) GetResult

func (x *HashCodeResponse) GetResult() int32

func (*HashCodeResponse) ProtoMessage

func (*HashCodeResponse) ProtoMessage()

func (*HashCodeResponse) ProtoReflect

func (x *HashCodeResponse) ProtoReflect() protoreflect.Message

func (*HashCodeResponse) Reset

func (x *HashCodeResponse) Reset()

func (*HashCodeResponse) String

func (x *HashCodeResponse) String() string

type InstanceCountViolationServiceClient

type InstanceCountViolationServiceClient interface {
	GetNumberOfInstances(ctx context.Context, in *GetNumberOfInstancesRequest, opts ...grpc.CallOption) (*GetNumberOfInstancesResponse, error)
}

InstanceCountViolationServiceClient is the client API for InstanceCountViolationService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type InstanceCountViolationServiceServer

type InstanceCountViolationServiceServer interface {
	GetNumberOfInstances(context.Context, *GetNumberOfInstancesRequest) (*GetNumberOfInstancesResponse, error)
	// contains filtered or unexported methods
}

InstanceCountViolationServiceServer is the server API for InstanceCountViolationService service. All implementations must embed UnimplementedInstanceCountViolationServiceServer for forward compatibility.

type NewUnsafeIntentLaunchViolationRequest

type NewUnsafeIntentLaunchViolationRequest struct {
	Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*NewUnsafeIntentLaunchViolationRequest) Descriptor deprecated

func (*NewUnsafeIntentLaunchViolationRequest) Descriptor() ([]byte, []int)

Deprecated: Use NewUnsafeIntentLaunchViolationRequest.ProtoReflect.Descriptor instead.

func (*NewUnsafeIntentLaunchViolationRequest) GetArg0

func (*NewUnsafeIntentLaunchViolationRequest) ProtoMessage

func (*NewUnsafeIntentLaunchViolationRequest) ProtoMessage()

func (*NewUnsafeIntentLaunchViolationRequest) ProtoReflect

func (*NewUnsafeIntentLaunchViolationRequest) Reset

func (*NewUnsafeIntentLaunchViolationRequest) String

type NewUnsafeIntentLaunchViolationResponse

type NewUnsafeIntentLaunchViolationResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*NewUnsafeIntentLaunchViolationResponse) Descriptor deprecated

func (*NewUnsafeIntentLaunchViolationResponse) Descriptor() ([]byte, []int)

Deprecated: Use NewUnsafeIntentLaunchViolationResponse.ProtoReflect.Descriptor instead.

func (*NewUnsafeIntentLaunchViolationResponse) GetResult

func (*NewUnsafeIntentLaunchViolationResponse) ProtoMessage

func (*NewUnsafeIntentLaunchViolationResponse) ProtoReflect

func (*NewUnsafeIntentLaunchViolationResponse) Reset

func (*NewUnsafeIntentLaunchViolationResponse) String

type SetStackTraceRequest

type SetStackTraceRequest struct {
	Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*SetStackTraceRequest) Descriptor deprecated

func (*SetStackTraceRequest) Descriptor() ([]byte, []int)

Deprecated: Use SetStackTraceRequest.ProtoReflect.Descriptor instead.

func (*SetStackTraceRequest) GetArg0

func (x *SetStackTraceRequest) GetArg0() int64

func (*SetStackTraceRequest) ProtoMessage

func (*SetStackTraceRequest) ProtoMessage()

func (*SetStackTraceRequest) ProtoReflect

func (x *SetStackTraceRequest) ProtoReflect() protoreflect.Message

func (*SetStackTraceRequest) Reset

func (x *SetStackTraceRequest) Reset()

func (*SetStackTraceRequest) String

func (x *SetStackTraceRequest) String() string

type SetStackTraceResponse

type SetStackTraceResponse struct {
	// contains filtered or unexported fields
}

func (*SetStackTraceResponse) Descriptor deprecated

func (*SetStackTraceResponse) Descriptor() ([]byte, []int)

Deprecated: Use SetStackTraceResponse.ProtoReflect.Descriptor instead.

func (*SetStackTraceResponse) ProtoMessage

func (*SetStackTraceResponse) ProtoMessage()

func (*SetStackTraceResponse) ProtoReflect

func (x *SetStackTraceResponse) ProtoReflect() protoreflect.Message

func (*SetStackTraceResponse) Reset

func (x *SetStackTraceResponse) Reset()

func (*SetStackTraceResponse) String

func (x *SetStackTraceResponse) String() string

type UnimplementedInstanceCountViolationServiceServer

type UnimplementedInstanceCountViolationServiceServer struct{}

UnimplementedInstanceCountViolationServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedInstanceCountViolationServiceServer) GetNumberOfInstances

type UnimplementedUnsafeIntentLaunchViolationServiceServer

type UnimplementedUnsafeIntentLaunchViolationServiceServer struct{}

UnimplementedUnsafeIntentLaunchViolationServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedUnsafeIntentLaunchViolationServiceServer) GetIntent

type UnimplementedViolationServiceServer

type UnimplementedViolationServiceServer struct{}

UnimplementedViolationServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedViolationServiceServer) HashCode

func (UnimplementedViolationServiceServer) SetStackTrace

type UnsafeInstanceCountViolationServiceServer

type UnsafeInstanceCountViolationServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeInstanceCountViolationServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to InstanceCountViolationServiceServer will result in compilation errors.

type UnsafeIntentLaunchViolationServiceClient

type UnsafeIntentLaunchViolationServiceClient interface {
	NewUnsafeIntentLaunchViolation(ctx context.Context, in *NewUnsafeIntentLaunchViolationRequest, opts ...grpc.CallOption) (*NewUnsafeIntentLaunchViolationResponse, error)
	GetIntent(ctx context.Context, in *GetIntentRequest, opts ...grpc.CallOption) (*GetIntentResponse, error)
}

UnsafeIntentLaunchViolationServiceClient is the client API for UnsafeIntentLaunchViolationService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type UnsafeIntentLaunchViolationServiceServer

type UnsafeIntentLaunchViolationServiceServer interface {
	NewUnsafeIntentLaunchViolation(context.Context, *NewUnsafeIntentLaunchViolationRequest) (*NewUnsafeIntentLaunchViolationResponse, error)
	GetIntent(context.Context, *GetIntentRequest) (*GetIntentResponse, error)
	// contains filtered or unexported methods
}

UnsafeIntentLaunchViolationServiceServer is the server API for UnsafeIntentLaunchViolationService service. All implementations must embed UnimplementedUnsafeIntentLaunchViolationServiceServer for forward compatibility.

type UnsafeUnsafeIntentLaunchViolationServiceServer

type UnsafeUnsafeIntentLaunchViolationServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeUnsafeIntentLaunchViolationServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to UnsafeIntentLaunchViolationServiceServer will result in compilation errors.

type UnsafeViolationServiceServer

type UnsafeViolationServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeViolationServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ViolationServiceServer will result in compilation errors.

type ViolationServiceClient

type ViolationServiceClient interface {
	HashCode(ctx context.Context, in *HashCodeRequest, opts ...grpc.CallOption) (*HashCodeResponse, error)
	SetStackTrace(ctx context.Context, in *SetStackTraceRequest, opts ...grpc.CallOption) (*SetStackTraceResponse, error)
}

ViolationServiceClient is the client API for ViolationService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type ViolationServiceServer

type ViolationServiceServer interface {
	HashCode(context.Context, *HashCodeRequest) (*HashCodeResponse, error)
	SetStackTrace(context.Context, *SetStackTraceRequest) (*SetStackTraceResponse, error)
	// contains filtered or unexported methods
}

ViolationServiceServer is the server API for ViolationService service. All implementations must embed UnimplementedViolationServiceServer for forward compatibility.

Jump to