Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterToastServiceServer(s grpc.ServiceRegistrar, srv ToastServiceServer)
- type AddCallbackRequest
- type AddCallbackResponse
- type CancelRequest
- type CancelResponse
- type GetDurationRequest
- type GetDurationResponse
- func (*GetDurationResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetDurationResponse) GetResult() int32
- func (*GetDurationResponse) ProtoMessage()
- func (x *GetDurationResponse) ProtoReflect() protoreflect.Message
- func (x *GetDurationResponse) Reset()
- func (x *GetDurationResponse) String() string
- type GetGravityRequest
- type GetGravityResponse
- func (*GetGravityResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetGravityResponse) GetResult() int32
- func (*GetGravityResponse) ProtoMessage()
- func (x *GetGravityResponse) ProtoReflect() protoreflect.Message
- func (x *GetGravityResponse) Reset()
- func (x *GetGravityResponse) String() string
- type GetHorizontalMarginRequest
- type GetHorizontalMarginResponse
- func (*GetHorizontalMarginResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetHorizontalMarginResponse) GetResult() float32
- func (*GetHorizontalMarginResponse) ProtoMessage()
- func (x *GetHorizontalMarginResponse) ProtoReflect() protoreflect.Message
- func (x *GetHorizontalMarginResponse) Reset()
- func (x *GetHorizontalMarginResponse) String() string
- type GetVerticalMarginRequest
- type GetVerticalMarginResponse
- func (*GetVerticalMarginResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetVerticalMarginResponse) GetResult() float32
- func (*GetVerticalMarginResponse) ProtoMessage()
- func (x *GetVerticalMarginResponse) ProtoReflect() protoreflect.Message
- func (x *GetVerticalMarginResponse) Reset()
- func (x *GetVerticalMarginResponse) String() string
- type GetViewRequest
- type GetViewResponse
- type GetXOffsetRequest
- type GetXOffsetResponse
- func (*GetXOffsetResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetXOffsetResponse) GetResult() int32
- func (*GetXOffsetResponse) ProtoMessage()
- func (x *GetXOffsetResponse) ProtoReflect() protoreflect.Message
- func (x *GetXOffsetResponse) Reset()
- func (x *GetXOffsetResponse) String() string
- type GetYOffsetRequest
- type GetYOffsetResponse
- func (*GetYOffsetResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetYOffsetResponse) GetResult() int32
- func (*GetYOffsetResponse) ProtoMessage()
- func (x *GetYOffsetResponse) ProtoReflect() protoreflect.Message
- func (x *GetYOffsetResponse) Reset()
- func (x *GetYOffsetResponse) String() string
- type MakeText3Request
- func (*MakeText3Request) Descriptor() ([]byte, []int)deprecated
- func (x *MakeText3Request) GetArg0() int64
- func (x *MakeText3Request) GetArg1() int32
- func (x *MakeText3Request) GetArg2() int32
- func (*MakeText3Request) ProtoMessage()
- func (x *MakeText3Request) ProtoReflect() protoreflect.Message
- func (x *MakeText3Request) Reset()
- func (x *MakeText3Request) String() string
- type MakeText3Response
- type MakeText3_1Request
- func (*MakeText3_1Request) Descriptor() ([]byte, []int)deprecated
- func (x *MakeText3_1Request) GetArg0() int64
- func (x *MakeText3_1Request) GetArg1() string
- func (x *MakeText3_1Request) GetArg2() int32
- func (*MakeText3_1Request) ProtoMessage()
- func (x *MakeText3_1Request) ProtoReflect() protoreflect.Message
- func (x *MakeText3_1Request) Reset()
- func (x *MakeText3_1Request) String() string
- type MakeText3_1Response
- func (*MakeText3_1Response) Descriptor() ([]byte, []int)deprecated
- func (x *MakeText3_1Response) GetResult() int64
- func (*MakeText3_1Response) ProtoMessage()
- func (x *MakeText3_1Response) ProtoReflect() protoreflect.Message
- func (x *MakeText3_1Response) Reset()
- func (x *MakeText3_1Response) String() string
- type RemoveCallbackRequest
- func (*RemoveCallbackRequest) Descriptor() ([]byte, []int)deprecated
- func (x *RemoveCallbackRequest) GetArg0() int64
- func (*RemoveCallbackRequest) ProtoMessage()
- func (x *RemoveCallbackRequest) ProtoReflect() protoreflect.Message
- func (x *RemoveCallbackRequest) Reset()
- func (x *RemoveCallbackRequest) String() string
- type RemoveCallbackResponse
- type SetDurationRequest
- type SetDurationResponse
- type SetGravityRequest
- func (*SetGravityRequest) Descriptor() ([]byte, []int)deprecated
- func (x *SetGravityRequest) GetArg0() int32
- func (x *SetGravityRequest) GetArg1() int32
- func (x *SetGravityRequest) GetArg2() int32
- func (*SetGravityRequest) ProtoMessage()
- func (x *SetGravityRequest) ProtoReflect() protoreflect.Message
- func (x *SetGravityRequest) Reset()
- func (x *SetGravityRequest) String() string
- type SetGravityResponse
- type SetMarginRequest
- func (*SetMarginRequest) Descriptor() ([]byte, []int)deprecated
- func (x *SetMarginRequest) GetArg0() float32
- func (x *SetMarginRequest) GetArg1() float32
- func (*SetMarginRequest) ProtoMessage()
- func (x *SetMarginRequest) ProtoReflect() protoreflect.Message
- func (x *SetMarginRequest) Reset()
- func (x *SetMarginRequest) String() string
- type SetMarginResponse
- type SetText1Request
- type SetText1Response
- type SetText1_1Request
- type SetText1_1Response
- type SetViewRequest
- type SetViewResponse
- type ShowRequest
- type ShowResponse
- type ToastServiceClient
- type ToastServiceServer
- type UnimplementedToastServiceServer
- func (UnimplementedToastServiceServer) AddCallback(context.Context, *AddCallbackRequest) (*AddCallbackResponse, error)
- func (UnimplementedToastServiceServer) Cancel(context.Context, *CancelRequest) (*CancelResponse, error)
- func (UnimplementedToastServiceServer) GetDuration(context.Context, *GetDurationRequest) (*GetDurationResponse, error)
- func (UnimplementedToastServiceServer) GetGravity(context.Context, *GetGravityRequest) (*GetGravityResponse, error)
- func (UnimplementedToastServiceServer) GetHorizontalMargin(context.Context, *GetHorizontalMarginRequest) (*GetHorizontalMarginResponse, error)
- func (UnimplementedToastServiceServer) GetVerticalMargin(context.Context, *GetVerticalMarginRequest) (*GetVerticalMarginResponse, error)
- func (UnimplementedToastServiceServer) GetView(context.Context, *GetViewRequest) (*GetViewResponse, error)
- func (UnimplementedToastServiceServer) GetXOffset(context.Context, *GetXOffsetRequest) (*GetXOffsetResponse, error)
- func (UnimplementedToastServiceServer) GetYOffset(context.Context, *GetYOffsetRequest) (*GetYOffsetResponse, error)
- func (UnimplementedToastServiceServer) MakeText3(context.Context, *MakeText3Request) (*MakeText3Response, error)
- func (UnimplementedToastServiceServer) MakeText3_1(context.Context, *MakeText3_1Request) (*MakeText3_1Response, error)
- func (UnimplementedToastServiceServer) RemoveCallback(context.Context, *RemoveCallbackRequest) (*RemoveCallbackResponse, error)
- func (UnimplementedToastServiceServer) SetDuration(context.Context, *SetDurationRequest) (*SetDurationResponse, error)
- func (UnimplementedToastServiceServer) SetGravity(context.Context, *SetGravityRequest) (*SetGravityResponse, error)
- func (UnimplementedToastServiceServer) SetMargin(context.Context, *SetMarginRequest) (*SetMarginResponse, error)
- func (UnimplementedToastServiceServer) SetText1(context.Context, *SetText1Request) (*SetText1Response, error)
- func (UnimplementedToastServiceServer) SetText1_1(context.Context, *SetText1_1Request) (*SetText1_1Response, error)
- func (UnimplementedToastServiceServer) SetView(context.Context, *SetViewRequest) (*SetViewResponse, error)
- func (UnimplementedToastServiceServer) Show(context.Context, *ShowRequest) (*ShowResponse, error)
- type UnsafeToastServiceServer
Constants ¶
const ( ToastService_AddCallback_FullMethodName = "/toast.ToastService/AddCallback" ToastService_Cancel_FullMethodName = "/toast.ToastService/Cancel" ToastService_GetDuration_FullMethodName = "/toast.ToastService/GetDuration" ToastService_GetGravity_FullMethodName = "/toast.ToastService/GetGravity" ToastService_GetHorizontalMargin_FullMethodName = "/toast.ToastService/GetHorizontalMargin" ToastService_GetVerticalMargin_FullMethodName = "/toast.ToastService/GetVerticalMargin" ToastService_GetView_FullMethodName = "/toast.ToastService/GetView" ToastService_GetXOffset_FullMethodName = "/toast.ToastService/GetXOffset" ToastService_GetYOffset_FullMethodName = "/toast.ToastService/GetYOffset" ToastService_RemoveCallback_FullMethodName = "/toast.ToastService/RemoveCallback" ToastService_SetDuration_FullMethodName = "/toast.ToastService/SetDuration" ToastService_SetGravity_FullMethodName = "/toast.ToastService/SetGravity" ToastService_SetMargin_FullMethodName = "/toast.ToastService/SetMargin" ToastService_SetText1_FullMethodName = "/toast.ToastService/SetText1" ToastService_SetText1_1_FullMethodName = "/toast.ToastService/SetText1_1" ToastService_SetView_FullMethodName = "/toast.ToastService/SetView" ToastService_Show_FullMethodName = "/toast.ToastService/Show" ToastService_MakeText3_FullMethodName = "/toast.ToastService/MakeText3" ToastService_MakeText3_1_FullMethodName = "/toast.ToastService/MakeText3_1" )
Variables ¶
var File_proto_toast_toast_proto protoreflect.FileDescriptor
var ToastService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "toast.ToastService", HandlerType: (*ToastServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "AddCallback", Handler: _ToastService_AddCallback_Handler, }, { MethodName: "Cancel", Handler: _ToastService_Cancel_Handler, }, { MethodName: "GetDuration", Handler: _ToastService_GetDuration_Handler, }, { MethodName: "GetGravity", Handler: _ToastService_GetGravity_Handler, }, { MethodName: "GetHorizontalMargin", Handler: _ToastService_GetHorizontalMargin_Handler, }, { MethodName: "GetVerticalMargin", Handler: _ToastService_GetVerticalMargin_Handler, }, { MethodName: "GetView", Handler: _ToastService_GetView_Handler, }, { MethodName: "GetXOffset", Handler: _ToastService_GetXOffset_Handler, }, { MethodName: "GetYOffset", Handler: _ToastService_GetYOffset_Handler, }, { MethodName: "RemoveCallback", Handler: _ToastService_RemoveCallback_Handler, }, { MethodName: "SetDuration", Handler: _ToastService_SetDuration_Handler, }, { MethodName: "SetGravity", Handler: _ToastService_SetGravity_Handler, }, { MethodName: "SetMargin", Handler: _ToastService_SetMargin_Handler, }, { MethodName: "SetText1", Handler: _ToastService_SetText1_Handler, }, { MethodName: "SetText1_1", Handler: _ToastService_SetText1_1_Handler, }, { MethodName: "SetView", Handler: _ToastService_SetView_Handler, }, { MethodName: "Show", Handler: _ToastService_Show_Handler, }, { MethodName: "MakeText3", Handler: _ToastService_MakeText3_Handler, }, { MethodName: "MakeText3_1", Handler: _ToastService_MakeText3_1_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "proto/toast/toast.proto", }
ToastService_ServiceDesc is the grpc.ServiceDesc for ToastService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterToastServiceServer ¶
func RegisterToastServiceServer(s grpc.ServiceRegistrar, srv ToastServiceServer)
Types ¶
type AddCallbackRequest ¶
type AddCallbackRequest struct {
Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
// contains filtered or unexported fields
}
func (*AddCallbackRequest) Descriptor
deprecated
func (*AddCallbackRequest) Descriptor() ([]byte, []int)
Deprecated: Use AddCallbackRequest.ProtoReflect.Descriptor instead.
func (*AddCallbackRequest) GetArg0 ¶
func (x *AddCallbackRequest) GetArg0() int64
func (*AddCallbackRequest) ProtoMessage ¶
func (*AddCallbackRequest) ProtoMessage()
func (*AddCallbackRequest) ProtoReflect ¶
func (x *AddCallbackRequest) ProtoReflect() protoreflect.Message
func (*AddCallbackRequest) Reset ¶
func (x *AddCallbackRequest) Reset()
func (*AddCallbackRequest) String ¶
func (x *AddCallbackRequest) String() string
type AddCallbackResponse ¶
type AddCallbackResponse struct {
// contains filtered or unexported fields
}
func (*AddCallbackResponse) Descriptor
deprecated
func (*AddCallbackResponse) Descriptor() ([]byte, []int)
Deprecated: Use AddCallbackResponse.ProtoReflect.Descriptor instead.
func (*AddCallbackResponse) ProtoMessage ¶
func (*AddCallbackResponse) ProtoMessage()
func (*AddCallbackResponse) ProtoReflect ¶
func (x *AddCallbackResponse) ProtoReflect() protoreflect.Message
func (*AddCallbackResponse) Reset ¶
func (x *AddCallbackResponse) Reset()
func (*AddCallbackResponse) String ¶
func (x *AddCallbackResponse) String() string
type CancelRequest ¶
type CancelRequest struct {
// contains filtered or unexported fields
}
func (*CancelRequest) Descriptor
deprecated
func (*CancelRequest) Descriptor() ([]byte, []int)
Deprecated: Use CancelRequest.ProtoReflect.Descriptor instead.
func (*CancelRequest) ProtoMessage ¶
func (*CancelRequest) ProtoMessage()
func (*CancelRequest) ProtoReflect ¶
func (x *CancelRequest) ProtoReflect() protoreflect.Message
func (*CancelRequest) Reset ¶
func (x *CancelRequest) Reset()
func (*CancelRequest) String ¶
func (x *CancelRequest) String() string
type CancelResponse ¶
type CancelResponse struct {
// contains filtered or unexported fields
}
func (*CancelResponse) Descriptor
deprecated
func (*CancelResponse) Descriptor() ([]byte, []int)
Deprecated: Use CancelResponse.ProtoReflect.Descriptor instead.
func (*CancelResponse) ProtoMessage ¶
func (*CancelResponse) ProtoMessage()
func (*CancelResponse) ProtoReflect ¶
func (x *CancelResponse) ProtoReflect() protoreflect.Message
func (*CancelResponse) Reset ¶
func (x *CancelResponse) Reset()
func (*CancelResponse) String ¶
func (x *CancelResponse) String() string
type GetDurationRequest ¶
type GetDurationRequest struct {
// contains filtered or unexported fields
}
func (*GetDurationRequest) Descriptor
deprecated
func (*GetDurationRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetDurationRequest.ProtoReflect.Descriptor instead.
func (*GetDurationRequest) ProtoMessage ¶
func (*GetDurationRequest) ProtoMessage()
func (*GetDurationRequest) ProtoReflect ¶
func (x *GetDurationRequest) ProtoReflect() protoreflect.Message
func (*GetDurationRequest) Reset ¶
func (x *GetDurationRequest) Reset()
func (*GetDurationRequest) String ¶
func (x *GetDurationRequest) String() string
type GetDurationResponse ¶
type GetDurationResponse struct {
Result int32 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*GetDurationResponse) Descriptor
deprecated
func (*GetDurationResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetDurationResponse.ProtoReflect.Descriptor instead.
func (*GetDurationResponse) GetResult ¶
func (x *GetDurationResponse) GetResult() int32
func (*GetDurationResponse) ProtoMessage ¶
func (*GetDurationResponse) ProtoMessage()
func (*GetDurationResponse) ProtoReflect ¶
func (x *GetDurationResponse) ProtoReflect() protoreflect.Message
func (*GetDurationResponse) Reset ¶
func (x *GetDurationResponse) Reset()
func (*GetDurationResponse) String ¶
func (x *GetDurationResponse) String() string
type GetGravityRequest ¶
type GetGravityRequest struct {
// contains filtered or unexported fields
}
func (*GetGravityRequest) Descriptor
deprecated
func (*GetGravityRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetGravityRequest.ProtoReflect.Descriptor instead.
func (*GetGravityRequest) ProtoMessage ¶
func (*GetGravityRequest) ProtoMessage()
func (*GetGravityRequest) ProtoReflect ¶
func (x *GetGravityRequest) ProtoReflect() protoreflect.Message
func (*GetGravityRequest) Reset ¶
func (x *GetGravityRequest) Reset()
func (*GetGravityRequest) String ¶
func (x *GetGravityRequest) String() string
type GetGravityResponse ¶
type GetGravityResponse struct {
Result int32 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*GetGravityResponse) Descriptor
deprecated
func (*GetGravityResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetGravityResponse.ProtoReflect.Descriptor instead.
func (*GetGravityResponse) GetResult ¶
func (x *GetGravityResponse) GetResult() int32
func (*GetGravityResponse) ProtoMessage ¶
func (*GetGravityResponse) ProtoMessage()
func (*GetGravityResponse) ProtoReflect ¶
func (x *GetGravityResponse) ProtoReflect() protoreflect.Message
func (*GetGravityResponse) Reset ¶
func (x *GetGravityResponse) Reset()
func (*GetGravityResponse) String ¶
func (x *GetGravityResponse) String() string
type GetHorizontalMarginRequest ¶
type GetHorizontalMarginRequest struct {
// contains filtered or unexported fields
}
func (*GetHorizontalMarginRequest) Descriptor
deprecated
func (*GetHorizontalMarginRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetHorizontalMarginRequest.ProtoReflect.Descriptor instead.
func (*GetHorizontalMarginRequest) ProtoMessage ¶
func (*GetHorizontalMarginRequest) ProtoMessage()
func (*GetHorizontalMarginRequest) ProtoReflect ¶
func (x *GetHorizontalMarginRequest) ProtoReflect() protoreflect.Message
func (*GetHorizontalMarginRequest) Reset ¶
func (x *GetHorizontalMarginRequest) Reset()
func (*GetHorizontalMarginRequest) String ¶
func (x *GetHorizontalMarginRequest) String() string
type GetHorizontalMarginResponse ¶
type GetHorizontalMarginResponse struct {
Result float32 `protobuf:"fixed32,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*GetHorizontalMarginResponse) Descriptor
deprecated
func (*GetHorizontalMarginResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetHorizontalMarginResponse.ProtoReflect.Descriptor instead.
func (*GetHorizontalMarginResponse) GetResult ¶
func (x *GetHorizontalMarginResponse) GetResult() float32
func (*GetHorizontalMarginResponse) ProtoMessage ¶
func (*GetHorizontalMarginResponse) ProtoMessage()
func (*GetHorizontalMarginResponse) ProtoReflect ¶
func (x *GetHorizontalMarginResponse) ProtoReflect() protoreflect.Message
func (*GetHorizontalMarginResponse) Reset ¶
func (x *GetHorizontalMarginResponse) Reset()
func (*GetHorizontalMarginResponse) String ¶
func (x *GetHorizontalMarginResponse) String() string
type GetVerticalMarginRequest ¶
type GetVerticalMarginRequest struct {
// contains filtered or unexported fields
}
func (*GetVerticalMarginRequest) Descriptor
deprecated
func (*GetVerticalMarginRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetVerticalMarginRequest.ProtoReflect.Descriptor instead.
func (*GetVerticalMarginRequest) ProtoMessage ¶
func (*GetVerticalMarginRequest) ProtoMessage()
func (*GetVerticalMarginRequest) ProtoReflect ¶
func (x *GetVerticalMarginRequest) ProtoReflect() protoreflect.Message
func (*GetVerticalMarginRequest) Reset ¶
func (x *GetVerticalMarginRequest) Reset()
func (*GetVerticalMarginRequest) String ¶
func (x *GetVerticalMarginRequest) String() string
type GetVerticalMarginResponse ¶
type GetVerticalMarginResponse struct {
Result float32 `protobuf:"fixed32,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*GetVerticalMarginResponse) Descriptor
deprecated
func (*GetVerticalMarginResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetVerticalMarginResponse.ProtoReflect.Descriptor instead.
func (*GetVerticalMarginResponse) GetResult ¶
func (x *GetVerticalMarginResponse) GetResult() float32
func (*GetVerticalMarginResponse) ProtoMessage ¶
func (*GetVerticalMarginResponse) ProtoMessage()
func (*GetVerticalMarginResponse) ProtoReflect ¶
func (x *GetVerticalMarginResponse) ProtoReflect() protoreflect.Message
func (*GetVerticalMarginResponse) Reset ¶
func (x *GetVerticalMarginResponse) Reset()
func (*GetVerticalMarginResponse) String ¶
func (x *GetVerticalMarginResponse) String() string
type GetViewRequest ¶
type GetViewRequest struct {
// contains filtered or unexported fields
}
func (*GetViewRequest) Descriptor
deprecated
func (*GetViewRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetViewRequest.ProtoReflect.Descriptor instead.
func (*GetViewRequest) ProtoMessage ¶
func (*GetViewRequest) ProtoMessage()
func (*GetViewRequest) ProtoReflect ¶
func (x *GetViewRequest) ProtoReflect() protoreflect.Message
func (*GetViewRequest) Reset ¶
func (x *GetViewRequest) Reset()
func (*GetViewRequest) String ¶
func (x *GetViewRequest) String() string
type GetViewResponse ¶
type GetViewResponse struct {
Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*GetViewResponse) Descriptor
deprecated
func (*GetViewResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetViewResponse.ProtoReflect.Descriptor instead.
func (*GetViewResponse) GetResult ¶
func (x *GetViewResponse) GetResult() int64
func (*GetViewResponse) ProtoMessage ¶
func (*GetViewResponse) ProtoMessage()
func (*GetViewResponse) ProtoReflect ¶
func (x *GetViewResponse) ProtoReflect() protoreflect.Message
func (*GetViewResponse) Reset ¶
func (x *GetViewResponse) Reset()
func (*GetViewResponse) String ¶
func (x *GetViewResponse) String() string
type GetXOffsetRequest ¶
type GetXOffsetRequest struct {
// contains filtered or unexported fields
}
func (*GetXOffsetRequest) Descriptor
deprecated
func (*GetXOffsetRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetXOffsetRequest.ProtoReflect.Descriptor instead.
func (*GetXOffsetRequest) ProtoMessage ¶
func (*GetXOffsetRequest) ProtoMessage()
func (*GetXOffsetRequest) ProtoReflect ¶
func (x *GetXOffsetRequest) ProtoReflect() protoreflect.Message
func (*GetXOffsetRequest) Reset ¶
func (x *GetXOffsetRequest) Reset()
func (*GetXOffsetRequest) String ¶
func (x *GetXOffsetRequest) String() string
type GetXOffsetResponse ¶
type GetXOffsetResponse struct {
Result int32 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*GetXOffsetResponse) Descriptor
deprecated
func (*GetXOffsetResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetXOffsetResponse.ProtoReflect.Descriptor instead.
func (*GetXOffsetResponse) GetResult ¶
func (x *GetXOffsetResponse) GetResult() int32
func (*GetXOffsetResponse) ProtoMessage ¶
func (*GetXOffsetResponse) ProtoMessage()
func (*GetXOffsetResponse) ProtoReflect ¶
func (x *GetXOffsetResponse) ProtoReflect() protoreflect.Message
func (*GetXOffsetResponse) Reset ¶
func (x *GetXOffsetResponse) Reset()
func (*GetXOffsetResponse) String ¶
func (x *GetXOffsetResponse) String() string
type GetYOffsetRequest ¶
type GetYOffsetRequest struct {
// contains filtered or unexported fields
}
func (*GetYOffsetRequest) Descriptor
deprecated
func (*GetYOffsetRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetYOffsetRequest.ProtoReflect.Descriptor instead.
func (*GetYOffsetRequest) ProtoMessage ¶
func (*GetYOffsetRequest) ProtoMessage()
func (*GetYOffsetRequest) ProtoReflect ¶
func (x *GetYOffsetRequest) ProtoReflect() protoreflect.Message
func (*GetYOffsetRequest) Reset ¶
func (x *GetYOffsetRequest) Reset()
func (*GetYOffsetRequest) String ¶
func (x *GetYOffsetRequest) String() string
type GetYOffsetResponse ¶
type GetYOffsetResponse struct {
Result int32 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*GetYOffsetResponse) Descriptor
deprecated
func (*GetYOffsetResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetYOffsetResponse.ProtoReflect.Descriptor instead.
func (*GetYOffsetResponse) GetResult ¶
func (x *GetYOffsetResponse) GetResult() int32
func (*GetYOffsetResponse) ProtoMessage ¶
func (*GetYOffsetResponse) ProtoMessage()
func (*GetYOffsetResponse) ProtoReflect ¶
func (x *GetYOffsetResponse) ProtoReflect() protoreflect.Message
func (*GetYOffsetResponse) Reset ¶
func (x *GetYOffsetResponse) Reset()
func (*GetYOffsetResponse) String ¶
func (x *GetYOffsetResponse) String() string
type MakeText3Request ¶
type MakeText3Request struct {
Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
Arg1 int32 `protobuf:"varint,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
Arg2 int32 `protobuf:"varint,3,opt,name=arg2,proto3" json:"arg2,omitempty"`
// contains filtered or unexported fields
}
func (*MakeText3Request) Descriptor
deprecated
func (*MakeText3Request) Descriptor() ([]byte, []int)
Deprecated: Use MakeText3Request.ProtoReflect.Descriptor instead.
func (*MakeText3Request) GetArg0 ¶
func (x *MakeText3Request) GetArg0() int64
func (*MakeText3Request) GetArg1 ¶
func (x *MakeText3Request) GetArg1() int32
func (*MakeText3Request) GetArg2 ¶
func (x *MakeText3Request) GetArg2() int32
func (*MakeText3Request) ProtoMessage ¶
func (*MakeText3Request) ProtoMessage()
func (*MakeText3Request) ProtoReflect ¶
func (x *MakeText3Request) ProtoReflect() protoreflect.Message
func (*MakeText3Request) Reset ¶
func (x *MakeText3Request) Reset()
func (*MakeText3Request) String ¶
func (x *MakeText3Request) String() string
type MakeText3Response ¶
type MakeText3Response struct {
Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*MakeText3Response) Descriptor
deprecated
func (*MakeText3Response) Descriptor() ([]byte, []int)
Deprecated: Use MakeText3Response.ProtoReflect.Descriptor instead.
func (*MakeText3Response) GetResult ¶
func (x *MakeText3Response) GetResult() int64
func (*MakeText3Response) ProtoMessage ¶
func (*MakeText3Response) ProtoMessage()
func (*MakeText3Response) ProtoReflect ¶
func (x *MakeText3Response) ProtoReflect() protoreflect.Message
func (*MakeText3Response) Reset ¶
func (x *MakeText3Response) Reset()
func (*MakeText3Response) String ¶
func (x *MakeText3Response) String() string
type MakeText3_1Request ¶
type MakeText3_1Request struct {
Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
Arg1 string `protobuf:"bytes,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
Arg2 int32 `protobuf:"varint,3,opt,name=arg2,proto3" json:"arg2,omitempty"`
// contains filtered or unexported fields
}
func (*MakeText3_1Request) Descriptor
deprecated
func (*MakeText3_1Request) Descriptor() ([]byte, []int)
Deprecated: Use MakeText3_1Request.ProtoReflect.Descriptor instead.
func (*MakeText3_1Request) GetArg0 ¶
func (x *MakeText3_1Request) GetArg0() int64
func (*MakeText3_1Request) GetArg1 ¶
func (x *MakeText3_1Request) GetArg1() string
func (*MakeText3_1Request) GetArg2 ¶
func (x *MakeText3_1Request) GetArg2() int32
func (*MakeText3_1Request) ProtoMessage ¶
func (*MakeText3_1Request) ProtoMessage()
func (*MakeText3_1Request) ProtoReflect ¶
func (x *MakeText3_1Request) ProtoReflect() protoreflect.Message
func (*MakeText3_1Request) Reset ¶
func (x *MakeText3_1Request) Reset()
func (*MakeText3_1Request) String ¶
func (x *MakeText3_1Request) String() string
type MakeText3_1Response ¶
type MakeText3_1Response struct {
Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*MakeText3_1Response) Descriptor
deprecated
func (*MakeText3_1Response) Descriptor() ([]byte, []int)
Deprecated: Use MakeText3_1Response.ProtoReflect.Descriptor instead.
func (*MakeText3_1Response) GetResult ¶
func (x *MakeText3_1Response) GetResult() int64
func (*MakeText3_1Response) ProtoMessage ¶
func (*MakeText3_1Response) ProtoMessage()
func (*MakeText3_1Response) ProtoReflect ¶
func (x *MakeText3_1Response) ProtoReflect() protoreflect.Message
func (*MakeText3_1Response) Reset ¶
func (x *MakeText3_1Response) Reset()
func (*MakeText3_1Response) String ¶
func (x *MakeText3_1Response) String() string
type RemoveCallbackRequest ¶
type RemoveCallbackRequest struct {
Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
// contains filtered or unexported fields
}
func (*RemoveCallbackRequest) Descriptor
deprecated
func (*RemoveCallbackRequest) Descriptor() ([]byte, []int)
Deprecated: Use RemoveCallbackRequest.ProtoReflect.Descriptor instead.
func (*RemoveCallbackRequest) GetArg0 ¶
func (x *RemoveCallbackRequest) GetArg0() int64
func (*RemoveCallbackRequest) ProtoMessage ¶
func (*RemoveCallbackRequest) ProtoMessage()
func (*RemoveCallbackRequest) ProtoReflect ¶
func (x *RemoveCallbackRequest) ProtoReflect() protoreflect.Message
func (*RemoveCallbackRequest) Reset ¶
func (x *RemoveCallbackRequest) Reset()
func (*RemoveCallbackRequest) String ¶
func (x *RemoveCallbackRequest) String() string
type RemoveCallbackResponse ¶
type RemoveCallbackResponse struct {
// contains filtered or unexported fields
}
func (*RemoveCallbackResponse) Descriptor
deprecated
func (*RemoveCallbackResponse) Descriptor() ([]byte, []int)
Deprecated: Use RemoveCallbackResponse.ProtoReflect.Descriptor instead.
func (*RemoveCallbackResponse) ProtoMessage ¶
func (*RemoveCallbackResponse) ProtoMessage()
func (*RemoveCallbackResponse) ProtoReflect ¶
func (x *RemoveCallbackResponse) ProtoReflect() protoreflect.Message
func (*RemoveCallbackResponse) Reset ¶
func (x *RemoveCallbackResponse) Reset()
func (*RemoveCallbackResponse) String ¶
func (x *RemoveCallbackResponse) String() string
type SetDurationRequest ¶
type SetDurationRequest struct {
Arg0 int32 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
// contains filtered or unexported fields
}
func (*SetDurationRequest) Descriptor
deprecated
func (*SetDurationRequest) Descriptor() ([]byte, []int)
Deprecated: Use SetDurationRequest.ProtoReflect.Descriptor instead.
func (*SetDurationRequest) GetArg0 ¶
func (x *SetDurationRequest) GetArg0() int32
func (*SetDurationRequest) ProtoMessage ¶
func (*SetDurationRequest) ProtoMessage()
func (*SetDurationRequest) ProtoReflect ¶
func (x *SetDurationRequest) ProtoReflect() protoreflect.Message
func (*SetDurationRequest) Reset ¶
func (x *SetDurationRequest) Reset()
func (*SetDurationRequest) String ¶
func (x *SetDurationRequest) String() string
type SetDurationResponse ¶
type SetDurationResponse struct {
// contains filtered or unexported fields
}
func (*SetDurationResponse) Descriptor
deprecated
func (*SetDurationResponse) Descriptor() ([]byte, []int)
Deprecated: Use SetDurationResponse.ProtoReflect.Descriptor instead.
func (*SetDurationResponse) ProtoMessage ¶
func (*SetDurationResponse) ProtoMessage()
func (*SetDurationResponse) ProtoReflect ¶
func (x *SetDurationResponse) ProtoReflect() protoreflect.Message
func (*SetDurationResponse) Reset ¶
func (x *SetDurationResponse) Reset()
func (*SetDurationResponse) String ¶
func (x *SetDurationResponse) String() string
type SetGravityRequest ¶
type SetGravityRequest struct {
Arg0 int32 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
Arg1 int32 `protobuf:"varint,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
Arg2 int32 `protobuf:"varint,3,opt,name=arg2,proto3" json:"arg2,omitempty"`
// contains filtered or unexported fields
}
func (*SetGravityRequest) Descriptor
deprecated
func (*SetGravityRequest) Descriptor() ([]byte, []int)
Deprecated: Use SetGravityRequest.ProtoReflect.Descriptor instead.
func (*SetGravityRequest) GetArg0 ¶
func (x *SetGravityRequest) GetArg0() int32
func (*SetGravityRequest) GetArg1 ¶
func (x *SetGravityRequest) GetArg1() int32
func (*SetGravityRequest) GetArg2 ¶
func (x *SetGravityRequest) GetArg2() int32
func (*SetGravityRequest) ProtoMessage ¶
func (*SetGravityRequest) ProtoMessage()
func (*SetGravityRequest) ProtoReflect ¶
func (x *SetGravityRequest) ProtoReflect() protoreflect.Message
func (*SetGravityRequest) Reset ¶
func (x *SetGravityRequest) Reset()
func (*SetGravityRequest) String ¶
func (x *SetGravityRequest) String() string
type SetGravityResponse ¶
type SetGravityResponse struct {
// contains filtered or unexported fields
}
func (*SetGravityResponse) Descriptor
deprecated
func (*SetGravityResponse) Descriptor() ([]byte, []int)
Deprecated: Use SetGravityResponse.ProtoReflect.Descriptor instead.
func (*SetGravityResponse) ProtoMessage ¶
func (*SetGravityResponse) ProtoMessage()
func (*SetGravityResponse) ProtoReflect ¶
func (x *SetGravityResponse) ProtoReflect() protoreflect.Message
func (*SetGravityResponse) Reset ¶
func (x *SetGravityResponse) Reset()
func (*SetGravityResponse) String ¶
func (x *SetGravityResponse) String() string
type SetMarginRequest ¶
type SetMarginRequest struct {
Arg0 float32 `protobuf:"fixed32,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
Arg1 float32 `protobuf:"fixed32,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
// contains filtered or unexported fields
}
func (*SetMarginRequest) Descriptor
deprecated
func (*SetMarginRequest) Descriptor() ([]byte, []int)
Deprecated: Use SetMarginRequest.ProtoReflect.Descriptor instead.
func (*SetMarginRequest) GetArg0 ¶
func (x *SetMarginRequest) GetArg0() float32
func (*SetMarginRequest) GetArg1 ¶
func (x *SetMarginRequest) GetArg1() float32
func (*SetMarginRequest) ProtoMessage ¶
func (*SetMarginRequest) ProtoMessage()
func (*SetMarginRequest) ProtoReflect ¶
func (x *SetMarginRequest) ProtoReflect() protoreflect.Message
func (*SetMarginRequest) Reset ¶
func (x *SetMarginRequest) Reset()
func (*SetMarginRequest) String ¶
func (x *SetMarginRequest) String() string
type SetMarginResponse ¶
type SetMarginResponse struct {
// contains filtered or unexported fields
}
func (*SetMarginResponse) Descriptor
deprecated
func (*SetMarginResponse) Descriptor() ([]byte, []int)
Deprecated: Use SetMarginResponse.ProtoReflect.Descriptor instead.
func (*SetMarginResponse) ProtoMessage ¶
func (*SetMarginResponse) ProtoMessage()
func (*SetMarginResponse) ProtoReflect ¶
func (x *SetMarginResponse) ProtoReflect() protoreflect.Message
func (*SetMarginResponse) Reset ¶
func (x *SetMarginResponse) Reset()
func (*SetMarginResponse) String ¶
func (x *SetMarginResponse) String() string
type SetText1Request ¶
type SetText1Request struct {
Arg0 int32 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
// contains filtered or unexported fields
}
func (*SetText1Request) Descriptor
deprecated
func (*SetText1Request) Descriptor() ([]byte, []int)
Deprecated: Use SetText1Request.ProtoReflect.Descriptor instead.
func (*SetText1Request) GetArg0 ¶
func (x *SetText1Request) GetArg0() int32
func (*SetText1Request) ProtoMessage ¶
func (*SetText1Request) ProtoMessage()
func (*SetText1Request) ProtoReflect ¶
func (x *SetText1Request) ProtoReflect() protoreflect.Message
func (*SetText1Request) Reset ¶
func (x *SetText1Request) Reset()
func (*SetText1Request) String ¶
func (x *SetText1Request) String() string
type SetText1Response ¶
type SetText1Response struct {
// contains filtered or unexported fields
}
func (*SetText1Response) Descriptor
deprecated
func (*SetText1Response) Descriptor() ([]byte, []int)
Deprecated: Use SetText1Response.ProtoReflect.Descriptor instead.
func (*SetText1Response) ProtoMessage ¶
func (*SetText1Response) ProtoMessage()
func (*SetText1Response) ProtoReflect ¶
func (x *SetText1Response) ProtoReflect() protoreflect.Message
func (*SetText1Response) Reset ¶
func (x *SetText1Response) Reset()
func (*SetText1Response) String ¶
func (x *SetText1Response) String() string
type SetText1_1Request ¶
type SetText1_1Request struct {
Arg0 string `protobuf:"bytes,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
// contains filtered or unexported fields
}
func (*SetText1_1Request) Descriptor
deprecated
func (*SetText1_1Request) Descriptor() ([]byte, []int)
Deprecated: Use SetText1_1Request.ProtoReflect.Descriptor instead.
func (*SetText1_1Request) GetArg0 ¶
func (x *SetText1_1Request) GetArg0() string
func (*SetText1_1Request) ProtoMessage ¶
func (*SetText1_1Request) ProtoMessage()
func (*SetText1_1Request) ProtoReflect ¶
func (x *SetText1_1Request) ProtoReflect() protoreflect.Message
func (*SetText1_1Request) Reset ¶
func (x *SetText1_1Request) Reset()
func (*SetText1_1Request) String ¶
func (x *SetText1_1Request) String() string
type SetText1_1Response ¶
type SetText1_1Response struct {
// contains filtered or unexported fields
}
func (*SetText1_1Response) Descriptor
deprecated
func (*SetText1_1Response) Descriptor() ([]byte, []int)
Deprecated: Use SetText1_1Response.ProtoReflect.Descriptor instead.
func (*SetText1_1Response) ProtoMessage ¶
func (*SetText1_1Response) ProtoMessage()
func (*SetText1_1Response) ProtoReflect ¶
func (x *SetText1_1Response) ProtoReflect() protoreflect.Message
func (*SetText1_1Response) Reset ¶
func (x *SetText1_1Response) Reset()
func (*SetText1_1Response) String ¶
func (x *SetText1_1Response) String() string
type SetViewRequest ¶
type SetViewRequest struct {
Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
// contains filtered or unexported fields
}
func (*SetViewRequest) Descriptor
deprecated
func (*SetViewRequest) Descriptor() ([]byte, []int)
Deprecated: Use SetViewRequest.ProtoReflect.Descriptor instead.
func (*SetViewRequest) GetArg0 ¶
func (x *SetViewRequest) GetArg0() int64
func (*SetViewRequest) ProtoMessage ¶
func (*SetViewRequest) ProtoMessage()
func (*SetViewRequest) ProtoReflect ¶
func (x *SetViewRequest) ProtoReflect() protoreflect.Message
func (*SetViewRequest) Reset ¶
func (x *SetViewRequest) Reset()
func (*SetViewRequest) String ¶
func (x *SetViewRequest) String() string
type SetViewResponse ¶
type SetViewResponse struct {
// contains filtered or unexported fields
}
func (*SetViewResponse) Descriptor
deprecated
func (*SetViewResponse) Descriptor() ([]byte, []int)
Deprecated: Use SetViewResponse.ProtoReflect.Descriptor instead.
func (*SetViewResponse) ProtoMessage ¶
func (*SetViewResponse) ProtoMessage()
func (*SetViewResponse) ProtoReflect ¶
func (x *SetViewResponse) ProtoReflect() protoreflect.Message
func (*SetViewResponse) Reset ¶
func (x *SetViewResponse) Reset()
func (*SetViewResponse) String ¶
func (x *SetViewResponse) String() string
type ShowRequest ¶
type ShowRequest struct {
// contains filtered or unexported fields
}
func (*ShowRequest) Descriptor
deprecated
func (*ShowRequest) Descriptor() ([]byte, []int)
Deprecated: Use ShowRequest.ProtoReflect.Descriptor instead.
func (*ShowRequest) ProtoMessage ¶
func (*ShowRequest) ProtoMessage()
func (*ShowRequest) ProtoReflect ¶
func (x *ShowRequest) ProtoReflect() protoreflect.Message
func (*ShowRequest) Reset ¶
func (x *ShowRequest) Reset()
func (*ShowRequest) String ¶
func (x *ShowRequest) String() string
type ShowResponse ¶
type ShowResponse struct {
// contains filtered or unexported fields
}
func (*ShowResponse) Descriptor
deprecated
func (*ShowResponse) Descriptor() ([]byte, []int)
Deprecated: Use ShowResponse.ProtoReflect.Descriptor instead.
func (*ShowResponse) ProtoMessage ¶
func (*ShowResponse) ProtoMessage()
func (*ShowResponse) ProtoReflect ¶
func (x *ShowResponse) ProtoReflect() protoreflect.Message
func (*ShowResponse) Reset ¶
func (x *ShowResponse) Reset()
func (*ShowResponse) String ¶
func (x *ShowResponse) String() string
type ToastServiceClient ¶
type ToastServiceClient interface {
AddCallback(ctx context.Context, in *AddCallbackRequest, opts ...grpc.CallOption) (*AddCallbackResponse, error)
Cancel(ctx context.Context, in *CancelRequest, opts ...grpc.CallOption) (*CancelResponse, error)
GetDuration(ctx context.Context, in *GetDurationRequest, opts ...grpc.CallOption) (*GetDurationResponse, error)
GetGravity(ctx context.Context, in *GetGravityRequest, opts ...grpc.CallOption) (*GetGravityResponse, error)
GetHorizontalMargin(ctx context.Context, in *GetHorizontalMarginRequest, opts ...grpc.CallOption) (*GetHorizontalMarginResponse, error)
GetVerticalMargin(ctx context.Context, in *GetVerticalMarginRequest, opts ...grpc.CallOption) (*GetVerticalMarginResponse, error)
GetView(ctx context.Context, in *GetViewRequest, opts ...grpc.CallOption) (*GetViewResponse, error)
GetXOffset(ctx context.Context, in *GetXOffsetRequest, opts ...grpc.CallOption) (*GetXOffsetResponse, error)
GetYOffset(ctx context.Context, in *GetYOffsetRequest, opts ...grpc.CallOption) (*GetYOffsetResponse, error)
RemoveCallback(ctx context.Context, in *RemoveCallbackRequest, opts ...grpc.CallOption) (*RemoveCallbackResponse, error)
SetDuration(ctx context.Context, in *SetDurationRequest, opts ...grpc.CallOption) (*SetDurationResponse, error)
SetGravity(ctx context.Context, in *SetGravityRequest, opts ...grpc.CallOption) (*SetGravityResponse, error)
SetMargin(ctx context.Context, in *SetMarginRequest, opts ...grpc.CallOption) (*SetMarginResponse, error)
SetText1(ctx context.Context, in *SetText1Request, opts ...grpc.CallOption) (*SetText1Response, error)
SetText1_1(ctx context.Context, in *SetText1_1Request, opts ...grpc.CallOption) (*SetText1_1Response, error)
SetView(ctx context.Context, in *SetViewRequest, opts ...grpc.CallOption) (*SetViewResponse, error)
Show(ctx context.Context, in *ShowRequest, opts ...grpc.CallOption) (*ShowResponse, error)
MakeText3(ctx context.Context, in *MakeText3Request, opts ...grpc.CallOption) (*MakeText3Response, error)
MakeText3_1(ctx context.Context, in *MakeText3_1Request, opts ...grpc.CallOption) (*MakeText3_1Response, error)
}
ToastServiceClient is the client API for ToastService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewToastServiceClient ¶
func NewToastServiceClient(cc grpc.ClientConnInterface) ToastServiceClient
type ToastServiceServer ¶
type ToastServiceServer interface {
AddCallback(context.Context, *AddCallbackRequest) (*AddCallbackResponse, error)
Cancel(context.Context, *CancelRequest) (*CancelResponse, error)
GetDuration(context.Context, *GetDurationRequest) (*GetDurationResponse, error)
GetGravity(context.Context, *GetGravityRequest) (*GetGravityResponse, error)
GetHorizontalMargin(context.Context, *GetHorizontalMarginRequest) (*GetHorizontalMarginResponse, error)
GetVerticalMargin(context.Context, *GetVerticalMarginRequest) (*GetVerticalMarginResponse, error)
GetView(context.Context, *GetViewRequest) (*GetViewResponse, error)
GetXOffset(context.Context, *GetXOffsetRequest) (*GetXOffsetResponse, error)
GetYOffset(context.Context, *GetYOffsetRequest) (*GetYOffsetResponse, error)
RemoveCallback(context.Context, *RemoveCallbackRequest) (*RemoveCallbackResponse, error)
SetDuration(context.Context, *SetDurationRequest) (*SetDurationResponse, error)
SetGravity(context.Context, *SetGravityRequest) (*SetGravityResponse, error)
SetMargin(context.Context, *SetMarginRequest) (*SetMarginResponse, error)
SetText1(context.Context, *SetText1Request) (*SetText1Response, error)
SetText1_1(context.Context, *SetText1_1Request) (*SetText1_1Response, error)
SetView(context.Context, *SetViewRequest) (*SetViewResponse, error)
Show(context.Context, *ShowRequest) (*ShowResponse, error)
MakeText3(context.Context, *MakeText3Request) (*MakeText3Response, error)
MakeText3_1(context.Context, *MakeText3_1Request) (*MakeText3_1Response, error)
// contains filtered or unexported methods
}
ToastServiceServer is the server API for ToastService service. All implementations must embed UnimplementedToastServiceServer for forward compatibility.
type UnimplementedToastServiceServer ¶
type UnimplementedToastServiceServer struct{}
UnimplementedToastServiceServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedToastServiceServer) AddCallback ¶
func (UnimplementedToastServiceServer) AddCallback(context.Context, *AddCallbackRequest) (*AddCallbackResponse, error)
func (UnimplementedToastServiceServer) Cancel ¶
func (UnimplementedToastServiceServer) Cancel(context.Context, *CancelRequest) (*CancelResponse, error)
func (UnimplementedToastServiceServer) GetDuration ¶
func (UnimplementedToastServiceServer) GetDuration(context.Context, *GetDurationRequest) (*GetDurationResponse, error)
func (UnimplementedToastServiceServer) GetGravity ¶
func (UnimplementedToastServiceServer) GetGravity(context.Context, *GetGravityRequest) (*GetGravityResponse, error)
func (UnimplementedToastServiceServer) GetHorizontalMargin ¶
func (UnimplementedToastServiceServer) GetHorizontalMargin(context.Context, *GetHorizontalMarginRequest) (*GetHorizontalMarginResponse, error)
func (UnimplementedToastServiceServer) GetVerticalMargin ¶
func (UnimplementedToastServiceServer) GetVerticalMargin(context.Context, *GetVerticalMarginRequest) (*GetVerticalMarginResponse, error)
func (UnimplementedToastServiceServer) GetView ¶
func (UnimplementedToastServiceServer) GetView(context.Context, *GetViewRequest) (*GetViewResponse, error)
func (UnimplementedToastServiceServer) GetXOffset ¶
func (UnimplementedToastServiceServer) GetXOffset(context.Context, *GetXOffsetRequest) (*GetXOffsetResponse, error)
func (UnimplementedToastServiceServer) GetYOffset ¶
func (UnimplementedToastServiceServer) GetYOffset(context.Context, *GetYOffsetRequest) (*GetYOffsetResponse, error)
func (UnimplementedToastServiceServer) MakeText3 ¶
func (UnimplementedToastServiceServer) MakeText3(context.Context, *MakeText3Request) (*MakeText3Response, error)
func (UnimplementedToastServiceServer) MakeText3_1 ¶
func (UnimplementedToastServiceServer) MakeText3_1(context.Context, *MakeText3_1Request) (*MakeText3_1Response, error)
func (UnimplementedToastServiceServer) RemoveCallback ¶
func (UnimplementedToastServiceServer) RemoveCallback(context.Context, *RemoveCallbackRequest) (*RemoveCallbackResponse, error)
func (UnimplementedToastServiceServer) SetDuration ¶
func (UnimplementedToastServiceServer) SetDuration(context.Context, *SetDurationRequest) (*SetDurationResponse, error)
func (UnimplementedToastServiceServer) SetGravity ¶
func (UnimplementedToastServiceServer) SetGravity(context.Context, *SetGravityRequest) (*SetGravityResponse, error)
func (UnimplementedToastServiceServer) SetMargin ¶
func (UnimplementedToastServiceServer) SetMargin(context.Context, *SetMarginRequest) (*SetMarginResponse, error)
func (UnimplementedToastServiceServer) SetText1 ¶
func (UnimplementedToastServiceServer) SetText1(context.Context, *SetText1Request) (*SetText1Response, error)
func (UnimplementedToastServiceServer) SetText1_1 ¶
func (UnimplementedToastServiceServer) SetText1_1(context.Context, *SetText1_1Request) (*SetText1_1Response, error)
func (UnimplementedToastServiceServer) SetView ¶
func (UnimplementedToastServiceServer) SetView(context.Context, *SetViewRequest) (*SetViewResponse, error)
func (UnimplementedToastServiceServer) Show ¶
func (UnimplementedToastServiceServer) Show(context.Context, *ShowRequest) (*ShowResponse, error)
type UnsafeToastServiceServer ¶
type UnsafeToastServiceServer interface {
// contains filtered or unexported methods
}
UnsafeToastServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ToastServiceServer will result in compilation errors.