Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterVibratorServiceServer(s grpc.ServiceRegistrar, srv VibratorServiceServer)
- type AreEffectsSupportedRequest
- func (*AreEffectsSupportedRequest) Descriptor() ([]byte, []int)deprecated
- func (x *AreEffectsSupportedRequest) GetArg0() int64
- func (*AreEffectsSupportedRequest) ProtoMessage()
- func (x *AreEffectsSupportedRequest) ProtoReflect() protoreflect.Message
- func (x *AreEffectsSupportedRequest) Reset()
- func (x *AreEffectsSupportedRequest) String() string
- type AreEffectsSupportedResponse
- func (*AreEffectsSupportedResponse) Descriptor() ([]byte, []int)deprecated
- func (x *AreEffectsSupportedResponse) GetResult() int64
- func (*AreEffectsSupportedResponse) ProtoMessage()
- func (x *AreEffectsSupportedResponse) ProtoReflect() protoreflect.Message
- func (x *AreEffectsSupportedResponse) Reset()
- func (x *AreEffectsSupportedResponse) String() string
- type AreEnvelopeEffectsSupportedRequest
- func (*AreEnvelopeEffectsSupportedRequest) Descriptor() ([]byte, []int)deprecated
- func (*AreEnvelopeEffectsSupportedRequest) ProtoMessage()
- func (x *AreEnvelopeEffectsSupportedRequest) ProtoReflect() protoreflect.Message
- func (x *AreEnvelopeEffectsSupportedRequest) Reset()
- func (x *AreEnvelopeEffectsSupportedRequest) String() string
- type AreEnvelopeEffectsSupportedResponse
- func (*AreEnvelopeEffectsSupportedResponse) Descriptor() ([]byte, []int)deprecated
- func (x *AreEnvelopeEffectsSupportedResponse) GetResult() bool
- func (*AreEnvelopeEffectsSupportedResponse) ProtoMessage()
- func (x *AreEnvelopeEffectsSupportedResponse) ProtoReflect() protoreflect.Message
- func (x *AreEnvelopeEffectsSupportedResponse) Reset()
- func (x *AreEnvelopeEffectsSupportedResponse) String() string
- type ArePrimitivesSupportedRequest
- func (*ArePrimitivesSupportedRequest) Descriptor() ([]byte, []int)deprecated
- func (x *ArePrimitivesSupportedRequest) GetArg0() int64
- func (*ArePrimitivesSupportedRequest) ProtoMessage()
- func (x *ArePrimitivesSupportedRequest) ProtoReflect() protoreflect.Message
- func (x *ArePrimitivesSupportedRequest) Reset()
- func (x *ArePrimitivesSupportedRequest) String() string
- type ArePrimitivesSupportedResponse
- func (*ArePrimitivesSupportedResponse) Descriptor() ([]byte, []int)deprecated
- func (x *ArePrimitivesSupportedResponse) GetResult() int64
- func (*ArePrimitivesSupportedResponse) ProtoMessage()
- func (x *ArePrimitivesSupportedResponse) ProtoReflect() protoreflect.Message
- func (x *ArePrimitivesSupportedResponse) Reset()
- func (x *ArePrimitivesSupportedResponse) String() string
- type GetEnvelopeEffectInfoRequest
- func (*GetEnvelopeEffectInfoRequest) Descriptor() ([]byte, []int)deprecated
- func (*GetEnvelopeEffectInfoRequest) ProtoMessage()
- func (x *GetEnvelopeEffectInfoRequest) ProtoReflect() protoreflect.Message
- func (x *GetEnvelopeEffectInfoRequest) Reset()
- func (x *GetEnvelopeEffectInfoRequest) String() string
- type GetEnvelopeEffectInfoResponse
- func (*GetEnvelopeEffectInfoResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetEnvelopeEffectInfoResponse) GetResult() int64
- func (*GetEnvelopeEffectInfoResponse) ProtoMessage()
- func (x *GetEnvelopeEffectInfoResponse) ProtoReflect() protoreflect.Message
- func (x *GetEnvelopeEffectInfoResponse) Reset()
- func (x *GetEnvelopeEffectInfoResponse) String() string
- type GetFrequencyProfileRequest
- type GetFrequencyProfileResponse
- func (*GetFrequencyProfileResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetFrequencyProfileResponse) GetResult() int64
- func (*GetFrequencyProfileResponse) ProtoMessage()
- func (x *GetFrequencyProfileResponse) ProtoReflect() protoreflect.Message
- func (x *GetFrequencyProfileResponse) Reset()
- func (x *GetFrequencyProfileResponse) String() string
- type GetIdRequest
- type GetIdResponse
- type GetPrimitiveDurationsRequest
- func (*GetPrimitiveDurationsRequest) Descriptor() ([]byte, []int)deprecated
- func (x *GetPrimitiveDurationsRequest) GetArg0() int64
- func (*GetPrimitiveDurationsRequest) ProtoMessage()
- func (x *GetPrimitiveDurationsRequest) ProtoReflect() protoreflect.Message
- func (x *GetPrimitiveDurationsRequest) Reset()
- func (x *GetPrimitiveDurationsRequest) String() string
- type GetPrimitiveDurationsResponse
- func (*GetPrimitiveDurationsResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetPrimitiveDurationsResponse) GetResult() int64
- func (*GetPrimitiveDurationsResponse) ProtoMessage()
- func (x *GetPrimitiveDurationsResponse) ProtoReflect() protoreflect.Message
- func (x *GetPrimitiveDurationsResponse) Reset()
- func (x *GetPrimitiveDurationsResponse) String() string
- type GetQFactorRequest
- type GetQFactorResponse
- func (*GetQFactorResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetQFactorResponse) GetResult() float32
- func (*GetQFactorResponse) ProtoMessage()
- func (x *GetQFactorResponse) ProtoReflect() protoreflect.Message
- func (x *GetQFactorResponse) Reset()
- func (x *GetQFactorResponse) String() string
- type GetResonantFrequencyRequest
- type GetResonantFrequencyResponse
- func (*GetResonantFrequencyResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetResonantFrequencyResponse) GetResult() float32
- func (*GetResonantFrequencyResponse) ProtoMessage()
- func (x *GetResonantFrequencyResponse) ProtoReflect() protoreflect.Message
- func (x *GetResonantFrequencyResponse) Reset()
- func (x *GetResonantFrequencyResponse) String() string
- type UnimplementedVibratorServiceServer
- func (UnimplementedVibratorServiceServer) AreEffectsSupported(context.Context, *AreEffectsSupportedRequest) (*AreEffectsSupportedResponse, error)
- func (UnimplementedVibratorServiceServer) AreEnvelopeEffectsSupported(context.Context, *AreEnvelopeEffectsSupportedRequest) (*AreEnvelopeEffectsSupportedResponse, error)
- func (UnimplementedVibratorServiceServer) ArePrimitivesSupported(context.Context, *ArePrimitivesSupportedRequest) (*ArePrimitivesSupportedResponse, error)
- func (UnimplementedVibratorServiceServer) GetEnvelopeEffectInfo(context.Context, *GetEnvelopeEffectInfoRequest) (*GetEnvelopeEffectInfoResponse, error)
- func (UnimplementedVibratorServiceServer) GetFrequencyProfile(context.Context, *GetFrequencyProfileRequest) (*GetFrequencyProfileResponse, error)
- func (UnimplementedVibratorServiceServer) GetId(context.Context, *GetIdRequest) (*GetIdResponse, error)
- func (UnimplementedVibratorServiceServer) GetPrimitiveDurations(context.Context, *GetPrimitiveDurationsRequest) (*GetPrimitiveDurationsResponse, error)
- func (UnimplementedVibratorServiceServer) GetQFactor(context.Context, *GetQFactorRequest) (*GetQFactorResponse, error)
- func (UnimplementedVibratorServiceServer) GetResonantFrequency(context.Context, *GetResonantFrequencyRequest) (*GetResonantFrequencyResponse, error)
- func (UnimplementedVibratorServiceServer) Vibrate1(context.Context, *Vibrate1Request) (*Vibrate1Response, error)
- func (UnimplementedVibratorServiceServer) Vibrate1_3(context.Context, *Vibrate1_3Request) (*Vibrate1_3Response, error)
- func (UnimplementedVibratorServiceServer) Vibrate2_1(context.Context, *Vibrate2_1Request) (*Vibrate2_1Response, error)
- func (UnimplementedVibratorServiceServer) Vibrate2_2(context.Context, *Vibrate2_2Request) (*Vibrate2_2Response, error)
- func (UnimplementedVibratorServiceServer) Vibrate2_4(context.Context, *Vibrate2_4Request) (*Vibrate2_4Response, error)
- func (UnimplementedVibratorServiceServer) Vibrate2_5(context.Context, *Vibrate2_5Request) (*Vibrate2_5Response, error)
- func (UnimplementedVibratorServiceServer) Vibrate3_6(context.Context, *Vibrate3_6Request) (*Vibrate3_6Response, error)
- type UnsafeVibratorServiceServer
- type Vibrate1Request
- type Vibrate1Response
- type Vibrate1_3Request
- type Vibrate1_3Response
- type Vibrate2_1Request
- func (*Vibrate2_1Request) Descriptor() ([]byte, []int)deprecated
- func (x *Vibrate2_1Request) GetArg0() int64
- func (x *Vibrate2_1Request) GetArg1() int64
- func (*Vibrate2_1Request) ProtoMessage()
- func (x *Vibrate2_1Request) ProtoReflect() protoreflect.Message
- func (x *Vibrate2_1Request) Reset()
- func (x *Vibrate2_1Request) String() string
- type Vibrate2_1Response
- type Vibrate2_2Request
- func (*Vibrate2_2Request) Descriptor() ([]byte, []int)deprecated
- func (x *Vibrate2_2Request) GetArg0() int64
- func (x *Vibrate2_2Request) GetArg1() int64
- func (*Vibrate2_2Request) ProtoMessage()
- func (x *Vibrate2_2Request) ProtoReflect() protoreflect.Message
- func (x *Vibrate2_2Request) Reset()
- func (x *Vibrate2_2Request) String() string
- type Vibrate2_2Response
- type Vibrate2_4Request
- func (*Vibrate2_4Request) Descriptor() ([]byte, []int)deprecated
- func (x *Vibrate2_4Request) GetArg0() int64
- func (x *Vibrate2_4Request) GetArg1() int64
- func (*Vibrate2_4Request) ProtoMessage()
- func (x *Vibrate2_4Request) ProtoReflect() protoreflect.Message
- func (x *Vibrate2_4Request) Reset()
- func (x *Vibrate2_4Request) String() string
- type Vibrate2_4Response
- type Vibrate2_5Request
- func (*Vibrate2_5Request) Descriptor() ([]byte, []int)deprecated
- func (x *Vibrate2_5Request) GetArg0() int64
- func (x *Vibrate2_5Request) GetArg1() int32
- func (*Vibrate2_5Request) ProtoMessage()
- func (x *Vibrate2_5Request) ProtoReflect() protoreflect.Message
- func (x *Vibrate2_5Request) Reset()
- func (x *Vibrate2_5Request) String() string
- type Vibrate2_5Response
- type Vibrate3_6Request
- func (*Vibrate3_6Request) Descriptor() ([]byte, []int)deprecated
- func (x *Vibrate3_6Request) GetArg0() int64
- func (x *Vibrate3_6Request) GetArg1() int32
- func (x *Vibrate3_6Request) GetArg2() int64
- func (*Vibrate3_6Request) ProtoMessage()
- func (x *Vibrate3_6Request) ProtoReflect() protoreflect.Message
- func (x *Vibrate3_6Request) Reset()
- func (x *Vibrate3_6Request) String() string
- type Vibrate3_6Response
- type VibratorServiceClient
- type VibratorServiceServer
Constants ¶
const ( VibratorService_AreEffectsSupported_FullMethodName = "/vibrator.VibratorService/AreEffectsSupported" VibratorService_AreEnvelopeEffectsSupported_FullMethodName = "/vibrator.VibratorService/AreEnvelopeEffectsSupported" VibratorService_ArePrimitivesSupported_FullMethodName = "/vibrator.VibratorService/ArePrimitivesSupported" VibratorService_GetEnvelopeEffectInfo_FullMethodName = "/vibrator.VibratorService/GetEnvelopeEffectInfo" VibratorService_GetFrequencyProfile_FullMethodName = "/vibrator.VibratorService/GetFrequencyProfile" VibratorService_GetId_FullMethodName = "/vibrator.VibratorService/GetId" VibratorService_GetPrimitiveDurations_FullMethodName = "/vibrator.VibratorService/GetPrimitiveDurations" VibratorService_GetQFactor_FullMethodName = "/vibrator.VibratorService/GetQFactor" VibratorService_GetResonantFrequency_FullMethodName = "/vibrator.VibratorService/GetResonantFrequency" VibratorService_Vibrate1_FullMethodName = "/vibrator.VibratorService/Vibrate1" VibratorService_Vibrate2_1_FullMethodName = "/vibrator.VibratorService/Vibrate2_1" VibratorService_Vibrate2_2_FullMethodName = "/vibrator.VibratorService/Vibrate2_2" VibratorService_Vibrate1_3_FullMethodName = "/vibrator.VibratorService/Vibrate1_3" VibratorService_Vibrate2_4_FullMethodName = "/vibrator.VibratorService/Vibrate2_4" VibratorService_Vibrate2_5_FullMethodName = "/vibrator.VibratorService/Vibrate2_5" VibratorService_Vibrate3_6_FullMethodName = "/vibrator.VibratorService/Vibrate3_6" )
Variables ¶
var File_proto_vibrator_vibrator_proto protoreflect.FileDescriptor
var VibratorService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "vibrator.VibratorService", HandlerType: (*VibratorServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "AreEffectsSupported", Handler: _VibratorService_AreEffectsSupported_Handler, }, { MethodName: "AreEnvelopeEffectsSupported", Handler: _VibratorService_AreEnvelopeEffectsSupported_Handler, }, { MethodName: "ArePrimitivesSupported", Handler: _VibratorService_ArePrimitivesSupported_Handler, }, { MethodName: "GetEnvelopeEffectInfo", Handler: _VibratorService_GetEnvelopeEffectInfo_Handler, }, { MethodName: "GetFrequencyProfile", Handler: _VibratorService_GetFrequencyProfile_Handler, }, { MethodName: "GetId", Handler: _VibratorService_GetId_Handler, }, { MethodName: "GetPrimitiveDurations", Handler: _VibratorService_GetPrimitiveDurations_Handler, }, { MethodName: "GetQFactor", Handler: _VibratorService_GetQFactor_Handler, }, { MethodName: "GetResonantFrequency", Handler: _VibratorService_GetResonantFrequency_Handler, }, { MethodName: "Vibrate1", Handler: _VibratorService_Vibrate1_Handler, }, { MethodName: "Vibrate2_1", Handler: _VibratorService_Vibrate2_1_Handler, }, { MethodName: "Vibrate2_2", Handler: _VibratorService_Vibrate2_2_Handler, }, { MethodName: "Vibrate1_3", Handler: _VibratorService_Vibrate1_3_Handler, }, { MethodName: "Vibrate2_4", Handler: _VibratorService_Vibrate2_4_Handler, }, { MethodName: "Vibrate2_5", Handler: _VibratorService_Vibrate2_5_Handler, }, { MethodName: "Vibrate3_6", Handler: _VibratorService_Vibrate3_6_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "proto/vibrator/vibrator.proto", }
VibratorService_ServiceDesc is the grpc.ServiceDesc for VibratorService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterVibratorServiceServer ¶
func RegisterVibratorServiceServer(s grpc.ServiceRegistrar, srv VibratorServiceServer)
Types ¶
type AreEffectsSupportedRequest ¶
type AreEffectsSupportedRequest struct {
Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
// contains filtered or unexported fields
}
func (*AreEffectsSupportedRequest) Descriptor
deprecated
func (*AreEffectsSupportedRequest) Descriptor() ([]byte, []int)
Deprecated: Use AreEffectsSupportedRequest.ProtoReflect.Descriptor instead.
func (*AreEffectsSupportedRequest) GetArg0 ¶
func (x *AreEffectsSupportedRequest) GetArg0() int64
func (*AreEffectsSupportedRequest) ProtoMessage ¶
func (*AreEffectsSupportedRequest) ProtoMessage()
func (*AreEffectsSupportedRequest) ProtoReflect ¶
func (x *AreEffectsSupportedRequest) ProtoReflect() protoreflect.Message
func (*AreEffectsSupportedRequest) Reset ¶
func (x *AreEffectsSupportedRequest) Reset()
func (*AreEffectsSupportedRequest) String ¶
func (x *AreEffectsSupportedRequest) String() string
type AreEffectsSupportedResponse ¶
type AreEffectsSupportedResponse struct {
Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*AreEffectsSupportedResponse) Descriptor
deprecated
func (*AreEffectsSupportedResponse) Descriptor() ([]byte, []int)
Deprecated: Use AreEffectsSupportedResponse.ProtoReflect.Descriptor instead.
func (*AreEffectsSupportedResponse) GetResult ¶
func (x *AreEffectsSupportedResponse) GetResult() int64
func (*AreEffectsSupportedResponse) ProtoMessage ¶
func (*AreEffectsSupportedResponse) ProtoMessage()
func (*AreEffectsSupportedResponse) ProtoReflect ¶
func (x *AreEffectsSupportedResponse) ProtoReflect() protoreflect.Message
func (*AreEffectsSupportedResponse) Reset ¶
func (x *AreEffectsSupportedResponse) Reset()
func (*AreEffectsSupportedResponse) String ¶
func (x *AreEffectsSupportedResponse) String() string
type AreEnvelopeEffectsSupportedRequest ¶
type AreEnvelopeEffectsSupportedRequest struct {
// contains filtered or unexported fields
}
func (*AreEnvelopeEffectsSupportedRequest) Descriptor
deprecated
func (*AreEnvelopeEffectsSupportedRequest) Descriptor() ([]byte, []int)
Deprecated: Use AreEnvelopeEffectsSupportedRequest.ProtoReflect.Descriptor instead.
func (*AreEnvelopeEffectsSupportedRequest) ProtoMessage ¶
func (*AreEnvelopeEffectsSupportedRequest) ProtoMessage()
func (*AreEnvelopeEffectsSupportedRequest) ProtoReflect ¶
func (x *AreEnvelopeEffectsSupportedRequest) ProtoReflect() protoreflect.Message
func (*AreEnvelopeEffectsSupportedRequest) Reset ¶
func (x *AreEnvelopeEffectsSupportedRequest) Reset()
func (*AreEnvelopeEffectsSupportedRequest) String ¶
func (x *AreEnvelopeEffectsSupportedRequest) String() string
type AreEnvelopeEffectsSupportedResponse ¶
type AreEnvelopeEffectsSupportedResponse struct {
Result bool `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*AreEnvelopeEffectsSupportedResponse) Descriptor
deprecated
func (*AreEnvelopeEffectsSupportedResponse) Descriptor() ([]byte, []int)
Deprecated: Use AreEnvelopeEffectsSupportedResponse.ProtoReflect.Descriptor instead.
func (*AreEnvelopeEffectsSupportedResponse) GetResult ¶
func (x *AreEnvelopeEffectsSupportedResponse) GetResult() bool
func (*AreEnvelopeEffectsSupportedResponse) ProtoMessage ¶
func (*AreEnvelopeEffectsSupportedResponse) ProtoMessage()
func (*AreEnvelopeEffectsSupportedResponse) ProtoReflect ¶
func (x *AreEnvelopeEffectsSupportedResponse) ProtoReflect() protoreflect.Message
func (*AreEnvelopeEffectsSupportedResponse) Reset ¶
func (x *AreEnvelopeEffectsSupportedResponse) Reset()
func (*AreEnvelopeEffectsSupportedResponse) String ¶
func (x *AreEnvelopeEffectsSupportedResponse) String() string
type ArePrimitivesSupportedRequest ¶
type ArePrimitivesSupportedRequest struct {
Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
// contains filtered or unexported fields
}
func (*ArePrimitivesSupportedRequest) Descriptor
deprecated
func (*ArePrimitivesSupportedRequest) Descriptor() ([]byte, []int)
Deprecated: Use ArePrimitivesSupportedRequest.ProtoReflect.Descriptor instead.
func (*ArePrimitivesSupportedRequest) GetArg0 ¶
func (x *ArePrimitivesSupportedRequest) GetArg0() int64
func (*ArePrimitivesSupportedRequest) ProtoMessage ¶
func (*ArePrimitivesSupportedRequest) ProtoMessage()
func (*ArePrimitivesSupportedRequest) ProtoReflect ¶
func (x *ArePrimitivesSupportedRequest) ProtoReflect() protoreflect.Message
func (*ArePrimitivesSupportedRequest) Reset ¶
func (x *ArePrimitivesSupportedRequest) Reset()
func (*ArePrimitivesSupportedRequest) String ¶
func (x *ArePrimitivesSupportedRequest) String() string
type ArePrimitivesSupportedResponse ¶
type ArePrimitivesSupportedResponse struct {
Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*ArePrimitivesSupportedResponse) Descriptor
deprecated
func (*ArePrimitivesSupportedResponse) Descriptor() ([]byte, []int)
Deprecated: Use ArePrimitivesSupportedResponse.ProtoReflect.Descriptor instead.
func (*ArePrimitivesSupportedResponse) GetResult ¶
func (x *ArePrimitivesSupportedResponse) GetResult() int64
func (*ArePrimitivesSupportedResponse) ProtoMessage ¶
func (*ArePrimitivesSupportedResponse) ProtoMessage()
func (*ArePrimitivesSupportedResponse) ProtoReflect ¶
func (x *ArePrimitivesSupportedResponse) ProtoReflect() protoreflect.Message
func (*ArePrimitivesSupportedResponse) Reset ¶
func (x *ArePrimitivesSupportedResponse) Reset()
func (*ArePrimitivesSupportedResponse) String ¶
func (x *ArePrimitivesSupportedResponse) String() string
type GetEnvelopeEffectInfoRequest ¶
type GetEnvelopeEffectInfoRequest struct {
// contains filtered or unexported fields
}
func (*GetEnvelopeEffectInfoRequest) Descriptor
deprecated
func (*GetEnvelopeEffectInfoRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetEnvelopeEffectInfoRequest.ProtoReflect.Descriptor instead.
func (*GetEnvelopeEffectInfoRequest) ProtoMessage ¶
func (*GetEnvelopeEffectInfoRequest) ProtoMessage()
func (*GetEnvelopeEffectInfoRequest) ProtoReflect ¶
func (x *GetEnvelopeEffectInfoRequest) ProtoReflect() protoreflect.Message
func (*GetEnvelopeEffectInfoRequest) Reset ¶
func (x *GetEnvelopeEffectInfoRequest) Reset()
func (*GetEnvelopeEffectInfoRequest) String ¶
func (x *GetEnvelopeEffectInfoRequest) String() string
type GetEnvelopeEffectInfoResponse ¶
type GetEnvelopeEffectInfoResponse struct {
Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*GetEnvelopeEffectInfoResponse) Descriptor
deprecated
func (*GetEnvelopeEffectInfoResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetEnvelopeEffectInfoResponse.ProtoReflect.Descriptor instead.
func (*GetEnvelopeEffectInfoResponse) GetResult ¶
func (x *GetEnvelopeEffectInfoResponse) GetResult() int64
func (*GetEnvelopeEffectInfoResponse) ProtoMessage ¶
func (*GetEnvelopeEffectInfoResponse) ProtoMessage()
func (*GetEnvelopeEffectInfoResponse) ProtoReflect ¶
func (x *GetEnvelopeEffectInfoResponse) ProtoReflect() protoreflect.Message
func (*GetEnvelopeEffectInfoResponse) Reset ¶
func (x *GetEnvelopeEffectInfoResponse) Reset()
func (*GetEnvelopeEffectInfoResponse) String ¶
func (x *GetEnvelopeEffectInfoResponse) String() string
type GetFrequencyProfileRequest ¶
type GetFrequencyProfileRequest struct {
// contains filtered or unexported fields
}
func (*GetFrequencyProfileRequest) Descriptor
deprecated
func (*GetFrequencyProfileRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetFrequencyProfileRequest.ProtoReflect.Descriptor instead.
func (*GetFrequencyProfileRequest) ProtoMessage ¶
func (*GetFrequencyProfileRequest) ProtoMessage()
func (*GetFrequencyProfileRequest) ProtoReflect ¶
func (x *GetFrequencyProfileRequest) ProtoReflect() protoreflect.Message
func (*GetFrequencyProfileRequest) Reset ¶
func (x *GetFrequencyProfileRequest) Reset()
func (*GetFrequencyProfileRequest) String ¶
func (x *GetFrequencyProfileRequest) String() string
type GetFrequencyProfileResponse ¶
type GetFrequencyProfileResponse struct {
Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*GetFrequencyProfileResponse) Descriptor
deprecated
func (*GetFrequencyProfileResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetFrequencyProfileResponse.ProtoReflect.Descriptor instead.
func (*GetFrequencyProfileResponse) GetResult ¶
func (x *GetFrequencyProfileResponse) GetResult() int64
func (*GetFrequencyProfileResponse) ProtoMessage ¶
func (*GetFrequencyProfileResponse) ProtoMessage()
func (*GetFrequencyProfileResponse) ProtoReflect ¶
func (x *GetFrequencyProfileResponse) ProtoReflect() protoreflect.Message
func (*GetFrequencyProfileResponse) Reset ¶
func (x *GetFrequencyProfileResponse) Reset()
func (*GetFrequencyProfileResponse) String ¶
func (x *GetFrequencyProfileResponse) String() string
type GetIdRequest ¶
type GetIdRequest struct {
// contains filtered or unexported fields
}
func (*GetIdRequest) Descriptor
deprecated
func (*GetIdRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetIdRequest.ProtoReflect.Descriptor instead.
func (*GetIdRequest) ProtoMessage ¶
func (*GetIdRequest) ProtoMessage()
func (*GetIdRequest) ProtoReflect ¶
func (x *GetIdRequest) ProtoReflect() protoreflect.Message
func (*GetIdRequest) Reset ¶
func (x *GetIdRequest) Reset()
func (*GetIdRequest) String ¶
func (x *GetIdRequest) String() string
type GetIdResponse ¶
type GetIdResponse struct {
Result int32 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*GetIdResponse) Descriptor
deprecated
func (*GetIdResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetIdResponse.ProtoReflect.Descriptor instead.
func (*GetIdResponse) GetResult ¶
func (x *GetIdResponse) GetResult() int32
func (*GetIdResponse) ProtoMessage ¶
func (*GetIdResponse) ProtoMessage()
func (*GetIdResponse) ProtoReflect ¶
func (x *GetIdResponse) ProtoReflect() protoreflect.Message
func (*GetIdResponse) Reset ¶
func (x *GetIdResponse) Reset()
func (*GetIdResponse) String ¶
func (x *GetIdResponse) String() string
type GetPrimitiveDurationsRequest ¶
type GetPrimitiveDurationsRequest struct {
Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
// contains filtered or unexported fields
}
func (*GetPrimitiveDurationsRequest) Descriptor
deprecated
func (*GetPrimitiveDurationsRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetPrimitiveDurationsRequest.ProtoReflect.Descriptor instead.
func (*GetPrimitiveDurationsRequest) GetArg0 ¶
func (x *GetPrimitiveDurationsRequest) GetArg0() int64
func (*GetPrimitiveDurationsRequest) ProtoMessage ¶
func (*GetPrimitiveDurationsRequest) ProtoMessage()
func (*GetPrimitiveDurationsRequest) ProtoReflect ¶
func (x *GetPrimitiveDurationsRequest) ProtoReflect() protoreflect.Message
func (*GetPrimitiveDurationsRequest) Reset ¶
func (x *GetPrimitiveDurationsRequest) Reset()
func (*GetPrimitiveDurationsRequest) String ¶
func (x *GetPrimitiveDurationsRequest) String() string
type GetPrimitiveDurationsResponse ¶
type GetPrimitiveDurationsResponse struct {
Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*GetPrimitiveDurationsResponse) Descriptor
deprecated
func (*GetPrimitiveDurationsResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetPrimitiveDurationsResponse.ProtoReflect.Descriptor instead.
func (*GetPrimitiveDurationsResponse) GetResult ¶
func (x *GetPrimitiveDurationsResponse) GetResult() int64
func (*GetPrimitiveDurationsResponse) ProtoMessage ¶
func (*GetPrimitiveDurationsResponse) ProtoMessage()
func (*GetPrimitiveDurationsResponse) ProtoReflect ¶
func (x *GetPrimitiveDurationsResponse) ProtoReflect() protoreflect.Message
func (*GetPrimitiveDurationsResponse) Reset ¶
func (x *GetPrimitiveDurationsResponse) Reset()
func (*GetPrimitiveDurationsResponse) String ¶
func (x *GetPrimitiveDurationsResponse) String() string
type GetQFactorRequest ¶
type GetQFactorRequest struct {
// contains filtered or unexported fields
}
func (*GetQFactorRequest) Descriptor
deprecated
func (*GetQFactorRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetQFactorRequest.ProtoReflect.Descriptor instead.
func (*GetQFactorRequest) ProtoMessage ¶
func (*GetQFactorRequest) ProtoMessage()
func (*GetQFactorRequest) ProtoReflect ¶
func (x *GetQFactorRequest) ProtoReflect() protoreflect.Message
func (*GetQFactorRequest) Reset ¶
func (x *GetQFactorRequest) Reset()
func (*GetQFactorRequest) String ¶
func (x *GetQFactorRequest) String() string
type GetQFactorResponse ¶
type GetQFactorResponse struct {
Result float32 `protobuf:"fixed32,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*GetQFactorResponse) Descriptor
deprecated
func (*GetQFactorResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetQFactorResponse.ProtoReflect.Descriptor instead.
func (*GetQFactorResponse) GetResult ¶
func (x *GetQFactorResponse) GetResult() float32
func (*GetQFactorResponse) ProtoMessage ¶
func (*GetQFactorResponse) ProtoMessage()
func (*GetQFactorResponse) ProtoReflect ¶
func (x *GetQFactorResponse) ProtoReflect() protoreflect.Message
func (*GetQFactorResponse) Reset ¶
func (x *GetQFactorResponse) Reset()
func (*GetQFactorResponse) String ¶
func (x *GetQFactorResponse) String() string
type GetResonantFrequencyRequest ¶
type GetResonantFrequencyRequest struct {
// contains filtered or unexported fields
}
func (*GetResonantFrequencyRequest) Descriptor
deprecated
func (*GetResonantFrequencyRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetResonantFrequencyRequest.ProtoReflect.Descriptor instead.
func (*GetResonantFrequencyRequest) ProtoMessage ¶
func (*GetResonantFrequencyRequest) ProtoMessage()
func (*GetResonantFrequencyRequest) ProtoReflect ¶
func (x *GetResonantFrequencyRequest) ProtoReflect() protoreflect.Message
func (*GetResonantFrequencyRequest) Reset ¶
func (x *GetResonantFrequencyRequest) Reset()
func (*GetResonantFrequencyRequest) String ¶
func (x *GetResonantFrequencyRequest) String() string
type GetResonantFrequencyResponse ¶
type GetResonantFrequencyResponse struct {
Result float32 `protobuf:"fixed32,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*GetResonantFrequencyResponse) Descriptor
deprecated
func (*GetResonantFrequencyResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetResonantFrequencyResponse.ProtoReflect.Descriptor instead.
func (*GetResonantFrequencyResponse) GetResult ¶
func (x *GetResonantFrequencyResponse) GetResult() float32
func (*GetResonantFrequencyResponse) ProtoMessage ¶
func (*GetResonantFrequencyResponse) ProtoMessage()
func (*GetResonantFrequencyResponse) ProtoReflect ¶
func (x *GetResonantFrequencyResponse) ProtoReflect() protoreflect.Message
func (*GetResonantFrequencyResponse) Reset ¶
func (x *GetResonantFrequencyResponse) Reset()
func (*GetResonantFrequencyResponse) String ¶
func (x *GetResonantFrequencyResponse) String() string
type UnimplementedVibratorServiceServer ¶
type UnimplementedVibratorServiceServer struct{}
UnimplementedVibratorServiceServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedVibratorServiceServer) AreEffectsSupported ¶
func (UnimplementedVibratorServiceServer) AreEffectsSupported(context.Context, *AreEffectsSupportedRequest) (*AreEffectsSupportedResponse, error)
func (UnimplementedVibratorServiceServer) AreEnvelopeEffectsSupported ¶
func (UnimplementedVibratorServiceServer) AreEnvelopeEffectsSupported(context.Context, *AreEnvelopeEffectsSupportedRequest) (*AreEnvelopeEffectsSupportedResponse, error)
func (UnimplementedVibratorServiceServer) ArePrimitivesSupported ¶
func (UnimplementedVibratorServiceServer) ArePrimitivesSupported(context.Context, *ArePrimitivesSupportedRequest) (*ArePrimitivesSupportedResponse, error)
func (UnimplementedVibratorServiceServer) GetEnvelopeEffectInfo ¶
func (UnimplementedVibratorServiceServer) GetEnvelopeEffectInfo(context.Context, *GetEnvelopeEffectInfoRequest) (*GetEnvelopeEffectInfoResponse, error)
func (UnimplementedVibratorServiceServer) GetFrequencyProfile ¶
func (UnimplementedVibratorServiceServer) GetFrequencyProfile(context.Context, *GetFrequencyProfileRequest) (*GetFrequencyProfileResponse, error)
func (UnimplementedVibratorServiceServer) GetId ¶
func (UnimplementedVibratorServiceServer) GetId(context.Context, *GetIdRequest) (*GetIdResponse, error)
func (UnimplementedVibratorServiceServer) GetPrimitiveDurations ¶
func (UnimplementedVibratorServiceServer) GetPrimitiveDurations(context.Context, *GetPrimitiveDurationsRequest) (*GetPrimitiveDurationsResponse, error)
func (UnimplementedVibratorServiceServer) GetQFactor ¶
func (UnimplementedVibratorServiceServer) GetQFactor(context.Context, *GetQFactorRequest) (*GetQFactorResponse, error)
func (UnimplementedVibratorServiceServer) GetResonantFrequency ¶
func (UnimplementedVibratorServiceServer) GetResonantFrequency(context.Context, *GetResonantFrequencyRequest) (*GetResonantFrequencyResponse, error)
func (UnimplementedVibratorServiceServer) Vibrate1 ¶
func (UnimplementedVibratorServiceServer) Vibrate1(context.Context, *Vibrate1Request) (*Vibrate1Response, error)
func (UnimplementedVibratorServiceServer) Vibrate1_3 ¶
func (UnimplementedVibratorServiceServer) Vibrate1_3(context.Context, *Vibrate1_3Request) (*Vibrate1_3Response, error)
func (UnimplementedVibratorServiceServer) Vibrate2_1 ¶
func (UnimplementedVibratorServiceServer) Vibrate2_1(context.Context, *Vibrate2_1Request) (*Vibrate2_1Response, error)
func (UnimplementedVibratorServiceServer) Vibrate2_2 ¶
func (UnimplementedVibratorServiceServer) Vibrate2_2(context.Context, *Vibrate2_2Request) (*Vibrate2_2Response, error)
func (UnimplementedVibratorServiceServer) Vibrate2_4 ¶
func (UnimplementedVibratorServiceServer) Vibrate2_4(context.Context, *Vibrate2_4Request) (*Vibrate2_4Response, error)
func (UnimplementedVibratorServiceServer) Vibrate2_5 ¶
func (UnimplementedVibratorServiceServer) Vibrate2_5(context.Context, *Vibrate2_5Request) (*Vibrate2_5Response, error)
func (UnimplementedVibratorServiceServer) Vibrate3_6 ¶
func (UnimplementedVibratorServiceServer) Vibrate3_6(context.Context, *Vibrate3_6Request) (*Vibrate3_6Response, error)
type UnsafeVibratorServiceServer ¶
type UnsafeVibratorServiceServer interface {
// contains filtered or unexported methods
}
UnsafeVibratorServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to VibratorServiceServer will result in compilation errors.
type Vibrate1Request ¶
type Vibrate1Request struct {
Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
// contains filtered or unexported fields
}
func (*Vibrate1Request) Descriptor
deprecated
func (*Vibrate1Request) Descriptor() ([]byte, []int)
Deprecated: Use Vibrate1Request.ProtoReflect.Descriptor instead.
func (*Vibrate1Request) GetArg0 ¶
func (x *Vibrate1Request) GetArg0() int64
func (*Vibrate1Request) ProtoMessage ¶
func (*Vibrate1Request) ProtoMessage()
func (*Vibrate1Request) ProtoReflect ¶
func (x *Vibrate1Request) ProtoReflect() protoreflect.Message
func (*Vibrate1Request) Reset ¶
func (x *Vibrate1Request) Reset()
func (*Vibrate1Request) String ¶
func (x *Vibrate1Request) String() string
type Vibrate1Response ¶
type Vibrate1Response struct {
// contains filtered or unexported fields
}
func (*Vibrate1Response) Descriptor
deprecated
func (*Vibrate1Response) Descriptor() ([]byte, []int)
Deprecated: Use Vibrate1Response.ProtoReflect.Descriptor instead.
func (*Vibrate1Response) ProtoMessage ¶
func (*Vibrate1Response) ProtoMessage()
func (*Vibrate1Response) ProtoReflect ¶
func (x *Vibrate1Response) ProtoReflect() protoreflect.Message
func (*Vibrate1Response) Reset ¶
func (x *Vibrate1Response) Reset()
func (*Vibrate1Response) String ¶
func (x *Vibrate1Response) String() string
type Vibrate1_3Request ¶
type Vibrate1_3Request struct {
Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
// contains filtered or unexported fields
}
func (*Vibrate1_3Request) Descriptor
deprecated
func (*Vibrate1_3Request) Descriptor() ([]byte, []int)
Deprecated: Use Vibrate1_3Request.ProtoReflect.Descriptor instead.
func (*Vibrate1_3Request) GetArg0 ¶
func (x *Vibrate1_3Request) GetArg0() int64
func (*Vibrate1_3Request) ProtoMessage ¶
func (*Vibrate1_3Request) ProtoMessage()
func (*Vibrate1_3Request) ProtoReflect ¶
func (x *Vibrate1_3Request) ProtoReflect() protoreflect.Message
func (*Vibrate1_3Request) Reset ¶
func (x *Vibrate1_3Request) Reset()
func (*Vibrate1_3Request) String ¶
func (x *Vibrate1_3Request) String() string
type Vibrate1_3Response ¶
type Vibrate1_3Response struct {
// contains filtered or unexported fields
}
func (*Vibrate1_3Response) Descriptor
deprecated
func (*Vibrate1_3Response) Descriptor() ([]byte, []int)
Deprecated: Use Vibrate1_3Response.ProtoReflect.Descriptor instead.
func (*Vibrate1_3Response) ProtoMessage ¶
func (*Vibrate1_3Response) ProtoMessage()
func (*Vibrate1_3Response) ProtoReflect ¶
func (x *Vibrate1_3Response) ProtoReflect() protoreflect.Message
func (*Vibrate1_3Response) Reset ¶
func (x *Vibrate1_3Response) Reset()
func (*Vibrate1_3Response) String ¶
func (x *Vibrate1_3Response) String() string
type Vibrate2_1Request ¶
type Vibrate2_1Request struct {
Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
Arg1 int64 `protobuf:"varint,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
// contains filtered or unexported fields
}
func (*Vibrate2_1Request) Descriptor
deprecated
func (*Vibrate2_1Request) Descriptor() ([]byte, []int)
Deprecated: Use Vibrate2_1Request.ProtoReflect.Descriptor instead.
func (*Vibrate2_1Request) GetArg0 ¶
func (x *Vibrate2_1Request) GetArg0() int64
func (*Vibrate2_1Request) GetArg1 ¶
func (x *Vibrate2_1Request) GetArg1() int64
func (*Vibrate2_1Request) ProtoMessage ¶
func (*Vibrate2_1Request) ProtoMessage()
func (*Vibrate2_1Request) ProtoReflect ¶
func (x *Vibrate2_1Request) ProtoReflect() protoreflect.Message
func (*Vibrate2_1Request) Reset ¶
func (x *Vibrate2_1Request) Reset()
func (*Vibrate2_1Request) String ¶
func (x *Vibrate2_1Request) String() string
type Vibrate2_1Response ¶
type Vibrate2_1Response struct {
// contains filtered or unexported fields
}
func (*Vibrate2_1Response) Descriptor
deprecated
func (*Vibrate2_1Response) Descriptor() ([]byte, []int)
Deprecated: Use Vibrate2_1Response.ProtoReflect.Descriptor instead.
func (*Vibrate2_1Response) ProtoMessage ¶
func (*Vibrate2_1Response) ProtoMessage()
func (*Vibrate2_1Response) ProtoReflect ¶
func (x *Vibrate2_1Response) ProtoReflect() protoreflect.Message
func (*Vibrate2_1Response) Reset ¶
func (x *Vibrate2_1Response) Reset()
func (*Vibrate2_1Response) String ¶
func (x *Vibrate2_1Response) String() string
type Vibrate2_2Request ¶
type Vibrate2_2Request struct {
Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
Arg1 int64 `protobuf:"varint,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
// contains filtered or unexported fields
}
func (*Vibrate2_2Request) Descriptor
deprecated
func (*Vibrate2_2Request) Descriptor() ([]byte, []int)
Deprecated: Use Vibrate2_2Request.ProtoReflect.Descriptor instead.
func (*Vibrate2_2Request) GetArg0 ¶
func (x *Vibrate2_2Request) GetArg0() int64
func (*Vibrate2_2Request) GetArg1 ¶
func (x *Vibrate2_2Request) GetArg1() int64
func (*Vibrate2_2Request) ProtoMessage ¶
func (*Vibrate2_2Request) ProtoMessage()
func (*Vibrate2_2Request) ProtoReflect ¶
func (x *Vibrate2_2Request) ProtoReflect() protoreflect.Message
func (*Vibrate2_2Request) Reset ¶
func (x *Vibrate2_2Request) Reset()
func (*Vibrate2_2Request) String ¶
func (x *Vibrate2_2Request) String() string
type Vibrate2_2Response ¶
type Vibrate2_2Response struct {
// contains filtered or unexported fields
}
func (*Vibrate2_2Response) Descriptor
deprecated
func (*Vibrate2_2Response) Descriptor() ([]byte, []int)
Deprecated: Use Vibrate2_2Response.ProtoReflect.Descriptor instead.
func (*Vibrate2_2Response) ProtoMessage ¶
func (*Vibrate2_2Response) ProtoMessage()
func (*Vibrate2_2Response) ProtoReflect ¶
func (x *Vibrate2_2Response) ProtoReflect() protoreflect.Message
func (*Vibrate2_2Response) Reset ¶
func (x *Vibrate2_2Response) Reset()
func (*Vibrate2_2Response) String ¶
func (x *Vibrate2_2Response) String() string
type Vibrate2_4Request ¶
type Vibrate2_4Request struct {
Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
Arg1 int64 `protobuf:"varint,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
// contains filtered or unexported fields
}
func (*Vibrate2_4Request) Descriptor
deprecated
func (*Vibrate2_4Request) Descriptor() ([]byte, []int)
Deprecated: Use Vibrate2_4Request.ProtoReflect.Descriptor instead.
func (*Vibrate2_4Request) GetArg0 ¶
func (x *Vibrate2_4Request) GetArg0() int64
func (*Vibrate2_4Request) GetArg1 ¶
func (x *Vibrate2_4Request) GetArg1() int64
func (*Vibrate2_4Request) ProtoMessage ¶
func (*Vibrate2_4Request) ProtoMessage()
func (*Vibrate2_4Request) ProtoReflect ¶
func (x *Vibrate2_4Request) ProtoReflect() protoreflect.Message
func (*Vibrate2_4Request) Reset ¶
func (x *Vibrate2_4Request) Reset()
func (*Vibrate2_4Request) String ¶
func (x *Vibrate2_4Request) String() string
type Vibrate2_4Response ¶
type Vibrate2_4Response struct {
// contains filtered or unexported fields
}
func (*Vibrate2_4Response) Descriptor
deprecated
func (*Vibrate2_4Response) Descriptor() ([]byte, []int)
Deprecated: Use Vibrate2_4Response.ProtoReflect.Descriptor instead.
func (*Vibrate2_4Response) ProtoMessage ¶
func (*Vibrate2_4Response) ProtoMessage()
func (*Vibrate2_4Response) ProtoReflect ¶
func (x *Vibrate2_4Response) ProtoReflect() protoreflect.Message
func (*Vibrate2_4Response) Reset ¶
func (x *Vibrate2_4Response) Reset()
func (*Vibrate2_4Response) String ¶
func (x *Vibrate2_4Response) String() string
type Vibrate2_5Request ¶
type Vibrate2_5Request struct {
Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
Arg1 int32 `protobuf:"varint,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
// contains filtered or unexported fields
}
func (*Vibrate2_5Request) Descriptor
deprecated
func (*Vibrate2_5Request) Descriptor() ([]byte, []int)
Deprecated: Use Vibrate2_5Request.ProtoReflect.Descriptor instead.
func (*Vibrate2_5Request) GetArg0 ¶
func (x *Vibrate2_5Request) GetArg0() int64
func (*Vibrate2_5Request) GetArg1 ¶
func (x *Vibrate2_5Request) GetArg1() int32
func (*Vibrate2_5Request) ProtoMessage ¶
func (*Vibrate2_5Request) ProtoMessage()
func (*Vibrate2_5Request) ProtoReflect ¶
func (x *Vibrate2_5Request) ProtoReflect() protoreflect.Message
func (*Vibrate2_5Request) Reset ¶
func (x *Vibrate2_5Request) Reset()
func (*Vibrate2_5Request) String ¶
func (x *Vibrate2_5Request) String() string
type Vibrate2_5Response ¶
type Vibrate2_5Response struct {
// contains filtered or unexported fields
}
func (*Vibrate2_5Response) Descriptor
deprecated
func (*Vibrate2_5Response) Descriptor() ([]byte, []int)
Deprecated: Use Vibrate2_5Response.ProtoReflect.Descriptor instead.
func (*Vibrate2_5Response) ProtoMessage ¶
func (*Vibrate2_5Response) ProtoMessage()
func (*Vibrate2_5Response) ProtoReflect ¶
func (x *Vibrate2_5Response) ProtoReflect() protoreflect.Message
func (*Vibrate2_5Response) Reset ¶
func (x *Vibrate2_5Response) Reset()
func (*Vibrate2_5Response) String ¶
func (x *Vibrate2_5Response) String() string
type Vibrate3_6Request ¶
type Vibrate3_6Request struct {
Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
Arg1 int32 `protobuf:"varint,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
Arg2 int64 `protobuf:"varint,3,opt,name=arg2,proto3" json:"arg2,omitempty"`
// contains filtered or unexported fields
}
func (*Vibrate3_6Request) Descriptor
deprecated
func (*Vibrate3_6Request) Descriptor() ([]byte, []int)
Deprecated: Use Vibrate3_6Request.ProtoReflect.Descriptor instead.
func (*Vibrate3_6Request) GetArg0 ¶
func (x *Vibrate3_6Request) GetArg0() int64
func (*Vibrate3_6Request) GetArg1 ¶
func (x *Vibrate3_6Request) GetArg1() int32
func (*Vibrate3_6Request) GetArg2 ¶
func (x *Vibrate3_6Request) GetArg2() int64
func (*Vibrate3_6Request) ProtoMessage ¶
func (*Vibrate3_6Request) ProtoMessage()
func (*Vibrate3_6Request) ProtoReflect ¶
func (x *Vibrate3_6Request) ProtoReflect() protoreflect.Message
func (*Vibrate3_6Request) Reset ¶
func (x *Vibrate3_6Request) Reset()
func (*Vibrate3_6Request) String ¶
func (x *Vibrate3_6Request) String() string
type Vibrate3_6Response ¶
type Vibrate3_6Response struct {
// contains filtered or unexported fields
}
func (*Vibrate3_6Response) Descriptor
deprecated
func (*Vibrate3_6Response) Descriptor() ([]byte, []int)
Deprecated: Use Vibrate3_6Response.ProtoReflect.Descriptor instead.
func (*Vibrate3_6Response) ProtoMessage ¶
func (*Vibrate3_6Response) ProtoMessage()
func (*Vibrate3_6Response) ProtoReflect ¶
func (x *Vibrate3_6Response) ProtoReflect() protoreflect.Message
func (*Vibrate3_6Response) Reset ¶
func (x *Vibrate3_6Response) Reset()
func (*Vibrate3_6Response) String ¶
func (x *Vibrate3_6Response) String() string
type VibratorServiceClient ¶
type VibratorServiceClient interface {
AreEffectsSupported(ctx context.Context, in *AreEffectsSupportedRequest, opts ...grpc.CallOption) (*AreEffectsSupportedResponse, error)
AreEnvelopeEffectsSupported(ctx context.Context, in *AreEnvelopeEffectsSupportedRequest, opts ...grpc.CallOption) (*AreEnvelopeEffectsSupportedResponse, error)
ArePrimitivesSupported(ctx context.Context, in *ArePrimitivesSupportedRequest, opts ...grpc.CallOption) (*ArePrimitivesSupportedResponse, error)
GetEnvelopeEffectInfo(ctx context.Context, in *GetEnvelopeEffectInfoRequest, opts ...grpc.CallOption) (*GetEnvelopeEffectInfoResponse, error)
GetFrequencyProfile(ctx context.Context, in *GetFrequencyProfileRequest, opts ...grpc.CallOption) (*GetFrequencyProfileResponse, error)
GetId(ctx context.Context, in *GetIdRequest, opts ...grpc.CallOption) (*GetIdResponse, error)
GetPrimitiveDurations(ctx context.Context, in *GetPrimitiveDurationsRequest, opts ...grpc.CallOption) (*GetPrimitiveDurationsResponse, error)
GetQFactor(ctx context.Context, in *GetQFactorRequest, opts ...grpc.CallOption) (*GetQFactorResponse, error)
GetResonantFrequency(ctx context.Context, in *GetResonantFrequencyRequest, opts ...grpc.CallOption) (*GetResonantFrequencyResponse, error)
Vibrate1(ctx context.Context, in *Vibrate1Request, opts ...grpc.CallOption) (*Vibrate1Response, error)
Vibrate2_1(ctx context.Context, in *Vibrate2_1Request, opts ...grpc.CallOption) (*Vibrate2_1Response, error)
Vibrate2_2(ctx context.Context, in *Vibrate2_2Request, opts ...grpc.CallOption) (*Vibrate2_2Response, error)
Vibrate1_3(ctx context.Context, in *Vibrate1_3Request, opts ...grpc.CallOption) (*Vibrate1_3Response, error)
Vibrate2_4(ctx context.Context, in *Vibrate2_4Request, opts ...grpc.CallOption) (*Vibrate2_4Response, error)
Vibrate2_5(ctx context.Context, in *Vibrate2_5Request, opts ...grpc.CallOption) (*Vibrate2_5Response, error)
Vibrate3_6(ctx context.Context, in *Vibrate3_6Request, opts ...grpc.CallOption) (*Vibrate3_6Response, error)
}
VibratorServiceClient is the client API for VibratorService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewVibratorServiceClient ¶
func NewVibratorServiceClient(cc grpc.ClientConnInterface) VibratorServiceClient
type VibratorServiceServer ¶
type VibratorServiceServer interface {
AreEffectsSupported(context.Context, *AreEffectsSupportedRequest) (*AreEffectsSupportedResponse, error)
AreEnvelopeEffectsSupported(context.Context, *AreEnvelopeEffectsSupportedRequest) (*AreEnvelopeEffectsSupportedResponse, error)
ArePrimitivesSupported(context.Context, *ArePrimitivesSupportedRequest) (*ArePrimitivesSupportedResponse, error)
GetEnvelopeEffectInfo(context.Context, *GetEnvelopeEffectInfoRequest) (*GetEnvelopeEffectInfoResponse, error)
GetFrequencyProfile(context.Context, *GetFrequencyProfileRequest) (*GetFrequencyProfileResponse, error)
GetId(context.Context, *GetIdRequest) (*GetIdResponse, error)
GetPrimitiveDurations(context.Context, *GetPrimitiveDurationsRequest) (*GetPrimitiveDurationsResponse, error)
GetQFactor(context.Context, *GetQFactorRequest) (*GetQFactorResponse, error)
GetResonantFrequency(context.Context, *GetResonantFrequencyRequest) (*GetResonantFrequencyResponse, error)
Vibrate1(context.Context, *Vibrate1Request) (*Vibrate1Response, error)
Vibrate2_1(context.Context, *Vibrate2_1Request) (*Vibrate2_1Response, error)
Vibrate2_2(context.Context, *Vibrate2_2Request) (*Vibrate2_2Response, error)
Vibrate1_3(context.Context, *Vibrate1_3Request) (*Vibrate1_3Response, error)
Vibrate2_4(context.Context, *Vibrate2_4Request) (*Vibrate2_4Response, error)
Vibrate2_5(context.Context, *Vibrate2_5Request) (*Vibrate2_5Response, error)
Vibrate3_6(context.Context, *Vibrate3_6Request) (*Vibrate3_6Response, error)
// contains filtered or unexported methods
}
VibratorServiceServer is the server API for VibratorService service. All implementations must embed UnimplementedVibratorServiceServer for forward compatibility.