Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterServiceServiceServer(s grpc.ServiceRegistrar, srv ServiceServiceServer)
- type IsAlwaysOnRequest
- type IsAlwaysOnResponse
- func (*IsAlwaysOnResponse) Descriptor() ([]byte, []int)deprecated
- func (x *IsAlwaysOnResponse) GetResult() bool
- func (*IsAlwaysOnResponse) ProtoMessage()
- func (x *IsAlwaysOnResponse) ProtoReflect() protoreflect.Message
- func (x *IsAlwaysOnResponse) Reset()
- func (x *IsAlwaysOnResponse) String() string
- type IsLockdownEnabledRequest
- type IsLockdownEnabledResponse
- func (*IsLockdownEnabledResponse) Descriptor() ([]byte, []int)deprecated
- func (x *IsLockdownEnabledResponse) GetResult() bool
- func (*IsLockdownEnabledResponse) ProtoMessage()
- func (x *IsLockdownEnabledResponse) ProtoReflect() protoreflect.Message
- func (x *IsLockdownEnabledResponse) Reset()
- func (x *IsLockdownEnabledResponse) String() string
- type OnBindRequest
- type OnBindResponse
- type OnRevokeRequest
- type OnRevokeResponse
- type PrepareRequest
- type PrepareResponse
- type Protect1Request
- type Protect1Response
- type Protect1_1Request
- type Protect1_1Response
- func (*Protect1_1Response) Descriptor() ([]byte, []int)deprecated
- func (x *Protect1_1Response) GetResult() bool
- func (*Protect1_1Response) ProtoMessage()
- func (x *Protect1_1Response) ProtoReflect() protoreflect.Message
- func (x *Protect1_1Response) Reset()
- func (x *Protect1_1Response) String() string
- type Protect1_2Request
- type Protect1_2Response
- func (*Protect1_2Response) Descriptor() ([]byte, []int)deprecated
- func (x *Protect1_2Response) GetResult() bool
- func (*Protect1_2Response) ProtoMessage()
- func (x *Protect1_2Response) ProtoReflect() protoreflect.Message
- func (x *Protect1_2Response) Reset()
- func (x *Protect1_2Response) String() string
- type ServiceServiceClient
- type ServiceServiceServer
- type SetUnderlyingNetworksRequest
- func (*SetUnderlyingNetworksRequest) Descriptor() ([]byte, []int)deprecated
- func (x *SetUnderlyingNetworksRequest) GetArg0() int64
- func (*SetUnderlyingNetworksRequest) ProtoMessage()
- func (x *SetUnderlyingNetworksRequest) ProtoReflect() protoreflect.Message
- func (x *SetUnderlyingNetworksRequest) Reset()
- func (x *SetUnderlyingNetworksRequest) String() string
- type SetUnderlyingNetworksResponse
- func (*SetUnderlyingNetworksResponse) Descriptor() ([]byte, []int)deprecated
- func (x *SetUnderlyingNetworksResponse) GetResult() bool
- func (*SetUnderlyingNetworksResponse) ProtoMessage()
- func (x *SetUnderlyingNetworksResponse) ProtoReflect() protoreflect.Message
- func (x *SetUnderlyingNetworksResponse) Reset()
- func (x *SetUnderlyingNetworksResponse) String() string
- type UnimplementedServiceServiceServer
- func (UnimplementedServiceServiceServer) IsAlwaysOn(context.Context, *IsAlwaysOnRequest) (*IsAlwaysOnResponse, error)
- func (UnimplementedServiceServiceServer) IsLockdownEnabled(context.Context, *IsLockdownEnabledRequest) (*IsLockdownEnabledResponse, error)
- func (UnimplementedServiceServiceServer) OnBind(context.Context, *OnBindRequest) (*OnBindResponse, error)
- func (UnimplementedServiceServiceServer) OnRevoke(context.Context, *OnRevokeRequest) (*OnRevokeResponse, error)
- func (UnimplementedServiceServiceServer) Prepare(context.Context, *PrepareRequest) (*PrepareResponse, error)
- func (UnimplementedServiceServiceServer) Protect1(context.Context, *Protect1Request) (*Protect1Response, error)
- func (UnimplementedServiceServiceServer) Protect1_1(context.Context, *Protect1_1Request) (*Protect1_1Response, error)
- func (UnimplementedServiceServiceServer) Protect1_2(context.Context, *Protect1_2Request) (*Protect1_2Response, error)
- func (UnimplementedServiceServiceServer) SetUnderlyingNetworks(context.Context, *SetUnderlyingNetworksRequest) (*SetUnderlyingNetworksResponse, error)
- type UnsafeServiceServiceServer
Constants ¶
const ( ServiceService_IsAlwaysOn_FullMethodName = "/vpn.ServiceService/IsAlwaysOn" ServiceService_IsLockdownEnabled_FullMethodName = "/vpn.ServiceService/IsLockdownEnabled" ServiceService_OnBind_FullMethodName = "/vpn.ServiceService/OnBind" ServiceService_OnRevoke_FullMethodName = "/vpn.ServiceService/OnRevoke" ServiceService_Protect1_FullMethodName = "/vpn.ServiceService/Protect1" ServiceService_Protect1_1_FullMethodName = "/vpn.ServiceService/Protect1_1" ServiceService_Protect1_2_FullMethodName = "/vpn.ServiceService/Protect1_2" ServiceService_SetUnderlyingNetworks_FullMethodName = "/vpn.ServiceService/SetUnderlyingNetworks" ServiceService_Prepare_FullMethodName = "/vpn.ServiceService/Prepare" )
Variables ¶
var File_proto_vpn_vpn_proto protoreflect.FileDescriptor
var ServiceService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "vpn.ServiceService", HandlerType: (*ServiceServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "IsAlwaysOn", Handler: _ServiceService_IsAlwaysOn_Handler, }, { MethodName: "IsLockdownEnabled", Handler: _ServiceService_IsLockdownEnabled_Handler, }, { MethodName: "OnBind", Handler: _ServiceService_OnBind_Handler, }, { MethodName: "OnRevoke", Handler: _ServiceService_OnRevoke_Handler, }, { MethodName: "Protect1", Handler: _ServiceService_Protect1_Handler, }, { MethodName: "Protect1_1", Handler: _ServiceService_Protect1_1_Handler, }, { MethodName: "Protect1_2", Handler: _ServiceService_Protect1_2_Handler, }, { MethodName: "SetUnderlyingNetworks", Handler: _ServiceService_SetUnderlyingNetworks_Handler, }, { MethodName: "Prepare", Handler: _ServiceService_Prepare_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "proto/vpn/vpn.proto", }
ServiceService_ServiceDesc is the grpc.ServiceDesc for ServiceService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterServiceServiceServer ¶ added in v0.0.4
func RegisterServiceServiceServer(s grpc.ServiceRegistrar, srv ServiceServiceServer)
Types ¶
type IsAlwaysOnRequest ¶ added in v0.0.4
type IsAlwaysOnRequest struct {
// contains filtered or unexported fields
}
func (*IsAlwaysOnRequest) Descriptor
deprecated
added in
v0.0.4
func (*IsAlwaysOnRequest) Descriptor() ([]byte, []int)
Deprecated: Use IsAlwaysOnRequest.ProtoReflect.Descriptor instead.
func (*IsAlwaysOnRequest) ProtoMessage ¶ added in v0.0.4
func (*IsAlwaysOnRequest) ProtoMessage()
func (*IsAlwaysOnRequest) ProtoReflect ¶ added in v0.0.4
func (x *IsAlwaysOnRequest) ProtoReflect() protoreflect.Message
func (*IsAlwaysOnRequest) Reset ¶ added in v0.0.4
func (x *IsAlwaysOnRequest) Reset()
func (*IsAlwaysOnRequest) String ¶ added in v0.0.4
func (x *IsAlwaysOnRequest) String() string
type IsAlwaysOnResponse ¶ added in v0.0.4
type IsAlwaysOnResponse struct {
Result bool `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*IsAlwaysOnResponse) Descriptor
deprecated
added in
v0.0.4
func (*IsAlwaysOnResponse) Descriptor() ([]byte, []int)
Deprecated: Use IsAlwaysOnResponse.ProtoReflect.Descriptor instead.
func (*IsAlwaysOnResponse) GetResult ¶ added in v0.0.4
func (x *IsAlwaysOnResponse) GetResult() bool
func (*IsAlwaysOnResponse) ProtoMessage ¶ added in v0.0.4
func (*IsAlwaysOnResponse) ProtoMessage()
func (*IsAlwaysOnResponse) ProtoReflect ¶ added in v0.0.4
func (x *IsAlwaysOnResponse) ProtoReflect() protoreflect.Message
func (*IsAlwaysOnResponse) Reset ¶ added in v0.0.4
func (x *IsAlwaysOnResponse) Reset()
func (*IsAlwaysOnResponse) String ¶ added in v0.0.4
func (x *IsAlwaysOnResponse) String() string
type IsLockdownEnabledRequest ¶ added in v0.0.4
type IsLockdownEnabledRequest struct {
// contains filtered or unexported fields
}
func (*IsLockdownEnabledRequest) Descriptor
deprecated
added in
v0.0.4
func (*IsLockdownEnabledRequest) Descriptor() ([]byte, []int)
Deprecated: Use IsLockdownEnabledRequest.ProtoReflect.Descriptor instead.
func (*IsLockdownEnabledRequest) ProtoMessage ¶ added in v0.0.4
func (*IsLockdownEnabledRequest) ProtoMessage()
func (*IsLockdownEnabledRequest) ProtoReflect ¶ added in v0.0.4
func (x *IsLockdownEnabledRequest) ProtoReflect() protoreflect.Message
func (*IsLockdownEnabledRequest) Reset ¶ added in v0.0.4
func (x *IsLockdownEnabledRequest) Reset()
func (*IsLockdownEnabledRequest) String ¶ added in v0.0.4
func (x *IsLockdownEnabledRequest) String() string
type IsLockdownEnabledResponse ¶ added in v0.0.4
type IsLockdownEnabledResponse struct {
Result bool `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*IsLockdownEnabledResponse) Descriptor
deprecated
added in
v0.0.4
func (*IsLockdownEnabledResponse) Descriptor() ([]byte, []int)
Deprecated: Use IsLockdownEnabledResponse.ProtoReflect.Descriptor instead.
func (*IsLockdownEnabledResponse) GetResult ¶ added in v0.0.4
func (x *IsLockdownEnabledResponse) GetResult() bool
func (*IsLockdownEnabledResponse) ProtoMessage ¶ added in v0.0.4
func (*IsLockdownEnabledResponse) ProtoMessage()
func (*IsLockdownEnabledResponse) ProtoReflect ¶ added in v0.0.4
func (x *IsLockdownEnabledResponse) ProtoReflect() protoreflect.Message
func (*IsLockdownEnabledResponse) Reset ¶ added in v0.0.4
func (x *IsLockdownEnabledResponse) Reset()
func (*IsLockdownEnabledResponse) String ¶ added in v0.0.4
func (x *IsLockdownEnabledResponse) String() string
type OnBindRequest ¶
type OnBindRequest struct {
Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
// contains filtered or unexported fields
}
func (*OnBindRequest) Descriptor
deprecated
func (*OnBindRequest) Descriptor() ([]byte, []int)
Deprecated: Use OnBindRequest.ProtoReflect.Descriptor instead.
func (*OnBindRequest) GetArg0 ¶
func (x *OnBindRequest) GetArg0() int64
func (*OnBindRequest) ProtoMessage ¶
func (*OnBindRequest) ProtoMessage()
func (*OnBindRequest) ProtoReflect ¶
func (x *OnBindRequest) ProtoReflect() protoreflect.Message
func (*OnBindRequest) Reset ¶
func (x *OnBindRequest) Reset()
func (*OnBindRequest) String ¶
func (x *OnBindRequest) String() string
type OnBindResponse ¶
type OnBindResponse struct {
Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*OnBindResponse) Descriptor
deprecated
func (*OnBindResponse) Descriptor() ([]byte, []int)
Deprecated: Use OnBindResponse.ProtoReflect.Descriptor instead.
func (*OnBindResponse) GetResult ¶
func (x *OnBindResponse) GetResult() int64
func (*OnBindResponse) ProtoMessage ¶
func (*OnBindResponse) ProtoMessage()
func (*OnBindResponse) ProtoReflect ¶
func (x *OnBindResponse) ProtoReflect() protoreflect.Message
func (*OnBindResponse) Reset ¶
func (x *OnBindResponse) Reset()
func (*OnBindResponse) String ¶
func (x *OnBindResponse) String() string
type OnRevokeRequest ¶
type OnRevokeRequest struct {
// contains filtered or unexported fields
}
func (*OnRevokeRequest) Descriptor
deprecated
func (*OnRevokeRequest) Descriptor() ([]byte, []int)
Deprecated: Use OnRevokeRequest.ProtoReflect.Descriptor instead.
func (*OnRevokeRequest) ProtoMessage ¶
func (*OnRevokeRequest) ProtoMessage()
func (*OnRevokeRequest) ProtoReflect ¶
func (x *OnRevokeRequest) ProtoReflect() protoreflect.Message
func (*OnRevokeRequest) Reset ¶
func (x *OnRevokeRequest) Reset()
func (*OnRevokeRequest) String ¶
func (x *OnRevokeRequest) String() string
type OnRevokeResponse ¶
type OnRevokeResponse struct {
// contains filtered or unexported fields
}
func (*OnRevokeResponse) Descriptor
deprecated
func (*OnRevokeResponse) Descriptor() ([]byte, []int)
Deprecated: Use OnRevokeResponse.ProtoReflect.Descriptor instead.
func (*OnRevokeResponse) ProtoMessage ¶
func (*OnRevokeResponse) ProtoMessage()
func (*OnRevokeResponse) ProtoReflect ¶
func (x *OnRevokeResponse) ProtoReflect() protoreflect.Message
func (*OnRevokeResponse) Reset ¶
func (x *OnRevokeResponse) Reset()
func (*OnRevokeResponse) String ¶
func (x *OnRevokeResponse) String() string
type PrepareRequest ¶
type PrepareRequest struct {
Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
// contains filtered or unexported fields
}
func (*PrepareRequest) Descriptor
deprecated
func (*PrepareRequest) Descriptor() ([]byte, []int)
Deprecated: Use PrepareRequest.ProtoReflect.Descriptor instead.
func (*PrepareRequest) GetArg0 ¶
func (x *PrepareRequest) GetArg0() int64
func (*PrepareRequest) ProtoMessage ¶
func (*PrepareRequest) ProtoMessage()
func (*PrepareRequest) ProtoReflect ¶
func (x *PrepareRequest) ProtoReflect() protoreflect.Message
func (*PrepareRequest) Reset ¶
func (x *PrepareRequest) Reset()
func (*PrepareRequest) String ¶
func (x *PrepareRequest) String() string
type PrepareResponse ¶
type PrepareResponse struct {
Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*PrepareResponse) Descriptor
deprecated
func (*PrepareResponse) Descriptor() ([]byte, []int)
Deprecated: Use PrepareResponse.ProtoReflect.Descriptor instead.
func (*PrepareResponse) GetResult ¶
func (x *PrepareResponse) GetResult() int64
func (*PrepareResponse) ProtoMessage ¶
func (*PrepareResponse) ProtoMessage()
func (*PrepareResponse) ProtoReflect ¶
func (x *PrepareResponse) ProtoReflect() protoreflect.Message
func (*PrepareResponse) Reset ¶
func (x *PrepareResponse) Reset()
func (*PrepareResponse) String ¶
func (x *PrepareResponse) String() string
type Protect1Request ¶
type Protect1Request struct {
Arg0 int32 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
// contains filtered or unexported fields
}
func (*Protect1Request) Descriptor
deprecated
func (*Protect1Request) Descriptor() ([]byte, []int)
Deprecated: Use Protect1Request.ProtoReflect.Descriptor instead.
func (*Protect1Request) GetArg0 ¶
func (x *Protect1Request) GetArg0() int32
func (*Protect1Request) ProtoMessage ¶
func (*Protect1Request) ProtoMessage()
func (*Protect1Request) ProtoReflect ¶
func (x *Protect1Request) ProtoReflect() protoreflect.Message
func (*Protect1Request) Reset ¶
func (x *Protect1Request) Reset()
func (*Protect1Request) String ¶
func (x *Protect1Request) String() string
type Protect1Response ¶
type Protect1Response struct {
Result bool `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*Protect1Response) Descriptor
deprecated
func (*Protect1Response) Descriptor() ([]byte, []int)
Deprecated: Use Protect1Response.ProtoReflect.Descriptor instead.
func (*Protect1Response) GetResult ¶
func (x *Protect1Response) GetResult() bool
func (*Protect1Response) ProtoMessage ¶
func (*Protect1Response) ProtoMessage()
func (*Protect1Response) ProtoReflect ¶
func (x *Protect1Response) ProtoReflect() protoreflect.Message
func (*Protect1Response) Reset ¶
func (x *Protect1Response) Reset()
func (*Protect1Response) String ¶
func (x *Protect1Response) String() string
type Protect1_1Request ¶
type Protect1_1Request struct {
Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
// contains filtered or unexported fields
}
func (*Protect1_1Request) Descriptor
deprecated
func (*Protect1_1Request) Descriptor() ([]byte, []int)
Deprecated: Use Protect1_1Request.ProtoReflect.Descriptor instead.
func (*Protect1_1Request) GetArg0 ¶
func (x *Protect1_1Request) GetArg0() int64
func (*Protect1_1Request) ProtoMessage ¶
func (*Protect1_1Request) ProtoMessage()
func (*Protect1_1Request) ProtoReflect ¶
func (x *Protect1_1Request) ProtoReflect() protoreflect.Message
func (*Protect1_1Request) Reset ¶
func (x *Protect1_1Request) Reset()
func (*Protect1_1Request) String ¶
func (x *Protect1_1Request) String() string
type Protect1_1Response ¶
type Protect1_1Response struct {
Result bool `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*Protect1_1Response) Descriptor
deprecated
func (*Protect1_1Response) Descriptor() ([]byte, []int)
Deprecated: Use Protect1_1Response.ProtoReflect.Descriptor instead.
func (*Protect1_1Response) GetResult ¶
func (x *Protect1_1Response) GetResult() bool
func (*Protect1_1Response) ProtoMessage ¶
func (*Protect1_1Response) ProtoMessage()
func (*Protect1_1Response) ProtoReflect ¶
func (x *Protect1_1Response) ProtoReflect() protoreflect.Message
func (*Protect1_1Response) Reset ¶
func (x *Protect1_1Response) Reset()
func (*Protect1_1Response) String ¶
func (x *Protect1_1Response) String() string
type Protect1_2Request ¶
type Protect1_2Request struct {
Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
// contains filtered or unexported fields
}
func (*Protect1_2Request) Descriptor
deprecated
func (*Protect1_2Request) Descriptor() ([]byte, []int)
Deprecated: Use Protect1_2Request.ProtoReflect.Descriptor instead.
func (*Protect1_2Request) GetArg0 ¶
func (x *Protect1_2Request) GetArg0() int64
func (*Protect1_2Request) ProtoMessage ¶
func (*Protect1_2Request) ProtoMessage()
func (*Protect1_2Request) ProtoReflect ¶
func (x *Protect1_2Request) ProtoReflect() protoreflect.Message
func (*Protect1_2Request) Reset ¶
func (x *Protect1_2Request) Reset()
func (*Protect1_2Request) String ¶
func (x *Protect1_2Request) String() string
type Protect1_2Response ¶
type Protect1_2Response struct {
Result bool `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*Protect1_2Response) Descriptor
deprecated
func (*Protect1_2Response) Descriptor() ([]byte, []int)
Deprecated: Use Protect1_2Response.ProtoReflect.Descriptor instead.
func (*Protect1_2Response) GetResult ¶
func (x *Protect1_2Response) GetResult() bool
func (*Protect1_2Response) ProtoMessage ¶
func (*Protect1_2Response) ProtoMessage()
func (*Protect1_2Response) ProtoReflect ¶
func (x *Protect1_2Response) ProtoReflect() protoreflect.Message
func (*Protect1_2Response) Reset ¶
func (x *Protect1_2Response) Reset()
func (*Protect1_2Response) String ¶
func (x *Protect1_2Response) String() string
type ServiceServiceClient ¶ added in v0.0.4
type ServiceServiceClient interface {
IsAlwaysOn(ctx context.Context, in *IsAlwaysOnRequest, opts ...grpc.CallOption) (*IsAlwaysOnResponse, error)
IsLockdownEnabled(ctx context.Context, in *IsLockdownEnabledRequest, opts ...grpc.CallOption) (*IsLockdownEnabledResponse, error)
OnBind(ctx context.Context, in *OnBindRequest, opts ...grpc.CallOption) (*OnBindResponse, error)
OnRevoke(ctx context.Context, in *OnRevokeRequest, opts ...grpc.CallOption) (*OnRevokeResponse, error)
Protect1(ctx context.Context, in *Protect1Request, opts ...grpc.CallOption) (*Protect1Response, error)
Protect1_1(ctx context.Context, in *Protect1_1Request, opts ...grpc.CallOption) (*Protect1_1Response, error)
Protect1_2(ctx context.Context, in *Protect1_2Request, opts ...grpc.CallOption) (*Protect1_2Response, error)
SetUnderlyingNetworks(ctx context.Context, in *SetUnderlyingNetworksRequest, opts ...grpc.CallOption) (*SetUnderlyingNetworksResponse, error)
Prepare(ctx context.Context, in *PrepareRequest, opts ...grpc.CallOption) (*PrepareResponse, error)
}
ServiceServiceClient is the client API for ServiceService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewServiceServiceClient ¶ added in v0.0.4
func NewServiceServiceClient(cc grpc.ClientConnInterface) ServiceServiceClient
type ServiceServiceServer ¶ added in v0.0.4
type ServiceServiceServer interface {
IsAlwaysOn(context.Context, *IsAlwaysOnRequest) (*IsAlwaysOnResponse, error)
IsLockdownEnabled(context.Context, *IsLockdownEnabledRequest) (*IsLockdownEnabledResponse, error)
OnBind(context.Context, *OnBindRequest) (*OnBindResponse, error)
OnRevoke(context.Context, *OnRevokeRequest) (*OnRevokeResponse, error)
Protect1(context.Context, *Protect1Request) (*Protect1Response, error)
Protect1_1(context.Context, *Protect1_1Request) (*Protect1_1Response, error)
Protect1_2(context.Context, *Protect1_2Request) (*Protect1_2Response, error)
SetUnderlyingNetworks(context.Context, *SetUnderlyingNetworksRequest) (*SetUnderlyingNetworksResponse, error)
Prepare(context.Context, *PrepareRequest) (*PrepareResponse, error)
// contains filtered or unexported methods
}
ServiceServiceServer is the server API for ServiceService service. All implementations must embed UnimplementedServiceServiceServer for forward compatibility.
type SetUnderlyingNetworksRequest ¶
type SetUnderlyingNetworksRequest struct {
Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
// contains filtered or unexported fields
}
func (*SetUnderlyingNetworksRequest) Descriptor
deprecated
func (*SetUnderlyingNetworksRequest) Descriptor() ([]byte, []int)
Deprecated: Use SetUnderlyingNetworksRequest.ProtoReflect.Descriptor instead.
func (*SetUnderlyingNetworksRequest) GetArg0 ¶
func (x *SetUnderlyingNetworksRequest) GetArg0() int64
func (*SetUnderlyingNetworksRequest) ProtoMessage ¶
func (*SetUnderlyingNetworksRequest) ProtoMessage()
func (*SetUnderlyingNetworksRequest) ProtoReflect ¶
func (x *SetUnderlyingNetworksRequest) ProtoReflect() protoreflect.Message
func (*SetUnderlyingNetworksRequest) Reset ¶
func (x *SetUnderlyingNetworksRequest) Reset()
func (*SetUnderlyingNetworksRequest) String ¶
func (x *SetUnderlyingNetworksRequest) String() string
type SetUnderlyingNetworksResponse ¶
type SetUnderlyingNetworksResponse struct {
Result bool `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*SetUnderlyingNetworksResponse) Descriptor
deprecated
func (*SetUnderlyingNetworksResponse) Descriptor() ([]byte, []int)
Deprecated: Use SetUnderlyingNetworksResponse.ProtoReflect.Descriptor instead.
func (*SetUnderlyingNetworksResponse) GetResult ¶
func (x *SetUnderlyingNetworksResponse) GetResult() bool
func (*SetUnderlyingNetworksResponse) ProtoMessage ¶
func (*SetUnderlyingNetworksResponse) ProtoMessage()
func (*SetUnderlyingNetworksResponse) ProtoReflect ¶
func (x *SetUnderlyingNetworksResponse) ProtoReflect() protoreflect.Message
func (*SetUnderlyingNetworksResponse) Reset ¶
func (x *SetUnderlyingNetworksResponse) Reset()
func (*SetUnderlyingNetworksResponse) String ¶
func (x *SetUnderlyingNetworksResponse) String() string
type UnimplementedServiceServiceServer ¶ added in v0.0.4
type UnimplementedServiceServiceServer struct{}
UnimplementedServiceServiceServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedServiceServiceServer) IsAlwaysOn ¶ added in v0.0.4
func (UnimplementedServiceServiceServer) IsAlwaysOn(context.Context, *IsAlwaysOnRequest) (*IsAlwaysOnResponse, error)
func (UnimplementedServiceServiceServer) IsLockdownEnabled ¶ added in v0.0.4
func (UnimplementedServiceServiceServer) IsLockdownEnabled(context.Context, *IsLockdownEnabledRequest) (*IsLockdownEnabledResponse, error)
func (UnimplementedServiceServiceServer) OnBind ¶ added in v0.0.4
func (UnimplementedServiceServiceServer) OnBind(context.Context, *OnBindRequest) (*OnBindResponse, error)
func (UnimplementedServiceServiceServer) OnRevoke ¶ added in v0.0.4
func (UnimplementedServiceServiceServer) OnRevoke(context.Context, *OnRevokeRequest) (*OnRevokeResponse, error)
func (UnimplementedServiceServiceServer) Prepare ¶ added in v0.0.4
func (UnimplementedServiceServiceServer) Prepare(context.Context, *PrepareRequest) (*PrepareResponse, error)
func (UnimplementedServiceServiceServer) Protect1 ¶ added in v0.0.4
func (UnimplementedServiceServiceServer) Protect1(context.Context, *Protect1Request) (*Protect1Response, error)
func (UnimplementedServiceServiceServer) Protect1_1 ¶ added in v0.0.4
func (UnimplementedServiceServiceServer) Protect1_1(context.Context, *Protect1_1Request) (*Protect1_1Response, error)
func (UnimplementedServiceServiceServer) Protect1_2 ¶ added in v0.0.4
func (UnimplementedServiceServiceServer) Protect1_2(context.Context, *Protect1_2Request) (*Protect1_2Response, error)
func (UnimplementedServiceServiceServer) SetUnderlyingNetworks ¶ added in v0.0.4
func (UnimplementedServiceServiceServer) SetUnderlyingNetworks(context.Context, *SetUnderlyingNetworksRequest) (*SetUnderlyingNetworksResponse, error)
type UnsafeServiceServiceServer ¶ added in v0.0.4
type UnsafeServiceServiceServer interface {
// contains filtered or unexported methods
}
UnsafeServiceServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ServiceServiceServer will result in compilation errors.