Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterBooleanActionServiceServer(s grpc.ServiceRegistrar, srv BooleanActionServiceServer)
- func RegisterCommandActionServiceServer(s grpc.ServiceRegistrar, srv CommandActionServiceServer)
- func RegisterControlActionServiceServer(s grpc.ServiceRegistrar, srv ControlActionServiceServer)
- func RegisterFloatActionServiceServer(s grpc.ServiceRegistrar, srv FloatActionServiceServer)
- func RegisterModeActionServiceServer(s grpc.ServiceRegistrar, srv ModeActionServiceServer)
- type BooleanActionServiceClient
- type BooleanActionServiceServer
- type CommandActionServiceClient
- type CommandActionServiceServer
- type ControlActionGetActionTypeRequest
- func (*ControlActionGetActionTypeRequest) Descriptor() ([]byte, []int)deprecated
- func (*ControlActionGetActionTypeRequest) ProtoMessage()
- func (x *ControlActionGetActionTypeRequest) ProtoReflect() protoreflect.Message
- func (x *ControlActionGetActionTypeRequest) Reset()
- func (x *ControlActionGetActionTypeRequest) String() string
- type ControlActionServiceClient
- type ControlActionServiceServer
- type FloatActionServiceClient
- type FloatActionServiceServer
- type GetActionTypeRequest
- func (*GetActionTypeRequest) Descriptor() ([]byte, []int)deprecated
- func (x *GetActionTypeRequest) GetHandle() int64
- func (*GetActionTypeRequest) ProtoMessage()
- func (x *GetActionTypeRequest) ProtoReflect() protoreflect.Message
- func (x *GetActionTypeRequest) Reset()
- func (x *GetActionTypeRequest) String() string
- type GetActionTypeResponse
- func (*GetActionTypeResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetActionTypeResponse) GetResult() int32
- func (*GetActionTypeResponse) ProtoMessage()
- func (x *GetActionTypeResponse) ProtoReflect() protoreflect.Message
- func (x *GetActionTypeResponse) Reset()
- func (x *GetActionTypeResponse) String() string
- type GetChallengeValueRequest
- type GetChallengeValueResponse
- func (*GetChallengeValueResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetChallengeValueResponse) GetResult() string
- func (*GetChallengeValueResponse) ProtoMessage()
- func (x *GetChallengeValueResponse) ProtoReflect() protoreflect.Message
- func (x *GetChallengeValueResponse) Reset()
- func (x *GetChallengeValueResponse) String() string
- type GetErrorActionRequest
- type GetErrorActionResponse
- func (*GetErrorActionResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetErrorActionResponse) GetResult() int64
- func (*GetErrorActionResponse) ProtoMessage()
- func (x *GetErrorActionResponse) ProtoReflect() protoreflect.Message
- func (x *GetErrorActionResponse) Reset()
- func (x *GetErrorActionResponse) String() string
- type GetNewModeRequest
- type GetNewModeResponse
- func (*GetNewModeResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetNewModeResponse) GetResult() int32
- func (*GetNewModeResponse) ProtoMessage()
- func (x *GetNewModeResponse) ProtoReflect() protoreflect.Message
- func (x *GetNewModeResponse) Reset()
- func (x *GetNewModeResponse) String() string
- type GetNewStateRequest
- func (*GetNewStateRequest) Descriptor() ([]byte, []int)deprecated
- func (x *GetNewStateRequest) GetHandle() int64
- func (*GetNewStateRequest) ProtoMessage()
- func (x *GetNewStateRequest) ProtoReflect() protoreflect.Message
- func (x *GetNewStateRequest) Reset()
- func (x *GetNewStateRequest) String() string
- type GetNewStateResponse
- func (*GetNewStateResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetNewStateResponse) GetResult() bool
- func (*GetNewStateResponse) ProtoMessage()
- func (x *GetNewStateResponse) ProtoReflect() protoreflect.Message
- func (x *GetNewStateResponse) Reset()
- func (x *GetNewStateResponse) String() string
- type GetNewValueRequest
- func (*GetNewValueRequest) Descriptor() ([]byte, []int)deprecated
- func (x *GetNewValueRequest) GetHandle() int64
- func (*GetNewValueRequest) ProtoMessage()
- func (x *GetNewValueRequest) ProtoReflect() protoreflect.Message
- func (x *GetNewValueRequest) Reset()
- func (x *GetNewValueRequest) String() string
- type GetNewValueResponse
- func (*GetNewValueResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetNewValueResponse) GetResult() float32
- func (*GetNewValueResponse) ProtoMessage()
- func (x *GetNewValueResponse) ProtoReflect() protoreflect.Message
- func (x *GetNewValueResponse) Reset()
- func (x *GetNewValueResponse) String() string
- type GetTemplateIdRequest
- type GetTemplateIdResponse
- func (*GetTemplateIdResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetTemplateIdResponse) GetResult() string
- func (*GetTemplateIdResponse) ProtoMessage()
- func (x *GetTemplateIdResponse) ProtoReflect() protoreflect.Message
- func (x *GetTemplateIdResponse) Reset()
- func (x *GetTemplateIdResponse) String() string
- type IsValidResponseRequest
- func (*IsValidResponseRequest) Descriptor() ([]byte, []int)deprecated
- func (x *IsValidResponseRequest) GetArg0() int32
- func (*IsValidResponseRequest) ProtoMessage()
- func (x *IsValidResponseRequest) ProtoReflect() protoreflect.Message
- func (x *IsValidResponseRequest) Reset()
- func (x *IsValidResponseRequest) String() string
- type IsValidResponseResponse
- func (*IsValidResponseResponse) Descriptor() ([]byte, []int)deprecated
- func (x *IsValidResponseResponse) GetResult() bool
- func (*IsValidResponseResponse) ProtoMessage()
- func (x *IsValidResponseResponse) ProtoReflect() protoreflect.Message
- func (x *IsValidResponseResponse) Reset()
- func (x *IsValidResponseResponse) String() string
- type ModeActionServiceClient
- type ModeActionServiceServer
- type NewBooleanActionRequest
- func (*NewBooleanActionRequest) Descriptor() ([]byte, []int)deprecated
- func (x *NewBooleanActionRequest) GetArg0() string
- func (x *NewBooleanActionRequest) GetArg1() bool
- func (*NewBooleanActionRequest) ProtoMessage()
- func (x *NewBooleanActionRequest) ProtoReflect() protoreflect.Message
- func (x *NewBooleanActionRequest) Reset()
- func (x *NewBooleanActionRequest) String() string
- type NewBooleanActionResponse
- func (*NewBooleanActionResponse) Descriptor() ([]byte, []int)deprecated
- func (x *NewBooleanActionResponse) GetResult() int64
- func (*NewBooleanActionResponse) ProtoMessage()
- func (x *NewBooleanActionResponse) ProtoReflect() protoreflect.Message
- func (x *NewBooleanActionResponse) Reset()
- func (x *NewBooleanActionResponse) String() string
- type NewCommandActionRequest
- func (*NewCommandActionRequest) Descriptor() ([]byte, []int)deprecated
- func (x *NewCommandActionRequest) GetArg0() string
- func (*NewCommandActionRequest) ProtoMessage()
- func (x *NewCommandActionRequest) ProtoReflect() protoreflect.Message
- func (x *NewCommandActionRequest) Reset()
- func (x *NewCommandActionRequest) String() string
- type NewCommandActionResponse
- func (*NewCommandActionResponse) Descriptor() ([]byte, []int)deprecated
- func (x *NewCommandActionResponse) GetResult() int64
- func (*NewCommandActionResponse) ProtoMessage()
- func (x *NewCommandActionResponse) ProtoReflect() protoreflect.Message
- func (x *NewCommandActionResponse) Reset()
- func (x *NewCommandActionResponse) String() string
- type NewFloatActionRequest
- func (*NewFloatActionRequest) Descriptor() ([]byte, []int)deprecated
- func (x *NewFloatActionRequest) GetArg0() string
- func (x *NewFloatActionRequest) GetArg1() float32
- func (*NewFloatActionRequest) ProtoMessage()
- func (x *NewFloatActionRequest) ProtoReflect() protoreflect.Message
- func (x *NewFloatActionRequest) Reset()
- func (x *NewFloatActionRequest) String() string
- type NewFloatActionResponse
- func (*NewFloatActionResponse) Descriptor() ([]byte, []int)deprecated
- func (x *NewFloatActionResponse) GetResult() int64
- func (*NewFloatActionResponse) ProtoMessage()
- func (x *NewFloatActionResponse) ProtoReflect() protoreflect.Message
- func (x *NewFloatActionResponse) Reset()
- func (x *NewFloatActionResponse) String() string
- type NewModeActionRequest
- func (*NewModeActionRequest) Descriptor() ([]byte, []int)deprecated
- func (x *NewModeActionRequest) GetArg0() string
- func (x *NewModeActionRequest) GetArg1() int32
- func (*NewModeActionRequest) ProtoMessage()
- func (x *NewModeActionRequest) ProtoReflect() protoreflect.Message
- func (x *NewModeActionRequest) Reset()
- func (x *NewModeActionRequest) String() string
- type NewModeActionResponse
- func (*NewModeActionResponse) Descriptor() ([]byte, []int)deprecated
- func (x *NewModeActionResponse) GetResult() int64
- func (*NewModeActionResponse) ProtoMessage()
- func (x *NewModeActionResponse) ProtoReflect() protoreflect.Message
- func (x *NewModeActionResponse) Reset()
- func (x *NewModeActionResponse) String() string
- type UnimplementedBooleanActionServiceServer
- func (UnimplementedBooleanActionServiceServer) GetActionType(context.Context, *GetActionTypeRequest) (*GetActionTypeResponse, error)
- func (UnimplementedBooleanActionServiceServer) GetNewState(context.Context, *GetNewStateRequest) (*GetNewStateResponse, error)
- func (UnimplementedBooleanActionServiceServer) NewBooleanAction(context.Context, *NewBooleanActionRequest) (*NewBooleanActionResponse, error)
- type UnimplementedCommandActionServiceServer
- type UnimplementedControlActionServiceServer
- func (UnimplementedControlActionServiceServer) GetActionType(context.Context, *ControlActionGetActionTypeRequest) (*GetActionTypeResponse, error)
- func (UnimplementedControlActionServiceServer) GetChallengeValue(context.Context, *GetChallengeValueRequest) (*GetChallengeValueResponse, error)
- func (UnimplementedControlActionServiceServer) GetErrorAction(context.Context, *GetErrorActionRequest) (*GetErrorActionResponse, error)
- func (UnimplementedControlActionServiceServer) GetTemplateId(context.Context, *GetTemplateIdRequest) (*GetTemplateIdResponse, error)
- func (UnimplementedControlActionServiceServer) IsValidResponse(context.Context, *IsValidResponseRequest) (*IsValidResponseResponse, error)
- type UnimplementedFloatActionServiceServer
- func (UnimplementedFloatActionServiceServer) GetActionType(context.Context, *GetActionTypeRequest) (*GetActionTypeResponse, error)
- func (UnimplementedFloatActionServiceServer) GetNewValue(context.Context, *GetNewValueRequest) (*GetNewValueResponse, error)
- func (UnimplementedFloatActionServiceServer) NewFloatAction(context.Context, *NewFloatActionRequest) (*NewFloatActionResponse, error)
- type UnimplementedModeActionServiceServer
- func (UnimplementedModeActionServiceServer) GetActionType(context.Context, *GetActionTypeRequest) (*GetActionTypeResponse, error)
- func (UnimplementedModeActionServiceServer) GetNewMode(context.Context, *GetNewModeRequest) (*GetNewModeResponse, error)
- func (UnimplementedModeActionServiceServer) NewModeAction(context.Context, *NewModeActionRequest) (*NewModeActionResponse, error)
- type UnsafeBooleanActionServiceServer
- type UnsafeCommandActionServiceServer
- type UnsafeControlActionServiceServer
- type UnsafeFloatActionServiceServer
- type UnsafeModeActionServiceServer
Constants ¶
const ( BooleanActionService_NewBooleanAction_FullMethodName = "/actions.BooleanActionService/NewBooleanAction" BooleanActionService_GetActionType_FullMethodName = "/actions.BooleanActionService/GetActionType" BooleanActionService_GetNewState_FullMethodName = "/actions.BooleanActionService/GetNewState" )
const ( ControlActionService_GetActionType_FullMethodName = "/actions.ControlActionService/GetActionType" ControlActionService_GetChallengeValue_FullMethodName = "/actions.ControlActionService/GetChallengeValue" ControlActionService_GetTemplateId_FullMethodName = "/actions.ControlActionService/GetTemplateId" ControlActionService_GetErrorAction_FullMethodName = "/actions.ControlActionService/GetErrorAction" ControlActionService_IsValidResponse_FullMethodName = "/actions.ControlActionService/IsValidResponse" )
const ( FloatActionService_NewFloatAction_FullMethodName = "/actions.FloatActionService/NewFloatAction" FloatActionService_GetActionType_FullMethodName = "/actions.FloatActionService/GetActionType" FloatActionService_GetNewValue_FullMethodName = "/actions.FloatActionService/GetNewValue" )
const ( CommandActionService_NewCommandAction_FullMethodName = "/actions.CommandActionService/NewCommandAction" CommandActionService_GetActionType_FullMethodName = "/actions.CommandActionService/GetActionType" )
const ( ModeActionService_NewModeAction_FullMethodName = "/actions.ModeActionService/NewModeAction" ModeActionService_GetActionType_FullMethodName = "/actions.ModeActionService/GetActionType" ModeActionService_GetNewMode_FullMethodName = "/actions.ModeActionService/GetNewMode" )
Variables ¶
var BooleanActionService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "actions.BooleanActionService", HandlerType: (*BooleanActionServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "NewBooleanAction", Handler: _BooleanActionService_NewBooleanAction_Handler, }, { MethodName: "GetActionType", Handler: _BooleanActionService_GetActionType_Handler, }, { MethodName: "GetNewState", Handler: _BooleanActionService_GetNewState_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "proto/actions/actions.proto", }
BooleanActionService_ServiceDesc is the grpc.ServiceDesc for BooleanActionService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var CommandActionService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "actions.CommandActionService", HandlerType: (*CommandActionServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "NewCommandAction", Handler: _CommandActionService_NewCommandAction_Handler, }, { MethodName: "GetActionType", Handler: _CommandActionService_GetActionType_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "proto/actions/actions.proto", }
CommandActionService_ServiceDesc is the grpc.ServiceDesc for CommandActionService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var ControlActionService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "actions.ControlActionService", HandlerType: (*ControlActionServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "GetActionType", Handler: _ControlActionService_GetActionType_Handler, }, { MethodName: "GetChallengeValue", Handler: _ControlActionService_GetChallengeValue_Handler, }, { MethodName: "GetTemplateId", Handler: _ControlActionService_GetTemplateId_Handler, }, { MethodName: "GetErrorAction", Handler: _ControlActionService_GetErrorAction_Handler, }, { MethodName: "IsValidResponse", Handler: _ControlActionService_IsValidResponse_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "proto/actions/actions.proto", }
ControlActionService_ServiceDesc is the grpc.ServiceDesc for ControlActionService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var File_proto_actions_actions_proto protoreflect.FileDescriptor
var FloatActionService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "actions.FloatActionService", HandlerType: (*FloatActionServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "NewFloatAction", Handler: _FloatActionService_NewFloatAction_Handler, }, { MethodName: "GetActionType", Handler: _FloatActionService_GetActionType_Handler, }, { MethodName: "GetNewValue", Handler: _FloatActionService_GetNewValue_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "proto/actions/actions.proto", }
FloatActionService_ServiceDesc is the grpc.ServiceDesc for FloatActionService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var ModeActionService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "actions.ModeActionService", HandlerType: (*ModeActionServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "NewModeAction", Handler: _ModeActionService_NewModeAction_Handler, }, { MethodName: "GetActionType", Handler: _ModeActionService_GetActionType_Handler, }, { MethodName: "GetNewMode", Handler: _ModeActionService_GetNewMode_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "proto/actions/actions.proto", }
ModeActionService_ServiceDesc is the grpc.ServiceDesc for ModeActionService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterBooleanActionServiceServer ¶
func RegisterBooleanActionServiceServer(s grpc.ServiceRegistrar, srv BooleanActionServiceServer)
func RegisterCommandActionServiceServer ¶
func RegisterCommandActionServiceServer(s grpc.ServiceRegistrar, srv CommandActionServiceServer)
func RegisterControlActionServiceServer ¶
func RegisterControlActionServiceServer(s grpc.ServiceRegistrar, srv ControlActionServiceServer)
func RegisterFloatActionServiceServer ¶
func RegisterFloatActionServiceServer(s grpc.ServiceRegistrar, srv FloatActionServiceServer)
func RegisterModeActionServiceServer ¶
func RegisterModeActionServiceServer(s grpc.ServiceRegistrar, srv ModeActionServiceServer)
Types ¶
type BooleanActionServiceClient ¶
type BooleanActionServiceClient interface {
NewBooleanAction(ctx context.Context, in *NewBooleanActionRequest, opts ...grpc.CallOption) (*NewBooleanActionResponse, error)
GetActionType(ctx context.Context, in *GetActionTypeRequest, opts ...grpc.CallOption) (*GetActionTypeResponse, error)
GetNewState(ctx context.Context, in *GetNewStateRequest, opts ...grpc.CallOption) (*GetNewStateResponse, error)
}
BooleanActionServiceClient is the client API for BooleanActionService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewBooleanActionServiceClient ¶
func NewBooleanActionServiceClient(cc grpc.ClientConnInterface) BooleanActionServiceClient
type BooleanActionServiceServer ¶
type BooleanActionServiceServer interface {
NewBooleanAction(context.Context, *NewBooleanActionRequest) (*NewBooleanActionResponse, error)
GetActionType(context.Context, *GetActionTypeRequest) (*GetActionTypeResponse, error)
GetNewState(context.Context, *GetNewStateRequest) (*GetNewStateResponse, error)
// contains filtered or unexported methods
}
BooleanActionServiceServer is the server API for BooleanActionService service. All implementations must embed UnimplementedBooleanActionServiceServer for forward compatibility.
type CommandActionServiceClient ¶
type CommandActionServiceClient interface {
NewCommandAction(ctx context.Context, in *NewCommandActionRequest, opts ...grpc.CallOption) (*NewCommandActionResponse, error)
GetActionType(ctx context.Context, in *GetActionTypeRequest, opts ...grpc.CallOption) (*GetActionTypeResponse, error)
}
CommandActionServiceClient is the client API for CommandActionService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewCommandActionServiceClient ¶
func NewCommandActionServiceClient(cc grpc.ClientConnInterface) CommandActionServiceClient
type CommandActionServiceServer ¶
type CommandActionServiceServer interface {
NewCommandAction(context.Context, *NewCommandActionRequest) (*NewCommandActionResponse, error)
GetActionType(context.Context, *GetActionTypeRequest) (*GetActionTypeResponse, error)
// contains filtered or unexported methods
}
CommandActionServiceServer is the server API for CommandActionService service. All implementations must embed UnimplementedCommandActionServiceServer for forward compatibility.
type ControlActionGetActionTypeRequest ¶
type ControlActionGetActionTypeRequest struct {
// contains filtered or unexported fields
}
func (*ControlActionGetActionTypeRequest) Descriptor
deprecated
func (*ControlActionGetActionTypeRequest) Descriptor() ([]byte, []int)
Deprecated: Use ControlActionGetActionTypeRequest.ProtoReflect.Descriptor instead.
func (*ControlActionGetActionTypeRequest) ProtoMessage ¶
func (*ControlActionGetActionTypeRequest) ProtoMessage()
func (*ControlActionGetActionTypeRequest) ProtoReflect ¶
func (x *ControlActionGetActionTypeRequest) ProtoReflect() protoreflect.Message
func (*ControlActionGetActionTypeRequest) Reset ¶
func (x *ControlActionGetActionTypeRequest) Reset()
func (*ControlActionGetActionTypeRequest) String ¶
func (x *ControlActionGetActionTypeRequest) String() string
type ControlActionServiceClient ¶
type ControlActionServiceClient interface {
GetActionType(ctx context.Context, in *ControlActionGetActionTypeRequest, opts ...grpc.CallOption) (*GetActionTypeResponse, error)
GetChallengeValue(ctx context.Context, in *GetChallengeValueRequest, opts ...grpc.CallOption) (*GetChallengeValueResponse, error)
GetTemplateId(ctx context.Context, in *GetTemplateIdRequest, opts ...grpc.CallOption) (*GetTemplateIdResponse, error)
GetErrorAction(ctx context.Context, in *GetErrorActionRequest, opts ...grpc.CallOption) (*GetErrorActionResponse, error)
IsValidResponse(ctx context.Context, in *IsValidResponseRequest, opts ...grpc.CallOption) (*IsValidResponseResponse, error)
}
ControlActionServiceClient is the client API for ControlActionService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewControlActionServiceClient ¶
func NewControlActionServiceClient(cc grpc.ClientConnInterface) ControlActionServiceClient
type ControlActionServiceServer ¶
type ControlActionServiceServer interface {
GetActionType(context.Context, *ControlActionGetActionTypeRequest) (*GetActionTypeResponse, error)
GetChallengeValue(context.Context, *GetChallengeValueRequest) (*GetChallengeValueResponse, error)
GetTemplateId(context.Context, *GetTemplateIdRequest) (*GetTemplateIdResponse, error)
GetErrorAction(context.Context, *GetErrorActionRequest) (*GetErrorActionResponse, error)
IsValidResponse(context.Context, *IsValidResponseRequest) (*IsValidResponseResponse, error)
// contains filtered or unexported methods
}
ControlActionServiceServer is the server API for ControlActionService service. All implementations must embed UnimplementedControlActionServiceServer for forward compatibility.
type FloatActionServiceClient ¶
type FloatActionServiceClient interface {
NewFloatAction(ctx context.Context, in *NewFloatActionRequest, opts ...grpc.CallOption) (*NewFloatActionResponse, error)
GetActionType(ctx context.Context, in *GetActionTypeRequest, opts ...grpc.CallOption) (*GetActionTypeResponse, error)
GetNewValue(ctx context.Context, in *GetNewValueRequest, opts ...grpc.CallOption) (*GetNewValueResponse, error)
}
FloatActionServiceClient is the client API for FloatActionService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewFloatActionServiceClient ¶
func NewFloatActionServiceClient(cc grpc.ClientConnInterface) FloatActionServiceClient
type FloatActionServiceServer ¶
type FloatActionServiceServer interface {
NewFloatAction(context.Context, *NewFloatActionRequest) (*NewFloatActionResponse, error)
GetActionType(context.Context, *GetActionTypeRequest) (*GetActionTypeResponse, error)
GetNewValue(context.Context, *GetNewValueRequest) (*GetNewValueResponse, error)
// contains filtered or unexported methods
}
FloatActionServiceServer is the server API for FloatActionService service. All implementations must embed UnimplementedFloatActionServiceServer for forward compatibility.
type GetActionTypeRequest ¶
type GetActionTypeRequest struct {
Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
// contains filtered or unexported fields
}
func (*GetActionTypeRequest) Descriptor
deprecated
func (*GetActionTypeRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetActionTypeRequest.ProtoReflect.Descriptor instead.
func (*GetActionTypeRequest) GetHandle ¶
func (x *GetActionTypeRequest) GetHandle() int64
func (*GetActionTypeRequest) ProtoMessage ¶
func (*GetActionTypeRequest) ProtoMessage()
func (*GetActionTypeRequest) ProtoReflect ¶
func (x *GetActionTypeRequest) ProtoReflect() protoreflect.Message
func (*GetActionTypeRequest) Reset ¶
func (x *GetActionTypeRequest) Reset()
func (*GetActionTypeRequest) String ¶
func (x *GetActionTypeRequest) String() string
type GetActionTypeResponse ¶
type GetActionTypeResponse struct {
Result int32 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*GetActionTypeResponse) Descriptor
deprecated
func (*GetActionTypeResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetActionTypeResponse.ProtoReflect.Descriptor instead.
func (*GetActionTypeResponse) GetResult ¶
func (x *GetActionTypeResponse) GetResult() int32
func (*GetActionTypeResponse) ProtoMessage ¶
func (*GetActionTypeResponse) ProtoMessage()
func (*GetActionTypeResponse) ProtoReflect ¶
func (x *GetActionTypeResponse) ProtoReflect() protoreflect.Message
func (*GetActionTypeResponse) Reset ¶
func (x *GetActionTypeResponse) Reset()
func (*GetActionTypeResponse) String ¶
func (x *GetActionTypeResponse) String() string
type GetChallengeValueRequest ¶
type GetChallengeValueRequest struct {
// contains filtered or unexported fields
}
func (*GetChallengeValueRequest) Descriptor
deprecated
func (*GetChallengeValueRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetChallengeValueRequest.ProtoReflect.Descriptor instead.
func (*GetChallengeValueRequest) ProtoMessage ¶
func (*GetChallengeValueRequest) ProtoMessage()
func (*GetChallengeValueRequest) ProtoReflect ¶
func (x *GetChallengeValueRequest) ProtoReflect() protoreflect.Message
func (*GetChallengeValueRequest) Reset ¶
func (x *GetChallengeValueRequest) Reset()
func (*GetChallengeValueRequest) String ¶
func (x *GetChallengeValueRequest) String() string
type GetChallengeValueResponse ¶
type GetChallengeValueResponse struct {
Result string `protobuf:"bytes,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*GetChallengeValueResponse) Descriptor
deprecated
func (*GetChallengeValueResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetChallengeValueResponse.ProtoReflect.Descriptor instead.
func (*GetChallengeValueResponse) GetResult ¶
func (x *GetChallengeValueResponse) GetResult() string
func (*GetChallengeValueResponse) ProtoMessage ¶
func (*GetChallengeValueResponse) ProtoMessage()
func (*GetChallengeValueResponse) ProtoReflect ¶
func (x *GetChallengeValueResponse) ProtoReflect() protoreflect.Message
func (*GetChallengeValueResponse) Reset ¶
func (x *GetChallengeValueResponse) Reset()
func (*GetChallengeValueResponse) String ¶
func (x *GetChallengeValueResponse) String() string
type GetErrorActionRequest ¶
type GetErrorActionRequest struct {
// contains filtered or unexported fields
}
func (*GetErrorActionRequest) Descriptor
deprecated
func (*GetErrorActionRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetErrorActionRequest.ProtoReflect.Descriptor instead.
func (*GetErrorActionRequest) ProtoMessage ¶
func (*GetErrorActionRequest) ProtoMessage()
func (*GetErrorActionRequest) ProtoReflect ¶
func (x *GetErrorActionRequest) ProtoReflect() protoreflect.Message
func (*GetErrorActionRequest) Reset ¶
func (x *GetErrorActionRequest) Reset()
func (*GetErrorActionRequest) String ¶
func (x *GetErrorActionRequest) String() string
type GetErrorActionResponse ¶
type GetErrorActionResponse struct {
Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*GetErrorActionResponse) Descriptor
deprecated
func (*GetErrorActionResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetErrorActionResponse.ProtoReflect.Descriptor instead.
func (*GetErrorActionResponse) GetResult ¶
func (x *GetErrorActionResponse) GetResult() int64
func (*GetErrorActionResponse) ProtoMessage ¶
func (*GetErrorActionResponse) ProtoMessage()
func (*GetErrorActionResponse) ProtoReflect ¶
func (x *GetErrorActionResponse) ProtoReflect() protoreflect.Message
func (*GetErrorActionResponse) Reset ¶
func (x *GetErrorActionResponse) Reset()
func (*GetErrorActionResponse) String ¶
func (x *GetErrorActionResponse) String() string
type GetNewModeRequest ¶
type GetNewModeRequest struct {
Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
// contains filtered or unexported fields
}
func (*GetNewModeRequest) Descriptor
deprecated
func (*GetNewModeRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetNewModeRequest.ProtoReflect.Descriptor instead.
func (*GetNewModeRequest) GetHandle ¶
func (x *GetNewModeRequest) GetHandle() int64
func (*GetNewModeRequest) ProtoMessage ¶
func (*GetNewModeRequest) ProtoMessage()
func (*GetNewModeRequest) ProtoReflect ¶
func (x *GetNewModeRequest) ProtoReflect() protoreflect.Message
func (*GetNewModeRequest) Reset ¶
func (x *GetNewModeRequest) Reset()
func (*GetNewModeRequest) String ¶
func (x *GetNewModeRequest) String() string
type GetNewModeResponse ¶
type GetNewModeResponse struct {
Result int32 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*GetNewModeResponse) Descriptor
deprecated
func (*GetNewModeResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetNewModeResponse.ProtoReflect.Descriptor instead.
func (*GetNewModeResponse) GetResult ¶
func (x *GetNewModeResponse) GetResult() int32
func (*GetNewModeResponse) ProtoMessage ¶
func (*GetNewModeResponse) ProtoMessage()
func (*GetNewModeResponse) ProtoReflect ¶
func (x *GetNewModeResponse) ProtoReflect() protoreflect.Message
func (*GetNewModeResponse) Reset ¶
func (x *GetNewModeResponse) Reset()
func (*GetNewModeResponse) String ¶
func (x *GetNewModeResponse) String() string
type GetNewStateRequest ¶
type GetNewStateRequest struct {
Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
// contains filtered or unexported fields
}
func (*GetNewStateRequest) Descriptor
deprecated
func (*GetNewStateRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetNewStateRequest.ProtoReflect.Descriptor instead.
func (*GetNewStateRequest) GetHandle ¶
func (x *GetNewStateRequest) GetHandle() int64
func (*GetNewStateRequest) ProtoMessage ¶
func (*GetNewStateRequest) ProtoMessage()
func (*GetNewStateRequest) ProtoReflect ¶
func (x *GetNewStateRequest) ProtoReflect() protoreflect.Message
func (*GetNewStateRequest) Reset ¶
func (x *GetNewStateRequest) Reset()
func (*GetNewStateRequest) String ¶
func (x *GetNewStateRequest) String() string
type GetNewStateResponse ¶
type GetNewStateResponse struct {
Result bool `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*GetNewStateResponse) Descriptor
deprecated
func (*GetNewStateResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetNewStateResponse.ProtoReflect.Descriptor instead.
func (*GetNewStateResponse) GetResult ¶
func (x *GetNewStateResponse) GetResult() bool
func (*GetNewStateResponse) ProtoMessage ¶
func (*GetNewStateResponse) ProtoMessage()
func (*GetNewStateResponse) ProtoReflect ¶
func (x *GetNewStateResponse) ProtoReflect() protoreflect.Message
func (*GetNewStateResponse) Reset ¶
func (x *GetNewStateResponse) Reset()
func (*GetNewStateResponse) String ¶
func (x *GetNewStateResponse) String() string
type GetNewValueRequest ¶
type GetNewValueRequest struct {
Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
// contains filtered or unexported fields
}
func (*GetNewValueRequest) Descriptor
deprecated
func (*GetNewValueRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetNewValueRequest.ProtoReflect.Descriptor instead.
func (*GetNewValueRequest) GetHandle ¶
func (x *GetNewValueRequest) GetHandle() int64
func (*GetNewValueRequest) ProtoMessage ¶
func (*GetNewValueRequest) ProtoMessage()
func (*GetNewValueRequest) ProtoReflect ¶
func (x *GetNewValueRequest) ProtoReflect() protoreflect.Message
func (*GetNewValueRequest) Reset ¶
func (x *GetNewValueRequest) Reset()
func (*GetNewValueRequest) String ¶
func (x *GetNewValueRequest) String() string
type GetNewValueResponse ¶
type GetNewValueResponse struct {
Result float32 `protobuf:"fixed32,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*GetNewValueResponse) Descriptor
deprecated
func (*GetNewValueResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetNewValueResponse.ProtoReflect.Descriptor instead.
func (*GetNewValueResponse) GetResult ¶
func (x *GetNewValueResponse) GetResult() float32
func (*GetNewValueResponse) ProtoMessage ¶
func (*GetNewValueResponse) ProtoMessage()
func (*GetNewValueResponse) ProtoReflect ¶
func (x *GetNewValueResponse) ProtoReflect() protoreflect.Message
func (*GetNewValueResponse) Reset ¶
func (x *GetNewValueResponse) Reset()
func (*GetNewValueResponse) String ¶
func (x *GetNewValueResponse) String() string
type GetTemplateIdRequest ¶
type GetTemplateIdRequest struct {
// contains filtered or unexported fields
}
func (*GetTemplateIdRequest) Descriptor
deprecated
func (*GetTemplateIdRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetTemplateIdRequest.ProtoReflect.Descriptor instead.
func (*GetTemplateIdRequest) ProtoMessage ¶
func (*GetTemplateIdRequest) ProtoMessage()
func (*GetTemplateIdRequest) ProtoReflect ¶
func (x *GetTemplateIdRequest) ProtoReflect() protoreflect.Message
func (*GetTemplateIdRequest) Reset ¶
func (x *GetTemplateIdRequest) Reset()
func (*GetTemplateIdRequest) String ¶
func (x *GetTemplateIdRequest) String() string
type GetTemplateIdResponse ¶
type GetTemplateIdResponse struct {
Result string `protobuf:"bytes,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*GetTemplateIdResponse) Descriptor
deprecated
func (*GetTemplateIdResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetTemplateIdResponse.ProtoReflect.Descriptor instead.
func (*GetTemplateIdResponse) GetResult ¶
func (x *GetTemplateIdResponse) GetResult() string
func (*GetTemplateIdResponse) ProtoMessage ¶
func (*GetTemplateIdResponse) ProtoMessage()
func (*GetTemplateIdResponse) ProtoReflect ¶
func (x *GetTemplateIdResponse) ProtoReflect() protoreflect.Message
func (*GetTemplateIdResponse) Reset ¶
func (x *GetTemplateIdResponse) Reset()
func (*GetTemplateIdResponse) String ¶
func (x *GetTemplateIdResponse) String() string
type IsValidResponseRequest ¶
type IsValidResponseRequest struct {
Arg0 int32 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
// contains filtered or unexported fields
}
func (*IsValidResponseRequest) Descriptor
deprecated
func (*IsValidResponseRequest) Descriptor() ([]byte, []int)
Deprecated: Use IsValidResponseRequest.ProtoReflect.Descriptor instead.
func (*IsValidResponseRequest) GetArg0 ¶
func (x *IsValidResponseRequest) GetArg0() int32
func (*IsValidResponseRequest) ProtoMessage ¶
func (*IsValidResponseRequest) ProtoMessage()
func (*IsValidResponseRequest) ProtoReflect ¶
func (x *IsValidResponseRequest) ProtoReflect() protoreflect.Message
func (*IsValidResponseRequest) Reset ¶
func (x *IsValidResponseRequest) Reset()
func (*IsValidResponseRequest) String ¶
func (x *IsValidResponseRequest) String() string
type IsValidResponseResponse ¶
type IsValidResponseResponse struct {
Result bool `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*IsValidResponseResponse) Descriptor
deprecated
func (*IsValidResponseResponse) Descriptor() ([]byte, []int)
Deprecated: Use IsValidResponseResponse.ProtoReflect.Descriptor instead.
func (*IsValidResponseResponse) GetResult ¶
func (x *IsValidResponseResponse) GetResult() bool
func (*IsValidResponseResponse) ProtoMessage ¶
func (*IsValidResponseResponse) ProtoMessage()
func (*IsValidResponseResponse) ProtoReflect ¶
func (x *IsValidResponseResponse) ProtoReflect() protoreflect.Message
func (*IsValidResponseResponse) Reset ¶
func (x *IsValidResponseResponse) Reset()
func (*IsValidResponseResponse) String ¶
func (x *IsValidResponseResponse) String() string
type ModeActionServiceClient ¶
type ModeActionServiceClient interface {
NewModeAction(ctx context.Context, in *NewModeActionRequest, opts ...grpc.CallOption) (*NewModeActionResponse, error)
GetActionType(ctx context.Context, in *GetActionTypeRequest, opts ...grpc.CallOption) (*GetActionTypeResponse, error)
GetNewMode(ctx context.Context, in *GetNewModeRequest, opts ...grpc.CallOption) (*GetNewModeResponse, error)
}
ModeActionServiceClient is the client API for ModeActionService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewModeActionServiceClient ¶
func NewModeActionServiceClient(cc grpc.ClientConnInterface) ModeActionServiceClient
type ModeActionServiceServer ¶
type ModeActionServiceServer interface {
NewModeAction(context.Context, *NewModeActionRequest) (*NewModeActionResponse, error)
GetActionType(context.Context, *GetActionTypeRequest) (*GetActionTypeResponse, error)
GetNewMode(context.Context, *GetNewModeRequest) (*GetNewModeResponse, error)
// contains filtered or unexported methods
}
ModeActionServiceServer is the server API for ModeActionService service. All implementations must embed UnimplementedModeActionServiceServer for forward compatibility.
type NewBooleanActionRequest ¶
type NewBooleanActionRequest struct {
Arg0 string `protobuf:"bytes,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
Arg1 bool `protobuf:"varint,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
// contains filtered or unexported fields
}
func (*NewBooleanActionRequest) Descriptor
deprecated
func (*NewBooleanActionRequest) Descriptor() ([]byte, []int)
Deprecated: Use NewBooleanActionRequest.ProtoReflect.Descriptor instead.
func (*NewBooleanActionRequest) GetArg0 ¶
func (x *NewBooleanActionRequest) GetArg0() string
func (*NewBooleanActionRequest) GetArg1 ¶
func (x *NewBooleanActionRequest) GetArg1() bool
func (*NewBooleanActionRequest) ProtoMessage ¶
func (*NewBooleanActionRequest) ProtoMessage()
func (*NewBooleanActionRequest) ProtoReflect ¶
func (x *NewBooleanActionRequest) ProtoReflect() protoreflect.Message
func (*NewBooleanActionRequest) Reset ¶
func (x *NewBooleanActionRequest) Reset()
func (*NewBooleanActionRequest) String ¶
func (x *NewBooleanActionRequest) String() string
type NewBooleanActionResponse ¶
type NewBooleanActionResponse struct {
Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*NewBooleanActionResponse) Descriptor
deprecated
func (*NewBooleanActionResponse) Descriptor() ([]byte, []int)
Deprecated: Use NewBooleanActionResponse.ProtoReflect.Descriptor instead.
func (*NewBooleanActionResponse) GetResult ¶
func (x *NewBooleanActionResponse) GetResult() int64
func (*NewBooleanActionResponse) ProtoMessage ¶
func (*NewBooleanActionResponse) ProtoMessage()
func (*NewBooleanActionResponse) ProtoReflect ¶
func (x *NewBooleanActionResponse) ProtoReflect() protoreflect.Message
func (*NewBooleanActionResponse) Reset ¶
func (x *NewBooleanActionResponse) Reset()
func (*NewBooleanActionResponse) String ¶
func (x *NewBooleanActionResponse) String() string
type NewCommandActionRequest ¶
type NewCommandActionRequest struct {
Arg0 string `protobuf:"bytes,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
// contains filtered or unexported fields
}
func (*NewCommandActionRequest) Descriptor
deprecated
func (*NewCommandActionRequest) Descriptor() ([]byte, []int)
Deprecated: Use NewCommandActionRequest.ProtoReflect.Descriptor instead.
func (*NewCommandActionRequest) GetArg0 ¶
func (x *NewCommandActionRequest) GetArg0() string
func (*NewCommandActionRequest) ProtoMessage ¶
func (*NewCommandActionRequest) ProtoMessage()
func (*NewCommandActionRequest) ProtoReflect ¶
func (x *NewCommandActionRequest) ProtoReflect() protoreflect.Message
func (*NewCommandActionRequest) Reset ¶
func (x *NewCommandActionRequest) Reset()
func (*NewCommandActionRequest) String ¶
func (x *NewCommandActionRequest) String() string
type NewCommandActionResponse ¶
type NewCommandActionResponse struct {
Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*NewCommandActionResponse) Descriptor
deprecated
func (*NewCommandActionResponse) Descriptor() ([]byte, []int)
Deprecated: Use NewCommandActionResponse.ProtoReflect.Descriptor instead.
func (*NewCommandActionResponse) GetResult ¶
func (x *NewCommandActionResponse) GetResult() int64
func (*NewCommandActionResponse) ProtoMessage ¶
func (*NewCommandActionResponse) ProtoMessage()
func (*NewCommandActionResponse) ProtoReflect ¶
func (x *NewCommandActionResponse) ProtoReflect() protoreflect.Message
func (*NewCommandActionResponse) Reset ¶
func (x *NewCommandActionResponse) Reset()
func (*NewCommandActionResponse) String ¶
func (x *NewCommandActionResponse) String() string
type NewFloatActionRequest ¶
type NewFloatActionRequest struct {
Arg0 string `protobuf:"bytes,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
Arg1 float32 `protobuf:"fixed32,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
// contains filtered or unexported fields
}
func (*NewFloatActionRequest) Descriptor
deprecated
func (*NewFloatActionRequest) Descriptor() ([]byte, []int)
Deprecated: Use NewFloatActionRequest.ProtoReflect.Descriptor instead.
func (*NewFloatActionRequest) GetArg0 ¶
func (x *NewFloatActionRequest) GetArg0() string
func (*NewFloatActionRequest) GetArg1 ¶
func (x *NewFloatActionRequest) GetArg1() float32
func (*NewFloatActionRequest) ProtoMessage ¶
func (*NewFloatActionRequest) ProtoMessage()
func (*NewFloatActionRequest) ProtoReflect ¶
func (x *NewFloatActionRequest) ProtoReflect() protoreflect.Message
func (*NewFloatActionRequest) Reset ¶
func (x *NewFloatActionRequest) Reset()
func (*NewFloatActionRequest) String ¶
func (x *NewFloatActionRequest) String() string
type NewFloatActionResponse ¶
type NewFloatActionResponse struct {
Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*NewFloatActionResponse) Descriptor
deprecated
func (*NewFloatActionResponse) Descriptor() ([]byte, []int)
Deprecated: Use NewFloatActionResponse.ProtoReflect.Descriptor instead.
func (*NewFloatActionResponse) GetResult ¶
func (x *NewFloatActionResponse) GetResult() int64
func (*NewFloatActionResponse) ProtoMessage ¶
func (*NewFloatActionResponse) ProtoMessage()
func (*NewFloatActionResponse) ProtoReflect ¶
func (x *NewFloatActionResponse) ProtoReflect() protoreflect.Message
func (*NewFloatActionResponse) Reset ¶
func (x *NewFloatActionResponse) Reset()
func (*NewFloatActionResponse) String ¶
func (x *NewFloatActionResponse) String() string
type NewModeActionRequest ¶
type NewModeActionRequest struct {
Arg0 string `protobuf:"bytes,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
Arg1 int32 `protobuf:"varint,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
// contains filtered or unexported fields
}
func (*NewModeActionRequest) Descriptor
deprecated
func (*NewModeActionRequest) Descriptor() ([]byte, []int)
Deprecated: Use NewModeActionRequest.ProtoReflect.Descriptor instead.
func (*NewModeActionRequest) GetArg0 ¶
func (x *NewModeActionRequest) GetArg0() string
func (*NewModeActionRequest) GetArg1 ¶
func (x *NewModeActionRequest) GetArg1() int32
func (*NewModeActionRequest) ProtoMessage ¶
func (*NewModeActionRequest) ProtoMessage()
func (*NewModeActionRequest) ProtoReflect ¶
func (x *NewModeActionRequest) ProtoReflect() protoreflect.Message
func (*NewModeActionRequest) Reset ¶
func (x *NewModeActionRequest) Reset()
func (*NewModeActionRequest) String ¶
func (x *NewModeActionRequest) String() string
type NewModeActionResponse ¶
type NewModeActionResponse struct {
Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*NewModeActionResponse) Descriptor
deprecated
func (*NewModeActionResponse) Descriptor() ([]byte, []int)
Deprecated: Use NewModeActionResponse.ProtoReflect.Descriptor instead.
func (*NewModeActionResponse) GetResult ¶
func (x *NewModeActionResponse) GetResult() int64
func (*NewModeActionResponse) ProtoMessage ¶
func (*NewModeActionResponse) ProtoMessage()
func (*NewModeActionResponse) ProtoReflect ¶
func (x *NewModeActionResponse) ProtoReflect() protoreflect.Message
func (*NewModeActionResponse) Reset ¶
func (x *NewModeActionResponse) Reset()
func (*NewModeActionResponse) String ¶
func (x *NewModeActionResponse) String() string
type UnimplementedBooleanActionServiceServer ¶
type UnimplementedBooleanActionServiceServer struct{}
UnimplementedBooleanActionServiceServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedBooleanActionServiceServer) GetActionType ¶
func (UnimplementedBooleanActionServiceServer) GetActionType(context.Context, *GetActionTypeRequest) (*GetActionTypeResponse, error)
func (UnimplementedBooleanActionServiceServer) GetNewState ¶
func (UnimplementedBooleanActionServiceServer) GetNewState(context.Context, *GetNewStateRequest) (*GetNewStateResponse, error)
func (UnimplementedBooleanActionServiceServer) NewBooleanAction ¶
func (UnimplementedBooleanActionServiceServer) NewBooleanAction(context.Context, *NewBooleanActionRequest) (*NewBooleanActionResponse, error)
type UnimplementedCommandActionServiceServer ¶
type UnimplementedCommandActionServiceServer struct{}
UnimplementedCommandActionServiceServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedCommandActionServiceServer) GetActionType ¶
func (UnimplementedCommandActionServiceServer) GetActionType(context.Context, *GetActionTypeRequest) (*GetActionTypeResponse, error)
func (UnimplementedCommandActionServiceServer) NewCommandAction ¶
func (UnimplementedCommandActionServiceServer) NewCommandAction(context.Context, *NewCommandActionRequest) (*NewCommandActionResponse, error)
type UnimplementedControlActionServiceServer ¶
type UnimplementedControlActionServiceServer struct{}
UnimplementedControlActionServiceServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedControlActionServiceServer) GetActionType ¶
func (UnimplementedControlActionServiceServer) GetActionType(context.Context, *ControlActionGetActionTypeRequest) (*GetActionTypeResponse, error)
func (UnimplementedControlActionServiceServer) GetChallengeValue ¶
func (UnimplementedControlActionServiceServer) GetChallengeValue(context.Context, *GetChallengeValueRequest) (*GetChallengeValueResponse, error)
func (UnimplementedControlActionServiceServer) GetErrorAction ¶
func (UnimplementedControlActionServiceServer) GetErrorAction(context.Context, *GetErrorActionRequest) (*GetErrorActionResponse, error)
func (UnimplementedControlActionServiceServer) GetTemplateId ¶
func (UnimplementedControlActionServiceServer) GetTemplateId(context.Context, *GetTemplateIdRequest) (*GetTemplateIdResponse, error)
func (UnimplementedControlActionServiceServer) IsValidResponse ¶
func (UnimplementedControlActionServiceServer) IsValidResponse(context.Context, *IsValidResponseRequest) (*IsValidResponseResponse, error)
type UnimplementedFloatActionServiceServer ¶
type UnimplementedFloatActionServiceServer struct{}
UnimplementedFloatActionServiceServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedFloatActionServiceServer) GetActionType ¶
func (UnimplementedFloatActionServiceServer) GetActionType(context.Context, *GetActionTypeRequest) (*GetActionTypeResponse, error)
func (UnimplementedFloatActionServiceServer) GetNewValue ¶
func (UnimplementedFloatActionServiceServer) GetNewValue(context.Context, *GetNewValueRequest) (*GetNewValueResponse, error)
func (UnimplementedFloatActionServiceServer) NewFloatAction ¶
func (UnimplementedFloatActionServiceServer) NewFloatAction(context.Context, *NewFloatActionRequest) (*NewFloatActionResponse, error)
type UnimplementedModeActionServiceServer ¶
type UnimplementedModeActionServiceServer struct{}
UnimplementedModeActionServiceServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedModeActionServiceServer) GetActionType ¶
func (UnimplementedModeActionServiceServer) GetActionType(context.Context, *GetActionTypeRequest) (*GetActionTypeResponse, error)
func (UnimplementedModeActionServiceServer) GetNewMode ¶
func (UnimplementedModeActionServiceServer) GetNewMode(context.Context, *GetNewModeRequest) (*GetNewModeResponse, error)
func (UnimplementedModeActionServiceServer) NewModeAction ¶
func (UnimplementedModeActionServiceServer) NewModeAction(context.Context, *NewModeActionRequest) (*NewModeActionResponse, error)
type UnsafeBooleanActionServiceServer ¶
type UnsafeBooleanActionServiceServer interface {
// contains filtered or unexported methods
}
UnsafeBooleanActionServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to BooleanActionServiceServer will result in compilation errors.
type UnsafeCommandActionServiceServer ¶
type UnsafeCommandActionServiceServer interface {
// contains filtered or unexported methods
}
UnsafeCommandActionServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to CommandActionServiceServer will result in compilation errors.
type UnsafeControlActionServiceServer ¶
type UnsafeControlActionServiceServer interface {
// contains filtered or unexported methods
}
UnsafeControlActionServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ControlActionServiceServer will result in compilation errors.
type UnsafeFloatActionServiceServer ¶
type UnsafeFloatActionServiceServer interface {
// contains filtered or unexported methods
}
UnsafeFloatActionServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to FloatActionServiceServer will result in compilation errors.
type UnsafeModeActionServiceServer ¶
type UnsafeModeActionServiceServer interface {
// contains filtered or unexported methods
}
UnsafeModeActionServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ModeActionServiceServer will result in compilation errors.