Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterSuppressLintServiceServer(s grpc.ServiceRegistrar, srv SuppressLintServiceServer)
- func RegisterTargetApiServiceServer(s grpc.ServiceRegistrar, srv TargetApiServiceServer)
- type SuppressLintServiceClient
- type SuppressLintServiceServer
- type SuppressLintValueResponse
- func (*SuppressLintValueResponse) Descriptor() ([]byte, []int)deprecated
- func (x *SuppressLintValueResponse) GetResult() int64
- func (*SuppressLintValueResponse) ProtoMessage()
- func (x *SuppressLintValueResponse) ProtoReflect() protoreflect.Message
- func (x *SuppressLintValueResponse) Reset()
- func (x *SuppressLintValueResponse) String() string
- type TargetApiServiceClient
- type TargetApiServiceServer
- type UnimplementedSuppressLintServiceServer
- type UnimplementedTargetApiServiceServer
- type UnsafeSuppressLintServiceServer
- type UnsafeTargetApiServiceServer
- type ValueRequest
- type ValueResponse
Constants ¶
const (
SuppressLintService_Value_FullMethodName = "/annotation.SuppressLintService/Value"
)
const (
TargetApiService_Value_FullMethodName = "/annotation.TargetApiService/Value"
)
Variables ¶
var File_proto_annotation_annotation_proto protoreflect.FileDescriptor
var SuppressLintService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "annotation.SuppressLintService", HandlerType: (*SuppressLintServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "Value", Handler: _SuppressLintService_Value_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "proto/annotation/annotation.proto", }
SuppressLintService_ServiceDesc is the grpc.ServiceDesc for SuppressLintService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var TargetApiService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "annotation.TargetApiService", HandlerType: (*TargetApiServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "Value", Handler: _TargetApiService_Value_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "proto/annotation/annotation.proto", }
TargetApiService_ServiceDesc is the grpc.ServiceDesc for TargetApiService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterSuppressLintServiceServer ¶
func RegisterSuppressLintServiceServer(s grpc.ServiceRegistrar, srv SuppressLintServiceServer)
func RegisterTargetApiServiceServer ¶
func RegisterTargetApiServiceServer(s grpc.ServiceRegistrar, srv TargetApiServiceServer)
Types ¶
type SuppressLintServiceClient ¶
type SuppressLintServiceClient interface {
Value(ctx context.Context, in *ValueRequest, opts ...grpc.CallOption) (*SuppressLintValueResponse, error)
}
SuppressLintServiceClient is the client API for SuppressLintService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewSuppressLintServiceClient ¶
func NewSuppressLintServiceClient(cc grpc.ClientConnInterface) SuppressLintServiceClient
type SuppressLintServiceServer ¶
type SuppressLintServiceServer interface {
Value(context.Context, *ValueRequest) (*SuppressLintValueResponse, error)
// contains filtered or unexported methods
}
SuppressLintServiceServer is the server API for SuppressLintService service. All implementations must embed UnimplementedSuppressLintServiceServer for forward compatibility.
type SuppressLintValueResponse ¶
type SuppressLintValueResponse struct {
Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*SuppressLintValueResponse) Descriptor
deprecated
func (*SuppressLintValueResponse) Descriptor() ([]byte, []int)
Deprecated: Use SuppressLintValueResponse.ProtoReflect.Descriptor instead.
func (*SuppressLintValueResponse) GetResult ¶
func (x *SuppressLintValueResponse) GetResult() int64
func (*SuppressLintValueResponse) ProtoMessage ¶
func (*SuppressLintValueResponse) ProtoMessage()
func (*SuppressLintValueResponse) ProtoReflect ¶
func (x *SuppressLintValueResponse) ProtoReflect() protoreflect.Message
func (*SuppressLintValueResponse) Reset ¶
func (x *SuppressLintValueResponse) Reset()
func (*SuppressLintValueResponse) String ¶
func (x *SuppressLintValueResponse) String() string
type TargetApiServiceClient ¶
type TargetApiServiceClient interface {
Value(ctx context.Context, in *ValueRequest, opts ...grpc.CallOption) (*ValueResponse, error)
}
TargetApiServiceClient is the client API for TargetApiService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewTargetApiServiceClient ¶
func NewTargetApiServiceClient(cc grpc.ClientConnInterface) TargetApiServiceClient
type TargetApiServiceServer ¶
type TargetApiServiceServer interface {
Value(context.Context, *ValueRequest) (*ValueResponse, error)
// contains filtered or unexported methods
}
TargetApiServiceServer is the server API for TargetApiService service. All implementations must embed UnimplementedTargetApiServiceServer for forward compatibility.
type UnimplementedSuppressLintServiceServer ¶
type UnimplementedSuppressLintServiceServer struct{}
UnimplementedSuppressLintServiceServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedSuppressLintServiceServer) Value ¶
func (UnimplementedSuppressLintServiceServer) Value(context.Context, *ValueRequest) (*SuppressLintValueResponse, error)
type UnimplementedTargetApiServiceServer ¶
type UnimplementedTargetApiServiceServer struct{}
UnimplementedTargetApiServiceServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedTargetApiServiceServer) Value ¶
func (UnimplementedTargetApiServiceServer) Value(context.Context, *ValueRequest) (*ValueResponse, error)
type UnsafeSuppressLintServiceServer ¶
type UnsafeSuppressLintServiceServer interface {
// contains filtered or unexported methods
}
UnsafeSuppressLintServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to SuppressLintServiceServer will result in compilation errors.
type UnsafeTargetApiServiceServer ¶
type UnsafeTargetApiServiceServer interface {
// contains filtered or unexported methods
}
UnsafeTargetApiServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to TargetApiServiceServer will result in compilation errors.
type ValueRequest ¶
type ValueRequest struct {
// contains filtered or unexported fields
}
func (*ValueRequest) Descriptor
deprecated
func (*ValueRequest) Descriptor() ([]byte, []int)
Deprecated: Use ValueRequest.ProtoReflect.Descriptor instead.
func (*ValueRequest) ProtoMessage ¶
func (*ValueRequest) ProtoMessage()
func (*ValueRequest) ProtoReflect ¶
func (x *ValueRequest) ProtoReflect() protoreflect.Message
func (*ValueRequest) Reset ¶
func (x *ValueRequest) Reset()
func (*ValueRequest) String ¶
func (x *ValueRequest) String() string
type ValueResponse ¶
type ValueResponse struct {
Result int32 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*ValueResponse) Descriptor
deprecated
func (*ValueResponse) Descriptor() ([]byte, []int)
Deprecated: Use ValueResponse.ProtoReflect.Descriptor instead.
func (*ValueResponse) GetResult ¶
func (x *ValueResponse) GetResult() int32
func (*ValueResponse) ProtoMessage ¶
func (*ValueResponse) ProtoMessage()
func (*ValueResponse) ProtoReflect ¶
func (x *ValueResponse) ProtoReflect() protoreflect.Message
func (*ValueResponse) Reset ¶
func (x *ValueResponse) Reset()
func (*ValueResponse) String ¶
func (x *ValueResponse) String() string