Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterAppSetIdManagerServiceServer(s grpc.ServiceRegistrar, srv AppSetIdManagerServiceServer)
- func RegisterAppSetIdServiceServer(s grpc.ServiceRegistrar, srv AppSetIdServiceServer)
- type AppSetIdManagerServiceClient
- type AppSetIdManagerServiceServer
- type AppSetIdServiceClient
- type AppSetIdServiceServer
- type EqualsRequest
- func (*EqualsRequest) Descriptor() ([]byte, []int)deprecated
- func (x *EqualsRequest) GetArg0() int64
- func (x *EqualsRequest) GetHandle() int64
- func (*EqualsRequest) ProtoMessage()
- func (x *EqualsRequest) ProtoReflect() protoreflect.Message
- func (x *EqualsRequest) Reset()
- func (x *EqualsRequest) String() string
- type EqualsResponse
- type GetIdRequest
- type GetIdResponse
- type GetRequest
- type GetResponse
- type GetScopeRequest
- type GetScopeResponse
- type HashCodeRequest
- type HashCodeResponse
- type NewAppSetIdRequest
- func (*NewAppSetIdRequest) Descriptor() ([]byte, []int)deprecated
- func (x *NewAppSetIdRequest) GetArg0() string
- func (x *NewAppSetIdRequest) GetArg1() int32
- func (*NewAppSetIdRequest) ProtoMessage()
- func (x *NewAppSetIdRequest) ProtoReflect() protoreflect.Message
- func (x *NewAppSetIdRequest) Reset()
- func (x *NewAppSetIdRequest) String() string
- type NewAppSetIdResponse
- func (*NewAppSetIdResponse) Descriptor() ([]byte, []int)deprecated
- func (x *NewAppSetIdResponse) GetResult() int64
- func (*NewAppSetIdResponse) ProtoMessage()
- func (x *NewAppSetIdResponse) ProtoReflect() protoreflect.Message
- func (x *NewAppSetIdResponse) Reset()
- func (x *NewAppSetIdResponse) String() string
- type UnimplementedAppSetIdManagerServiceServer
- type UnimplementedAppSetIdServiceServer
- func (UnimplementedAppSetIdServiceServer) Equals(context.Context, *EqualsRequest) (*EqualsResponse, error)
- func (UnimplementedAppSetIdServiceServer) GetId(context.Context, *GetIdRequest) (*GetIdResponse, error)
- func (UnimplementedAppSetIdServiceServer) GetScope(context.Context, *GetScopeRequest) (*GetScopeResponse, error)
- func (UnimplementedAppSetIdServiceServer) HashCode(context.Context, *HashCodeRequest) (*HashCodeResponse, error)
- func (UnimplementedAppSetIdServiceServer) NewAppSetId(context.Context, *NewAppSetIdRequest) (*NewAppSetIdResponse, error)
- type UnsafeAppSetIdManagerServiceServer
- type UnsafeAppSetIdServiceServer
Constants ¶
const ( AppSetIdService_NewAppSetId_FullMethodName = "/appsetid.AppSetIdService/NewAppSetId" AppSetIdService_Equals_FullMethodName = "/appsetid.AppSetIdService/Equals" AppSetIdService_GetId_FullMethodName = "/appsetid.AppSetIdService/GetId" AppSetIdService_GetScope_FullMethodName = "/appsetid.AppSetIdService/GetScope" AppSetIdService_HashCode_FullMethodName = "/appsetid.AppSetIdService/HashCode" )
const (
AppSetIdManagerService_Get_FullMethodName = "/appsetid.AppSetIdManagerService/Get"
)
Variables ¶
var AppSetIdManagerService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "appsetid.AppSetIdManagerService", HandlerType: (*AppSetIdManagerServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "Get", Handler: _AppSetIdManagerService_Get_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "proto/appsetid/appsetid.proto", }
AppSetIdManagerService_ServiceDesc is the grpc.ServiceDesc for AppSetIdManagerService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var AppSetIdService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "appsetid.AppSetIdService", HandlerType: (*AppSetIdServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "NewAppSetId", Handler: _AppSetIdService_NewAppSetId_Handler, }, { MethodName: "Equals", Handler: _AppSetIdService_Equals_Handler, }, { MethodName: "GetId", Handler: _AppSetIdService_GetId_Handler, }, { MethodName: "GetScope", Handler: _AppSetIdService_GetScope_Handler, }, { MethodName: "HashCode", Handler: _AppSetIdService_HashCode_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "proto/appsetid/appsetid.proto", }
AppSetIdService_ServiceDesc is the grpc.ServiceDesc for AppSetIdService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var File_proto_appsetid_appsetid_proto protoreflect.FileDescriptor
Functions ¶
func RegisterAppSetIdManagerServiceServer ¶
func RegisterAppSetIdManagerServiceServer(s grpc.ServiceRegistrar, srv AppSetIdManagerServiceServer)
func RegisterAppSetIdServiceServer ¶
func RegisterAppSetIdServiceServer(s grpc.ServiceRegistrar, srv AppSetIdServiceServer)
Types ¶
type AppSetIdManagerServiceClient ¶
type AppSetIdManagerServiceClient interface {
Get(ctx context.Context, in *GetRequest, opts ...grpc.CallOption) (*GetResponse, error)
}
AppSetIdManagerServiceClient is the client API for AppSetIdManagerService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewAppSetIdManagerServiceClient ¶
func NewAppSetIdManagerServiceClient(cc grpc.ClientConnInterface) AppSetIdManagerServiceClient
type AppSetIdManagerServiceServer ¶
type AppSetIdManagerServiceServer interface {
Get(context.Context, *GetRequest) (*GetResponse, error)
// contains filtered or unexported methods
}
AppSetIdManagerServiceServer is the server API for AppSetIdManagerService service. All implementations must embed UnimplementedAppSetIdManagerServiceServer for forward compatibility.
type AppSetIdServiceClient ¶
type AppSetIdServiceClient interface {
NewAppSetId(ctx context.Context, in *NewAppSetIdRequest, opts ...grpc.CallOption) (*NewAppSetIdResponse, error)
Equals(ctx context.Context, in *EqualsRequest, opts ...grpc.CallOption) (*EqualsResponse, error)
GetId(ctx context.Context, in *GetIdRequest, opts ...grpc.CallOption) (*GetIdResponse, error)
GetScope(ctx context.Context, in *GetScopeRequest, opts ...grpc.CallOption) (*GetScopeResponse, error)
HashCode(ctx context.Context, in *HashCodeRequest, opts ...grpc.CallOption) (*HashCodeResponse, error)
}
AppSetIdServiceClient is the client API for AppSetIdService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewAppSetIdServiceClient ¶
func NewAppSetIdServiceClient(cc grpc.ClientConnInterface) AppSetIdServiceClient
type AppSetIdServiceServer ¶
type AppSetIdServiceServer interface {
NewAppSetId(context.Context, *NewAppSetIdRequest) (*NewAppSetIdResponse, error)
Equals(context.Context, *EqualsRequest) (*EqualsResponse, error)
GetId(context.Context, *GetIdRequest) (*GetIdResponse, error)
GetScope(context.Context, *GetScopeRequest) (*GetScopeResponse, error)
HashCode(context.Context, *HashCodeRequest) (*HashCodeResponse, error)
// contains filtered or unexported methods
}
AppSetIdServiceServer is the server API for AppSetIdService service. All implementations must embed UnimplementedAppSetIdServiceServer for forward compatibility.
type EqualsRequest ¶
type EqualsRequest struct {
Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
Arg0 int64 `protobuf:"varint,2,opt,name=arg0,proto3" json:"arg0,omitempty"`
// contains filtered or unexported fields
}
func (*EqualsRequest) Descriptor
deprecated
func (*EqualsRequest) Descriptor() ([]byte, []int)
Deprecated: Use EqualsRequest.ProtoReflect.Descriptor instead.
func (*EqualsRequest) GetArg0 ¶
func (x *EqualsRequest) GetArg0() int64
func (*EqualsRequest) GetHandle ¶
func (x *EqualsRequest) GetHandle() int64
func (*EqualsRequest) ProtoMessage ¶
func (*EqualsRequest) ProtoMessage()
func (*EqualsRequest) ProtoReflect ¶
func (x *EqualsRequest) ProtoReflect() protoreflect.Message
func (*EqualsRequest) Reset ¶
func (x *EqualsRequest) Reset()
func (*EqualsRequest) String ¶
func (x *EqualsRequest) String() string
type EqualsResponse ¶
type EqualsResponse struct {
Result bool `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*EqualsResponse) Descriptor
deprecated
func (*EqualsResponse) Descriptor() ([]byte, []int)
Deprecated: Use EqualsResponse.ProtoReflect.Descriptor instead.
func (*EqualsResponse) GetResult ¶
func (x *EqualsResponse) GetResult() bool
func (*EqualsResponse) ProtoMessage ¶
func (*EqualsResponse) ProtoMessage()
func (*EqualsResponse) ProtoReflect ¶
func (x *EqualsResponse) ProtoReflect() protoreflect.Message
func (*EqualsResponse) Reset ¶
func (x *EqualsResponse) Reset()
func (*EqualsResponse) String ¶
func (x *EqualsResponse) String() string
type GetIdRequest ¶
type GetIdRequest struct {
Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
// contains filtered or unexported fields
}
func (*GetIdRequest) Descriptor
deprecated
func (*GetIdRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetIdRequest.ProtoReflect.Descriptor instead.
func (*GetIdRequest) GetHandle ¶
func (x *GetIdRequest) GetHandle() int64
func (*GetIdRequest) ProtoMessage ¶
func (*GetIdRequest) ProtoMessage()
func (*GetIdRequest) ProtoReflect ¶
func (x *GetIdRequest) ProtoReflect() protoreflect.Message
func (*GetIdRequest) Reset ¶
func (x *GetIdRequest) Reset()
func (*GetIdRequest) String ¶
func (x *GetIdRequest) String() string
type GetIdResponse ¶
type GetIdResponse struct {
Result string `protobuf:"bytes,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*GetIdResponse) Descriptor
deprecated
func (*GetIdResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetIdResponse.ProtoReflect.Descriptor instead.
func (*GetIdResponse) GetResult ¶
func (x *GetIdResponse) GetResult() string
func (*GetIdResponse) ProtoMessage ¶
func (*GetIdResponse) ProtoMessage()
func (*GetIdResponse) ProtoReflect ¶
func (x *GetIdResponse) ProtoReflect() protoreflect.Message
func (*GetIdResponse) Reset ¶
func (x *GetIdResponse) Reset()
func (*GetIdResponse) String ¶
func (x *GetIdResponse) String() string
type GetRequest ¶
type GetRequest struct {
Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
// contains filtered or unexported fields
}
func (*GetRequest) Descriptor
deprecated
func (*GetRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetRequest.ProtoReflect.Descriptor instead.
func (*GetRequest) GetArg0 ¶
func (x *GetRequest) GetArg0() int64
func (*GetRequest) ProtoMessage ¶
func (*GetRequest) ProtoMessage()
func (*GetRequest) ProtoReflect ¶
func (x *GetRequest) ProtoReflect() protoreflect.Message
func (*GetRequest) Reset ¶
func (x *GetRequest) Reset()
func (*GetRequest) String ¶
func (x *GetRequest) String() string
type GetResponse ¶
type GetResponse struct {
Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*GetResponse) Descriptor
deprecated
func (*GetResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetResponse.ProtoReflect.Descriptor instead.
func (*GetResponse) GetResult ¶
func (x *GetResponse) GetResult() int64
func (*GetResponse) ProtoMessage ¶
func (*GetResponse) ProtoMessage()
func (*GetResponse) ProtoReflect ¶
func (x *GetResponse) ProtoReflect() protoreflect.Message
func (*GetResponse) Reset ¶
func (x *GetResponse) Reset()
func (*GetResponse) String ¶
func (x *GetResponse) String() string
type GetScopeRequest ¶
type GetScopeRequest struct {
Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
// contains filtered or unexported fields
}
func (*GetScopeRequest) Descriptor
deprecated
func (*GetScopeRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetScopeRequest.ProtoReflect.Descriptor instead.
func (*GetScopeRequest) GetHandle ¶
func (x *GetScopeRequest) GetHandle() int64
func (*GetScopeRequest) ProtoMessage ¶
func (*GetScopeRequest) ProtoMessage()
func (*GetScopeRequest) ProtoReflect ¶
func (x *GetScopeRequest) ProtoReflect() protoreflect.Message
func (*GetScopeRequest) Reset ¶
func (x *GetScopeRequest) Reset()
func (*GetScopeRequest) String ¶
func (x *GetScopeRequest) String() string
type GetScopeResponse ¶
type GetScopeResponse struct {
Result int32 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*GetScopeResponse) Descriptor
deprecated
func (*GetScopeResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetScopeResponse.ProtoReflect.Descriptor instead.
func (*GetScopeResponse) GetResult ¶
func (x *GetScopeResponse) GetResult() int32
func (*GetScopeResponse) ProtoMessage ¶
func (*GetScopeResponse) ProtoMessage()
func (*GetScopeResponse) ProtoReflect ¶
func (x *GetScopeResponse) ProtoReflect() protoreflect.Message
func (*GetScopeResponse) Reset ¶
func (x *GetScopeResponse) Reset()
func (*GetScopeResponse) String ¶
func (x *GetScopeResponse) String() string
type HashCodeRequest ¶
type HashCodeRequest struct {
Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
// contains filtered or unexported fields
}
func (*HashCodeRequest) Descriptor
deprecated
func (*HashCodeRequest) Descriptor() ([]byte, []int)
Deprecated: Use HashCodeRequest.ProtoReflect.Descriptor instead.
func (*HashCodeRequest) GetHandle ¶
func (x *HashCodeRequest) GetHandle() int64
func (*HashCodeRequest) ProtoMessage ¶
func (*HashCodeRequest) ProtoMessage()
func (*HashCodeRequest) ProtoReflect ¶
func (x *HashCodeRequest) ProtoReflect() protoreflect.Message
func (*HashCodeRequest) Reset ¶
func (x *HashCodeRequest) Reset()
func (*HashCodeRequest) String ¶
func (x *HashCodeRequest) String() string
type HashCodeResponse ¶
type HashCodeResponse struct {
Result int32 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*HashCodeResponse) Descriptor
deprecated
func (*HashCodeResponse) Descriptor() ([]byte, []int)
Deprecated: Use HashCodeResponse.ProtoReflect.Descriptor instead.
func (*HashCodeResponse) GetResult ¶
func (x *HashCodeResponse) GetResult() int32
func (*HashCodeResponse) ProtoMessage ¶
func (*HashCodeResponse) ProtoMessage()
func (*HashCodeResponse) ProtoReflect ¶
func (x *HashCodeResponse) ProtoReflect() protoreflect.Message
func (*HashCodeResponse) Reset ¶
func (x *HashCodeResponse) Reset()
func (*HashCodeResponse) String ¶
func (x *HashCodeResponse) String() string
type NewAppSetIdRequest ¶
type NewAppSetIdRequest struct {
Arg0 string `protobuf:"bytes,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
Arg1 int32 `protobuf:"varint,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
// contains filtered or unexported fields
}
func (*NewAppSetIdRequest) Descriptor
deprecated
func (*NewAppSetIdRequest) Descriptor() ([]byte, []int)
Deprecated: Use NewAppSetIdRequest.ProtoReflect.Descriptor instead.
func (*NewAppSetIdRequest) GetArg0 ¶
func (x *NewAppSetIdRequest) GetArg0() string
func (*NewAppSetIdRequest) GetArg1 ¶
func (x *NewAppSetIdRequest) GetArg1() int32
func (*NewAppSetIdRequest) ProtoMessage ¶
func (*NewAppSetIdRequest) ProtoMessage()
func (*NewAppSetIdRequest) ProtoReflect ¶
func (x *NewAppSetIdRequest) ProtoReflect() protoreflect.Message
func (*NewAppSetIdRequest) Reset ¶
func (x *NewAppSetIdRequest) Reset()
func (*NewAppSetIdRequest) String ¶
func (x *NewAppSetIdRequest) String() string
type NewAppSetIdResponse ¶
type NewAppSetIdResponse struct {
Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*NewAppSetIdResponse) Descriptor
deprecated
func (*NewAppSetIdResponse) Descriptor() ([]byte, []int)
Deprecated: Use NewAppSetIdResponse.ProtoReflect.Descriptor instead.
func (*NewAppSetIdResponse) GetResult ¶
func (x *NewAppSetIdResponse) GetResult() int64
func (*NewAppSetIdResponse) ProtoMessage ¶
func (*NewAppSetIdResponse) ProtoMessage()
func (*NewAppSetIdResponse) ProtoReflect ¶
func (x *NewAppSetIdResponse) ProtoReflect() protoreflect.Message
func (*NewAppSetIdResponse) Reset ¶
func (x *NewAppSetIdResponse) Reset()
func (*NewAppSetIdResponse) String ¶
func (x *NewAppSetIdResponse) String() string
type UnimplementedAppSetIdManagerServiceServer ¶
type UnimplementedAppSetIdManagerServiceServer struct{}
UnimplementedAppSetIdManagerServiceServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedAppSetIdManagerServiceServer) Get ¶
func (UnimplementedAppSetIdManagerServiceServer) Get(context.Context, *GetRequest) (*GetResponse, error)
type UnimplementedAppSetIdServiceServer ¶
type UnimplementedAppSetIdServiceServer struct{}
UnimplementedAppSetIdServiceServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedAppSetIdServiceServer) Equals ¶
func (UnimplementedAppSetIdServiceServer) Equals(context.Context, *EqualsRequest) (*EqualsResponse, error)
func (UnimplementedAppSetIdServiceServer) GetId ¶
func (UnimplementedAppSetIdServiceServer) GetId(context.Context, *GetIdRequest) (*GetIdResponse, error)
func (UnimplementedAppSetIdServiceServer) GetScope ¶
func (UnimplementedAppSetIdServiceServer) GetScope(context.Context, *GetScopeRequest) (*GetScopeResponse, error)
func (UnimplementedAppSetIdServiceServer) HashCode ¶
func (UnimplementedAppSetIdServiceServer) HashCode(context.Context, *HashCodeRequest) (*HashCodeResponse, error)
func (UnimplementedAppSetIdServiceServer) NewAppSetId ¶
func (UnimplementedAppSetIdServiceServer) NewAppSetId(context.Context, *NewAppSetIdRequest) (*NewAppSetIdResponse, error)
type UnsafeAppSetIdManagerServiceServer ¶
type UnsafeAppSetIdManagerServiceServer interface {
// contains filtered or unexported methods
}
UnsafeAppSetIdManagerServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to AppSetIdManagerServiceServer will result in compilation errors.
type UnsafeAppSetIdServiceServer ¶
type UnsafeAppSetIdServiceServer interface {
// contains filtered or unexported methods
}
UnsafeAppSetIdServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to AppSetIdServiceServer will result in compilation errors.