Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterBuildServiceServer(s grpc.ServiceRegistrar, srv BuildServiceServer)
- func RegisterPartitionServiceServer(s grpc.ServiceRegistrar, srv PartitionServiceServer)
- type BuildServiceClient
- type BuildServiceServer
- type EqualsRequest
- type EqualsResponse
- type GetBuildTimeMillisRequest
- type GetBuildTimeMillisResponse
- func (*GetBuildTimeMillisResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetBuildTimeMillisResponse) GetResult() int64
- func (*GetBuildTimeMillisResponse) ProtoMessage()
- func (x *GetBuildTimeMillisResponse) ProtoReflect() protoreflect.Message
- func (x *GetBuildTimeMillisResponse) Reset()
- func (x *GetBuildTimeMillisResponse) String() string
- type GetFingerprintRequest
- type GetFingerprintResponse
- func (*GetFingerprintResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetFingerprintResponse) GetResult() string
- func (*GetFingerprintResponse) ProtoMessage()
- func (x *GetFingerprintResponse) ProtoReflect() protoreflect.Message
- func (x *GetFingerprintResponse) Reset()
- func (x *GetFingerprintResponse) String() string
- type GetFingerprintedPartitionsRequest
- func (*GetFingerprintedPartitionsRequest) Descriptor() ([]byte, []int)deprecated
- func (x *GetFingerprintedPartitionsRequest) GetHandle() int64
- func (*GetFingerprintedPartitionsRequest) ProtoMessage()
- func (x *GetFingerprintedPartitionsRequest) ProtoReflect() protoreflect.Message
- func (x *GetFingerprintedPartitionsRequest) Reset()
- func (x *GetFingerprintedPartitionsRequest) String() string
- type GetFingerprintedPartitionsResponse
- func (*GetFingerprintedPartitionsResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetFingerprintedPartitionsResponse) GetResult() int64
- func (*GetFingerprintedPartitionsResponse) ProtoMessage()
- func (x *GetFingerprintedPartitionsResponse) ProtoReflect() protoreflect.Message
- func (x *GetFingerprintedPartitionsResponse) Reset()
- func (x *GetFingerprintedPartitionsResponse) String() string
- type GetMajorSdkVersionRequest
- func (*GetMajorSdkVersionRequest) Descriptor() ([]byte, []int)deprecated
- func (x *GetMajorSdkVersionRequest) GetArg0() int32
- func (x *GetMajorSdkVersionRequest) GetHandle() int64
- func (*GetMajorSdkVersionRequest) ProtoMessage()
- func (x *GetMajorSdkVersionRequest) ProtoReflect() protoreflect.Message
- func (x *GetMajorSdkVersionRequest) Reset()
- func (x *GetMajorSdkVersionRequest) String() string
- type GetMajorSdkVersionResponse
- func (*GetMajorSdkVersionResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetMajorSdkVersionResponse) GetResult() int32
- func (*GetMajorSdkVersionResponse) ProtoMessage()
- func (x *GetMajorSdkVersionResponse) ProtoReflect() protoreflect.Message
- func (x *GetMajorSdkVersionResponse) Reset()
- func (x *GetMajorSdkVersionResponse) String() string
- type GetMinorSdkVersionRequest
- func (*GetMinorSdkVersionRequest) Descriptor() ([]byte, []int)deprecated
- func (x *GetMinorSdkVersionRequest) GetArg0() int32
- func (x *GetMinorSdkVersionRequest) GetHandle() int64
- func (*GetMinorSdkVersionRequest) ProtoMessage()
- func (x *GetMinorSdkVersionRequest) ProtoReflect() protoreflect.Message
- func (x *GetMinorSdkVersionRequest) Reset()
- func (x *GetMinorSdkVersionRequest) String() string
- type GetMinorSdkVersionResponse
- func (*GetMinorSdkVersionResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetMinorSdkVersionResponse) GetResult() int32
- func (*GetMinorSdkVersionResponse) ProtoMessage()
- func (x *GetMinorSdkVersionResponse) ProtoReflect() protoreflect.Message
- func (x *GetMinorSdkVersionResponse) Reset()
- func (x *GetMinorSdkVersionResponse) String() string
- type GetNameRequest
- type GetNameResponse
- type GetRadioVersionRequest
- func (*GetRadioVersionRequest) Descriptor() ([]byte, []int)deprecated
- func (x *GetRadioVersionRequest) GetHandle() int64
- func (*GetRadioVersionRequest) ProtoMessage()
- func (x *GetRadioVersionRequest) ProtoReflect() protoreflect.Message
- func (x *GetRadioVersionRequest) Reset()
- func (x *GetRadioVersionRequest) String() string
- type GetRadioVersionResponse
- func (*GetRadioVersionResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetRadioVersionResponse) GetResult() string
- func (*GetRadioVersionResponse) ProtoMessage()
- func (x *GetRadioVersionResponse) ProtoReflect() protoreflect.Message
- func (x *GetRadioVersionResponse) Reset()
- func (x *GetRadioVersionResponse) String() string
- type GetSerialRequest
- type GetSerialResponse
- type HashCodeRequest
- type HashCodeResponse
- type NewBuildRequest
- type NewBuildResponse
- type PartitionServiceClient
- type PartitionServiceServer
- type UnimplementedBuildServiceServer
- func (UnimplementedBuildServiceServer) GetFingerprintedPartitions(context.Context, *GetFingerprintedPartitionsRequest) (*GetFingerprintedPartitionsResponse, error)
- func (UnimplementedBuildServiceServer) GetMajorSdkVersion(context.Context, *GetMajorSdkVersionRequest) (*GetMajorSdkVersionResponse, error)
- func (UnimplementedBuildServiceServer) GetMinorSdkVersion(context.Context, *GetMinorSdkVersionRequest) (*GetMinorSdkVersionResponse, error)
- func (UnimplementedBuildServiceServer) GetRadioVersion(context.Context, *GetRadioVersionRequest) (*GetRadioVersionResponse, error)
- func (UnimplementedBuildServiceServer) GetSerial(context.Context, *GetSerialRequest) (*GetSerialResponse, error)
- func (UnimplementedBuildServiceServer) NewBuild(context.Context, *NewBuildRequest) (*NewBuildResponse, error)
- type UnimplementedPartitionServiceServer
- func (UnimplementedPartitionServiceServer) Equals(context.Context, *EqualsRequest) (*EqualsResponse, error)
- func (UnimplementedPartitionServiceServer) GetBuildTimeMillis(context.Context, *GetBuildTimeMillisRequest) (*GetBuildTimeMillisResponse, error)
- func (UnimplementedPartitionServiceServer) GetFingerprint(context.Context, *GetFingerprintRequest) (*GetFingerprintResponse, error)
- func (UnimplementedPartitionServiceServer) GetName(context.Context, *GetNameRequest) (*GetNameResponse, error)
- func (UnimplementedPartitionServiceServer) HashCode(context.Context, *HashCodeRequest) (*HashCodeResponse, error)
- type UnsafeBuildServiceServer
- type UnsafePartitionServiceServer
Constants ¶
const ( BuildService_NewBuild_FullMethodName = "/build.BuildService/NewBuild" BuildService_GetFingerprintedPartitions_FullMethodName = "/build.BuildService/GetFingerprintedPartitions" BuildService_GetMajorSdkVersion_FullMethodName = "/build.BuildService/GetMajorSdkVersion" BuildService_GetMinorSdkVersion_FullMethodName = "/build.BuildService/GetMinorSdkVersion" BuildService_GetRadioVersion_FullMethodName = "/build.BuildService/GetRadioVersion" BuildService_GetSerial_FullMethodName = "/build.BuildService/GetSerial" )
const ( PartitionService_Equals_FullMethodName = "/build.PartitionService/Equals" PartitionService_GetBuildTimeMillis_FullMethodName = "/build.PartitionService/GetBuildTimeMillis" PartitionService_GetFingerprint_FullMethodName = "/build.PartitionService/GetFingerprint" PartitionService_GetName_FullMethodName = "/build.PartitionService/GetName" PartitionService_HashCode_FullMethodName = "/build.PartitionService/HashCode" )
Variables ¶
var BuildService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "build.BuildService", HandlerType: (*BuildServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "NewBuild", Handler: _BuildService_NewBuild_Handler, }, { MethodName: "GetFingerprintedPartitions", Handler: _BuildService_GetFingerprintedPartitions_Handler, }, { MethodName: "GetMajorSdkVersion", Handler: _BuildService_GetMajorSdkVersion_Handler, }, { MethodName: "GetMinorSdkVersion", Handler: _BuildService_GetMinorSdkVersion_Handler, }, { MethodName: "GetRadioVersion", Handler: _BuildService_GetRadioVersion_Handler, }, { MethodName: "GetSerial", Handler: _BuildService_GetSerial_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "proto/build/build.proto", }
BuildService_ServiceDesc is the grpc.ServiceDesc for BuildService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var File_proto_build_build_proto protoreflect.FileDescriptor
var PartitionService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "build.PartitionService", HandlerType: (*PartitionServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "Equals", Handler: _PartitionService_Equals_Handler, }, { MethodName: "GetBuildTimeMillis", Handler: _PartitionService_GetBuildTimeMillis_Handler, }, { MethodName: "GetFingerprint", Handler: _PartitionService_GetFingerprint_Handler, }, { MethodName: "GetName", Handler: _PartitionService_GetName_Handler, }, { MethodName: "HashCode", Handler: _PartitionService_HashCode_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "proto/build/build.proto", }
PartitionService_ServiceDesc is the grpc.ServiceDesc for PartitionService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterBuildServiceServer ¶
func RegisterBuildServiceServer(s grpc.ServiceRegistrar, srv BuildServiceServer)
func RegisterPartitionServiceServer ¶ added in v0.0.6
func RegisterPartitionServiceServer(s grpc.ServiceRegistrar, srv PartitionServiceServer)
Types ¶
type BuildServiceClient ¶
type BuildServiceClient interface {
NewBuild(ctx context.Context, in *NewBuildRequest, opts ...grpc.CallOption) (*NewBuildResponse, error)
GetFingerprintedPartitions(ctx context.Context, in *GetFingerprintedPartitionsRequest, opts ...grpc.CallOption) (*GetFingerprintedPartitionsResponse, error)
GetMajorSdkVersion(ctx context.Context, in *GetMajorSdkVersionRequest, opts ...grpc.CallOption) (*GetMajorSdkVersionResponse, error)
GetMinorSdkVersion(ctx context.Context, in *GetMinorSdkVersionRequest, opts ...grpc.CallOption) (*GetMinorSdkVersionResponse, error)
GetRadioVersion(ctx context.Context, in *GetRadioVersionRequest, opts ...grpc.CallOption) (*GetRadioVersionResponse, error)
GetSerial(ctx context.Context, in *GetSerialRequest, opts ...grpc.CallOption) (*GetSerialResponse, error)
}
BuildServiceClient is the client API for BuildService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewBuildServiceClient ¶
func NewBuildServiceClient(cc grpc.ClientConnInterface) BuildServiceClient
type BuildServiceServer ¶
type BuildServiceServer interface {
NewBuild(context.Context, *NewBuildRequest) (*NewBuildResponse, error)
GetFingerprintedPartitions(context.Context, *GetFingerprintedPartitionsRequest) (*GetFingerprintedPartitionsResponse, error)
GetMajorSdkVersion(context.Context, *GetMajorSdkVersionRequest) (*GetMajorSdkVersionResponse, error)
GetMinorSdkVersion(context.Context, *GetMinorSdkVersionRequest) (*GetMinorSdkVersionResponse, error)
GetRadioVersion(context.Context, *GetRadioVersionRequest) (*GetRadioVersionResponse, error)
GetSerial(context.Context, *GetSerialRequest) (*GetSerialResponse, error)
// contains filtered or unexported methods
}
BuildServiceServer is the server API for BuildService service. All implementations must embed UnimplementedBuildServiceServer for forward compatibility.
type EqualsRequest ¶ added in v0.0.6
type EqualsRequest struct {
Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
// contains filtered or unexported fields
}
func (*EqualsRequest) Descriptor
deprecated
added in
v0.0.6
func (*EqualsRequest) Descriptor() ([]byte, []int)
Deprecated: Use EqualsRequest.ProtoReflect.Descriptor instead.
func (*EqualsRequest) GetArg0 ¶ added in v0.0.6
func (x *EqualsRequest) GetArg0() int64
func (*EqualsRequest) ProtoMessage ¶ added in v0.0.6
func (*EqualsRequest) ProtoMessage()
func (*EqualsRequest) ProtoReflect ¶ added in v0.0.6
func (x *EqualsRequest) ProtoReflect() protoreflect.Message
func (*EqualsRequest) Reset ¶ added in v0.0.6
func (x *EqualsRequest) Reset()
func (*EqualsRequest) String ¶ added in v0.0.6
func (x *EqualsRequest) String() string
type EqualsResponse ¶ added in v0.0.6
type EqualsResponse struct {
Result bool `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*EqualsResponse) Descriptor
deprecated
added in
v0.0.6
func (*EqualsResponse) Descriptor() ([]byte, []int)
Deprecated: Use EqualsResponse.ProtoReflect.Descriptor instead.
func (*EqualsResponse) GetResult ¶ added in v0.0.6
func (x *EqualsResponse) GetResult() bool
func (*EqualsResponse) ProtoMessage ¶ added in v0.0.6
func (*EqualsResponse) ProtoMessage()
func (*EqualsResponse) ProtoReflect ¶ added in v0.0.6
func (x *EqualsResponse) ProtoReflect() protoreflect.Message
func (*EqualsResponse) Reset ¶ added in v0.0.6
func (x *EqualsResponse) Reset()
func (*EqualsResponse) String ¶ added in v0.0.6
func (x *EqualsResponse) String() string
type GetBuildTimeMillisRequest ¶ added in v0.0.6
type GetBuildTimeMillisRequest struct {
// contains filtered or unexported fields
}
func (*GetBuildTimeMillisRequest) Descriptor
deprecated
added in
v0.0.6
func (*GetBuildTimeMillisRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetBuildTimeMillisRequest.ProtoReflect.Descriptor instead.
func (*GetBuildTimeMillisRequest) ProtoMessage ¶ added in v0.0.6
func (*GetBuildTimeMillisRequest) ProtoMessage()
func (*GetBuildTimeMillisRequest) ProtoReflect ¶ added in v0.0.6
func (x *GetBuildTimeMillisRequest) ProtoReflect() protoreflect.Message
func (*GetBuildTimeMillisRequest) Reset ¶ added in v0.0.6
func (x *GetBuildTimeMillisRequest) Reset()
func (*GetBuildTimeMillisRequest) String ¶ added in v0.0.6
func (x *GetBuildTimeMillisRequest) String() string
type GetBuildTimeMillisResponse ¶ added in v0.0.6
type GetBuildTimeMillisResponse struct {
Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*GetBuildTimeMillisResponse) Descriptor
deprecated
added in
v0.0.6
func (*GetBuildTimeMillisResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetBuildTimeMillisResponse.ProtoReflect.Descriptor instead.
func (*GetBuildTimeMillisResponse) GetResult ¶ added in v0.0.6
func (x *GetBuildTimeMillisResponse) GetResult() int64
func (*GetBuildTimeMillisResponse) ProtoMessage ¶ added in v0.0.6
func (*GetBuildTimeMillisResponse) ProtoMessage()
func (*GetBuildTimeMillisResponse) ProtoReflect ¶ added in v0.0.6
func (x *GetBuildTimeMillisResponse) ProtoReflect() protoreflect.Message
func (*GetBuildTimeMillisResponse) Reset ¶ added in v0.0.6
func (x *GetBuildTimeMillisResponse) Reset()
func (*GetBuildTimeMillisResponse) String ¶ added in v0.0.6
func (x *GetBuildTimeMillisResponse) String() string
type GetFingerprintRequest ¶ added in v0.0.6
type GetFingerprintRequest struct {
// contains filtered or unexported fields
}
func (*GetFingerprintRequest) Descriptor
deprecated
added in
v0.0.6
func (*GetFingerprintRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetFingerprintRequest.ProtoReflect.Descriptor instead.
func (*GetFingerprintRequest) ProtoMessage ¶ added in v0.0.6
func (*GetFingerprintRequest) ProtoMessage()
func (*GetFingerprintRequest) ProtoReflect ¶ added in v0.0.6
func (x *GetFingerprintRequest) ProtoReflect() protoreflect.Message
func (*GetFingerprintRequest) Reset ¶ added in v0.0.6
func (x *GetFingerprintRequest) Reset()
func (*GetFingerprintRequest) String ¶ added in v0.0.6
func (x *GetFingerprintRequest) String() string
type GetFingerprintResponse ¶ added in v0.0.6
type GetFingerprintResponse struct {
Result string `protobuf:"bytes,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*GetFingerprintResponse) Descriptor
deprecated
added in
v0.0.6
func (*GetFingerprintResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetFingerprintResponse.ProtoReflect.Descriptor instead.
func (*GetFingerprintResponse) GetResult ¶ added in v0.0.6
func (x *GetFingerprintResponse) GetResult() string
func (*GetFingerprintResponse) ProtoMessage ¶ added in v0.0.6
func (*GetFingerprintResponse) ProtoMessage()
func (*GetFingerprintResponse) ProtoReflect ¶ added in v0.0.6
func (x *GetFingerprintResponse) ProtoReflect() protoreflect.Message
func (*GetFingerprintResponse) Reset ¶ added in v0.0.6
func (x *GetFingerprintResponse) Reset()
func (*GetFingerprintResponse) String ¶ added in v0.0.6
func (x *GetFingerprintResponse) String() string
type GetFingerprintedPartitionsRequest ¶
type GetFingerprintedPartitionsRequest struct {
Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
// contains filtered or unexported fields
}
func (*GetFingerprintedPartitionsRequest) Descriptor
deprecated
func (*GetFingerprintedPartitionsRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetFingerprintedPartitionsRequest.ProtoReflect.Descriptor instead.
func (*GetFingerprintedPartitionsRequest) GetHandle ¶ added in v0.0.6
func (x *GetFingerprintedPartitionsRequest) GetHandle() int64
func (*GetFingerprintedPartitionsRequest) ProtoMessage ¶
func (*GetFingerprintedPartitionsRequest) ProtoMessage()
func (*GetFingerprintedPartitionsRequest) ProtoReflect ¶
func (x *GetFingerprintedPartitionsRequest) ProtoReflect() protoreflect.Message
func (*GetFingerprintedPartitionsRequest) Reset ¶
func (x *GetFingerprintedPartitionsRequest) Reset()
func (*GetFingerprintedPartitionsRequest) String ¶
func (x *GetFingerprintedPartitionsRequest) String() string
type GetFingerprintedPartitionsResponse ¶
type GetFingerprintedPartitionsResponse struct {
Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*GetFingerprintedPartitionsResponse) Descriptor
deprecated
func (*GetFingerprintedPartitionsResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetFingerprintedPartitionsResponse.ProtoReflect.Descriptor instead.
func (*GetFingerprintedPartitionsResponse) GetResult ¶
func (x *GetFingerprintedPartitionsResponse) GetResult() int64
func (*GetFingerprintedPartitionsResponse) ProtoMessage ¶
func (*GetFingerprintedPartitionsResponse) ProtoMessage()
func (*GetFingerprintedPartitionsResponse) ProtoReflect ¶
func (x *GetFingerprintedPartitionsResponse) ProtoReflect() protoreflect.Message
func (*GetFingerprintedPartitionsResponse) Reset ¶
func (x *GetFingerprintedPartitionsResponse) Reset()
func (*GetFingerprintedPartitionsResponse) String ¶
func (x *GetFingerprintedPartitionsResponse) String() string
type GetMajorSdkVersionRequest ¶
type GetMajorSdkVersionRequest struct {
Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
Arg0 int32 `protobuf:"varint,2,opt,name=arg0,proto3" json:"arg0,omitempty"`
// contains filtered or unexported fields
}
func (*GetMajorSdkVersionRequest) Descriptor
deprecated
func (*GetMajorSdkVersionRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetMajorSdkVersionRequest.ProtoReflect.Descriptor instead.
func (*GetMajorSdkVersionRequest) GetArg0 ¶
func (x *GetMajorSdkVersionRequest) GetArg0() int32
func (*GetMajorSdkVersionRequest) GetHandle ¶ added in v0.0.6
func (x *GetMajorSdkVersionRequest) GetHandle() int64
func (*GetMajorSdkVersionRequest) ProtoMessage ¶
func (*GetMajorSdkVersionRequest) ProtoMessage()
func (*GetMajorSdkVersionRequest) ProtoReflect ¶
func (x *GetMajorSdkVersionRequest) ProtoReflect() protoreflect.Message
func (*GetMajorSdkVersionRequest) Reset ¶
func (x *GetMajorSdkVersionRequest) Reset()
func (*GetMajorSdkVersionRequest) String ¶
func (x *GetMajorSdkVersionRequest) String() string
type GetMajorSdkVersionResponse ¶
type GetMajorSdkVersionResponse struct {
Result int32 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*GetMajorSdkVersionResponse) Descriptor
deprecated
func (*GetMajorSdkVersionResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetMajorSdkVersionResponse.ProtoReflect.Descriptor instead.
func (*GetMajorSdkVersionResponse) GetResult ¶
func (x *GetMajorSdkVersionResponse) GetResult() int32
func (*GetMajorSdkVersionResponse) ProtoMessage ¶
func (*GetMajorSdkVersionResponse) ProtoMessage()
func (*GetMajorSdkVersionResponse) ProtoReflect ¶
func (x *GetMajorSdkVersionResponse) ProtoReflect() protoreflect.Message
func (*GetMajorSdkVersionResponse) Reset ¶
func (x *GetMajorSdkVersionResponse) Reset()
func (*GetMajorSdkVersionResponse) String ¶
func (x *GetMajorSdkVersionResponse) String() string
type GetMinorSdkVersionRequest ¶
type GetMinorSdkVersionRequest struct {
Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
Arg0 int32 `protobuf:"varint,2,opt,name=arg0,proto3" json:"arg0,omitempty"`
// contains filtered or unexported fields
}
func (*GetMinorSdkVersionRequest) Descriptor
deprecated
func (*GetMinorSdkVersionRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetMinorSdkVersionRequest.ProtoReflect.Descriptor instead.
func (*GetMinorSdkVersionRequest) GetArg0 ¶
func (x *GetMinorSdkVersionRequest) GetArg0() int32
func (*GetMinorSdkVersionRequest) GetHandle ¶ added in v0.0.6
func (x *GetMinorSdkVersionRequest) GetHandle() int64
func (*GetMinorSdkVersionRequest) ProtoMessage ¶
func (*GetMinorSdkVersionRequest) ProtoMessage()
func (*GetMinorSdkVersionRequest) ProtoReflect ¶
func (x *GetMinorSdkVersionRequest) ProtoReflect() protoreflect.Message
func (*GetMinorSdkVersionRequest) Reset ¶
func (x *GetMinorSdkVersionRequest) Reset()
func (*GetMinorSdkVersionRequest) String ¶
func (x *GetMinorSdkVersionRequest) String() string
type GetMinorSdkVersionResponse ¶
type GetMinorSdkVersionResponse struct {
Result int32 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*GetMinorSdkVersionResponse) Descriptor
deprecated
func (*GetMinorSdkVersionResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetMinorSdkVersionResponse.ProtoReflect.Descriptor instead.
func (*GetMinorSdkVersionResponse) GetResult ¶
func (x *GetMinorSdkVersionResponse) GetResult() int32
func (*GetMinorSdkVersionResponse) ProtoMessage ¶
func (*GetMinorSdkVersionResponse) ProtoMessage()
func (*GetMinorSdkVersionResponse) ProtoReflect ¶
func (x *GetMinorSdkVersionResponse) ProtoReflect() protoreflect.Message
func (*GetMinorSdkVersionResponse) Reset ¶
func (x *GetMinorSdkVersionResponse) Reset()
func (*GetMinorSdkVersionResponse) String ¶
func (x *GetMinorSdkVersionResponse) String() string
type GetNameRequest ¶ added in v0.0.6
type GetNameRequest struct {
// contains filtered or unexported fields
}
func (*GetNameRequest) Descriptor
deprecated
added in
v0.0.6
func (*GetNameRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetNameRequest.ProtoReflect.Descriptor instead.
func (*GetNameRequest) ProtoMessage ¶ added in v0.0.6
func (*GetNameRequest) ProtoMessage()
func (*GetNameRequest) ProtoReflect ¶ added in v0.0.6
func (x *GetNameRequest) ProtoReflect() protoreflect.Message
func (*GetNameRequest) Reset ¶ added in v0.0.6
func (x *GetNameRequest) Reset()
func (*GetNameRequest) String ¶ added in v0.0.6
func (x *GetNameRequest) String() string
type GetNameResponse ¶ added in v0.0.6
type GetNameResponse struct {
Result string `protobuf:"bytes,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*GetNameResponse) Descriptor
deprecated
added in
v0.0.6
func (*GetNameResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetNameResponse.ProtoReflect.Descriptor instead.
func (*GetNameResponse) GetResult ¶ added in v0.0.6
func (x *GetNameResponse) GetResult() string
func (*GetNameResponse) ProtoMessage ¶ added in v0.0.6
func (*GetNameResponse) ProtoMessage()
func (*GetNameResponse) ProtoReflect ¶ added in v0.0.6
func (x *GetNameResponse) ProtoReflect() protoreflect.Message
func (*GetNameResponse) Reset ¶ added in v0.0.6
func (x *GetNameResponse) Reset()
func (*GetNameResponse) String ¶ added in v0.0.6
func (x *GetNameResponse) String() string
type GetRadioVersionRequest ¶
type GetRadioVersionRequest struct {
Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
// contains filtered or unexported fields
}
func (*GetRadioVersionRequest) Descriptor
deprecated
func (*GetRadioVersionRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetRadioVersionRequest.ProtoReflect.Descriptor instead.
func (*GetRadioVersionRequest) GetHandle ¶ added in v0.0.6
func (x *GetRadioVersionRequest) GetHandle() int64
func (*GetRadioVersionRequest) ProtoMessage ¶
func (*GetRadioVersionRequest) ProtoMessage()
func (*GetRadioVersionRequest) ProtoReflect ¶
func (x *GetRadioVersionRequest) ProtoReflect() protoreflect.Message
func (*GetRadioVersionRequest) Reset ¶
func (x *GetRadioVersionRequest) Reset()
func (*GetRadioVersionRequest) String ¶
func (x *GetRadioVersionRequest) String() string
type GetRadioVersionResponse ¶
type GetRadioVersionResponse struct {
Result string `protobuf:"bytes,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*GetRadioVersionResponse) Descriptor
deprecated
func (*GetRadioVersionResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetRadioVersionResponse.ProtoReflect.Descriptor instead.
func (*GetRadioVersionResponse) GetResult ¶
func (x *GetRadioVersionResponse) GetResult() string
func (*GetRadioVersionResponse) ProtoMessage ¶
func (*GetRadioVersionResponse) ProtoMessage()
func (*GetRadioVersionResponse) ProtoReflect ¶
func (x *GetRadioVersionResponse) ProtoReflect() protoreflect.Message
func (*GetRadioVersionResponse) Reset ¶
func (x *GetRadioVersionResponse) Reset()
func (*GetRadioVersionResponse) String ¶
func (x *GetRadioVersionResponse) String() string
type GetSerialRequest ¶
type GetSerialRequest struct {
Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
// contains filtered or unexported fields
}
func (*GetSerialRequest) Descriptor
deprecated
func (*GetSerialRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetSerialRequest.ProtoReflect.Descriptor instead.
func (*GetSerialRequest) GetHandle ¶ added in v0.0.6
func (x *GetSerialRequest) GetHandle() int64
func (*GetSerialRequest) ProtoMessage ¶
func (*GetSerialRequest) ProtoMessage()
func (*GetSerialRequest) ProtoReflect ¶
func (x *GetSerialRequest) ProtoReflect() protoreflect.Message
func (*GetSerialRequest) Reset ¶
func (x *GetSerialRequest) Reset()
func (*GetSerialRequest) String ¶
func (x *GetSerialRequest) String() string
type GetSerialResponse ¶
type GetSerialResponse struct {
Result string `protobuf:"bytes,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*GetSerialResponse) Descriptor
deprecated
func (*GetSerialResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetSerialResponse.ProtoReflect.Descriptor instead.
func (*GetSerialResponse) GetResult ¶
func (x *GetSerialResponse) GetResult() string
func (*GetSerialResponse) ProtoMessage ¶
func (*GetSerialResponse) ProtoMessage()
func (*GetSerialResponse) ProtoReflect ¶
func (x *GetSerialResponse) ProtoReflect() protoreflect.Message
func (*GetSerialResponse) Reset ¶
func (x *GetSerialResponse) Reset()
func (*GetSerialResponse) String ¶
func (x *GetSerialResponse) String() string
type HashCodeRequest ¶ added in v0.0.6
type HashCodeRequest struct {
// contains filtered or unexported fields
}
func (*HashCodeRequest) Descriptor
deprecated
added in
v0.0.6
func (*HashCodeRequest) Descriptor() ([]byte, []int)
Deprecated: Use HashCodeRequest.ProtoReflect.Descriptor instead.
func (*HashCodeRequest) ProtoMessage ¶ added in v0.0.6
func (*HashCodeRequest) ProtoMessage()
func (*HashCodeRequest) ProtoReflect ¶ added in v0.0.6
func (x *HashCodeRequest) ProtoReflect() protoreflect.Message
func (*HashCodeRequest) Reset ¶ added in v0.0.6
func (x *HashCodeRequest) Reset()
func (*HashCodeRequest) String ¶ added in v0.0.6
func (x *HashCodeRequest) String() string
type HashCodeResponse ¶ added in v0.0.6
type HashCodeResponse struct {
Result int32 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*HashCodeResponse) Descriptor
deprecated
added in
v0.0.6
func (*HashCodeResponse) Descriptor() ([]byte, []int)
Deprecated: Use HashCodeResponse.ProtoReflect.Descriptor instead.
func (*HashCodeResponse) GetResult ¶ added in v0.0.6
func (x *HashCodeResponse) GetResult() int32
func (*HashCodeResponse) ProtoMessage ¶ added in v0.0.6
func (*HashCodeResponse) ProtoMessage()
func (*HashCodeResponse) ProtoReflect ¶ added in v0.0.6
func (x *HashCodeResponse) ProtoReflect() protoreflect.Message
func (*HashCodeResponse) Reset ¶ added in v0.0.6
func (x *HashCodeResponse) Reset()
func (*HashCodeResponse) String ¶ added in v0.0.6
func (x *HashCodeResponse) String() string
type NewBuildRequest ¶ added in v0.0.6
type NewBuildRequest struct {
// contains filtered or unexported fields
}
func (*NewBuildRequest) Descriptor
deprecated
added in
v0.0.6
func (*NewBuildRequest) Descriptor() ([]byte, []int)
Deprecated: Use NewBuildRequest.ProtoReflect.Descriptor instead.
func (*NewBuildRequest) ProtoMessage ¶ added in v0.0.6
func (*NewBuildRequest) ProtoMessage()
func (*NewBuildRequest) ProtoReflect ¶ added in v0.0.6
func (x *NewBuildRequest) ProtoReflect() protoreflect.Message
func (*NewBuildRequest) Reset ¶ added in v0.0.6
func (x *NewBuildRequest) Reset()
func (*NewBuildRequest) String ¶ added in v0.0.6
func (x *NewBuildRequest) String() string
type NewBuildResponse ¶ added in v0.0.6
type NewBuildResponse struct {
Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*NewBuildResponse) Descriptor
deprecated
added in
v0.0.6
func (*NewBuildResponse) Descriptor() ([]byte, []int)
Deprecated: Use NewBuildResponse.ProtoReflect.Descriptor instead.
func (*NewBuildResponse) GetResult ¶ added in v0.0.6
func (x *NewBuildResponse) GetResult() int64
func (*NewBuildResponse) ProtoMessage ¶ added in v0.0.6
func (*NewBuildResponse) ProtoMessage()
func (*NewBuildResponse) ProtoReflect ¶ added in v0.0.6
func (x *NewBuildResponse) ProtoReflect() protoreflect.Message
func (*NewBuildResponse) Reset ¶ added in v0.0.6
func (x *NewBuildResponse) Reset()
func (*NewBuildResponse) String ¶ added in v0.0.6
func (x *NewBuildResponse) String() string
type PartitionServiceClient ¶ added in v0.0.6
type PartitionServiceClient interface {
Equals(ctx context.Context, in *EqualsRequest, opts ...grpc.CallOption) (*EqualsResponse, error)
GetBuildTimeMillis(ctx context.Context, in *GetBuildTimeMillisRequest, opts ...grpc.CallOption) (*GetBuildTimeMillisResponse, error)
GetFingerprint(ctx context.Context, in *GetFingerprintRequest, opts ...grpc.CallOption) (*GetFingerprintResponse, error)
GetName(ctx context.Context, in *GetNameRequest, opts ...grpc.CallOption) (*GetNameResponse, error)
HashCode(ctx context.Context, in *HashCodeRequest, opts ...grpc.CallOption) (*HashCodeResponse, error)
}
PartitionServiceClient is the client API for PartitionService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewPartitionServiceClient ¶ added in v0.0.6
func NewPartitionServiceClient(cc grpc.ClientConnInterface) PartitionServiceClient
type PartitionServiceServer ¶ added in v0.0.6
type PartitionServiceServer interface {
Equals(context.Context, *EqualsRequest) (*EqualsResponse, error)
GetBuildTimeMillis(context.Context, *GetBuildTimeMillisRequest) (*GetBuildTimeMillisResponse, error)
GetFingerprint(context.Context, *GetFingerprintRequest) (*GetFingerprintResponse, error)
GetName(context.Context, *GetNameRequest) (*GetNameResponse, error)
HashCode(context.Context, *HashCodeRequest) (*HashCodeResponse, error)
// contains filtered or unexported methods
}
PartitionServiceServer is the server API for PartitionService service. All implementations must embed UnimplementedPartitionServiceServer for forward compatibility.
type UnimplementedBuildServiceServer ¶
type UnimplementedBuildServiceServer struct{}
UnimplementedBuildServiceServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedBuildServiceServer) GetFingerprintedPartitions ¶
func (UnimplementedBuildServiceServer) GetFingerprintedPartitions(context.Context, *GetFingerprintedPartitionsRequest) (*GetFingerprintedPartitionsResponse, error)
func (UnimplementedBuildServiceServer) GetMajorSdkVersion ¶
func (UnimplementedBuildServiceServer) GetMajorSdkVersion(context.Context, *GetMajorSdkVersionRequest) (*GetMajorSdkVersionResponse, error)
func (UnimplementedBuildServiceServer) GetMinorSdkVersion ¶
func (UnimplementedBuildServiceServer) GetMinorSdkVersion(context.Context, *GetMinorSdkVersionRequest) (*GetMinorSdkVersionResponse, error)
func (UnimplementedBuildServiceServer) GetRadioVersion ¶
func (UnimplementedBuildServiceServer) GetRadioVersion(context.Context, *GetRadioVersionRequest) (*GetRadioVersionResponse, error)
func (UnimplementedBuildServiceServer) GetSerial ¶
func (UnimplementedBuildServiceServer) GetSerial(context.Context, *GetSerialRequest) (*GetSerialResponse, error)
func (UnimplementedBuildServiceServer) NewBuild ¶ added in v0.0.6
func (UnimplementedBuildServiceServer) NewBuild(context.Context, *NewBuildRequest) (*NewBuildResponse, error)
type UnimplementedPartitionServiceServer ¶ added in v0.0.6
type UnimplementedPartitionServiceServer struct{}
UnimplementedPartitionServiceServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedPartitionServiceServer) Equals ¶ added in v0.0.6
func (UnimplementedPartitionServiceServer) Equals(context.Context, *EqualsRequest) (*EqualsResponse, error)
func (UnimplementedPartitionServiceServer) GetBuildTimeMillis ¶ added in v0.0.6
func (UnimplementedPartitionServiceServer) GetBuildTimeMillis(context.Context, *GetBuildTimeMillisRequest) (*GetBuildTimeMillisResponse, error)
func (UnimplementedPartitionServiceServer) GetFingerprint ¶ added in v0.0.6
func (UnimplementedPartitionServiceServer) GetFingerprint(context.Context, *GetFingerprintRequest) (*GetFingerprintResponse, error)
func (UnimplementedPartitionServiceServer) GetName ¶ added in v0.0.6
func (UnimplementedPartitionServiceServer) GetName(context.Context, *GetNameRequest) (*GetNameResponse, error)
func (UnimplementedPartitionServiceServer) HashCode ¶ added in v0.0.6
func (UnimplementedPartitionServiceServer) HashCode(context.Context, *HashCodeRequest) (*HashCodeResponse, error)
type UnsafeBuildServiceServer ¶
type UnsafeBuildServiceServer interface {
// contains filtered or unexported methods
}
UnsafeBuildServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to BuildServiceServer will result in compilation errors.
type UnsafePartitionServiceServer ¶ added in v0.0.6
type UnsafePartitionServiceServer interface {
// contains filtered or unexported methods
}
UnsafePartitionServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to PartitionServiceServer will result in compilation errors.