Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterBuildServiceServer(s grpc.ServiceRegistrar, srv BuildServiceServer)
- type BuildServiceClient
- type BuildServiceServer
- type GetFingerprintedPartitionsRequest
- func (*GetFingerprintedPartitionsRequest) Descriptor() ([]byte, []int)deprecated
- func (*GetFingerprintedPartitionsRequest) ProtoMessage()
- func (x *GetFingerprintedPartitionsRequest) ProtoReflect() protoreflect.Message
- func (x *GetFingerprintedPartitionsRequest) Reset()
- func (x *GetFingerprintedPartitionsRequest) String() string
- type GetFingerprintedPartitionsResponse
- func (*GetFingerprintedPartitionsResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetFingerprintedPartitionsResponse) GetResult() int64
- func (*GetFingerprintedPartitionsResponse) ProtoMessage()
- func (x *GetFingerprintedPartitionsResponse) ProtoReflect() protoreflect.Message
- func (x *GetFingerprintedPartitionsResponse) Reset()
- func (x *GetFingerprintedPartitionsResponse) String() string
- type GetMajorSdkVersionRequest
- func (*GetMajorSdkVersionRequest) Descriptor() ([]byte, []int)deprecated
- func (x *GetMajorSdkVersionRequest) GetArg0() int32
- func (*GetMajorSdkVersionRequest) ProtoMessage()
- func (x *GetMajorSdkVersionRequest) ProtoReflect() protoreflect.Message
- func (x *GetMajorSdkVersionRequest) Reset()
- func (x *GetMajorSdkVersionRequest) String() string
- type GetMajorSdkVersionResponse
- func (*GetMajorSdkVersionResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetMajorSdkVersionResponse) GetResult() int32
- func (*GetMajorSdkVersionResponse) ProtoMessage()
- func (x *GetMajorSdkVersionResponse) ProtoReflect() protoreflect.Message
- func (x *GetMajorSdkVersionResponse) Reset()
- func (x *GetMajorSdkVersionResponse) String() string
- type GetMinorSdkVersionRequest
- func (*GetMinorSdkVersionRequest) Descriptor() ([]byte, []int)deprecated
- func (x *GetMinorSdkVersionRequest) GetArg0() int32
- func (*GetMinorSdkVersionRequest) ProtoMessage()
- func (x *GetMinorSdkVersionRequest) ProtoReflect() protoreflect.Message
- func (x *GetMinorSdkVersionRequest) Reset()
- func (x *GetMinorSdkVersionRequest) String() string
- type GetMinorSdkVersionResponse
- func (*GetMinorSdkVersionResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetMinorSdkVersionResponse) GetResult() int32
- func (*GetMinorSdkVersionResponse) ProtoMessage()
- func (x *GetMinorSdkVersionResponse) ProtoReflect() protoreflect.Message
- func (x *GetMinorSdkVersionResponse) Reset()
- func (x *GetMinorSdkVersionResponse) String() string
- type GetRadioVersionRequest
- type GetRadioVersionResponse
- func (*GetRadioVersionResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetRadioVersionResponse) GetResult() string
- func (*GetRadioVersionResponse) ProtoMessage()
- func (x *GetRadioVersionResponse) ProtoReflect() protoreflect.Message
- func (x *GetRadioVersionResponse) Reset()
- func (x *GetRadioVersionResponse) String() string
- type GetSerialRequest
- type GetSerialResponse
- type UnimplementedBuildServiceServer
- func (UnimplementedBuildServiceServer) GetFingerprintedPartitions(context.Context, *GetFingerprintedPartitionsRequest) (*GetFingerprintedPartitionsResponse, error)
- func (UnimplementedBuildServiceServer) GetMajorSdkVersion(context.Context, *GetMajorSdkVersionRequest) (*GetMajorSdkVersionResponse, error)
- func (UnimplementedBuildServiceServer) GetMinorSdkVersion(context.Context, *GetMinorSdkVersionRequest) (*GetMinorSdkVersionResponse, error)
- func (UnimplementedBuildServiceServer) GetRadioVersion(context.Context, *GetRadioVersionRequest) (*GetRadioVersionResponse, error)
- func (UnimplementedBuildServiceServer) GetSerial(context.Context, *GetSerialRequest) (*GetSerialResponse, error)
- type UnsafeBuildServiceServer
Constants ¶
const ( BuildService_GetFingerprintedPartitions_FullMethodName = "/build.BuildService/GetFingerprintedPartitions" BuildService_GetMajorSdkVersion_FullMethodName = "/build.BuildService/GetMajorSdkVersion" BuildService_GetMinorSdkVersion_FullMethodName = "/build.BuildService/GetMinorSdkVersion" BuildService_GetRadioVersion_FullMethodName = "/build.BuildService/GetRadioVersion" BuildService_GetSerial_FullMethodName = "/build.BuildService/GetSerial" )
Variables ¶
var BuildService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "build.BuildService", HandlerType: (*BuildServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "GetFingerprintedPartitions", Handler: _BuildService_GetFingerprintedPartitions_Handler, }, { MethodName: "GetMajorSdkVersion", Handler: _BuildService_GetMajorSdkVersion_Handler, }, { MethodName: "GetMinorSdkVersion", Handler: _BuildService_GetMinorSdkVersion_Handler, }, { MethodName: "GetRadioVersion", Handler: _BuildService_GetRadioVersion_Handler, }, { MethodName: "GetSerial", Handler: _BuildService_GetSerial_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "proto/build/build.proto", }
BuildService_ServiceDesc is the grpc.ServiceDesc for BuildService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var File_proto_build_build_proto protoreflect.FileDescriptor
Functions ¶
func RegisterBuildServiceServer ¶
func RegisterBuildServiceServer(s grpc.ServiceRegistrar, srv BuildServiceServer)
Types ¶
type BuildServiceClient ¶
type BuildServiceClient interface {
GetFingerprintedPartitions(ctx context.Context, in *GetFingerprintedPartitionsRequest, opts ...grpc.CallOption) (*GetFingerprintedPartitionsResponse, error)
GetMajorSdkVersion(ctx context.Context, in *GetMajorSdkVersionRequest, opts ...grpc.CallOption) (*GetMajorSdkVersionResponse, error)
GetMinorSdkVersion(ctx context.Context, in *GetMinorSdkVersionRequest, opts ...grpc.CallOption) (*GetMinorSdkVersionResponse, error)
GetRadioVersion(ctx context.Context, in *GetRadioVersionRequest, opts ...grpc.CallOption) (*GetRadioVersionResponse, error)
GetSerial(ctx context.Context, in *GetSerialRequest, opts ...grpc.CallOption) (*GetSerialResponse, error)
}
BuildServiceClient is the client API for BuildService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewBuildServiceClient ¶
func NewBuildServiceClient(cc grpc.ClientConnInterface) BuildServiceClient
type BuildServiceServer ¶
type BuildServiceServer interface {
GetFingerprintedPartitions(context.Context, *GetFingerprintedPartitionsRequest) (*GetFingerprintedPartitionsResponse, error)
GetMajorSdkVersion(context.Context, *GetMajorSdkVersionRequest) (*GetMajorSdkVersionResponse, error)
GetMinorSdkVersion(context.Context, *GetMinorSdkVersionRequest) (*GetMinorSdkVersionResponse, error)
GetRadioVersion(context.Context, *GetRadioVersionRequest) (*GetRadioVersionResponse, error)
GetSerial(context.Context, *GetSerialRequest) (*GetSerialResponse, error)
// contains filtered or unexported methods
}
BuildServiceServer is the server API for BuildService service. All implementations must embed UnimplementedBuildServiceServer for forward compatibility.
type GetFingerprintedPartitionsRequest ¶
type GetFingerprintedPartitionsRequest struct {
// contains filtered or unexported fields
}
func (*GetFingerprintedPartitionsRequest) Descriptor
deprecated
func (*GetFingerprintedPartitionsRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetFingerprintedPartitionsRequest.ProtoReflect.Descriptor instead.
func (*GetFingerprintedPartitionsRequest) ProtoMessage ¶
func (*GetFingerprintedPartitionsRequest) ProtoMessage()
func (*GetFingerprintedPartitionsRequest) ProtoReflect ¶
func (x *GetFingerprintedPartitionsRequest) ProtoReflect() protoreflect.Message
func (*GetFingerprintedPartitionsRequest) Reset ¶
func (x *GetFingerprintedPartitionsRequest) Reset()
func (*GetFingerprintedPartitionsRequest) String ¶
func (x *GetFingerprintedPartitionsRequest) String() string
type GetFingerprintedPartitionsResponse ¶
type GetFingerprintedPartitionsResponse struct {
Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*GetFingerprintedPartitionsResponse) Descriptor
deprecated
func (*GetFingerprintedPartitionsResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetFingerprintedPartitionsResponse.ProtoReflect.Descriptor instead.
func (*GetFingerprintedPartitionsResponse) GetResult ¶
func (x *GetFingerprintedPartitionsResponse) GetResult() int64
func (*GetFingerprintedPartitionsResponse) ProtoMessage ¶
func (*GetFingerprintedPartitionsResponse) ProtoMessage()
func (*GetFingerprintedPartitionsResponse) ProtoReflect ¶
func (x *GetFingerprintedPartitionsResponse) ProtoReflect() protoreflect.Message
func (*GetFingerprintedPartitionsResponse) Reset ¶
func (x *GetFingerprintedPartitionsResponse) Reset()
func (*GetFingerprintedPartitionsResponse) String ¶
func (x *GetFingerprintedPartitionsResponse) String() string
type GetMajorSdkVersionRequest ¶
type GetMajorSdkVersionRequest struct {
Arg0 int32 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
// contains filtered or unexported fields
}
func (*GetMajorSdkVersionRequest) Descriptor
deprecated
func (*GetMajorSdkVersionRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetMajorSdkVersionRequest.ProtoReflect.Descriptor instead.
func (*GetMajorSdkVersionRequest) GetArg0 ¶
func (x *GetMajorSdkVersionRequest) GetArg0() int32
func (*GetMajorSdkVersionRequest) ProtoMessage ¶
func (*GetMajorSdkVersionRequest) ProtoMessage()
func (*GetMajorSdkVersionRequest) ProtoReflect ¶
func (x *GetMajorSdkVersionRequest) ProtoReflect() protoreflect.Message
func (*GetMajorSdkVersionRequest) Reset ¶
func (x *GetMajorSdkVersionRequest) Reset()
func (*GetMajorSdkVersionRequest) String ¶
func (x *GetMajorSdkVersionRequest) String() string
type GetMajorSdkVersionResponse ¶
type GetMajorSdkVersionResponse struct {
Result int32 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*GetMajorSdkVersionResponse) Descriptor
deprecated
func (*GetMajorSdkVersionResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetMajorSdkVersionResponse.ProtoReflect.Descriptor instead.
func (*GetMajorSdkVersionResponse) GetResult ¶
func (x *GetMajorSdkVersionResponse) GetResult() int32
func (*GetMajorSdkVersionResponse) ProtoMessage ¶
func (*GetMajorSdkVersionResponse) ProtoMessage()
func (*GetMajorSdkVersionResponse) ProtoReflect ¶
func (x *GetMajorSdkVersionResponse) ProtoReflect() protoreflect.Message
func (*GetMajorSdkVersionResponse) Reset ¶
func (x *GetMajorSdkVersionResponse) Reset()
func (*GetMajorSdkVersionResponse) String ¶
func (x *GetMajorSdkVersionResponse) String() string
type GetMinorSdkVersionRequest ¶
type GetMinorSdkVersionRequest struct {
Arg0 int32 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
// contains filtered or unexported fields
}
func (*GetMinorSdkVersionRequest) Descriptor
deprecated
func (*GetMinorSdkVersionRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetMinorSdkVersionRequest.ProtoReflect.Descriptor instead.
func (*GetMinorSdkVersionRequest) GetArg0 ¶
func (x *GetMinorSdkVersionRequest) GetArg0() int32
func (*GetMinorSdkVersionRequest) ProtoMessage ¶
func (*GetMinorSdkVersionRequest) ProtoMessage()
func (*GetMinorSdkVersionRequest) ProtoReflect ¶
func (x *GetMinorSdkVersionRequest) ProtoReflect() protoreflect.Message
func (*GetMinorSdkVersionRequest) Reset ¶
func (x *GetMinorSdkVersionRequest) Reset()
func (*GetMinorSdkVersionRequest) String ¶
func (x *GetMinorSdkVersionRequest) String() string
type GetMinorSdkVersionResponse ¶
type GetMinorSdkVersionResponse struct {
Result int32 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*GetMinorSdkVersionResponse) Descriptor
deprecated
func (*GetMinorSdkVersionResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetMinorSdkVersionResponse.ProtoReflect.Descriptor instead.
func (*GetMinorSdkVersionResponse) GetResult ¶
func (x *GetMinorSdkVersionResponse) GetResult() int32
func (*GetMinorSdkVersionResponse) ProtoMessage ¶
func (*GetMinorSdkVersionResponse) ProtoMessage()
func (*GetMinorSdkVersionResponse) ProtoReflect ¶
func (x *GetMinorSdkVersionResponse) ProtoReflect() protoreflect.Message
func (*GetMinorSdkVersionResponse) Reset ¶
func (x *GetMinorSdkVersionResponse) Reset()
func (*GetMinorSdkVersionResponse) String ¶
func (x *GetMinorSdkVersionResponse) String() string
type GetRadioVersionRequest ¶
type GetRadioVersionRequest struct {
// contains filtered or unexported fields
}
func (*GetRadioVersionRequest) Descriptor
deprecated
func (*GetRadioVersionRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetRadioVersionRequest.ProtoReflect.Descriptor instead.
func (*GetRadioVersionRequest) ProtoMessage ¶
func (*GetRadioVersionRequest) ProtoMessage()
func (*GetRadioVersionRequest) ProtoReflect ¶
func (x *GetRadioVersionRequest) ProtoReflect() protoreflect.Message
func (*GetRadioVersionRequest) Reset ¶
func (x *GetRadioVersionRequest) Reset()
func (*GetRadioVersionRequest) String ¶
func (x *GetRadioVersionRequest) String() string
type GetRadioVersionResponse ¶
type GetRadioVersionResponse struct {
Result string `protobuf:"bytes,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*GetRadioVersionResponse) Descriptor
deprecated
func (*GetRadioVersionResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetRadioVersionResponse.ProtoReflect.Descriptor instead.
func (*GetRadioVersionResponse) GetResult ¶
func (x *GetRadioVersionResponse) GetResult() string
func (*GetRadioVersionResponse) ProtoMessage ¶
func (*GetRadioVersionResponse) ProtoMessage()
func (*GetRadioVersionResponse) ProtoReflect ¶
func (x *GetRadioVersionResponse) ProtoReflect() protoreflect.Message
func (*GetRadioVersionResponse) Reset ¶
func (x *GetRadioVersionResponse) Reset()
func (*GetRadioVersionResponse) String ¶
func (x *GetRadioVersionResponse) String() string
type GetSerialRequest ¶
type GetSerialRequest struct {
// contains filtered or unexported fields
}
func (*GetSerialRequest) Descriptor
deprecated
func (*GetSerialRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetSerialRequest.ProtoReflect.Descriptor instead.
func (*GetSerialRequest) ProtoMessage ¶
func (*GetSerialRequest) ProtoMessage()
func (*GetSerialRequest) ProtoReflect ¶
func (x *GetSerialRequest) ProtoReflect() protoreflect.Message
func (*GetSerialRequest) Reset ¶
func (x *GetSerialRequest) Reset()
func (*GetSerialRequest) String ¶
func (x *GetSerialRequest) String() string
type GetSerialResponse ¶
type GetSerialResponse struct {
Result string `protobuf:"bytes,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*GetSerialResponse) Descriptor
deprecated
func (*GetSerialResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetSerialResponse.ProtoReflect.Descriptor instead.
func (*GetSerialResponse) GetResult ¶
func (x *GetSerialResponse) GetResult() string
func (*GetSerialResponse) ProtoMessage ¶
func (*GetSerialResponse) ProtoMessage()
func (*GetSerialResponse) ProtoReflect ¶
func (x *GetSerialResponse) ProtoReflect() protoreflect.Message
func (*GetSerialResponse) Reset ¶
func (x *GetSerialResponse) Reset()
func (*GetSerialResponse) String ¶
func (x *GetSerialResponse) String() string
type UnimplementedBuildServiceServer ¶
type UnimplementedBuildServiceServer struct{}
UnimplementedBuildServiceServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedBuildServiceServer) GetFingerprintedPartitions ¶
func (UnimplementedBuildServiceServer) GetFingerprintedPartitions(context.Context, *GetFingerprintedPartitionsRequest) (*GetFingerprintedPartitionsResponse, error)
func (UnimplementedBuildServiceServer) GetMajorSdkVersion ¶
func (UnimplementedBuildServiceServer) GetMajorSdkVersion(context.Context, *GetMajorSdkVersionRequest) (*GetMajorSdkVersionResponse, error)
func (UnimplementedBuildServiceServer) GetMinorSdkVersion ¶
func (UnimplementedBuildServiceServer) GetMinorSdkVersion(context.Context, *GetMinorSdkVersionRequest) (*GetMinorSdkVersionResponse, error)
func (UnimplementedBuildServiceServer) GetRadioVersion ¶
func (UnimplementedBuildServiceServer) GetRadioVersion(context.Context, *GetRadioVersionRequest) (*GetRadioVersionResponse, error)
func (UnimplementedBuildServiceServer) GetSerial ¶
func (UnimplementedBuildServiceServer) GetSerial(context.Context, *GetSerialRequest) (*GetSerialResponse, error)
type UnsafeBuildServiceServer ¶
type UnsafeBuildServiceServer interface {
// contains filtered or unexported methods
}
UnsafeBuildServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to BuildServiceServer will result in compilation errors.