Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterContractServiceServer(s grpc.ServiceRegistrar, srv ContractServiceServer)
- type ContractServiceClient
- type ContractServiceServer
- type IsProfileIdRequest
- type IsProfileIdResponse
- func (*IsProfileIdResponse) Descriptor() ([]byte, []int)deprecated
- func (x *IsProfileIdResponse) GetResult() bool
- func (*IsProfileIdResponse) ProtoMessage()
- func (x *IsProfileIdResponse) ProtoReflect() protoreflect.Message
- func (x *IsProfileIdResponse) Reset()
- func (x *IsProfileIdResponse) String() string
- type UnimplementedContractServiceServer
- type UnsafeContractServiceServer
Constants ¶
const (
ContractService_IsProfileId_FullMethodName = "/contacts.ContractService/IsProfileId"
)
Variables ¶
var ContractService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "contacts.ContractService", HandlerType: (*ContractServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "IsProfileId", Handler: _ContractService_IsProfileId_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "proto/contacts/contacts.proto", }
ContractService_ServiceDesc is the grpc.ServiceDesc for ContractService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var File_proto_contacts_contacts_proto protoreflect.FileDescriptor
Functions ¶
func RegisterContractServiceServer ¶ added in v0.0.4
func RegisterContractServiceServer(s grpc.ServiceRegistrar, srv ContractServiceServer)
Types ¶
type ContractServiceClient ¶ added in v0.0.4
type ContractServiceClient interface {
IsProfileId(ctx context.Context, in *IsProfileIdRequest, opts ...grpc.CallOption) (*IsProfileIdResponse, error)
}
ContractServiceClient is the client API for ContractService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewContractServiceClient ¶ added in v0.0.4
func NewContractServiceClient(cc grpc.ClientConnInterface) ContractServiceClient
type ContractServiceServer ¶ added in v0.0.4
type ContractServiceServer interface {
IsProfileId(context.Context, *IsProfileIdRequest) (*IsProfileIdResponse, error)
// contains filtered or unexported methods
}
ContractServiceServer is the server API for ContractService service. All implementations must embed UnimplementedContractServiceServer for forward compatibility.
type IsProfileIdRequest ¶
type IsProfileIdRequest struct {
Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
// contains filtered or unexported fields
}
func (*IsProfileIdRequest) Descriptor
deprecated
func (*IsProfileIdRequest) Descriptor() ([]byte, []int)
Deprecated: Use IsProfileIdRequest.ProtoReflect.Descriptor instead.
func (*IsProfileIdRequest) GetArg0 ¶
func (x *IsProfileIdRequest) GetArg0() int64
func (*IsProfileIdRequest) ProtoMessage ¶
func (*IsProfileIdRequest) ProtoMessage()
func (*IsProfileIdRequest) ProtoReflect ¶
func (x *IsProfileIdRequest) ProtoReflect() protoreflect.Message
func (*IsProfileIdRequest) Reset ¶
func (x *IsProfileIdRequest) Reset()
func (*IsProfileIdRequest) String ¶
func (x *IsProfileIdRequest) String() string
type IsProfileIdResponse ¶
type IsProfileIdResponse struct {
Result bool `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*IsProfileIdResponse) Descriptor
deprecated
func (*IsProfileIdResponse) Descriptor() ([]byte, []int)
Deprecated: Use IsProfileIdResponse.ProtoReflect.Descriptor instead.
func (*IsProfileIdResponse) GetResult ¶
func (x *IsProfileIdResponse) GetResult() bool
func (*IsProfileIdResponse) ProtoMessage ¶
func (*IsProfileIdResponse) ProtoMessage()
func (*IsProfileIdResponse) ProtoReflect ¶
func (x *IsProfileIdResponse) ProtoReflect() protoreflect.Message
func (*IsProfileIdResponse) Reset ¶
func (x *IsProfileIdResponse) Reset()
func (*IsProfileIdResponse) String ¶
func (x *IsProfileIdResponse) String() string
type UnimplementedContractServiceServer ¶ added in v0.0.4
type UnimplementedContractServiceServer struct{}
UnimplementedContractServiceServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedContractServiceServer) IsProfileId ¶ added in v0.0.4
func (UnimplementedContractServiceServer) IsProfileId(context.Context, *IsProfileIdRequest) (*IsProfileIdResponse, error)
type UnsafeContractServiceServer ¶ added in v0.0.4
type UnsafeContractServiceServer interface {
// contains filtered or unexported methods
}
UnsafeContractServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ContractServiceServer will result in compilation errors.