Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterContactsContractServiceServer(s grpc.ServiceRegistrar, srv ContactsContractServiceServer)
- type ContactsContractServiceClient
- type ContactsContractServiceServer
- type IsProfileIdRequest
- type IsProfileIdResponse
- func (*IsProfileIdResponse) Descriptor() ([]byte, []int)deprecated
- func (x *IsProfileIdResponse) GetResult() bool
- func (*IsProfileIdResponse) ProtoMessage()
- func (x *IsProfileIdResponse) ProtoReflect() protoreflect.Message
- func (x *IsProfileIdResponse) Reset()
- func (x *IsProfileIdResponse) String() string
- type UnimplementedContactsContractServiceServer
- type UnsafeContactsContractServiceServer
Constants ¶
const (
ContactsContractService_IsProfileId_FullMethodName = "/contacts.ContactsContractService/IsProfileId"
)
Variables ¶
var ContactsContractService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "contacts.ContactsContractService", HandlerType: (*ContactsContractServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "IsProfileId", Handler: _ContactsContractService_IsProfileId_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "proto/contacts/contacts.proto", }
ContactsContractService_ServiceDesc is the grpc.ServiceDesc for ContactsContractService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var File_proto_contacts_contacts_proto protoreflect.FileDescriptor
Functions ¶
func RegisterContactsContractServiceServer ¶
func RegisterContactsContractServiceServer(s grpc.ServiceRegistrar, srv ContactsContractServiceServer)
Types ¶
type ContactsContractServiceClient ¶
type ContactsContractServiceClient interface {
IsProfileId(ctx context.Context, in *IsProfileIdRequest, opts ...grpc.CallOption) (*IsProfileIdResponse, error)
}
ContactsContractServiceClient is the client API for ContactsContractService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewContactsContractServiceClient ¶
func NewContactsContractServiceClient(cc grpc.ClientConnInterface) ContactsContractServiceClient
type ContactsContractServiceServer ¶
type ContactsContractServiceServer interface {
IsProfileId(context.Context, *IsProfileIdRequest) (*IsProfileIdResponse, error)
// contains filtered or unexported methods
}
ContactsContractServiceServer is the server API for ContactsContractService service. All implementations must embed UnimplementedContactsContractServiceServer for forward compatibility.
type IsProfileIdRequest ¶
type IsProfileIdRequest struct {
Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
// contains filtered or unexported fields
}
func (*IsProfileIdRequest) Descriptor
deprecated
func (*IsProfileIdRequest) Descriptor() ([]byte, []int)
Deprecated: Use IsProfileIdRequest.ProtoReflect.Descriptor instead.
func (*IsProfileIdRequest) GetArg0 ¶
func (x *IsProfileIdRequest) GetArg0() int64
func (*IsProfileIdRequest) ProtoMessage ¶
func (*IsProfileIdRequest) ProtoMessage()
func (*IsProfileIdRequest) ProtoReflect ¶
func (x *IsProfileIdRequest) ProtoReflect() protoreflect.Message
func (*IsProfileIdRequest) Reset ¶
func (x *IsProfileIdRequest) Reset()
func (*IsProfileIdRequest) String ¶
func (x *IsProfileIdRequest) String() string
type IsProfileIdResponse ¶
type IsProfileIdResponse struct {
Result bool `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*IsProfileIdResponse) Descriptor
deprecated
func (*IsProfileIdResponse) Descriptor() ([]byte, []int)
Deprecated: Use IsProfileIdResponse.ProtoReflect.Descriptor instead.
func (*IsProfileIdResponse) GetResult ¶
func (x *IsProfileIdResponse) GetResult() bool
func (*IsProfileIdResponse) ProtoMessage ¶
func (*IsProfileIdResponse) ProtoMessage()
func (*IsProfileIdResponse) ProtoReflect ¶
func (x *IsProfileIdResponse) ProtoReflect() protoreflect.Message
func (*IsProfileIdResponse) Reset ¶
func (x *IsProfileIdResponse) Reset()
func (*IsProfileIdResponse) String ¶
func (x *IsProfileIdResponse) String() string
type UnimplementedContactsContractServiceServer ¶
type UnimplementedContactsContractServiceServer struct{}
UnimplementedContactsContractServiceServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedContactsContractServiceServer) IsProfileId ¶
func (UnimplementedContactsContractServiceServer) IsProfileId(context.Context, *IsProfileIdRequest) (*IsProfileIdResponse, error)
type UnsafeContactsContractServiceServer ¶
type UnsafeContactsContractServiceServer interface {
// contains filtered or unexported methods
}
UnsafeContactsContractServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ContactsContractServiceServer will result in compilation errors.