Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterDeviceIdServiceServer(s grpc.ServiceRegistrar, srv DeviceIdServiceServer)
- type DeviceIdServiceClient
- type DeviceIdServiceServer
- type GetIdRequest
- type GetIdResponse
- type GetTypeRequest
- type GetTypeResponse
- type UnimplementedDeviceIdServiceServer
- type UnsafeDeviceIdServiceServer
Constants ¶
const ( DeviceIdService_GetId_FullMethodName = "/devicelock.DeviceIdService/GetId" DeviceIdService_GetType_FullMethodName = "/devicelock.DeviceIdService/GetType" )
Variables ¶
var DeviceIdService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "devicelock.DeviceIdService", HandlerType: (*DeviceIdServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "GetId", Handler: _DeviceIdService_GetId_Handler, }, { MethodName: "GetType", Handler: _DeviceIdService_GetType_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "proto/devicelock/devicelock.proto", }
DeviceIdService_ServiceDesc is the grpc.ServiceDesc for DeviceIdService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var File_proto_devicelock_devicelock_proto protoreflect.FileDescriptor
Functions ¶
func RegisterDeviceIdServiceServer ¶
func RegisterDeviceIdServiceServer(s grpc.ServiceRegistrar, srv DeviceIdServiceServer)
Types ¶
type DeviceIdServiceClient ¶
type DeviceIdServiceClient interface {
GetId(ctx context.Context, in *GetIdRequest, opts ...grpc.CallOption) (*GetIdResponse, error)
GetType(ctx context.Context, in *GetTypeRequest, opts ...grpc.CallOption) (*GetTypeResponse, error)
}
DeviceIdServiceClient is the client API for DeviceIdService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewDeviceIdServiceClient ¶
func NewDeviceIdServiceClient(cc grpc.ClientConnInterface) DeviceIdServiceClient
type DeviceIdServiceServer ¶
type DeviceIdServiceServer interface {
GetId(context.Context, *GetIdRequest) (*GetIdResponse, error)
GetType(context.Context, *GetTypeRequest) (*GetTypeResponse, error)
// contains filtered or unexported methods
}
DeviceIdServiceServer is the server API for DeviceIdService service. All implementations must embed UnimplementedDeviceIdServiceServer for forward compatibility.
type GetIdRequest ¶
type GetIdRequest struct {
// contains filtered or unexported fields
}
func (*GetIdRequest) Descriptor
deprecated
func (*GetIdRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetIdRequest.ProtoReflect.Descriptor instead.
func (*GetIdRequest) ProtoMessage ¶
func (*GetIdRequest) ProtoMessage()
func (*GetIdRequest) ProtoReflect ¶
func (x *GetIdRequest) ProtoReflect() protoreflect.Message
func (*GetIdRequest) Reset ¶
func (x *GetIdRequest) Reset()
func (*GetIdRequest) String ¶
func (x *GetIdRequest) String() string
type GetIdResponse ¶
type GetIdResponse struct {
Result string `protobuf:"bytes,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*GetIdResponse) Descriptor
deprecated
func (*GetIdResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetIdResponse.ProtoReflect.Descriptor instead.
func (*GetIdResponse) GetResult ¶
func (x *GetIdResponse) GetResult() string
func (*GetIdResponse) ProtoMessage ¶
func (*GetIdResponse) ProtoMessage()
func (*GetIdResponse) ProtoReflect ¶
func (x *GetIdResponse) ProtoReflect() protoreflect.Message
func (*GetIdResponse) Reset ¶
func (x *GetIdResponse) Reset()
func (*GetIdResponse) String ¶
func (x *GetIdResponse) String() string
type GetTypeRequest ¶
type GetTypeRequest struct {
// contains filtered or unexported fields
}
func (*GetTypeRequest) Descriptor
deprecated
func (*GetTypeRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetTypeRequest.ProtoReflect.Descriptor instead.
func (*GetTypeRequest) ProtoMessage ¶
func (*GetTypeRequest) ProtoMessage()
func (*GetTypeRequest) ProtoReflect ¶
func (x *GetTypeRequest) ProtoReflect() protoreflect.Message
func (*GetTypeRequest) Reset ¶
func (x *GetTypeRequest) Reset()
func (*GetTypeRequest) String ¶
func (x *GetTypeRequest) String() string
type GetTypeResponse ¶
type GetTypeResponse struct {
Result int32 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*GetTypeResponse) Descriptor
deprecated
func (*GetTypeResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetTypeResponse.ProtoReflect.Descriptor instead.
func (*GetTypeResponse) GetResult ¶
func (x *GetTypeResponse) GetResult() int32
func (*GetTypeResponse) ProtoMessage ¶
func (*GetTypeResponse) ProtoMessage()
func (*GetTypeResponse) ProtoReflect ¶
func (x *GetTypeResponse) ProtoReflect() protoreflect.Message
func (*GetTypeResponse) Reset ¶
func (x *GetTypeResponse) Reset()
func (*GetTypeResponse) String ¶
func (x *GetTypeResponse) String() string
type UnimplementedDeviceIdServiceServer ¶
type UnimplementedDeviceIdServiceServer struct{}
UnimplementedDeviceIdServiceServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedDeviceIdServiceServer) GetId ¶
func (UnimplementedDeviceIdServiceServer) GetId(context.Context, *GetIdRequest) (*GetIdResponse, error)
func (UnimplementedDeviceIdServiceServer) GetType ¶
func (UnimplementedDeviceIdServiceServer) GetType(context.Context, *GetTypeRequest) (*GetTypeResponse, error)
type UnsafeDeviceIdServiceServer ¶
type UnsafeDeviceIdServiceServer interface {
// contains filtered or unexported methods
}
UnsafeDeviceIdServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to DeviceIdServiceServer will result in compilation errors.