Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterContextServiceServer(s grpc.ServiceRegistrar, srv ContextServiceServer)
- func RegisterEffectServiceServer(s grpc.ServiceRegistrar, srv EffectServiceServer)
- func RegisterFactoryServiceServer(s grpc.ServiceRegistrar, srv FactoryServiceServer)
- func RegisterUpdateListenerServiceServer(s grpc.ServiceRegistrar, srv UpdateListenerServiceServer)
- type ApplyRequest
- func (*ApplyRequest) Descriptor() ([]byte, []int)deprecated
- func (x *ApplyRequest) GetArg0() int32
- func (x *ApplyRequest) GetArg1() int32
- func (x *ApplyRequest) GetArg2() int32
- func (x *ApplyRequest) GetArg3() int32
- func (*ApplyRequest) ProtoMessage()
- func (x *ApplyRequest) ProtoReflect() protoreflect.Message
- func (x *ApplyRequest) Reset()
- func (x *ApplyRequest) String() string
- type ApplyResponse
- type ContextServiceClient
- type ContextServiceServer
- type CreateEffectRequest
- func (*CreateEffectRequest) Descriptor() ([]byte, []int)deprecated
- func (x *CreateEffectRequest) GetArg0() string
- func (*CreateEffectRequest) ProtoMessage()
- func (x *CreateEffectRequest) ProtoReflect() protoreflect.Message
- func (x *CreateEffectRequest) Reset()
- func (x *CreateEffectRequest) String() string
- type CreateEffectResponse
- func (*CreateEffectResponse) Descriptor() ([]byte, []int)deprecated
- func (x *CreateEffectResponse) GetResult() int64
- func (*CreateEffectResponse) ProtoMessage()
- func (x *CreateEffectResponse) ProtoReflect() protoreflect.Message
- func (x *CreateEffectResponse) Reset()
- func (x *CreateEffectResponse) String() string
- type CreateWithCurrentGlContextRequest
- func (*CreateWithCurrentGlContextRequest) Descriptor() ([]byte, []int)deprecated
- func (*CreateWithCurrentGlContextRequest) ProtoMessage()
- func (x *CreateWithCurrentGlContextRequest) ProtoReflect() protoreflect.Message
- func (x *CreateWithCurrentGlContextRequest) Reset()
- func (x *CreateWithCurrentGlContextRequest) String() string
- type CreateWithCurrentGlContextResponse
- func (*CreateWithCurrentGlContextResponse) Descriptor() ([]byte, []int)deprecated
- func (x *CreateWithCurrentGlContextResponse) GetResult() int64
- func (*CreateWithCurrentGlContextResponse) ProtoMessage()
- func (x *CreateWithCurrentGlContextResponse) ProtoReflect() protoreflect.Message
- func (x *CreateWithCurrentGlContextResponse) Reset()
- func (x *CreateWithCurrentGlContextResponse) String() string
- type EffectServiceClient
- type EffectServiceServer
- type FactoryServiceClient
- type FactoryServiceServer
- type GetFactoryRequest
- type GetFactoryResponse
- func (*GetFactoryResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetFactoryResponse) GetResult() int64
- func (*GetFactoryResponse) ProtoMessage()
- func (x *GetFactoryResponse) ProtoReflect() protoreflect.Message
- func (x *GetFactoryResponse) Reset()
- func (x *GetFactoryResponse) String() string
- type GetNameRequest
- type GetNameResponse
- type IsEffectSupportedRequest
- func (*IsEffectSupportedRequest) Descriptor() ([]byte, []int)deprecated
- func (x *IsEffectSupportedRequest) GetArg0() string
- func (*IsEffectSupportedRequest) ProtoMessage()
- func (x *IsEffectSupportedRequest) ProtoReflect() protoreflect.Message
- func (x *IsEffectSupportedRequest) Reset()
- func (x *IsEffectSupportedRequest) String() string
- type IsEffectSupportedResponse
- func (*IsEffectSupportedResponse) Descriptor() ([]byte, []int)deprecated
- func (x *IsEffectSupportedResponse) GetResult() bool
- func (*IsEffectSupportedResponse) ProtoMessage()
- func (x *IsEffectSupportedResponse) ProtoReflect() protoreflect.Message
- func (x *IsEffectSupportedResponse) Reset()
- func (x *IsEffectSupportedResponse) String() string
- type OnEffectUpdatedRequest
- func (*OnEffectUpdatedRequest) Descriptor() ([]byte, []int)deprecated
- func (x *OnEffectUpdatedRequest) GetArg0() int64
- func (x *OnEffectUpdatedRequest) GetArg1() int64
- func (*OnEffectUpdatedRequest) ProtoMessage()
- func (x *OnEffectUpdatedRequest) ProtoReflect() protoreflect.Message
- func (x *OnEffectUpdatedRequest) Reset()
- func (x *OnEffectUpdatedRequest) String() string
- type OnEffectUpdatedResponse
- type ReleaseRequest
- type ReleaseResponse
- type SetParameterRequest
- func (*SetParameterRequest) Descriptor() ([]byte, []int)deprecated
- func (x *SetParameterRequest) GetArg0() string
- func (x *SetParameterRequest) GetArg1() int64
- func (*SetParameterRequest) ProtoMessage()
- func (x *SetParameterRequest) ProtoReflect() protoreflect.Message
- func (x *SetParameterRequest) Reset()
- func (x *SetParameterRequest) String() string
- type SetParameterResponse
- type SetUpdateListenerRequest
- func (*SetUpdateListenerRequest) Descriptor() ([]byte, []int)deprecated
- func (x *SetUpdateListenerRequest) GetArg0() int64
- func (*SetUpdateListenerRequest) ProtoMessage()
- func (x *SetUpdateListenerRequest) ProtoReflect() protoreflect.Message
- func (x *SetUpdateListenerRequest) Reset()
- func (x *SetUpdateListenerRequest) String() string
- type SetUpdateListenerResponse
- type UnimplementedContextServiceServer
- func (UnimplementedContextServiceServer) CreateWithCurrentGlContext(context.Context, *CreateWithCurrentGlContextRequest) (*CreateWithCurrentGlContextResponse, error)
- func (UnimplementedContextServiceServer) GetFactory(context.Context, *GetFactoryRequest) (*GetFactoryResponse, error)
- func (UnimplementedContextServiceServer) Release(context.Context, *ReleaseRequest) (*ReleaseResponse, error)
- type UnimplementedEffectServiceServer
- func (UnimplementedEffectServiceServer) Apply(context.Context, *ApplyRequest) (*ApplyResponse, error)
- func (UnimplementedEffectServiceServer) GetName(context.Context, *GetNameRequest) (*GetNameResponse, error)
- func (UnimplementedEffectServiceServer) Release(context.Context, *ReleaseRequest) (*ReleaseResponse, error)
- func (UnimplementedEffectServiceServer) SetParameter(context.Context, *SetParameterRequest) (*SetParameterResponse, error)
- func (UnimplementedEffectServiceServer) SetUpdateListener(context.Context, *SetUpdateListenerRequest) (*SetUpdateListenerResponse, error)
- type UnimplementedFactoryServiceServer
- type UnimplementedUpdateListenerServiceServer
- type UnsafeContextServiceServer
- type UnsafeEffectServiceServer
- type UnsafeFactoryServiceServer
- type UnsafeUpdateListenerServiceServer
- type UpdateListenerServiceClient
- type UpdateListenerServiceServer
Constants ¶
const ( FactoryService_CreateEffect_FullMethodName = "/effect.FactoryService/CreateEffect" FactoryService_IsEffectSupported_FullMethodName = "/effect.FactoryService/IsEffectSupported" )
const ( ContextService_GetFactory_FullMethodName = "/effect.ContextService/GetFactory" ContextService_Release_FullMethodName = "/effect.ContextService/Release" ContextService_CreateWithCurrentGlContext_FullMethodName = "/effect.ContextService/CreateWithCurrentGlContext" )
const ( EffectService_Apply_FullMethodName = "/effect.EffectService/Apply" EffectService_GetName_FullMethodName = "/effect.EffectService/GetName" EffectService_Release_FullMethodName = "/effect.EffectService/Release" EffectService_SetParameter_FullMethodName = "/effect.EffectService/SetParameter" EffectService_SetUpdateListener_FullMethodName = "/effect.EffectService/SetUpdateListener" )
const (
UpdateListenerService_OnEffectUpdated_FullMethodName = "/effect.UpdateListenerService/OnEffectUpdated"
)
Variables ¶
var ContextService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "effect.ContextService", HandlerType: (*ContextServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "GetFactory", Handler: _ContextService_GetFactory_Handler, }, { MethodName: "Release", Handler: _ContextService_Release_Handler, }, { MethodName: "CreateWithCurrentGlContext", Handler: _ContextService_CreateWithCurrentGlContext_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "proto/effect/effect.proto", }
ContextService_ServiceDesc is the grpc.ServiceDesc for ContextService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var EffectService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "effect.EffectService", HandlerType: (*EffectServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "Apply", Handler: _EffectService_Apply_Handler, }, { MethodName: "GetName", Handler: _EffectService_GetName_Handler, }, { MethodName: "Release", Handler: _EffectService_Release_Handler, }, { MethodName: "SetParameter", Handler: _EffectService_SetParameter_Handler, }, { MethodName: "SetUpdateListener", Handler: _EffectService_SetUpdateListener_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "proto/effect/effect.proto", }
EffectService_ServiceDesc is the grpc.ServiceDesc for EffectService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var FactoryService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "effect.FactoryService", HandlerType: (*FactoryServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "CreateEffect", Handler: _FactoryService_CreateEffect_Handler, }, { MethodName: "IsEffectSupported", Handler: _FactoryService_IsEffectSupported_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "proto/effect/effect.proto", }
FactoryService_ServiceDesc is the grpc.ServiceDesc for FactoryService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var File_proto_effect_effect_proto protoreflect.FileDescriptor
var UpdateListenerService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "effect.UpdateListenerService", HandlerType: (*UpdateListenerServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "OnEffectUpdated", Handler: _UpdateListenerService_OnEffectUpdated_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "proto/effect/effect.proto", }
UpdateListenerService_ServiceDesc is the grpc.ServiceDesc for UpdateListenerService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterContextServiceServer ¶
func RegisterContextServiceServer(s grpc.ServiceRegistrar, srv ContextServiceServer)
func RegisterEffectServiceServer ¶
func RegisterEffectServiceServer(s grpc.ServiceRegistrar, srv EffectServiceServer)
func RegisterFactoryServiceServer ¶
func RegisterFactoryServiceServer(s grpc.ServiceRegistrar, srv FactoryServiceServer)
func RegisterUpdateListenerServiceServer ¶
func RegisterUpdateListenerServiceServer(s grpc.ServiceRegistrar, srv UpdateListenerServiceServer)
Types ¶
type ApplyRequest ¶
type ApplyRequest struct {
Arg0 int32 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
Arg1 int32 `protobuf:"varint,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
Arg2 int32 `protobuf:"varint,3,opt,name=arg2,proto3" json:"arg2,omitempty"`
Arg3 int32 `protobuf:"varint,4,opt,name=arg3,proto3" json:"arg3,omitempty"`
// contains filtered or unexported fields
}
func (*ApplyRequest) Descriptor
deprecated
func (*ApplyRequest) Descriptor() ([]byte, []int)
Deprecated: Use ApplyRequest.ProtoReflect.Descriptor instead.
func (*ApplyRequest) GetArg0 ¶
func (x *ApplyRequest) GetArg0() int32
func (*ApplyRequest) GetArg1 ¶
func (x *ApplyRequest) GetArg1() int32
func (*ApplyRequest) GetArg2 ¶
func (x *ApplyRequest) GetArg2() int32
func (*ApplyRequest) GetArg3 ¶
func (x *ApplyRequest) GetArg3() int32
func (*ApplyRequest) ProtoMessage ¶
func (*ApplyRequest) ProtoMessage()
func (*ApplyRequest) ProtoReflect ¶
func (x *ApplyRequest) ProtoReflect() protoreflect.Message
func (*ApplyRequest) Reset ¶
func (x *ApplyRequest) Reset()
func (*ApplyRequest) String ¶
func (x *ApplyRequest) String() string
type ApplyResponse ¶
type ApplyResponse struct {
// contains filtered or unexported fields
}
func (*ApplyResponse) Descriptor
deprecated
func (*ApplyResponse) Descriptor() ([]byte, []int)
Deprecated: Use ApplyResponse.ProtoReflect.Descriptor instead.
func (*ApplyResponse) ProtoMessage ¶
func (*ApplyResponse) ProtoMessage()
func (*ApplyResponse) ProtoReflect ¶
func (x *ApplyResponse) ProtoReflect() protoreflect.Message
func (*ApplyResponse) Reset ¶
func (x *ApplyResponse) Reset()
func (*ApplyResponse) String ¶
func (x *ApplyResponse) String() string
type ContextServiceClient ¶
type ContextServiceClient interface {
GetFactory(ctx context.Context, in *GetFactoryRequest, opts ...grpc.CallOption) (*GetFactoryResponse, error)
Release(ctx context.Context, in *ReleaseRequest, opts ...grpc.CallOption) (*ReleaseResponse, error)
CreateWithCurrentGlContext(ctx context.Context, in *CreateWithCurrentGlContextRequest, opts ...grpc.CallOption) (*CreateWithCurrentGlContextResponse, error)
}
ContextServiceClient is the client API for ContextService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewContextServiceClient ¶
func NewContextServiceClient(cc grpc.ClientConnInterface) ContextServiceClient
type ContextServiceServer ¶
type ContextServiceServer interface {
GetFactory(context.Context, *GetFactoryRequest) (*GetFactoryResponse, error)
Release(context.Context, *ReleaseRequest) (*ReleaseResponse, error)
CreateWithCurrentGlContext(context.Context, *CreateWithCurrentGlContextRequest) (*CreateWithCurrentGlContextResponse, error)
// contains filtered or unexported methods
}
ContextServiceServer is the server API for ContextService service. All implementations must embed UnimplementedContextServiceServer for forward compatibility.
type CreateEffectRequest ¶
type CreateEffectRequest struct {
Arg0 string `protobuf:"bytes,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
// contains filtered or unexported fields
}
func (*CreateEffectRequest) Descriptor
deprecated
func (*CreateEffectRequest) Descriptor() ([]byte, []int)
Deprecated: Use CreateEffectRequest.ProtoReflect.Descriptor instead.
func (*CreateEffectRequest) GetArg0 ¶
func (x *CreateEffectRequest) GetArg0() string
func (*CreateEffectRequest) ProtoMessage ¶
func (*CreateEffectRequest) ProtoMessage()
func (*CreateEffectRequest) ProtoReflect ¶
func (x *CreateEffectRequest) ProtoReflect() protoreflect.Message
func (*CreateEffectRequest) Reset ¶
func (x *CreateEffectRequest) Reset()
func (*CreateEffectRequest) String ¶
func (x *CreateEffectRequest) String() string
type CreateEffectResponse ¶
type CreateEffectResponse struct {
Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*CreateEffectResponse) Descriptor
deprecated
func (*CreateEffectResponse) Descriptor() ([]byte, []int)
Deprecated: Use CreateEffectResponse.ProtoReflect.Descriptor instead.
func (*CreateEffectResponse) GetResult ¶
func (x *CreateEffectResponse) GetResult() int64
func (*CreateEffectResponse) ProtoMessage ¶
func (*CreateEffectResponse) ProtoMessage()
func (*CreateEffectResponse) ProtoReflect ¶
func (x *CreateEffectResponse) ProtoReflect() protoreflect.Message
func (*CreateEffectResponse) Reset ¶
func (x *CreateEffectResponse) Reset()
func (*CreateEffectResponse) String ¶
func (x *CreateEffectResponse) String() string
type CreateWithCurrentGlContextRequest ¶
type CreateWithCurrentGlContextRequest struct {
// contains filtered or unexported fields
}
func (*CreateWithCurrentGlContextRequest) Descriptor
deprecated
func (*CreateWithCurrentGlContextRequest) Descriptor() ([]byte, []int)
Deprecated: Use CreateWithCurrentGlContextRequest.ProtoReflect.Descriptor instead.
func (*CreateWithCurrentGlContextRequest) ProtoMessage ¶
func (*CreateWithCurrentGlContextRequest) ProtoMessage()
func (*CreateWithCurrentGlContextRequest) ProtoReflect ¶
func (x *CreateWithCurrentGlContextRequest) ProtoReflect() protoreflect.Message
func (*CreateWithCurrentGlContextRequest) Reset ¶
func (x *CreateWithCurrentGlContextRequest) Reset()
func (*CreateWithCurrentGlContextRequest) String ¶
func (x *CreateWithCurrentGlContextRequest) String() string
type CreateWithCurrentGlContextResponse ¶
type CreateWithCurrentGlContextResponse struct {
Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*CreateWithCurrentGlContextResponse) Descriptor
deprecated
func (*CreateWithCurrentGlContextResponse) Descriptor() ([]byte, []int)
Deprecated: Use CreateWithCurrentGlContextResponse.ProtoReflect.Descriptor instead.
func (*CreateWithCurrentGlContextResponse) GetResult ¶
func (x *CreateWithCurrentGlContextResponse) GetResult() int64
func (*CreateWithCurrentGlContextResponse) ProtoMessage ¶
func (*CreateWithCurrentGlContextResponse) ProtoMessage()
func (*CreateWithCurrentGlContextResponse) ProtoReflect ¶
func (x *CreateWithCurrentGlContextResponse) ProtoReflect() protoreflect.Message
func (*CreateWithCurrentGlContextResponse) Reset ¶
func (x *CreateWithCurrentGlContextResponse) Reset()
func (*CreateWithCurrentGlContextResponse) String ¶
func (x *CreateWithCurrentGlContextResponse) String() string
type EffectServiceClient ¶
type EffectServiceClient interface {
Apply(ctx context.Context, in *ApplyRequest, opts ...grpc.CallOption) (*ApplyResponse, error)
GetName(ctx context.Context, in *GetNameRequest, opts ...grpc.CallOption) (*GetNameResponse, error)
Release(ctx context.Context, in *ReleaseRequest, opts ...grpc.CallOption) (*ReleaseResponse, error)
SetParameter(ctx context.Context, in *SetParameterRequest, opts ...grpc.CallOption) (*SetParameterResponse, error)
SetUpdateListener(ctx context.Context, in *SetUpdateListenerRequest, opts ...grpc.CallOption) (*SetUpdateListenerResponse, error)
}
EffectServiceClient is the client API for EffectService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewEffectServiceClient ¶
func NewEffectServiceClient(cc grpc.ClientConnInterface) EffectServiceClient
type EffectServiceServer ¶
type EffectServiceServer interface {
Apply(context.Context, *ApplyRequest) (*ApplyResponse, error)
GetName(context.Context, *GetNameRequest) (*GetNameResponse, error)
Release(context.Context, *ReleaseRequest) (*ReleaseResponse, error)
SetParameter(context.Context, *SetParameterRequest) (*SetParameterResponse, error)
SetUpdateListener(context.Context, *SetUpdateListenerRequest) (*SetUpdateListenerResponse, error)
// contains filtered or unexported methods
}
EffectServiceServer is the server API for EffectService service. All implementations must embed UnimplementedEffectServiceServer for forward compatibility.
type FactoryServiceClient ¶
type FactoryServiceClient interface {
CreateEffect(ctx context.Context, in *CreateEffectRequest, opts ...grpc.CallOption) (*CreateEffectResponse, error)
IsEffectSupported(ctx context.Context, in *IsEffectSupportedRequest, opts ...grpc.CallOption) (*IsEffectSupportedResponse, error)
}
FactoryServiceClient is the client API for FactoryService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewFactoryServiceClient ¶
func NewFactoryServiceClient(cc grpc.ClientConnInterface) FactoryServiceClient
type FactoryServiceServer ¶
type FactoryServiceServer interface {
CreateEffect(context.Context, *CreateEffectRequest) (*CreateEffectResponse, error)
IsEffectSupported(context.Context, *IsEffectSupportedRequest) (*IsEffectSupportedResponse, error)
// contains filtered or unexported methods
}
FactoryServiceServer is the server API for FactoryService service. All implementations must embed UnimplementedFactoryServiceServer for forward compatibility.
type GetFactoryRequest ¶
type GetFactoryRequest struct {
// contains filtered or unexported fields
}
func (*GetFactoryRequest) Descriptor
deprecated
func (*GetFactoryRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetFactoryRequest.ProtoReflect.Descriptor instead.
func (*GetFactoryRequest) ProtoMessage ¶
func (*GetFactoryRequest) ProtoMessage()
func (*GetFactoryRequest) ProtoReflect ¶
func (x *GetFactoryRequest) ProtoReflect() protoreflect.Message
func (*GetFactoryRequest) Reset ¶
func (x *GetFactoryRequest) Reset()
func (*GetFactoryRequest) String ¶
func (x *GetFactoryRequest) String() string
type GetFactoryResponse ¶
type GetFactoryResponse struct {
Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*GetFactoryResponse) Descriptor
deprecated
func (*GetFactoryResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetFactoryResponse.ProtoReflect.Descriptor instead.
func (*GetFactoryResponse) GetResult ¶
func (x *GetFactoryResponse) GetResult() int64
func (*GetFactoryResponse) ProtoMessage ¶
func (*GetFactoryResponse) ProtoMessage()
func (*GetFactoryResponse) ProtoReflect ¶
func (x *GetFactoryResponse) ProtoReflect() protoreflect.Message
func (*GetFactoryResponse) Reset ¶
func (x *GetFactoryResponse) Reset()
func (*GetFactoryResponse) String ¶
func (x *GetFactoryResponse) String() string
type GetNameRequest ¶
type GetNameRequest struct {
// contains filtered or unexported fields
}
func (*GetNameRequest) Descriptor
deprecated
func (*GetNameRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetNameRequest.ProtoReflect.Descriptor instead.
func (*GetNameRequest) ProtoMessage ¶
func (*GetNameRequest) ProtoMessage()
func (*GetNameRequest) ProtoReflect ¶
func (x *GetNameRequest) ProtoReflect() protoreflect.Message
func (*GetNameRequest) Reset ¶
func (x *GetNameRequest) Reset()
func (*GetNameRequest) String ¶
func (x *GetNameRequest) String() string
type GetNameResponse ¶
type GetNameResponse struct {
Result string `protobuf:"bytes,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*GetNameResponse) Descriptor
deprecated
func (*GetNameResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetNameResponse.ProtoReflect.Descriptor instead.
func (*GetNameResponse) GetResult ¶
func (x *GetNameResponse) GetResult() string
func (*GetNameResponse) ProtoMessage ¶
func (*GetNameResponse) ProtoMessage()
func (*GetNameResponse) ProtoReflect ¶
func (x *GetNameResponse) ProtoReflect() protoreflect.Message
func (*GetNameResponse) Reset ¶
func (x *GetNameResponse) Reset()
func (*GetNameResponse) String ¶
func (x *GetNameResponse) String() string
type IsEffectSupportedRequest ¶
type IsEffectSupportedRequest struct {
Arg0 string `protobuf:"bytes,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
// contains filtered or unexported fields
}
func (*IsEffectSupportedRequest) Descriptor
deprecated
func (*IsEffectSupportedRequest) Descriptor() ([]byte, []int)
Deprecated: Use IsEffectSupportedRequest.ProtoReflect.Descriptor instead.
func (*IsEffectSupportedRequest) GetArg0 ¶
func (x *IsEffectSupportedRequest) GetArg0() string
func (*IsEffectSupportedRequest) ProtoMessage ¶
func (*IsEffectSupportedRequest) ProtoMessage()
func (*IsEffectSupportedRequest) ProtoReflect ¶
func (x *IsEffectSupportedRequest) ProtoReflect() protoreflect.Message
func (*IsEffectSupportedRequest) Reset ¶
func (x *IsEffectSupportedRequest) Reset()
func (*IsEffectSupportedRequest) String ¶
func (x *IsEffectSupportedRequest) String() string
type IsEffectSupportedResponse ¶
type IsEffectSupportedResponse struct {
Result bool `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*IsEffectSupportedResponse) Descriptor
deprecated
func (*IsEffectSupportedResponse) Descriptor() ([]byte, []int)
Deprecated: Use IsEffectSupportedResponse.ProtoReflect.Descriptor instead.
func (*IsEffectSupportedResponse) GetResult ¶
func (x *IsEffectSupportedResponse) GetResult() bool
func (*IsEffectSupportedResponse) ProtoMessage ¶
func (*IsEffectSupportedResponse) ProtoMessage()
func (*IsEffectSupportedResponse) ProtoReflect ¶
func (x *IsEffectSupportedResponse) ProtoReflect() protoreflect.Message
func (*IsEffectSupportedResponse) Reset ¶
func (x *IsEffectSupportedResponse) Reset()
func (*IsEffectSupportedResponse) String ¶
func (x *IsEffectSupportedResponse) String() string
type OnEffectUpdatedRequest ¶
type OnEffectUpdatedRequest struct {
Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
Arg1 int64 `protobuf:"varint,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
// contains filtered or unexported fields
}
func (*OnEffectUpdatedRequest) Descriptor
deprecated
func (*OnEffectUpdatedRequest) Descriptor() ([]byte, []int)
Deprecated: Use OnEffectUpdatedRequest.ProtoReflect.Descriptor instead.
func (*OnEffectUpdatedRequest) GetArg0 ¶
func (x *OnEffectUpdatedRequest) GetArg0() int64
func (*OnEffectUpdatedRequest) GetArg1 ¶
func (x *OnEffectUpdatedRequest) GetArg1() int64
func (*OnEffectUpdatedRequest) ProtoMessage ¶
func (*OnEffectUpdatedRequest) ProtoMessage()
func (*OnEffectUpdatedRequest) ProtoReflect ¶
func (x *OnEffectUpdatedRequest) ProtoReflect() protoreflect.Message
func (*OnEffectUpdatedRequest) Reset ¶
func (x *OnEffectUpdatedRequest) Reset()
func (*OnEffectUpdatedRequest) String ¶
func (x *OnEffectUpdatedRequest) String() string
type OnEffectUpdatedResponse ¶
type OnEffectUpdatedResponse struct {
// contains filtered or unexported fields
}
func (*OnEffectUpdatedResponse) Descriptor
deprecated
func (*OnEffectUpdatedResponse) Descriptor() ([]byte, []int)
Deprecated: Use OnEffectUpdatedResponse.ProtoReflect.Descriptor instead.
func (*OnEffectUpdatedResponse) ProtoMessage ¶
func (*OnEffectUpdatedResponse) ProtoMessage()
func (*OnEffectUpdatedResponse) ProtoReflect ¶
func (x *OnEffectUpdatedResponse) ProtoReflect() protoreflect.Message
func (*OnEffectUpdatedResponse) Reset ¶
func (x *OnEffectUpdatedResponse) Reset()
func (*OnEffectUpdatedResponse) String ¶
func (x *OnEffectUpdatedResponse) String() string
type ReleaseRequest ¶
type ReleaseRequest struct {
// contains filtered or unexported fields
}
func (*ReleaseRequest) Descriptor
deprecated
func (*ReleaseRequest) Descriptor() ([]byte, []int)
Deprecated: Use ReleaseRequest.ProtoReflect.Descriptor instead.
func (*ReleaseRequest) ProtoMessage ¶
func (*ReleaseRequest) ProtoMessage()
func (*ReleaseRequest) ProtoReflect ¶
func (x *ReleaseRequest) ProtoReflect() protoreflect.Message
func (*ReleaseRequest) Reset ¶
func (x *ReleaseRequest) Reset()
func (*ReleaseRequest) String ¶
func (x *ReleaseRequest) String() string
type ReleaseResponse ¶
type ReleaseResponse struct {
// contains filtered or unexported fields
}
func (*ReleaseResponse) Descriptor
deprecated
func (*ReleaseResponse) Descriptor() ([]byte, []int)
Deprecated: Use ReleaseResponse.ProtoReflect.Descriptor instead.
func (*ReleaseResponse) ProtoMessage ¶
func (*ReleaseResponse) ProtoMessage()
func (*ReleaseResponse) ProtoReflect ¶
func (x *ReleaseResponse) ProtoReflect() protoreflect.Message
func (*ReleaseResponse) Reset ¶
func (x *ReleaseResponse) Reset()
func (*ReleaseResponse) String ¶
func (x *ReleaseResponse) String() string
type SetParameterRequest ¶
type SetParameterRequest struct {
Arg0 string `protobuf:"bytes,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
Arg1 int64 `protobuf:"varint,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
// contains filtered or unexported fields
}
func (*SetParameterRequest) Descriptor
deprecated
func (*SetParameterRequest) Descriptor() ([]byte, []int)
Deprecated: Use SetParameterRequest.ProtoReflect.Descriptor instead.
func (*SetParameterRequest) GetArg0 ¶
func (x *SetParameterRequest) GetArg0() string
func (*SetParameterRequest) GetArg1 ¶
func (x *SetParameterRequest) GetArg1() int64
func (*SetParameterRequest) ProtoMessage ¶
func (*SetParameterRequest) ProtoMessage()
func (*SetParameterRequest) ProtoReflect ¶
func (x *SetParameterRequest) ProtoReflect() protoreflect.Message
func (*SetParameterRequest) Reset ¶
func (x *SetParameterRequest) Reset()
func (*SetParameterRequest) String ¶
func (x *SetParameterRequest) String() string
type SetParameterResponse ¶
type SetParameterResponse struct {
// contains filtered or unexported fields
}
func (*SetParameterResponse) Descriptor
deprecated
func (*SetParameterResponse) Descriptor() ([]byte, []int)
Deprecated: Use SetParameterResponse.ProtoReflect.Descriptor instead.
func (*SetParameterResponse) ProtoMessage ¶
func (*SetParameterResponse) ProtoMessage()
func (*SetParameterResponse) ProtoReflect ¶
func (x *SetParameterResponse) ProtoReflect() protoreflect.Message
func (*SetParameterResponse) Reset ¶
func (x *SetParameterResponse) Reset()
func (*SetParameterResponse) String ¶
func (x *SetParameterResponse) String() string
type SetUpdateListenerRequest ¶
type SetUpdateListenerRequest struct {
Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
// contains filtered or unexported fields
}
func (*SetUpdateListenerRequest) Descriptor
deprecated
func (*SetUpdateListenerRequest) Descriptor() ([]byte, []int)
Deprecated: Use SetUpdateListenerRequest.ProtoReflect.Descriptor instead.
func (*SetUpdateListenerRequest) GetArg0 ¶
func (x *SetUpdateListenerRequest) GetArg0() int64
func (*SetUpdateListenerRequest) ProtoMessage ¶
func (*SetUpdateListenerRequest) ProtoMessage()
func (*SetUpdateListenerRequest) ProtoReflect ¶
func (x *SetUpdateListenerRequest) ProtoReflect() protoreflect.Message
func (*SetUpdateListenerRequest) Reset ¶
func (x *SetUpdateListenerRequest) Reset()
func (*SetUpdateListenerRequest) String ¶
func (x *SetUpdateListenerRequest) String() string
type SetUpdateListenerResponse ¶
type SetUpdateListenerResponse struct {
// contains filtered or unexported fields
}
func (*SetUpdateListenerResponse) Descriptor
deprecated
func (*SetUpdateListenerResponse) Descriptor() ([]byte, []int)
Deprecated: Use SetUpdateListenerResponse.ProtoReflect.Descriptor instead.
func (*SetUpdateListenerResponse) ProtoMessage ¶
func (*SetUpdateListenerResponse) ProtoMessage()
func (*SetUpdateListenerResponse) ProtoReflect ¶
func (x *SetUpdateListenerResponse) ProtoReflect() protoreflect.Message
func (*SetUpdateListenerResponse) Reset ¶
func (x *SetUpdateListenerResponse) Reset()
func (*SetUpdateListenerResponse) String ¶
func (x *SetUpdateListenerResponse) String() string
type UnimplementedContextServiceServer ¶
type UnimplementedContextServiceServer struct{}
UnimplementedContextServiceServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedContextServiceServer) CreateWithCurrentGlContext ¶
func (UnimplementedContextServiceServer) CreateWithCurrentGlContext(context.Context, *CreateWithCurrentGlContextRequest) (*CreateWithCurrentGlContextResponse, error)
func (UnimplementedContextServiceServer) GetFactory ¶
func (UnimplementedContextServiceServer) GetFactory(context.Context, *GetFactoryRequest) (*GetFactoryResponse, error)
func (UnimplementedContextServiceServer) Release ¶
func (UnimplementedContextServiceServer) Release(context.Context, *ReleaseRequest) (*ReleaseResponse, error)
type UnimplementedEffectServiceServer ¶
type UnimplementedEffectServiceServer struct{}
UnimplementedEffectServiceServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedEffectServiceServer) Apply ¶
func (UnimplementedEffectServiceServer) Apply(context.Context, *ApplyRequest) (*ApplyResponse, error)
func (UnimplementedEffectServiceServer) GetName ¶
func (UnimplementedEffectServiceServer) GetName(context.Context, *GetNameRequest) (*GetNameResponse, error)
func (UnimplementedEffectServiceServer) Release ¶
func (UnimplementedEffectServiceServer) Release(context.Context, *ReleaseRequest) (*ReleaseResponse, error)
func (UnimplementedEffectServiceServer) SetParameter ¶
func (UnimplementedEffectServiceServer) SetParameter(context.Context, *SetParameterRequest) (*SetParameterResponse, error)
func (UnimplementedEffectServiceServer) SetUpdateListener ¶
func (UnimplementedEffectServiceServer) SetUpdateListener(context.Context, *SetUpdateListenerRequest) (*SetUpdateListenerResponse, error)
type UnimplementedFactoryServiceServer ¶
type UnimplementedFactoryServiceServer struct{}
UnimplementedFactoryServiceServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedFactoryServiceServer) CreateEffect ¶
func (UnimplementedFactoryServiceServer) CreateEffect(context.Context, *CreateEffectRequest) (*CreateEffectResponse, error)
func (UnimplementedFactoryServiceServer) IsEffectSupported ¶
func (UnimplementedFactoryServiceServer) IsEffectSupported(context.Context, *IsEffectSupportedRequest) (*IsEffectSupportedResponse, error)
type UnimplementedUpdateListenerServiceServer ¶
type UnimplementedUpdateListenerServiceServer struct{}
UnimplementedUpdateListenerServiceServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedUpdateListenerServiceServer) OnEffectUpdated ¶
func (UnimplementedUpdateListenerServiceServer) OnEffectUpdated(context.Context, *OnEffectUpdatedRequest) (*OnEffectUpdatedResponse, error)
type UnsafeContextServiceServer ¶
type UnsafeContextServiceServer interface {
// contains filtered or unexported methods
}
UnsafeContextServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ContextServiceServer will result in compilation errors.
type UnsafeEffectServiceServer ¶
type UnsafeEffectServiceServer interface {
// contains filtered or unexported methods
}
UnsafeEffectServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to EffectServiceServer will result in compilation errors.
type UnsafeFactoryServiceServer ¶
type UnsafeFactoryServiceServer interface {
// contains filtered or unexported methods
}
UnsafeFactoryServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to FactoryServiceServer will result in compilation errors.
type UnsafeUpdateListenerServiceServer ¶
type UnsafeUpdateListenerServiceServer interface {
// contains filtered or unexported methods
}
UnsafeUpdateListenerServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to UpdateListenerServiceServer will result in compilation errors.
type UpdateListenerServiceClient ¶
type UpdateListenerServiceClient interface {
OnEffectUpdated(ctx context.Context, in *OnEffectUpdatedRequest, opts ...grpc.CallOption) (*OnEffectUpdatedResponse, error)
}
UpdateListenerServiceClient is the client API for UpdateListenerService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewUpdateListenerServiceClient ¶
func NewUpdateListenerServiceClient(cc grpc.ClientConnInterface) UpdateListenerServiceClient
type UpdateListenerServiceServer ¶
type UpdateListenerServiceServer interface {
OnEffectUpdated(context.Context, *OnEffectUpdatedRequest) (*OnEffectUpdatedResponse, error)
// contains filtered or unexported methods
}
UpdateListenerServiceServer is the server API for UpdateListenerService service. All implementations must embed UnimplementedUpdateListenerServiceServer for forward compatibility.