Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterAconfigPackageServiceServer(s grpc.ServiceRegistrar, srv AconfigPackageServiceServer)
- func RegisterAconfigStorageReadExceptionServiceServer(s grpc.ServiceRegistrar, srv AconfigStorageReadExceptionServiceServer)
- type AconfigPackageServiceClient
- type AconfigPackageServiceServer
- type AconfigStorageReadExceptionServiceClient
- type AconfigStorageReadExceptionServiceServer
- type GetBooleanFlagValueRequest
- func (*GetBooleanFlagValueRequest) Descriptor() ([]byte, []int)deprecated
- func (x *GetBooleanFlagValueRequest) GetArg0() string
- func (x *GetBooleanFlagValueRequest) GetArg1() bool
- func (*GetBooleanFlagValueRequest) ProtoMessage()
- func (x *GetBooleanFlagValueRequest) ProtoReflect() protoreflect.Message
- func (x *GetBooleanFlagValueRequest) Reset()
- func (x *GetBooleanFlagValueRequest) String() string
- type GetBooleanFlagValueResponse
- func (*GetBooleanFlagValueResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetBooleanFlagValueResponse) GetResult() bool
- func (*GetBooleanFlagValueResponse) ProtoMessage()
- func (x *GetBooleanFlagValueResponse) ProtoReflect() protoreflect.Message
- func (x *GetBooleanFlagValueResponse) Reset()
- func (x *GetBooleanFlagValueResponse) String() string
- type GetErrorCodeRequest
- func (*GetErrorCodeRequest) Descriptor() ([]byte, []int)deprecated
- func (x *GetErrorCodeRequest) GetHandle() int64
- func (*GetErrorCodeRequest) ProtoMessage()
- func (x *GetErrorCodeRequest) ProtoReflect() protoreflect.Message
- func (x *GetErrorCodeRequest) Reset()
- func (x *GetErrorCodeRequest) String() string
- type GetErrorCodeResponse
- func (*GetErrorCodeResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetErrorCodeResponse) GetResult() int32
- func (*GetErrorCodeResponse) ProtoMessage()
- func (x *GetErrorCodeResponse) ProtoReflect() protoreflect.Message
- func (x *GetErrorCodeResponse) Reset()
- func (x *GetErrorCodeResponse) String() string
- type GetMessageRequest
- type GetMessageResponse
- func (*GetMessageResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetMessageResponse) GetResult() string
- func (*GetMessageResponse) ProtoMessage()
- func (x *GetMessageResponse) ProtoReflect() protoreflect.Message
- func (x *GetMessageResponse) Reset()
- func (x *GetMessageResponse) String() string
- type LoadRequest
- type LoadResponse
- type NewAconfigStorageReadExceptionRequest
- func (*NewAconfigStorageReadExceptionRequest) Descriptor() ([]byte, []int)deprecated
- func (x *NewAconfigStorageReadExceptionRequest) GetArg0() int32
- func (x *NewAconfigStorageReadExceptionRequest) GetArg1() string
- func (*NewAconfigStorageReadExceptionRequest) ProtoMessage()
- func (x *NewAconfigStorageReadExceptionRequest) ProtoReflect() protoreflect.Message
- func (x *NewAconfigStorageReadExceptionRequest) Reset()
- func (x *NewAconfigStorageReadExceptionRequest) String() string
- type NewAconfigStorageReadExceptionResponse
- func (*NewAconfigStorageReadExceptionResponse) Descriptor() ([]byte, []int)deprecated
- func (x *NewAconfigStorageReadExceptionResponse) GetResult() int64
- func (*NewAconfigStorageReadExceptionResponse) ProtoMessage()
- func (x *NewAconfigStorageReadExceptionResponse) ProtoReflect() protoreflect.Message
- func (x *NewAconfigStorageReadExceptionResponse) Reset()
- func (x *NewAconfigStorageReadExceptionResponse) String() string
- type UnimplementedAconfigPackageServiceServer
- type UnimplementedAconfigStorageReadExceptionServiceServer
- func (UnimplementedAconfigStorageReadExceptionServiceServer) GetErrorCode(context.Context, *GetErrorCodeRequest) (*GetErrorCodeResponse, error)
- func (UnimplementedAconfigStorageReadExceptionServiceServer) GetMessage(context.Context, *GetMessageRequest) (*GetMessageResponse, error)
- func (UnimplementedAconfigStorageReadExceptionServiceServer) NewAconfigStorageReadException(context.Context, *NewAconfigStorageReadExceptionRequest) (*NewAconfigStorageReadExceptionResponse, error)
- type UnsafeAconfigPackageServiceServer
- type UnsafeAconfigStorageReadExceptionServiceServer
Constants ¶
const ( AconfigPackageService_GetBooleanFlagValue_FullMethodName = "/flagging.AconfigPackageService/GetBooleanFlagValue" AconfigPackageService_Load_FullMethodName = "/flagging.AconfigPackageService/Load" )
const ( AconfigStorageReadExceptionService_NewAconfigStorageReadException_FullMethodName = "/flagging.AconfigStorageReadExceptionService/NewAconfigStorageReadException" AconfigStorageReadExceptionService_GetErrorCode_FullMethodName = "/flagging.AconfigStorageReadExceptionService/GetErrorCode" AconfigStorageReadExceptionService_GetMessage_FullMethodName = "/flagging.AconfigStorageReadExceptionService/GetMessage" )
Variables ¶
var AconfigPackageService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "flagging.AconfigPackageService", HandlerType: (*AconfigPackageServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "GetBooleanFlagValue", Handler: _AconfigPackageService_GetBooleanFlagValue_Handler, }, { MethodName: "Load", Handler: _AconfigPackageService_Load_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "proto/flagging/flagging.proto", }
AconfigPackageService_ServiceDesc is the grpc.ServiceDesc for AconfigPackageService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var AconfigStorageReadExceptionService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "flagging.AconfigStorageReadExceptionService", HandlerType: (*AconfigStorageReadExceptionServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "NewAconfigStorageReadException", Handler: _AconfigStorageReadExceptionService_NewAconfigStorageReadException_Handler, }, { MethodName: "GetErrorCode", Handler: _AconfigStorageReadExceptionService_GetErrorCode_Handler, }, { MethodName: "GetMessage", Handler: _AconfigStorageReadExceptionService_GetMessage_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "proto/flagging/flagging.proto", }
AconfigStorageReadExceptionService_ServiceDesc is the grpc.ServiceDesc for AconfigStorageReadExceptionService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var File_proto_flagging_flagging_proto protoreflect.FileDescriptor
Functions ¶
func RegisterAconfigPackageServiceServer ¶
func RegisterAconfigPackageServiceServer(s grpc.ServiceRegistrar, srv AconfigPackageServiceServer)
func RegisterAconfigStorageReadExceptionServiceServer ¶
func RegisterAconfigStorageReadExceptionServiceServer(s grpc.ServiceRegistrar, srv AconfigStorageReadExceptionServiceServer)
Types ¶
type AconfigPackageServiceClient ¶
type AconfigPackageServiceClient interface {
GetBooleanFlagValue(ctx context.Context, in *GetBooleanFlagValueRequest, opts ...grpc.CallOption) (*GetBooleanFlagValueResponse, error)
Load(ctx context.Context, in *LoadRequest, opts ...grpc.CallOption) (*LoadResponse, error)
}
AconfigPackageServiceClient is the client API for AconfigPackageService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewAconfigPackageServiceClient ¶
func NewAconfigPackageServiceClient(cc grpc.ClientConnInterface) AconfigPackageServiceClient
type AconfigPackageServiceServer ¶
type AconfigPackageServiceServer interface {
GetBooleanFlagValue(context.Context, *GetBooleanFlagValueRequest) (*GetBooleanFlagValueResponse, error)
Load(context.Context, *LoadRequest) (*LoadResponse, error)
// contains filtered or unexported methods
}
AconfigPackageServiceServer is the server API for AconfigPackageService service. All implementations must embed UnimplementedAconfigPackageServiceServer for forward compatibility.
type AconfigStorageReadExceptionServiceClient ¶
type AconfigStorageReadExceptionServiceClient interface {
NewAconfigStorageReadException(ctx context.Context, in *NewAconfigStorageReadExceptionRequest, opts ...grpc.CallOption) (*NewAconfigStorageReadExceptionResponse, error)
GetErrorCode(ctx context.Context, in *GetErrorCodeRequest, opts ...grpc.CallOption) (*GetErrorCodeResponse, error)
GetMessage(ctx context.Context, in *GetMessageRequest, opts ...grpc.CallOption) (*GetMessageResponse, error)
}
AconfigStorageReadExceptionServiceClient is the client API for AconfigStorageReadExceptionService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewAconfigStorageReadExceptionServiceClient ¶
func NewAconfigStorageReadExceptionServiceClient(cc grpc.ClientConnInterface) AconfigStorageReadExceptionServiceClient
type AconfigStorageReadExceptionServiceServer ¶
type AconfigStorageReadExceptionServiceServer interface {
NewAconfigStorageReadException(context.Context, *NewAconfigStorageReadExceptionRequest) (*NewAconfigStorageReadExceptionResponse, error)
GetErrorCode(context.Context, *GetErrorCodeRequest) (*GetErrorCodeResponse, error)
GetMessage(context.Context, *GetMessageRequest) (*GetMessageResponse, error)
// contains filtered or unexported methods
}
AconfigStorageReadExceptionServiceServer is the server API for AconfigStorageReadExceptionService service. All implementations must embed UnimplementedAconfigStorageReadExceptionServiceServer for forward compatibility.
type GetBooleanFlagValueRequest ¶
type GetBooleanFlagValueRequest struct {
Arg0 string `protobuf:"bytes,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
Arg1 bool `protobuf:"varint,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
// contains filtered or unexported fields
}
func (*GetBooleanFlagValueRequest) Descriptor
deprecated
func (*GetBooleanFlagValueRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetBooleanFlagValueRequest.ProtoReflect.Descriptor instead.
func (*GetBooleanFlagValueRequest) GetArg0 ¶
func (x *GetBooleanFlagValueRequest) GetArg0() string
func (*GetBooleanFlagValueRequest) GetArg1 ¶
func (x *GetBooleanFlagValueRequest) GetArg1() bool
func (*GetBooleanFlagValueRequest) ProtoMessage ¶
func (*GetBooleanFlagValueRequest) ProtoMessage()
func (*GetBooleanFlagValueRequest) ProtoReflect ¶
func (x *GetBooleanFlagValueRequest) ProtoReflect() protoreflect.Message
func (*GetBooleanFlagValueRequest) Reset ¶
func (x *GetBooleanFlagValueRequest) Reset()
func (*GetBooleanFlagValueRequest) String ¶
func (x *GetBooleanFlagValueRequest) String() string
type GetBooleanFlagValueResponse ¶
type GetBooleanFlagValueResponse struct {
Result bool `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*GetBooleanFlagValueResponse) Descriptor
deprecated
func (*GetBooleanFlagValueResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetBooleanFlagValueResponse.ProtoReflect.Descriptor instead.
func (*GetBooleanFlagValueResponse) GetResult ¶
func (x *GetBooleanFlagValueResponse) GetResult() bool
func (*GetBooleanFlagValueResponse) ProtoMessage ¶
func (*GetBooleanFlagValueResponse) ProtoMessage()
func (*GetBooleanFlagValueResponse) ProtoReflect ¶
func (x *GetBooleanFlagValueResponse) ProtoReflect() protoreflect.Message
func (*GetBooleanFlagValueResponse) Reset ¶
func (x *GetBooleanFlagValueResponse) Reset()
func (*GetBooleanFlagValueResponse) String ¶
func (x *GetBooleanFlagValueResponse) String() string
type GetErrorCodeRequest ¶
type GetErrorCodeRequest struct {
Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
// contains filtered or unexported fields
}
func (*GetErrorCodeRequest) Descriptor
deprecated
func (*GetErrorCodeRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetErrorCodeRequest.ProtoReflect.Descriptor instead.
func (*GetErrorCodeRequest) GetHandle ¶
func (x *GetErrorCodeRequest) GetHandle() int64
func (*GetErrorCodeRequest) ProtoMessage ¶
func (*GetErrorCodeRequest) ProtoMessage()
func (*GetErrorCodeRequest) ProtoReflect ¶
func (x *GetErrorCodeRequest) ProtoReflect() protoreflect.Message
func (*GetErrorCodeRequest) Reset ¶
func (x *GetErrorCodeRequest) Reset()
func (*GetErrorCodeRequest) String ¶
func (x *GetErrorCodeRequest) String() string
type GetErrorCodeResponse ¶
type GetErrorCodeResponse struct {
Result int32 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*GetErrorCodeResponse) Descriptor
deprecated
func (*GetErrorCodeResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetErrorCodeResponse.ProtoReflect.Descriptor instead.
func (*GetErrorCodeResponse) GetResult ¶
func (x *GetErrorCodeResponse) GetResult() int32
func (*GetErrorCodeResponse) ProtoMessage ¶
func (*GetErrorCodeResponse) ProtoMessage()
func (*GetErrorCodeResponse) ProtoReflect ¶
func (x *GetErrorCodeResponse) ProtoReflect() protoreflect.Message
func (*GetErrorCodeResponse) Reset ¶
func (x *GetErrorCodeResponse) Reset()
func (*GetErrorCodeResponse) String ¶
func (x *GetErrorCodeResponse) String() string
type GetMessageRequest ¶
type GetMessageRequest struct {
Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
// contains filtered or unexported fields
}
func (*GetMessageRequest) Descriptor
deprecated
func (*GetMessageRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetMessageRequest.ProtoReflect.Descriptor instead.
func (*GetMessageRequest) GetHandle ¶
func (x *GetMessageRequest) GetHandle() int64
func (*GetMessageRequest) ProtoMessage ¶
func (*GetMessageRequest) ProtoMessage()
func (*GetMessageRequest) ProtoReflect ¶
func (x *GetMessageRequest) ProtoReflect() protoreflect.Message
func (*GetMessageRequest) Reset ¶
func (x *GetMessageRequest) Reset()
func (*GetMessageRequest) String ¶
func (x *GetMessageRequest) String() string
type GetMessageResponse ¶
type GetMessageResponse struct {
Result string `protobuf:"bytes,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*GetMessageResponse) Descriptor
deprecated
func (*GetMessageResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetMessageResponse.ProtoReflect.Descriptor instead.
func (*GetMessageResponse) GetResult ¶
func (x *GetMessageResponse) GetResult() string
func (*GetMessageResponse) ProtoMessage ¶
func (*GetMessageResponse) ProtoMessage()
func (*GetMessageResponse) ProtoReflect ¶
func (x *GetMessageResponse) ProtoReflect() protoreflect.Message
func (*GetMessageResponse) Reset ¶
func (x *GetMessageResponse) Reset()
func (*GetMessageResponse) String ¶
func (x *GetMessageResponse) String() string
type LoadRequest ¶
type LoadRequest struct {
Arg0 string `protobuf:"bytes,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
// contains filtered or unexported fields
}
func (*LoadRequest) Descriptor
deprecated
func (*LoadRequest) Descriptor() ([]byte, []int)
Deprecated: Use LoadRequest.ProtoReflect.Descriptor instead.
func (*LoadRequest) GetArg0 ¶
func (x *LoadRequest) GetArg0() string
func (*LoadRequest) ProtoMessage ¶
func (*LoadRequest) ProtoMessage()
func (*LoadRequest) ProtoReflect ¶
func (x *LoadRequest) ProtoReflect() protoreflect.Message
func (*LoadRequest) Reset ¶
func (x *LoadRequest) Reset()
func (*LoadRequest) String ¶
func (x *LoadRequest) String() string
type LoadResponse ¶
type LoadResponse struct {
Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*LoadResponse) Descriptor
deprecated
func (*LoadResponse) Descriptor() ([]byte, []int)
Deprecated: Use LoadResponse.ProtoReflect.Descriptor instead.
func (*LoadResponse) GetResult ¶
func (x *LoadResponse) GetResult() int64
func (*LoadResponse) ProtoMessage ¶
func (*LoadResponse) ProtoMessage()
func (*LoadResponse) ProtoReflect ¶
func (x *LoadResponse) ProtoReflect() protoreflect.Message
func (*LoadResponse) Reset ¶
func (x *LoadResponse) Reset()
func (*LoadResponse) String ¶
func (x *LoadResponse) String() string
type NewAconfigStorageReadExceptionRequest ¶
type NewAconfigStorageReadExceptionRequest struct {
Arg0 int32 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
Arg1 string `protobuf:"bytes,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
// contains filtered or unexported fields
}
func (*NewAconfigStorageReadExceptionRequest) Descriptor
deprecated
func (*NewAconfigStorageReadExceptionRequest) Descriptor() ([]byte, []int)
Deprecated: Use NewAconfigStorageReadExceptionRequest.ProtoReflect.Descriptor instead.
func (*NewAconfigStorageReadExceptionRequest) GetArg0 ¶
func (x *NewAconfigStorageReadExceptionRequest) GetArg0() int32
func (*NewAconfigStorageReadExceptionRequest) GetArg1 ¶
func (x *NewAconfigStorageReadExceptionRequest) GetArg1() string
func (*NewAconfigStorageReadExceptionRequest) ProtoMessage ¶
func (*NewAconfigStorageReadExceptionRequest) ProtoMessage()
func (*NewAconfigStorageReadExceptionRequest) ProtoReflect ¶
func (x *NewAconfigStorageReadExceptionRequest) ProtoReflect() protoreflect.Message
func (*NewAconfigStorageReadExceptionRequest) Reset ¶
func (x *NewAconfigStorageReadExceptionRequest) Reset()
func (*NewAconfigStorageReadExceptionRequest) String ¶
func (x *NewAconfigStorageReadExceptionRequest) String() string
type NewAconfigStorageReadExceptionResponse ¶
type NewAconfigStorageReadExceptionResponse struct {
Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*NewAconfigStorageReadExceptionResponse) Descriptor
deprecated
func (*NewAconfigStorageReadExceptionResponse) Descriptor() ([]byte, []int)
Deprecated: Use NewAconfigStorageReadExceptionResponse.ProtoReflect.Descriptor instead.
func (*NewAconfigStorageReadExceptionResponse) GetResult ¶
func (x *NewAconfigStorageReadExceptionResponse) GetResult() int64
func (*NewAconfigStorageReadExceptionResponse) ProtoMessage ¶
func (*NewAconfigStorageReadExceptionResponse) ProtoMessage()
func (*NewAconfigStorageReadExceptionResponse) ProtoReflect ¶
func (x *NewAconfigStorageReadExceptionResponse) ProtoReflect() protoreflect.Message
func (*NewAconfigStorageReadExceptionResponse) Reset ¶
func (x *NewAconfigStorageReadExceptionResponse) Reset()
func (*NewAconfigStorageReadExceptionResponse) String ¶
func (x *NewAconfigStorageReadExceptionResponse) String() string
type UnimplementedAconfigPackageServiceServer ¶
type UnimplementedAconfigPackageServiceServer struct{}
UnimplementedAconfigPackageServiceServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedAconfigPackageServiceServer) GetBooleanFlagValue ¶
func (UnimplementedAconfigPackageServiceServer) GetBooleanFlagValue(context.Context, *GetBooleanFlagValueRequest) (*GetBooleanFlagValueResponse, error)
func (UnimplementedAconfigPackageServiceServer) Load ¶
func (UnimplementedAconfigPackageServiceServer) Load(context.Context, *LoadRequest) (*LoadResponse, error)
type UnimplementedAconfigStorageReadExceptionServiceServer ¶
type UnimplementedAconfigStorageReadExceptionServiceServer struct{}
UnimplementedAconfigStorageReadExceptionServiceServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedAconfigStorageReadExceptionServiceServer) GetErrorCode ¶
func (UnimplementedAconfigStorageReadExceptionServiceServer) GetErrorCode(context.Context, *GetErrorCodeRequest) (*GetErrorCodeResponse, error)
func (UnimplementedAconfigStorageReadExceptionServiceServer) GetMessage ¶
func (UnimplementedAconfigStorageReadExceptionServiceServer) GetMessage(context.Context, *GetMessageRequest) (*GetMessageResponse, error)
func (UnimplementedAconfigStorageReadExceptionServiceServer) NewAconfigStorageReadException ¶
func (UnimplementedAconfigStorageReadExceptionServiceServer) NewAconfigStorageReadException(context.Context, *NewAconfigStorageReadExceptionRequest) (*NewAconfigStorageReadExceptionResponse, error)
type UnsafeAconfigPackageServiceServer ¶
type UnsafeAconfigPackageServiceServer interface {
// contains filtered or unexported methods
}
UnsafeAconfigPackageServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to AconfigPackageServiceServer will result in compilation errors.
type UnsafeAconfigStorageReadExceptionServiceServer ¶
type UnsafeAconfigStorageReadExceptionServiceServer interface {
// contains filtered or unexported methods
}
UnsafeAconfigStorageReadExceptionServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to AconfigStorageReadExceptionServiceServer will result in compilation errors.