ir

package
v0.0.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 22, 2026 License: CC0-1.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

const (
	ConsumerIrManagerService_GetCarrierFrequencies_FullMethodName = "/ir.ConsumerIrManagerService/GetCarrierFrequencies"
	ConsumerIrManagerService_HasIrEmitter_FullMethodName          = "/ir.ConsumerIrManagerService/HasIrEmitter"
	ConsumerIrManagerService_Transmit_FullMethodName              = "/ir.ConsumerIrManagerService/Transmit"
)
const (
	ConsumerIrManagerCarrierFrequencyRangeService_GetMaxFrequency_FullMethodName = "/ir.ConsumerIrManagerCarrierFrequencyRangeService/GetMaxFrequency"
	ConsumerIrManagerCarrierFrequencyRangeService_GetMinFrequency_FullMethodName = "/ir.ConsumerIrManagerCarrierFrequencyRangeService/GetMinFrequency"
)

Variables

var ConsumerIrManagerCarrierFrequencyRangeService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "ir.ConsumerIrManagerCarrierFrequencyRangeService",
	HandlerType: (*ConsumerIrManagerCarrierFrequencyRangeServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "GetMaxFrequency",
			Handler:    _ConsumerIrManagerCarrierFrequencyRangeService_GetMaxFrequency_Handler,
		},
		{
			MethodName: "GetMinFrequency",
			Handler:    _ConsumerIrManagerCarrierFrequencyRangeService_GetMinFrequency_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/ir/ir.proto",
}

ConsumerIrManagerCarrierFrequencyRangeService_ServiceDesc is the grpc.ServiceDesc for ConsumerIrManagerCarrierFrequencyRangeService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var ConsumerIrManagerService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "ir.ConsumerIrManagerService",
	HandlerType: (*ConsumerIrManagerServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "GetCarrierFrequencies",
			Handler:    _ConsumerIrManagerService_GetCarrierFrequencies_Handler,
		},
		{
			MethodName: "HasIrEmitter",
			Handler:    _ConsumerIrManagerService_HasIrEmitter_Handler,
		},
		{
			MethodName: "Transmit",
			Handler:    _ConsumerIrManagerService_Transmit_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/ir/ir.proto",
}

ConsumerIrManagerService_ServiceDesc is the grpc.ServiceDesc for ConsumerIrManagerService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var File_proto_ir_ir_proto protoreflect.FileDescriptor

Functions

func RegisterConsumerIrManagerServiceServer

func RegisterConsumerIrManagerServiceServer(s grpc.ServiceRegistrar, srv ConsumerIrManagerServiceServer)

Types

type ConsumerIrManagerCarrierFrequencyRangeServiceClient

type ConsumerIrManagerCarrierFrequencyRangeServiceClient interface {
	GetMaxFrequency(ctx context.Context, in *GetMaxFrequencyRequest, opts ...grpc.CallOption) (*GetMaxFrequencyResponse, error)
	GetMinFrequency(ctx context.Context, in *GetMinFrequencyRequest, opts ...grpc.CallOption) (*GetMinFrequencyResponse, error)
}

ConsumerIrManagerCarrierFrequencyRangeServiceClient is the client API for ConsumerIrManagerCarrierFrequencyRangeService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type ConsumerIrManagerCarrierFrequencyRangeServiceServer

type ConsumerIrManagerCarrierFrequencyRangeServiceServer interface {
	GetMaxFrequency(context.Context, *GetMaxFrequencyRequest) (*GetMaxFrequencyResponse, error)
	GetMinFrequency(context.Context, *GetMinFrequencyRequest) (*GetMinFrequencyResponse, error)
	// contains filtered or unexported methods
}

ConsumerIrManagerCarrierFrequencyRangeServiceServer is the server API for ConsumerIrManagerCarrierFrequencyRangeService service. All implementations must embed UnimplementedConsumerIrManagerCarrierFrequencyRangeServiceServer for forward compatibility.

type ConsumerIrManagerServiceClient

type ConsumerIrManagerServiceClient interface {
	GetCarrierFrequencies(ctx context.Context, in *GetCarrierFrequenciesRequest, opts ...grpc.CallOption) (*GetCarrierFrequenciesResponse, error)
	HasIrEmitter(ctx context.Context, in *HasIrEmitterRequest, opts ...grpc.CallOption) (*HasIrEmitterResponse, error)
	Transmit(ctx context.Context, in *TransmitRequest, opts ...grpc.CallOption) (*TransmitResponse, error)
}

ConsumerIrManagerServiceClient is the client API for ConsumerIrManagerService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type ConsumerIrManagerServiceServer

type ConsumerIrManagerServiceServer interface {
	GetCarrierFrequencies(context.Context, *GetCarrierFrequenciesRequest) (*GetCarrierFrequenciesResponse, error)
	HasIrEmitter(context.Context, *HasIrEmitterRequest) (*HasIrEmitterResponse, error)
	Transmit(context.Context, *TransmitRequest) (*TransmitResponse, error)
	// contains filtered or unexported methods
}

ConsumerIrManagerServiceServer is the server API for ConsumerIrManagerService service. All implementations must embed UnimplementedConsumerIrManagerServiceServer for forward compatibility.

type GetCarrierFrequenciesRequest

type GetCarrierFrequenciesRequest struct {
	// contains filtered or unexported fields
}

func (*GetCarrierFrequenciesRequest) Descriptor deprecated

func (*GetCarrierFrequenciesRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetCarrierFrequenciesRequest.ProtoReflect.Descriptor instead.

func (*GetCarrierFrequenciesRequest) ProtoMessage

func (*GetCarrierFrequenciesRequest) ProtoMessage()

func (*GetCarrierFrequenciesRequest) ProtoReflect

func (*GetCarrierFrequenciesRequest) Reset

func (x *GetCarrierFrequenciesRequest) Reset()

func (*GetCarrierFrequenciesRequest) String

type GetCarrierFrequenciesResponse

type GetCarrierFrequenciesResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetCarrierFrequenciesResponse) Descriptor deprecated

func (*GetCarrierFrequenciesResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetCarrierFrequenciesResponse.ProtoReflect.Descriptor instead.

func (*GetCarrierFrequenciesResponse) GetResult

func (x *GetCarrierFrequenciesResponse) GetResult() int64

func (*GetCarrierFrequenciesResponse) ProtoMessage

func (*GetCarrierFrequenciesResponse) ProtoMessage()

func (*GetCarrierFrequenciesResponse) ProtoReflect

func (*GetCarrierFrequenciesResponse) Reset

func (x *GetCarrierFrequenciesResponse) Reset()

func (*GetCarrierFrequenciesResponse) String

type GetMaxFrequencyRequest

type GetMaxFrequencyRequest struct {
	// contains filtered or unexported fields
}

func (*GetMaxFrequencyRequest) Descriptor deprecated

func (*GetMaxFrequencyRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetMaxFrequencyRequest.ProtoReflect.Descriptor instead.

func (*GetMaxFrequencyRequest) ProtoMessage

func (*GetMaxFrequencyRequest) ProtoMessage()

func (*GetMaxFrequencyRequest) ProtoReflect

func (x *GetMaxFrequencyRequest) ProtoReflect() protoreflect.Message

func (*GetMaxFrequencyRequest) Reset

func (x *GetMaxFrequencyRequest) Reset()

func (*GetMaxFrequencyRequest) String

func (x *GetMaxFrequencyRequest) String() string

type GetMaxFrequencyResponse

type GetMaxFrequencyResponse struct {
	Result int32 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetMaxFrequencyResponse) Descriptor deprecated

func (*GetMaxFrequencyResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetMaxFrequencyResponse.ProtoReflect.Descriptor instead.

func (*GetMaxFrequencyResponse) GetResult

func (x *GetMaxFrequencyResponse) GetResult() int32

func (*GetMaxFrequencyResponse) ProtoMessage

func (*GetMaxFrequencyResponse) ProtoMessage()

func (*GetMaxFrequencyResponse) ProtoReflect

func (x *GetMaxFrequencyResponse) ProtoReflect() protoreflect.Message

func (*GetMaxFrequencyResponse) Reset

func (x *GetMaxFrequencyResponse) Reset()

func (*GetMaxFrequencyResponse) String

func (x *GetMaxFrequencyResponse) String() string

type GetMinFrequencyRequest

type GetMinFrequencyRequest struct {
	// contains filtered or unexported fields
}

func (*GetMinFrequencyRequest) Descriptor deprecated

func (*GetMinFrequencyRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetMinFrequencyRequest.ProtoReflect.Descriptor instead.

func (*GetMinFrequencyRequest) ProtoMessage

func (*GetMinFrequencyRequest) ProtoMessage()

func (*GetMinFrequencyRequest) ProtoReflect

func (x *GetMinFrequencyRequest) ProtoReflect() protoreflect.Message

func (*GetMinFrequencyRequest) Reset

func (x *GetMinFrequencyRequest) Reset()

func (*GetMinFrequencyRequest) String

func (x *GetMinFrequencyRequest) String() string

type GetMinFrequencyResponse

type GetMinFrequencyResponse struct {
	Result int32 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*GetMinFrequencyResponse) Descriptor deprecated

func (*GetMinFrequencyResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetMinFrequencyResponse.ProtoReflect.Descriptor instead.

func (*GetMinFrequencyResponse) GetResult

func (x *GetMinFrequencyResponse) GetResult() int32

func (*GetMinFrequencyResponse) ProtoMessage

func (*GetMinFrequencyResponse) ProtoMessage()

func (*GetMinFrequencyResponse) ProtoReflect

func (x *GetMinFrequencyResponse) ProtoReflect() protoreflect.Message

func (*GetMinFrequencyResponse) Reset

func (x *GetMinFrequencyResponse) Reset()

func (*GetMinFrequencyResponse) String

func (x *GetMinFrequencyResponse) String() string

type HasIrEmitterRequest

type HasIrEmitterRequest struct {
	// contains filtered or unexported fields
}

func (*HasIrEmitterRequest) Descriptor deprecated

func (*HasIrEmitterRequest) Descriptor() ([]byte, []int)

Deprecated: Use HasIrEmitterRequest.ProtoReflect.Descriptor instead.

func (*HasIrEmitterRequest) ProtoMessage

func (*HasIrEmitterRequest) ProtoMessage()

func (*HasIrEmitterRequest) ProtoReflect

func (x *HasIrEmitterRequest) ProtoReflect() protoreflect.Message

func (*HasIrEmitterRequest) Reset

func (x *HasIrEmitterRequest) Reset()

func (*HasIrEmitterRequest) String

func (x *HasIrEmitterRequest) String() string

type HasIrEmitterResponse

type HasIrEmitterResponse struct {
	Result bool `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*HasIrEmitterResponse) Descriptor deprecated

func (*HasIrEmitterResponse) Descriptor() ([]byte, []int)

Deprecated: Use HasIrEmitterResponse.ProtoReflect.Descriptor instead.

func (*HasIrEmitterResponse) GetResult

func (x *HasIrEmitterResponse) GetResult() bool

func (*HasIrEmitterResponse) ProtoMessage

func (*HasIrEmitterResponse) ProtoMessage()

func (*HasIrEmitterResponse) ProtoReflect

func (x *HasIrEmitterResponse) ProtoReflect() protoreflect.Message

func (*HasIrEmitterResponse) Reset

func (x *HasIrEmitterResponse) Reset()

func (*HasIrEmitterResponse) String

func (x *HasIrEmitterResponse) String() string

type TransmitRequest

type TransmitRequest struct {
	Arg0 int32 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	Arg1 int64 `protobuf:"varint,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
	// contains filtered or unexported fields
}

func (*TransmitRequest) Descriptor deprecated

func (*TransmitRequest) Descriptor() ([]byte, []int)

Deprecated: Use TransmitRequest.ProtoReflect.Descriptor instead.

func (*TransmitRequest) GetArg0

func (x *TransmitRequest) GetArg0() int32

func (*TransmitRequest) GetArg1

func (x *TransmitRequest) GetArg1() int64

func (*TransmitRequest) ProtoMessage

func (*TransmitRequest) ProtoMessage()

func (*TransmitRequest) ProtoReflect

func (x *TransmitRequest) ProtoReflect() protoreflect.Message

func (*TransmitRequest) Reset

func (x *TransmitRequest) Reset()

func (*TransmitRequest) String

func (x *TransmitRequest) String() string

type TransmitResponse

type TransmitResponse struct {
	// contains filtered or unexported fields
}

func (*TransmitResponse) Descriptor deprecated

func (*TransmitResponse) Descriptor() ([]byte, []int)

Deprecated: Use TransmitResponse.ProtoReflect.Descriptor instead.

func (*TransmitResponse) ProtoMessage

func (*TransmitResponse) ProtoMessage()

func (*TransmitResponse) ProtoReflect

func (x *TransmitResponse) ProtoReflect() protoreflect.Message

func (*TransmitResponse) Reset

func (x *TransmitResponse) Reset()

func (*TransmitResponse) String

func (x *TransmitResponse) String() string

type UnimplementedConsumerIrManagerCarrierFrequencyRangeServiceServer

type UnimplementedConsumerIrManagerCarrierFrequencyRangeServiceServer struct{}

UnimplementedConsumerIrManagerCarrierFrequencyRangeServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedConsumerIrManagerCarrierFrequencyRangeServiceServer) GetMaxFrequency

func (UnimplementedConsumerIrManagerCarrierFrequencyRangeServiceServer) GetMinFrequency

type UnimplementedConsumerIrManagerServiceServer

type UnimplementedConsumerIrManagerServiceServer struct{}

UnimplementedConsumerIrManagerServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedConsumerIrManagerServiceServer) GetCarrierFrequencies

func (UnimplementedConsumerIrManagerServiceServer) HasIrEmitter

func (UnimplementedConsumerIrManagerServiceServer) Transmit

type UnsafeConsumerIrManagerCarrierFrequencyRangeServiceServer

type UnsafeConsumerIrManagerCarrierFrequencyRangeServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeConsumerIrManagerCarrierFrequencyRangeServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ConsumerIrManagerCarrierFrequencyRangeServiceServer will result in compilation errors.

type UnsafeConsumerIrManagerServiceServer

type UnsafeConsumerIrManagerServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeConsumerIrManagerServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ConsumerIrManagerServiceServer will result in compilation errors.

Jump to