Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterAppJankStatsServiceServer(s grpc.ServiceRegistrar, srv AppJankStatsServiceServer)
- func RegisterRelativeFrameTimeHistogramServiceServer(s grpc.ServiceRegistrar, srv RelativeFrameTimeHistogramServiceServer)
- type AddRelativeFrameTimeMillisRequest
- func (*AddRelativeFrameTimeMillisRequest) Descriptor() ([]byte, []int)deprecated
- func (x *AddRelativeFrameTimeMillisRequest) GetArg0() int32
- func (x *AddRelativeFrameTimeMillisRequest) GetHandle() int64
- func (*AddRelativeFrameTimeMillisRequest) ProtoMessage()
- func (x *AddRelativeFrameTimeMillisRequest) ProtoReflect() protoreflect.Message
- func (x *AddRelativeFrameTimeMillisRequest) Reset()
- func (x *AddRelativeFrameTimeMillisRequest) String() string
- type AddRelativeFrameTimeMillisResponse
- func (*AddRelativeFrameTimeMillisResponse) Descriptor() ([]byte, []int)deprecated
- func (*AddRelativeFrameTimeMillisResponse) ProtoMessage()
- func (x *AddRelativeFrameTimeMillisResponse) ProtoReflect() protoreflect.Message
- func (x *AddRelativeFrameTimeMillisResponse) Reset()
- func (x *AddRelativeFrameTimeMillisResponse) String() string
- type AppJankStatsServiceClient
- type AppJankStatsServiceServer
- type GetBucketCountersRequest
- func (*GetBucketCountersRequest) Descriptor() ([]byte, []int)deprecated
- func (x *GetBucketCountersRequest) GetHandle() int64
- func (*GetBucketCountersRequest) ProtoMessage()
- func (x *GetBucketCountersRequest) ProtoReflect() protoreflect.Message
- func (x *GetBucketCountersRequest) Reset()
- func (x *GetBucketCountersRequest) String() string
- type GetBucketCountersResponse
- func (*GetBucketCountersResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetBucketCountersResponse) GetResult() int64
- func (*GetBucketCountersResponse) ProtoMessage()
- func (x *GetBucketCountersResponse) ProtoReflect() protoreflect.Message
- func (x *GetBucketCountersResponse) Reset()
- func (x *GetBucketCountersResponse) String() string
- type GetBucketEndpointsMillisRequest
- func (*GetBucketEndpointsMillisRequest) Descriptor() ([]byte, []int)deprecated
- func (x *GetBucketEndpointsMillisRequest) GetHandle() int64
- func (*GetBucketEndpointsMillisRequest) ProtoMessage()
- func (x *GetBucketEndpointsMillisRequest) ProtoReflect() protoreflect.Message
- func (x *GetBucketEndpointsMillisRequest) Reset()
- func (x *GetBucketEndpointsMillisRequest) String() string
- type GetBucketEndpointsMillisResponse
- func (*GetBucketEndpointsMillisResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetBucketEndpointsMillisResponse) GetResult() int64
- func (*GetBucketEndpointsMillisResponse) ProtoMessage()
- func (x *GetBucketEndpointsMillisResponse) ProtoReflect() protoreflect.Message
- func (x *GetBucketEndpointsMillisResponse) Reset()
- func (x *GetBucketEndpointsMillisResponse) String() string
- type GetJankyFrameCountRequest
- func (*GetJankyFrameCountRequest) Descriptor() ([]byte, []int)deprecated
- func (x *GetJankyFrameCountRequest) GetHandle() int64
- func (*GetJankyFrameCountRequest) ProtoMessage()
- func (x *GetJankyFrameCountRequest) ProtoReflect() protoreflect.Message
- func (x *GetJankyFrameCountRequest) Reset()
- func (x *GetJankyFrameCountRequest) String() string
- type GetJankyFrameCountResponse
- func (*GetJankyFrameCountResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetJankyFrameCountResponse) GetResult() int64
- func (*GetJankyFrameCountResponse) ProtoMessage()
- func (x *GetJankyFrameCountResponse) ProtoReflect() protoreflect.Message
- func (x *GetJankyFrameCountResponse) Reset()
- func (x *GetJankyFrameCountResponse) String() string
- type GetNavigationComponentRequest
- func (*GetNavigationComponentRequest) Descriptor() ([]byte, []int)deprecated
- func (x *GetNavigationComponentRequest) GetHandle() int64
- func (*GetNavigationComponentRequest) ProtoMessage()
- func (x *GetNavigationComponentRequest) ProtoReflect() protoreflect.Message
- func (x *GetNavigationComponentRequest) Reset()
- func (x *GetNavigationComponentRequest) String() string
- type GetNavigationComponentResponse
- func (*GetNavigationComponentResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetNavigationComponentResponse) GetResult() string
- func (*GetNavigationComponentResponse) ProtoMessage()
- func (x *GetNavigationComponentResponse) ProtoReflect() protoreflect.Message
- func (x *GetNavigationComponentResponse) Reset()
- func (x *GetNavigationComponentResponse) String() string
- type GetRelativeFrameTimeHistogramRequest
- func (*GetRelativeFrameTimeHistogramRequest) Descriptor() ([]byte, []int)deprecated
- func (x *GetRelativeFrameTimeHistogramRequest) GetHandle() int64
- func (*GetRelativeFrameTimeHistogramRequest) ProtoMessage()
- func (x *GetRelativeFrameTimeHistogramRequest) ProtoReflect() protoreflect.Message
- func (x *GetRelativeFrameTimeHistogramRequest) Reset()
- func (x *GetRelativeFrameTimeHistogramRequest) String() string
- type GetRelativeFrameTimeHistogramResponse
- func (*GetRelativeFrameTimeHistogramResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetRelativeFrameTimeHistogramResponse) GetResult() int64
- func (*GetRelativeFrameTimeHistogramResponse) ProtoMessage()
- func (x *GetRelativeFrameTimeHistogramResponse) ProtoReflect() protoreflect.Message
- func (x *GetRelativeFrameTimeHistogramResponse) Reset()
- func (x *GetRelativeFrameTimeHistogramResponse) String() string
- type GetTotalFrameCountRequest
- func (*GetTotalFrameCountRequest) Descriptor() ([]byte, []int)deprecated
- func (x *GetTotalFrameCountRequest) GetHandle() int64
- func (*GetTotalFrameCountRequest) ProtoMessage()
- func (x *GetTotalFrameCountRequest) ProtoReflect() protoreflect.Message
- func (x *GetTotalFrameCountRequest) Reset()
- func (x *GetTotalFrameCountRequest) String() string
- type GetTotalFrameCountResponse
- func (*GetTotalFrameCountResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetTotalFrameCountResponse) GetResult() int64
- func (*GetTotalFrameCountResponse) ProtoMessage()
- func (x *GetTotalFrameCountResponse) ProtoReflect() protoreflect.Message
- func (x *GetTotalFrameCountResponse) Reset()
- func (x *GetTotalFrameCountResponse) String() string
- type GetUidRequest
- type GetUidResponse
- type GetWidgetCategoryRequest
- func (*GetWidgetCategoryRequest) Descriptor() ([]byte, []int)deprecated
- func (x *GetWidgetCategoryRequest) GetHandle() int64
- func (*GetWidgetCategoryRequest) ProtoMessage()
- func (x *GetWidgetCategoryRequest) ProtoReflect() protoreflect.Message
- func (x *GetWidgetCategoryRequest) Reset()
- func (x *GetWidgetCategoryRequest) String() string
- type GetWidgetCategoryResponse
- func (*GetWidgetCategoryResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetWidgetCategoryResponse) GetResult() string
- func (*GetWidgetCategoryResponse) ProtoMessage()
- func (x *GetWidgetCategoryResponse) ProtoReflect() protoreflect.Message
- func (x *GetWidgetCategoryResponse) Reset()
- func (x *GetWidgetCategoryResponse) String() string
- type GetWidgetIdRequest
- func (*GetWidgetIdRequest) Descriptor() ([]byte, []int)deprecated
- func (x *GetWidgetIdRequest) GetHandle() int64
- func (*GetWidgetIdRequest) ProtoMessage()
- func (x *GetWidgetIdRequest) ProtoReflect() protoreflect.Message
- func (x *GetWidgetIdRequest) Reset()
- func (x *GetWidgetIdRequest) String() string
- type GetWidgetIdResponse
- func (*GetWidgetIdResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetWidgetIdResponse) GetResult() string
- func (*GetWidgetIdResponse) ProtoMessage()
- func (x *GetWidgetIdResponse) ProtoReflect() protoreflect.Message
- func (x *GetWidgetIdResponse) Reset()
- func (x *GetWidgetIdResponse) String() string
- type GetWidgetStateRequest
- func (*GetWidgetStateRequest) Descriptor() ([]byte, []int)deprecated
- func (x *GetWidgetStateRequest) GetHandle() int64
- func (*GetWidgetStateRequest) ProtoMessage()
- func (x *GetWidgetStateRequest) ProtoReflect() protoreflect.Message
- func (x *GetWidgetStateRequest) Reset()
- func (x *GetWidgetStateRequest) String() string
- type GetWidgetStateResponse
- func (*GetWidgetStateResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetWidgetStateResponse) GetResult() string
- func (*GetWidgetStateResponse) ProtoMessage()
- func (x *GetWidgetStateResponse) ProtoReflect() protoreflect.Message
- func (x *GetWidgetStateResponse) Reset()
- func (x *GetWidgetStateResponse) String() string
- type NewAppJankStatsRequest
- func (*NewAppJankStatsRequest) Descriptor() ([]byte, []int)deprecated
- func (x *NewAppJankStatsRequest) GetArg0() int32
- func (x *NewAppJankStatsRequest) GetArg1() string
- func (x *NewAppJankStatsRequest) GetArg2() string
- func (x *NewAppJankStatsRequest) GetArg3() string
- func (x *NewAppJankStatsRequest) GetArg4() string
- func (x *NewAppJankStatsRequest) GetArg5() int64
- func (x *NewAppJankStatsRequest) GetArg6() int64
- func (x *NewAppJankStatsRequest) GetArg7() int64
- func (*NewAppJankStatsRequest) ProtoMessage()
- func (x *NewAppJankStatsRequest) ProtoReflect() protoreflect.Message
- func (x *NewAppJankStatsRequest) Reset()
- func (x *NewAppJankStatsRequest) String() string
- type NewAppJankStatsResponse
- func (*NewAppJankStatsResponse) Descriptor() ([]byte, []int)deprecated
- func (x *NewAppJankStatsResponse) GetResult() int64
- func (*NewAppJankStatsResponse) ProtoMessage()
- func (x *NewAppJankStatsResponse) ProtoReflect() protoreflect.Message
- func (x *NewAppJankStatsResponse) Reset()
- func (x *NewAppJankStatsResponse) String() string
- type NewRelativeFrameTimeHistogramRequest
- func (*NewRelativeFrameTimeHistogramRequest) Descriptor() ([]byte, []int)deprecated
- func (*NewRelativeFrameTimeHistogramRequest) ProtoMessage()
- func (x *NewRelativeFrameTimeHistogramRequest) ProtoReflect() protoreflect.Message
- func (x *NewRelativeFrameTimeHistogramRequest) Reset()
- func (x *NewRelativeFrameTimeHistogramRequest) String() string
- type NewRelativeFrameTimeHistogramResponse
- func (*NewRelativeFrameTimeHistogramResponse) Descriptor() ([]byte, []int)deprecated
- func (x *NewRelativeFrameTimeHistogramResponse) GetResult() int64
- func (*NewRelativeFrameTimeHistogramResponse) ProtoMessage()
- func (x *NewRelativeFrameTimeHistogramResponse) ProtoReflect() protoreflect.Message
- func (x *NewRelativeFrameTimeHistogramResponse) Reset()
- func (x *NewRelativeFrameTimeHistogramResponse) String() string
- type RelativeFrameTimeHistogramServiceClient
- type RelativeFrameTimeHistogramServiceServer
- type UnimplementedAppJankStatsServiceServer
- func (UnimplementedAppJankStatsServiceServer) GetJankyFrameCount(context.Context, *GetJankyFrameCountRequest) (*GetJankyFrameCountResponse, error)
- func (UnimplementedAppJankStatsServiceServer) GetNavigationComponent(context.Context, *GetNavigationComponentRequest) (*GetNavigationComponentResponse, error)
- func (UnimplementedAppJankStatsServiceServer) GetRelativeFrameTimeHistogram(context.Context, *GetRelativeFrameTimeHistogramRequest) (*GetRelativeFrameTimeHistogramResponse, error)
- func (UnimplementedAppJankStatsServiceServer) GetTotalFrameCount(context.Context, *GetTotalFrameCountRequest) (*GetTotalFrameCountResponse, error)
- func (UnimplementedAppJankStatsServiceServer) GetUid(context.Context, *GetUidRequest) (*GetUidResponse, error)
- func (UnimplementedAppJankStatsServiceServer) GetWidgetCategory(context.Context, *GetWidgetCategoryRequest) (*GetWidgetCategoryResponse, error)
- func (UnimplementedAppJankStatsServiceServer) GetWidgetId(context.Context, *GetWidgetIdRequest) (*GetWidgetIdResponse, error)
- func (UnimplementedAppJankStatsServiceServer) GetWidgetState(context.Context, *GetWidgetStateRequest) (*GetWidgetStateResponse, error)
- func (UnimplementedAppJankStatsServiceServer) NewAppJankStats(context.Context, *NewAppJankStatsRequest) (*NewAppJankStatsResponse, error)
- type UnimplementedRelativeFrameTimeHistogramServiceServer
- func (UnimplementedRelativeFrameTimeHistogramServiceServer) AddRelativeFrameTimeMillis(context.Context, *AddRelativeFrameTimeMillisRequest) (*AddRelativeFrameTimeMillisResponse, error)
- func (UnimplementedRelativeFrameTimeHistogramServiceServer) GetBucketCounters(context.Context, *GetBucketCountersRequest) (*GetBucketCountersResponse, error)
- func (UnimplementedRelativeFrameTimeHistogramServiceServer) GetBucketEndpointsMillis(context.Context, *GetBucketEndpointsMillisRequest) (*GetBucketEndpointsMillisResponse, error)
- func (UnimplementedRelativeFrameTimeHistogramServiceServer) NewRelativeFrameTimeHistogram(context.Context, *NewRelativeFrameTimeHistogramRequest) (*NewRelativeFrameTimeHistogramResponse, error)
- type UnsafeAppJankStatsServiceServer
- type UnsafeRelativeFrameTimeHistogramServiceServer
Constants ¶
const ( AppJankStatsService_NewAppJankStats_FullMethodName = "/jank.AppJankStatsService/NewAppJankStats" AppJankStatsService_GetJankyFrameCount_FullMethodName = "/jank.AppJankStatsService/GetJankyFrameCount" AppJankStatsService_GetRelativeFrameTimeHistogram_FullMethodName = "/jank.AppJankStatsService/GetRelativeFrameTimeHistogram" AppJankStatsService_GetTotalFrameCount_FullMethodName = "/jank.AppJankStatsService/GetTotalFrameCount" AppJankStatsService_GetUid_FullMethodName = "/jank.AppJankStatsService/GetUid" AppJankStatsService_GetWidgetCategory_FullMethodName = "/jank.AppJankStatsService/GetWidgetCategory" AppJankStatsService_GetWidgetId_FullMethodName = "/jank.AppJankStatsService/GetWidgetId" AppJankStatsService_GetWidgetState_FullMethodName = "/jank.AppJankStatsService/GetWidgetState" )
const ( RelativeFrameTimeHistogramService_NewRelativeFrameTimeHistogram_FullMethodName = "/jank.RelativeFrameTimeHistogramService/NewRelativeFrameTimeHistogram" RelativeFrameTimeHistogramService_AddRelativeFrameTimeMillis_FullMethodName = "/jank.RelativeFrameTimeHistogramService/AddRelativeFrameTimeMillis" RelativeFrameTimeHistogramService_GetBucketCounters_FullMethodName = "/jank.RelativeFrameTimeHistogramService/GetBucketCounters" RelativeFrameTimeHistogramService_GetBucketEndpointsMillis_FullMethodName = "/jank.RelativeFrameTimeHistogramService/GetBucketEndpointsMillis" )
Variables ¶
var AppJankStatsService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "jank.AppJankStatsService", HandlerType: (*AppJankStatsServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "NewAppJankStats", Handler: _AppJankStatsService_NewAppJankStats_Handler, }, { MethodName: "GetJankyFrameCount", Handler: _AppJankStatsService_GetJankyFrameCount_Handler, }, { MethodName: "GetNavigationComponent", Handler: _AppJankStatsService_GetNavigationComponent_Handler, }, { MethodName: "GetRelativeFrameTimeHistogram", Handler: _AppJankStatsService_GetRelativeFrameTimeHistogram_Handler, }, { MethodName: "GetTotalFrameCount", Handler: _AppJankStatsService_GetTotalFrameCount_Handler, }, { MethodName: "GetUid", Handler: _AppJankStatsService_GetUid_Handler, }, { MethodName: "GetWidgetCategory", Handler: _AppJankStatsService_GetWidgetCategory_Handler, }, { MethodName: "GetWidgetId", Handler: _AppJankStatsService_GetWidgetId_Handler, }, { MethodName: "GetWidgetState", Handler: _AppJankStatsService_GetWidgetState_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "proto/jank/jank.proto", }
AppJankStatsService_ServiceDesc is the grpc.ServiceDesc for AppJankStatsService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var File_proto_jank_jank_proto protoreflect.FileDescriptor
var RelativeFrameTimeHistogramService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "jank.RelativeFrameTimeHistogramService", HandlerType: (*RelativeFrameTimeHistogramServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "NewRelativeFrameTimeHistogram", Handler: _RelativeFrameTimeHistogramService_NewRelativeFrameTimeHistogram_Handler, }, { MethodName: "AddRelativeFrameTimeMillis", Handler: _RelativeFrameTimeHistogramService_AddRelativeFrameTimeMillis_Handler, }, { MethodName: "GetBucketCounters", Handler: _RelativeFrameTimeHistogramService_GetBucketCounters_Handler, }, { MethodName: "GetBucketEndpointsMillis", Handler: _RelativeFrameTimeHistogramService_GetBucketEndpointsMillis_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "proto/jank/jank.proto", }
RelativeFrameTimeHistogramService_ServiceDesc is the grpc.ServiceDesc for RelativeFrameTimeHistogramService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterAppJankStatsServiceServer ¶
func RegisterAppJankStatsServiceServer(s grpc.ServiceRegistrar, srv AppJankStatsServiceServer)
func RegisterRelativeFrameTimeHistogramServiceServer ¶
func RegisterRelativeFrameTimeHistogramServiceServer(s grpc.ServiceRegistrar, srv RelativeFrameTimeHistogramServiceServer)
Types ¶
type AddRelativeFrameTimeMillisRequest ¶
type AddRelativeFrameTimeMillisRequest struct {
Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
Arg0 int32 `protobuf:"varint,2,opt,name=arg0,proto3" json:"arg0,omitempty"`
// contains filtered or unexported fields
}
func (*AddRelativeFrameTimeMillisRequest) Descriptor
deprecated
func (*AddRelativeFrameTimeMillisRequest) Descriptor() ([]byte, []int)
Deprecated: Use AddRelativeFrameTimeMillisRequest.ProtoReflect.Descriptor instead.
func (*AddRelativeFrameTimeMillisRequest) GetArg0 ¶
func (x *AddRelativeFrameTimeMillisRequest) GetArg0() int32
func (*AddRelativeFrameTimeMillisRequest) GetHandle ¶
func (x *AddRelativeFrameTimeMillisRequest) GetHandle() int64
func (*AddRelativeFrameTimeMillisRequest) ProtoMessage ¶
func (*AddRelativeFrameTimeMillisRequest) ProtoMessage()
func (*AddRelativeFrameTimeMillisRequest) ProtoReflect ¶
func (x *AddRelativeFrameTimeMillisRequest) ProtoReflect() protoreflect.Message
func (*AddRelativeFrameTimeMillisRequest) Reset ¶
func (x *AddRelativeFrameTimeMillisRequest) Reset()
func (*AddRelativeFrameTimeMillisRequest) String ¶
func (x *AddRelativeFrameTimeMillisRequest) String() string
type AddRelativeFrameTimeMillisResponse ¶
type AddRelativeFrameTimeMillisResponse struct {
// contains filtered or unexported fields
}
func (*AddRelativeFrameTimeMillisResponse) Descriptor
deprecated
func (*AddRelativeFrameTimeMillisResponse) Descriptor() ([]byte, []int)
Deprecated: Use AddRelativeFrameTimeMillisResponse.ProtoReflect.Descriptor instead.
func (*AddRelativeFrameTimeMillisResponse) ProtoMessage ¶
func (*AddRelativeFrameTimeMillisResponse) ProtoMessage()
func (*AddRelativeFrameTimeMillisResponse) ProtoReflect ¶
func (x *AddRelativeFrameTimeMillisResponse) ProtoReflect() protoreflect.Message
func (*AddRelativeFrameTimeMillisResponse) Reset ¶
func (x *AddRelativeFrameTimeMillisResponse) Reset()
func (*AddRelativeFrameTimeMillisResponse) String ¶
func (x *AddRelativeFrameTimeMillisResponse) String() string
type AppJankStatsServiceClient ¶
type AppJankStatsServiceClient interface {
NewAppJankStats(ctx context.Context, in *NewAppJankStatsRequest, opts ...grpc.CallOption) (*NewAppJankStatsResponse, error)
GetJankyFrameCount(ctx context.Context, in *GetJankyFrameCountRequest, opts ...grpc.CallOption) (*GetJankyFrameCountResponse, error)
GetRelativeFrameTimeHistogram(ctx context.Context, in *GetRelativeFrameTimeHistogramRequest, opts ...grpc.CallOption) (*GetRelativeFrameTimeHistogramResponse, error)
GetTotalFrameCount(ctx context.Context, in *GetTotalFrameCountRequest, opts ...grpc.CallOption) (*GetTotalFrameCountResponse, error)
GetUid(ctx context.Context, in *GetUidRequest, opts ...grpc.CallOption) (*GetUidResponse, error)
GetWidgetCategory(ctx context.Context, in *GetWidgetCategoryRequest, opts ...grpc.CallOption) (*GetWidgetCategoryResponse, error)
GetWidgetId(ctx context.Context, in *GetWidgetIdRequest, opts ...grpc.CallOption) (*GetWidgetIdResponse, error)
GetWidgetState(ctx context.Context, in *GetWidgetStateRequest, opts ...grpc.CallOption) (*GetWidgetStateResponse, error)
}
AppJankStatsServiceClient is the client API for AppJankStatsService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewAppJankStatsServiceClient ¶
func NewAppJankStatsServiceClient(cc grpc.ClientConnInterface) AppJankStatsServiceClient
type AppJankStatsServiceServer ¶
type AppJankStatsServiceServer interface {
NewAppJankStats(context.Context, *NewAppJankStatsRequest) (*NewAppJankStatsResponse, error)
GetJankyFrameCount(context.Context, *GetJankyFrameCountRequest) (*GetJankyFrameCountResponse, error)
GetRelativeFrameTimeHistogram(context.Context, *GetRelativeFrameTimeHistogramRequest) (*GetRelativeFrameTimeHistogramResponse, error)
GetTotalFrameCount(context.Context, *GetTotalFrameCountRequest) (*GetTotalFrameCountResponse, error)
GetUid(context.Context, *GetUidRequest) (*GetUidResponse, error)
GetWidgetCategory(context.Context, *GetWidgetCategoryRequest) (*GetWidgetCategoryResponse, error)
GetWidgetId(context.Context, *GetWidgetIdRequest) (*GetWidgetIdResponse, error)
GetWidgetState(context.Context, *GetWidgetStateRequest) (*GetWidgetStateResponse, error)
// contains filtered or unexported methods
}
AppJankStatsServiceServer is the server API for AppJankStatsService service. All implementations must embed UnimplementedAppJankStatsServiceServer for forward compatibility.
type GetBucketCountersRequest ¶
type GetBucketCountersRequest struct {
Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
// contains filtered or unexported fields
}
func (*GetBucketCountersRequest) Descriptor
deprecated
func (*GetBucketCountersRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetBucketCountersRequest.ProtoReflect.Descriptor instead.
func (*GetBucketCountersRequest) GetHandle ¶
func (x *GetBucketCountersRequest) GetHandle() int64
func (*GetBucketCountersRequest) ProtoMessage ¶
func (*GetBucketCountersRequest) ProtoMessage()
func (*GetBucketCountersRequest) ProtoReflect ¶
func (x *GetBucketCountersRequest) ProtoReflect() protoreflect.Message
func (*GetBucketCountersRequest) Reset ¶
func (x *GetBucketCountersRequest) Reset()
func (*GetBucketCountersRequest) String ¶
func (x *GetBucketCountersRequest) String() string
type GetBucketCountersResponse ¶
type GetBucketCountersResponse struct {
Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*GetBucketCountersResponse) Descriptor
deprecated
func (*GetBucketCountersResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetBucketCountersResponse.ProtoReflect.Descriptor instead.
func (*GetBucketCountersResponse) GetResult ¶
func (x *GetBucketCountersResponse) GetResult() int64
func (*GetBucketCountersResponse) ProtoMessage ¶
func (*GetBucketCountersResponse) ProtoMessage()
func (*GetBucketCountersResponse) ProtoReflect ¶
func (x *GetBucketCountersResponse) ProtoReflect() protoreflect.Message
func (*GetBucketCountersResponse) Reset ¶
func (x *GetBucketCountersResponse) Reset()
func (*GetBucketCountersResponse) String ¶
func (x *GetBucketCountersResponse) String() string
type GetBucketEndpointsMillisRequest ¶
type GetBucketEndpointsMillisRequest struct {
Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
// contains filtered or unexported fields
}
func (*GetBucketEndpointsMillisRequest) Descriptor
deprecated
func (*GetBucketEndpointsMillisRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetBucketEndpointsMillisRequest.ProtoReflect.Descriptor instead.
func (*GetBucketEndpointsMillisRequest) GetHandle ¶
func (x *GetBucketEndpointsMillisRequest) GetHandle() int64
func (*GetBucketEndpointsMillisRequest) ProtoMessage ¶
func (*GetBucketEndpointsMillisRequest) ProtoMessage()
func (*GetBucketEndpointsMillisRequest) ProtoReflect ¶
func (x *GetBucketEndpointsMillisRequest) ProtoReflect() protoreflect.Message
func (*GetBucketEndpointsMillisRequest) Reset ¶
func (x *GetBucketEndpointsMillisRequest) Reset()
func (*GetBucketEndpointsMillisRequest) String ¶
func (x *GetBucketEndpointsMillisRequest) String() string
type GetBucketEndpointsMillisResponse ¶
type GetBucketEndpointsMillisResponse struct {
Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*GetBucketEndpointsMillisResponse) Descriptor
deprecated
func (*GetBucketEndpointsMillisResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetBucketEndpointsMillisResponse.ProtoReflect.Descriptor instead.
func (*GetBucketEndpointsMillisResponse) GetResult ¶
func (x *GetBucketEndpointsMillisResponse) GetResult() int64
func (*GetBucketEndpointsMillisResponse) ProtoMessage ¶
func (*GetBucketEndpointsMillisResponse) ProtoMessage()
func (*GetBucketEndpointsMillisResponse) ProtoReflect ¶
func (x *GetBucketEndpointsMillisResponse) ProtoReflect() protoreflect.Message
func (*GetBucketEndpointsMillisResponse) Reset ¶
func (x *GetBucketEndpointsMillisResponse) Reset()
func (*GetBucketEndpointsMillisResponse) String ¶
func (x *GetBucketEndpointsMillisResponse) String() string
type GetJankyFrameCountRequest ¶
type GetJankyFrameCountRequest struct {
Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
// contains filtered or unexported fields
}
func (*GetJankyFrameCountRequest) Descriptor
deprecated
func (*GetJankyFrameCountRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetJankyFrameCountRequest.ProtoReflect.Descriptor instead.
func (*GetJankyFrameCountRequest) GetHandle ¶
func (x *GetJankyFrameCountRequest) GetHandle() int64
func (*GetJankyFrameCountRequest) ProtoMessage ¶
func (*GetJankyFrameCountRequest) ProtoMessage()
func (*GetJankyFrameCountRequest) ProtoReflect ¶
func (x *GetJankyFrameCountRequest) ProtoReflect() protoreflect.Message
func (*GetJankyFrameCountRequest) Reset ¶
func (x *GetJankyFrameCountRequest) Reset()
func (*GetJankyFrameCountRequest) String ¶
func (x *GetJankyFrameCountRequest) String() string
type GetJankyFrameCountResponse ¶
type GetJankyFrameCountResponse struct {
Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*GetJankyFrameCountResponse) Descriptor
deprecated
func (*GetJankyFrameCountResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetJankyFrameCountResponse.ProtoReflect.Descriptor instead.
func (*GetJankyFrameCountResponse) GetResult ¶
func (x *GetJankyFrameCountResponse) GetResult() int64
func (*GetJankyFrameCountResponse) ProtoMessage ¶
func (*GetJankyFrameCountResponse) ProtoMessage()
func (*GetJankyFrameCountResponse) ProtoReflect ¶
func (x *GetJankyFrameCountResponse) ProtoReflect() protoreflect.Message
func (*GetJankyFrameCountResponse) Reset ¶
func (x *GetJankyFrameCountResponse) Reset()
func (*GetJankyFrameCountResponse) String ¶
func (x *GetJankyFrameCountResponse) String() string
type GetNavigationComponentRequest ¶
type GetNavigationComponentRequest struct {
// contains filtered or unexported fields
}
func (*GetNavigationComponentRequest) Descriptor
deprecated
func (*GetNavigationComponentRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetNavigationComponentRequest.ProtoReflect.Descriptor instead.
func (*GetNavigationComponentRequest) GetHandle ¶
func (x *GetNavigationComponentRequest) GetHandle() int64
func (*GetNavigationComponentRequest) ProtoMessage ¶
func (*GetNavigationComponentRequest) ProtoMessage()
func (*GetNavigationComponentRequest) ProtoReflect ¶
func (x *GetNavigationComponentRequest) ProtoReflect() protoreflect.Message
func (*GetNavigationComponentRequest) Reset ¶
func (x *GetNavigationComponentRequest) Reset()
func (*GetNavigationComponentRequest) String ¶
func (x *GetNavigationComponentRequest) String() string
type GetNavigationComponentResponse ¶
type GetNavigationComponentResponse struct {
// contains filtered or unexported fields
}
func (*GetNavigationComponentResponse) Descriptor
deprecated
func (*GetNavigationComponentResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetNavigationComponentResponse.ProtoReflect.Descriptor instead.
func (*GetNavigationComponentResponse) GetResult ¶
func (x *GetNavigationComponentResponse) GetResult() string
func (*GetNavigationComponentResponse) ProtoMessage ¶
func (*GetNavigationComponentResponse) ProtoMessage()
func (*GetNavigationComponentResponse) ProtoReflect ¶
func (x *GetNavigationComponentResponse) ProtoReflect() protoreflect.Message
func (*GetNavigationComponentResponse) Reset ¶
func (x *GetNavigationComponentResponse) Reset()
func (*GetNavigationComponentResponse) String ¶
func (x *GetNavigationComponentResponse) String() string
type GetRelativeFrameTimeHistogramRequest ¶
type GetRelativeFrameTimeHistogramRequest struct {
Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
// contains filtered or unexported fields
}
func (*GetRelativeFrameTimeHistogramRequest) Descriptor
deprecated
func (*GetRelativeFrameTimeHistogramRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetRelativeFrameTimeHistogramRequest.ProtoReflect.Descriptor instead.
func (*GetRelativeFrameTimeHistogramRequest) GetHandle ¶
func (x *GetRelativeFrameTimeHistogramRequest) GetHandle() int64
func (*GetRelativeFrameTimeHistogramRequest) ProtoMessage ¶
func (*GetRelativeFrameTimeHistogramRequest) ProtoMessage()
func (*GetRelativeFrameTimeHistogramRequest) ProtoReflect ¶
func (x *GetRelativeFrameTimeHistogramRequest) ProtoReflect() protoreflect.Message
func (*GetRelativeFrameTimeHistogramRequest) Reset ¶
func (x *GetRelativeFrameTimeHistogramRequest) Reset()
func (*GetRelativeFrameTimeHistogramRequest) String ¶
func (x *GetRelativeFrameTimeHistogramRequest) String() string
type GetRelativeFrameTimeHistogramResponse ¶
type GetRelativeFrameTimeHistogramResponse struct {
Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*GetRelativeFrameTimeHistogramResponse) Descriptor
deprecated
func (*GetRelativeFrameTimeHistogramResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetRelativeFrameTimeHistogramResponse.ProtoReflect.Descriptor instead.
func (*GetRelativeFrameTimeHistogramResponse) GetResult ¶
func (x *GetRelativeFrameTimeHistogramResponse) GetResult() int64
func (*GetRelativeFrameTimeHistogramResponse) ProtoMessage ¶
func (*GetRelativeFrameTimeHistogramResponse) ProtoMessage()
func (*GetRelativeFrameTimeHistogramResponse) ProtoReflect ¶
func (x *GetRelativeFrameTimeHistogramResponse) ProtoReflect() protoreflect.Message
func (*GetRelativeFrameTimeHistogramResponse) Reset ¶
func (x *GetRelativeFrameTimeHistogramResponse) Reset()
func (*GetRelativeFrameTimeHistogramResponse) String ¶
func (x *GetRelativeFrameTimeHistogramResponse) String() string
type GetTotalFrameCountRequest ¶
type GetTotalFrameCountRequest struct {
Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
// contains filtered or unexported fields
}
func (*GetTotalFrameCountRequest) Descriptor
deprecated
func (*GetTotalFrameCountRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetTotalFrameCountRequest.ProtoReflect.Descriptor instead.
func (*GetTotalFrameCountRequest) GetHandle ¶
func (x *GetTotalFrameCountRequest) GetHandle() int64
func (*GetTotalFrameCountRequest) ProtoMessage ¶
func (*GetTotalFrameCountRequest) ProtoMessage()
func (*GetTotalFrameCountRequest) ProtoReflect ¶
func (x *GetTotalFrameCountRequest) ProtoReflect() protoreflect.Message
func (*GetTotalFrameCountRequest) Reset ¶
func (x *GetTotalFrameCountRequest) Reset()
func (*GetTotalFrameCountRequest) String ¶
func (x *GetTotalFrameCountRequest) String() string
type GetTotalFrameCountResponse ¶
type GetTotalFrameCountResponse struct {
Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*GetTotalFrameCountResponse) Descriptor
deprecated
func (*GetTotalFrameCountResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetTotalFrameCountResponse.ProtoReflect.Descriptor instead.
func (*GetTotalFrameCountResponse) GetResult ¶
func (x *GetTotalFrameCountResponse) GetResult() int64
func (*GetTotalFrameCountResponse) ProtoMessage ¶
func (*GetTotalFrameCountResponse) ProtoMessage()
func (*GetTotalFrameCountResponse) ProtoReflect ¶
func (x *GetTotalFrameCountResponse) ProtoReflect() protoreflect.Message
func (*GetTotalFrameCountResponse) Reset ¶
func (x *GetTotalFrameCountResponse) Reset()
func (*GetTotalFrameCountResponse) String ¶
func (x *GetTotalFrameCountResponse) String() string
type GetUidRequest ¶
type GetUidRequest struct {
Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
// contains filtered or unexported fields
}
func (*GetUidRequest) Descriptor
deprecated
func (*GetUidRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetUidRequest.ProtoReflect.Descriptor instead.
func (*GetUidRequest) GetHandle ¶
func (x *GetUidRequest) GetHandle() int64
func (*GetUidRequest) ProtoMessage ¶
func (*GetUidRequest) ProtoMessage()
func (*GetUidRequest) ProtoReflect ¶
func (x *GetUidRequest) ProtoReflect() protoreflect.Message
func (*GetUidRequest) Reset ¶
func (x *GetUidRequest) Reset()
func (*GetUidRequest) String ¶
func (x *GetUidRequest) String() string
type GetUidResponse ¶
type GetUidResponse struct {
Result int32 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*GetUidResponse) Descriptor
deprecated
func (*GetUidResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetUidResponse.ProtoReflect.Descriptor instead.
func (*GetUidResponse) GetResult ¶
func (x *GetUidResponse) GetResult() int32
func (*GetUidResponse) ProtoMessage ¶
func (*GetUidResponse) ProtoMessage()
func (*GetUidResponse) ProtoReflect ¶
func (x *GetUidResponse) ProtoReflect() protoreflect.Message
func (*GetUidResponse) Reset ¶
func (x *GetUidResponse) Reset()
func (*GetUidResponse) String ¶
func (x *GetUidResponse) String() string
type GetWidgetCategoryRequest ¶
type GetWidgetCategoryRequest struct {
Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
// contains filtered or unexported fields
}
func (*GetWidgetCategoryRequest) Descriptor
deprecated
func (*GetWidgetCategoryRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetWidgetCategoryRequest.ProtoReflect.Descriptor instead.
func (*GetWidgetCategoryRequest) GetHandle ¶
func (x *GetWidgetCategoryRequest) GetHandle() int64
func (*GetWidgetCategoryRequest) ProtoMessage ¶
func (*GetWidgetCategoryRequest) ProtoMessage()
func (*GetWidgetCategoryRequest) ProtoReflect ¶
func (x *GetWidgetCategoryRequest) ProtoReflect() protoreflect.Message
func (*GetWidgetCategoryRequest) Reset ¶
func (x *GetWidgetCategoryRequest) Reset()
func (*GetWidgetCategoryRequest) String ¶
func (x *GetWidgetCategoryRequest) String() string
type GetWidgetCategoryResponse ¶
type GetWidgetCategoryResponse struct {
Result string `protobuf:"bytes,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*GetWidgetCategoryResponse) Descriptor
deprecated
func (*GetWidgetCategoryResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetWidgetCategoryResponse.ProtoReflect.Descriptor instead.
func (*GetWidgetCategoryResponse) GetResult ¶
func (x *GetWidgetCategoryResponse) GetResult() string
func (*GetWidgetCategoryResponse) ProtoMessage ¶
func (*GetWidgetCategoryResponse) ProtoMessage()
func (*GetWidgetCategoryResponse) ProtoReflect ¶
func (x *GetWidgetCategoryResponse) ProtoReflect() protoreflect.Message
func (*GetWidgetCategoryResponse) Reset ¶
func (x *GetWidgetCategoryResponse) Reset()
func (*GetWidgetCategoryResponse) String ¶
func (x *GetWidgetCategoryResponse) String() string
type GetWidgetIdRequest ¶
type GetWidgetIdRequest struct {
Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
// contains filtered or unexported fields
}
func (*GetWidgetIdRequest) Descriptor
deprecated
func (*GetWidgetIdRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetWidgetIdRequest.ProtoReflect.Descriptor instead.
func (*GetWidgetIdRequest) GetHandle ¶
func (x *GetWidgetIdRequest) GetHandle() int64
func (*GetWidgetIdRequest) ProtoMessage ¶
func (*GetWidgetIdRequest) ProtoMessage()
func (*GetWidgetIdRequest) ProtoReflect ¶
func (x *GetWidgetIdRequest) ProtoReflect() protoreflect.Message
func (*GetWidgetIdRequest) Reset ¶
func (x *GetWidgetIdRequest) Reset()
func (*GetWidgetIdRequest) String ¶
func (x *GetWidgetIdRequest) String() string
type GetWidgetIdResponse ¶
type GetWidgetIdResponse struct {
Result string `protobuf:"bytes,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*GetWidgetIdResponse) Descriptor
deprecated
func (*GetWidgetIdResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetWidgetIdResponse.ProtoReflect.Descriptor instead.
func (*GetWidgetIdResponse) GetResult ¶
func (x *GetWidgetIdResponse) GetResult() string
func (*GetWidgetIdResponse) ProtoMessage ¶
func (*GetWidgetIdResponse) ProtoMessage()
func (*GetWidgetIdResponse) ProtoReflect ¶
func (x *GetWidgetIdResponse) ProtoReflect() protoreflect.Message
func (*GetWidgetIdResponse) Reset ¶
func (x *GetWidgetIdResponse) Reset()
func (*GetWidgetIdResponse) String ¶
func (x *GetWidgetIdResponse) String() string
type GetWidgetStateRequest ¶
type GetWidgetStateRequest struct {
Handle int64 `protobuf:"varint,1,opt,name=handle,proto3" json:"handle,omitempty"`
// contains filtered or unexported fields
}
func (*GetWidgetStateRequest) Descriptor
deprecated
func (*GetWidgetStateRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetWidgetStateRequest.ProtoReflect.Descriptor instead.
func (*GetWidgetStateRequest) GetHandle ¶
func (x *GetWidgetStateRequest) GetHandle() int64
func (*GetWidgetStateRequest) ProtoMessage ¶
func (*GetWidgetStateRequest) ProtoMessage()
func (*GetWidgetStateRequest) ProtoReflect ¶
func (x *GetWidgetStateRequest) ProtoReflect() protoreflect.Message
func (*GetWidgetStateRequest) Reset ¶
func (x *GetWidgetStateRequest) Reset()
func (*GetWidgetStateRequest) String ¶
func (x *GetWidgetStateRequest) String() string
type GetWidgetStateResponse ¶
type GetWidgetStateResponse struct {
Result string `protobuf:"bytes,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*GetWidgetStateResponse) Descriptor
deprecated
func (*GetWidgetStateResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetWidgetStateResponse.ProtoReflect.Descriptor instead.
func (*GetWidgetStateResponse) GetResult ¶
func (x *GetWidgetStateResponse) GetResult() string
func (*GetWidgetStateResponse) ProtoMessage ¶
func (*GetWidgetStateResponse) ProtoMessage()
func (*GetWidgetStateResponse) ProtoReflect ¶
func (x *GetWidgetStateResponse) ProtoReflect() protoreflect.Message
func (*GetWidgetStateResponse) Reset ¶
func (x *GetWidgetStateResponse) Reset()
func (*GetWidgetStateResponse) String ¶
func (x *GetWidgetStateResponse) String() string
type NewAppJankStatsRequest ¶
type NewAppJankStatsRequest struct {
Arg0 int32 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
Arg1 string `protobuf:"bytes,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
Arg2 string `protobuf:"bytes,3,opt,name=arg2,proto3" json:"arg2,omitempty"`
Arg3 string `protobuf:"bytes,4,opt,name=arg3,proto3" json:"arg3,omitempty"`
Arg4 string `protobuf:"bytes,5,opt,name=arg4,proto3" json:"arg4,omitempty"`
Arg5 int64 `protobuf:"varint,6,opt,name=arg5,proto3" json:"arg5,omitempty"`
Arg6 int64 `protobuf:"varint,7,opt,name=arg6,proto3" json:"arg6,omitempty"`
Arg7 int64 `protobuf:"varint,8,opt,name=arg7,proto3" json:"arg7,omitempty"`
// contains filtered or unexported fields
}
func (*NewAppJankStatsRequest) Descriptor
deprecated
func (*NewAppJankStatsRequest) Descriptor() ([]byte, []int)
Deprecated: Use NewAppJankStatsRequest.ProtoReflect.Descriptor instead.
func (*NewAppJankStatsRequest) GetArg0 ¶
func (x *NewAppJankStatsRequest) GetArg0() int32
func (*NewAppJankStatsRequest) GetArg1 ¶
func (x *NewAppJankStatsRequest) GetArg1() string
func (*NewAppJankStatsRequest) GetArg2 ¶
func (x *NewAppJankStatsRequest) GetArg2() string
func (*NewAppJankStatsRequest) GetArg3 ¶
func (x *NewAppJankStatsRequest) GetArg3() string
func (*NewAppJankStatsRequest) GetArg4 ¶
func (x *NewAppJankStatsRequest) GetArg4() string
func (*NewAppJankStatsRequest) GetArg5 ¶
func (x *NewAppJankStatsRequest) GetArg5() int64
func (*NewAppJankStatsRequest) GetArg6 ¶
func (x *NewAppJankStatsRequest) GetArg6() int64
func (*NewAppJankStatsRequest) GetArg7 ¶
func (x *NewAppJankStatsRequest) GetArg7() int64
func (*NewAppJankStatsRequest) ProtoMessage ¶
func (*NewAppJankStatsRequest) ProtoMessage()
func (*NewAppJankStatsRequest) ProtoReflect ¶
func (x *NewAppJankStatsRequest) ProtoReflect() protoreflect.Message
func (*NewAppJankStatsRequest) Reset ¶
func (x *NewAppJankStatsRequest) Reset()
func (*NewAppJankStatsRequest) String ¶
func (x *NewAppJankStatsRequest) String() string
type NewAppJankStatsResponse ¶
type NewAppJankStatsResponse struct {
Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*NewAppJankStatsResponse) Descriptor
deprecated
func (*NewAppJankStatsResponse) Descriptor() ([]byte, []int)
Deprecated: Use NewAppJankStatsResponse.ProtoReflect.Descriptor instead.
func (*NewAppJankStatsResponse) GetResult ¶
func (x *NewAppJankStatsResponse) GetResult() int64
func (*NewAppJankStatsResponse) ProtoMessage ¶
func (*NewAppJankStatsResponse) ProtoMessage()
func (*NewAppJankStatsResponse) ProtoReflect ¶
func (x *NewAppJankStatsResponse) ProtoReflect() protoreflect.Message
func (*NewAppJankStatsResponse) Reset ¶
func (x *NewAppJankStatsResponse) Reset()
func (*NewAppJankStatsResponse) String ¶
func (x *NewAppJankStatsResponse) String() string
type NewRelativeFrameTimeHistogramRequest ¶
type NewRelativeFrameTimeHistogramRequest struct {
// contains filtered or unexported fields
}
func (*NewRelativeFrameTimeHistogramRequest) Descriptor
deprecated
func (*NewRelativeFrameTimeHistogramRequest) Descriptor() ([]byte, []int)
Deprecated: Use NewRelativeFrameTimeHistogramRequest.ProtoReflect.Descriptor instead.
func (*NewRelativeFrameTimeHistogramRequest) ProtoMessage ¶
func (*NewRelativeFrameTimeHistogramRequest) ProtoMessage()
func (*NewRelativeFrameTimeHistogramRequest) ProtoReflect ¶
func (x *NewRelativeFrameTimeHistogramRequest) ProtoReflect() protoreflect.Message
func (*NewRelativeFrameTimeHistogramRequest) Reset ¶
func (x *NewRelativeFrameTimeHistogramRequest) Reset()
func (*NewRelativeFrameTimeHistogramRequest) String ¶
func (x *NewRelativeFrameTimeHistogramRequest) String() string
type NewRelativeFrameTimeHistogramResponse ¶
type NewRelativeFrameTimeHistogramResponse struct {
Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*NewRelativeFrameTimeHistogramResponse) Descriptor
deprecated
func (*NewRelativeFrameTimeHistogramResponse) Descriptor() ([]byte, []int)
Deprecated: Use NewRelativeFrameTimeHistogramResponse.ProtoReflect.Descriptor instead.
func (*NewRelativeFrameTimeHistogramResponse) GetResult ¶
func (x *NewRelativeFrameTimeHistogramResponse) GetResult() int64
func (*NewRelativeFrameTimeHistogramResponse) ProtoMessage ¶
func (*NewRelativeFrameTimeHistogramResponse) ProtoMessage()
func (*NewRelativeFrameTimeHistogramResponse) ProtoReflect ¶
func (x *NewRelativeFrameTimeHistogramResponse) ProtoReflect() protoreflect.Message
func (*NewRelativeFrameTimeHistogramResponse) Reset ¶
func (x *NewRelativeFrameTimeHistogramResponse) Reset()
func (*NewRelativeFrameTimeHistogramResponse) String ¶
func (x *NewRelativeFrameTimeHistogramResponse) String() string
type RelativeFrameTimeHistogramServiceClient ¶
type RelativeFrameTimeHistogramServiceClient interface {
NewRelativeFrameTimeHistogram(ctx context.Context, in *NewRelativeFrameTimeHistogramRequest, opts ...grpc.CallOption) (*NewRelativeFrameTimeHistogramResponse, error)
AddRelativeFrameTimeMillis(ctx context.Context, in *AddRelativeFrameTimeMillisRequest, opts ...grpc.CallOption) (*AddRelativeFrameTimeMillisResponse, error)
GetBucketCounters(ctx context.Context, in *GetBucketCountersRequest, opts ...grpc.CallOption) (*GetBucketCountersResponse, error)
GetBucketEndpointsMillis(ctx context.Context, in *GetBucketEndpointsMillisRequest, opts ...grpc.CallOption) (*GetBucketEndpointsMillisResponse, error)
}
RelativeFrameTimeHistogramServiceClient is the client API for RelativeFrameTimeHistogramService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewRelativeFrameTimeHistogramServiceClient ¶
func NewRelativeFrameTimeHistogramServiceClient(cc grpc.ClientConnInterface) RelativeFrameTimeHistogramServiceClient
type RelativeFrameTimeHistogramServiceServer ¶
type RelativeFrameTimeHistogramServiceServer interface {
NewRelativeFrameTimeHistogram(context.Context, *NewRelativeFrameTimeHistogramRequest) (*NewRelativeFrameTimeHistogramResponse, error)
AddRelativeFrameTimeMillis(context.Context, *AddRelativeFrameTimeMillisRequest) (*AddRelativeFrameTimeMillisResponse, error)
GetBucketCounters(context.Context, *GetBucketCountersRequest) (*GetBucketCountersResponse, error)
GetBucketEndpointsMillis(context.Context, *GetBucketEndpointsMillisRequest) (*GetBucketEndpointsMillisResponse, error)
// contains filtered or unexported methods
}
RelativeFrameTimeHistogramServiceServer is the server API for RelativeFrameTimeHistogramService service. All implementations must embed UnimplementedRelativeFrameTimeHistogramServiceServer for forward compatibility.
type UnimplementedAppJankStatsServiceServer ¶
type UnimplementedAppJankStatsServiceServer struct{}
UnimplementedAppJankStatsServiceServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedAppJankStatsServiceServer) GetJankyFrameCount ¶
func (UnimplementedAppJankStatsServiceServer) GetJankyFrameCount(context.Context, *GetJankyFrameCountRequest) (*GetJankyFrameCountResponse, error)
func (UnimplementedAppJankStatsServiceServer) GetNavigationComponent ¶
func (UnimplementedAppJankStatsServiceServer) GetNavigationComponent(context.Context, *GetNavigationComponentRequest) (*GetNavigationComponentResponse, error)
func (UnimplementedAppJankStatsServiceServer) GetRelativeFrameTimeHistogram ¶
func (UnimplementedAppJankStatsServiceServer) GetRelativeFrameTimeHistogram(context.Context, *GetRelativeFrameTimeHistogramRequest) (*GetRelativeFrameTimeHistogramResponse, error)
func (UnimplementedAppJankStatsServiceServer) GetTotalFrameCount ¶
func (UnimplementedAppJankStatsServiceServer) GetTotalFrameCount(context.Context, *GetTotalFrameCountRequest) (*GetTotalFrameCountResponse, error)
func (UnimplementedAppJankStatsServiceServer) GetUid ¶
func (UnimplementedAppJankStatsServiceServer) GetUid(context.Context, *GetUidRequest) (*GetUidResponse, error)
func (UnimplementedAppJankStatsServiceServer) GetWidgetCategory ¶
func (UnimplementedAppJankStatsServiceServer) GetWidgetCategory(context.Context, *GetWidgetCategoryRequest) (*GetWidgetCategoryResponse, error)
func (UnimplementedAppJankStatsServiceServer) GetWidgetId ¶
func (UnimplementedAppJankStatsServiceServer) GetWidgetId(context.Context, *GetWidgetIdRequest) (*GetWidgetIdResponse, error)
func (UnimplementedAppJankStatsServiceServer) GetWidgetState ¶
func (UnimplementedAppJankStatsServiceServer) GetWidgetState(context.Context, *GetWidgetStateRequest) (*GetWidgetStateResponse, error)
func (UnimplementedAppJankStatsServiceServer) NewAppJankStats ¶
func (UnimplementedAppJankStatsServiceServer) NewAppJankStats(context.Context, *NewAppJankStatsRequest) (*NewAppJankStatsResponse, error)
type UnimplementedRelativeFrameTimeHistogramServiceServer ¶
type UnimplementedRelativeFrameTimeHistogramServiceServer struct{}
UnimplementedRelativeFrameTimeHistogramServiceServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedRelativeFrameTimeHistogramServiceServer) AddRelativeFrameTimeMillis ¶
func (UnimplementedRelativeFrameTimeHistogramServiceServer) AddRelativeFrameTimeMillis(context.Context, *AddRelativeFrameTimeMillisRequest) (*AddRelativeFrameTimeMillisResponse, error)
func (UnimplementedRelativeFrameTimeHistogramServiceServer) GetBucketCounters ¶
func (UnimplementedRelativeFrameTimeHistogramServiceServer) GetBucketCounters(context.Context, *GetBucketCountersRequest) (*GetBucketCountersResponse, error)
func (UnimplementedRelativeFrameTimeHistogramServiceServer) GetBucketEndpointsMillis ¶
func (UnimplementedRelativeFrameTimeHistogramServiceServer) GetBucketEndpointsMillis(context.Context, *GetBucketEndpointsMillisRequest) (*GetBucketEndpointsMillisResponse, error)
func (UnimplementedRelativeFrameTimeHistogramServiceServer) NewRelativeFrameTimeHistogram ¶
func (UnimplementedRelativeFrameTimeHistogramServiceServer) NewRelativeFrameTimeHistogram(context.Context, *NewRelativeFrameTimeHistogramRequest) (*NewRelativeFrameTimeHistogramResponse, error)
type UnsafeAppJankStatsServiceServer ¶
type UnsafeAppJankStatsServiceServer interface {
// contains filtered or unexported methods
}
UnsafeAppJankStatsServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to AppJankStatsServiceServer will result in compilation errors.
type UnsafeRelativeFrameTimeHistogramServiceServer ¶
type UnsafeRelativeFrameTimeHistogramServiceServer interface {
// contains filtered or unexported methods
}
UnsafeRelativeFrameTimeHistogramServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to RelativeFrameTimeHistogramServiceServer will result in compilation errors.