Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterManagerServiceServer(s grpc.ServiceRegistrar, srv ManagerServiceServer)
- type AddKeyguardLockedStateListenerRequest
- func (*AddKeyguardLockedStateListenerRequest) Descriptor() ([]byte, []int)deprecated
- func (x *AddKeyguardLockedStateListenerRequest) GetArg0() int64
- func (x *AddKeyguardLockedStateListenerRequest) GetArg1() int64
- func (*AddKeyguardLockedStateListenerRequest) ProtoMessage()
- func (x *AddKeyguardLockedStateListenerRequest) ProtoReflect() protoreflect.Message
- func (x *AddKeyguardLockedStateListenerRequest) Reset()
- func (x *AddKeyguardLockedStateListenerRequest) String() string
- type AddKeyguardLockedStateListenerResponse
- func (*AddKeyguardLockedStateListenerResponse) Descriptor() ([]byte, []int)deprecated
- func (*AddKeyguardLockedStateListenerResponse) ProtoMessage()
- func (x *AddKeyguardLockedStateListenerResponse) ProtoReflect() protoreflect.Message
- func (x *AddKeyguardLockedStateListenerResponse) Reset()
- func (x *AddKeyguardLockedStateListenerResponse) String() string
- type CreateConfirmDeviceCredentialIntentRequest
- func (*CreateConfirmDeviceCredentialIntentRequest) Descriptor() ([]byte, []int)deprecated
- func (x *CreateConfirmDeviceCredentialIntentRequest) GetArg0() string
- func (x *CreateConfirmDeviceCredentialIntentRequest) GetArg1() string
- func (*CreateConfirmDeviceCredentialIntentRequest) ProtoMessage()
- func (x *CreateConfirmDeviceCredentialIntentRequest) ProtoReflect() protoreflect.Message
- func (x *CreateConfirmDeviceCredentialIntentRequest) Reset()
- func (x *CreateConfirmDeviceCredentialIntentRequest) String() string
- type CreateConfirmDeviceCredentialIntentResponse
- func (*CreateConfirmDeviceCredentialIntentResponse) Descriptor() ([]byte, []int)deprecated
- func (x *CreateConfirmDeviceCredentialIntentResponse) GetResult() int64
- func (*CreateConfirmDeviceCredentialIntentResponse) ProtoMessage()
- func (x *CreateConfirmDeviceCredentialIntentResponse) ProtoReflect() protoreflect.Message
- func (x *CreateConfirmDeviceCredentialIntentResponse) Reset()
- func (x *CreateConfirmDeviceCredentialIntentResponse) String() string
- type ExitKeyguardSecurelyRequest
- func (*ExitKeyguardSecurelyRequest) Descriptor() ([]byte, []int)deprecated
- func (x *ExitKeyguardSecurelyRequest) GetArg0() int64
- func (*ExitKeyguardSecurelyRequest) ProtoMessage()
- func (x *ExitKeyguardSecurelyRequest) ProtoReflect() protoreflect.Message
- func (x *ExitKeyguardSecurelyRequest) Reset()
- func (x *ExitKeyguardSecurelyRequest) String() string
- type ExitKeyguardSecurelyResponse
- func (*ExitKeyguardSecurelyResponse) Descriptor() ([]byte, []int)deprecated
- func (*ExitKeyguardSecurelyResponse) ProtoMessage()
- func (x *ExitKeyguardSecurelyResponse) ProtoReflect() protoreflect.Message
- func (x *ExitKeyguardSecurelyResponse) Reset()
- func (x *ExitKeyguardSecurelyResponse) String() string
- type InKeyguardRestrictedInputModeRequest
- func (*InKeyguardRestrictedInputModeRequest) Descriptor() ([]byte, []int)deprecated
- func (*InKeyguardRestrictedInputModeRequest) ProtoMessage()
- func (x *InKeyguardRestrictedInputModeRequest) ProtoReflect() protoreflect.Message
- func (x *InKeyguardRestrictedInputModeRequest) Reset()
- func (x *InKeyguardRestrictedInputModeRequest) String() string
- type InKeyguardRestrictedInputModeResponse
- func (*InKeyguardRestrictedInputModeResponse) Descriptor() ([]byte, []int)deprecated
- func (x *InKeyguardRestrictedInputModeResponse) GetResult() bool
- func (*InKeyguardRestrictedInputModeResponse) ProtoMessage()
- func (x *InKeyguardRestrictedInputModeResponse) ProtoReflect() protoreflect.Message
- func (x *InKeyguardRestrictedInputModeResponse) Reset()
- func (x *InKeyguardRestrictedInputModeResponse) String() string
- type IsDeviceLockedRequest
- type IsDeviceLockedResponse
- func (*IsDeviceLockedResponse) Descriptor() ([]byte, []int)deprecated
- func (x *IsDeviceLockedResponse) GetResult() bool
- func (*IsDeviceLockedResponse) ProtoMessage()
- func (x *IsDeviceLockedResponse) ProtoReflect() protoreflect.Message
- func (x *IsDeviceLockedResponse) Reset()
- func (x *IsDeviceLockedResponse) String() string
- type IsDeviceSecureRequest
- type IsDeviceSecureResponse
- func (*IsDeviceSecureResponse) Descriptor() ([]byte, []int)deprecated
- func (x *IsDeviceSecureResponse) GetResult() bool
- func (*IsDeviceSecureResponse) ProtoMessage()
- func (x *IsDeviceSecureResponse) ProtoReflect() protoreflect.Message
- func (x *IsDeviceSecureResponse) Reset()
- func (x *IsDeviceSecureResponse) String() string
- type IsKeyguardLockedRequest
- type IsKeyguardLockedResponse
- func (*IsKeyguardLockedResponse) Descriptor() ([]byte, []int)deprecated
- func (x *IsKeyguardLockedResponse) GetResult() bool
- func (*IsKeyguardLockedResponse) ProtoMessage()
- func (x *IsKeyguardLockedResponse) ProtoReflect() protoreflect.Message
- func (x *IsKeyguardLockedResponse) Reset()
- func (x *IsKeyguardLockedResponse) String() string
- type IsKeyguardSecureRequest
- type IsKeyguardSecureResponse
- func (*IsKeyguardSecureResponse) Descriptor() ([]byte, []int)deprecated
- func (x *IsKeyguardSecureResponse) GetResult() bool
- func (*IsKeyguardSecureResponse) ProtoMessage()
- func (x *IsKeyguardSecureResponse) ProtoReflect() protoreflect.Message
- func (x *IsKeyguardSecureResponse) Reset()
- func (x *IsKeyguardSecureResponse) String() string
- type ManagerServiceClient
- type ManagerServiceServer
- type NewKeyguardLockRequest
- func (*NewKeyguardLockRequest) Descriptor() ([]byte, []int)deprecated
- func (x *NewKeyguardLockRequest) GetArg0() string
- func (*NewKeyguardLockRequest) ProtoMessage()
- func (x *NewKeyguardLockRequest) ProtoReflect() protoreflect.Message
- func (x *NewKeyguardLockRequest) Reset()
- func (x *NewKeyguardLockRequest) String() string
- type NewKeyguardLockResponse
- func (*NewKeyguardLockResponse) Descriptor() ([]byte, []int)deprecated
- func (x *NewKeyguardLockResponse) GetResult() int64
- func (*NewKeyguardLockResponse) ProtoMessage()
- func (x *NewKeyguardLockResponse) ProtoReflect() protoreflect.Message
- func (x *NewKeyguardLockResponse) Reset()
- func (x *NewKeyguardLockResponse) String() string
- type RemoveKeyguardLockedStateListenerRequest
- func (*RemoveKeyguardLockedStateListenerRequest) Descriptor() ([]byte, []int)deprecated
- func (x *RemoveKeyguardLockedStateListenerRequest) GetArg0() int64
- func (*RemoveKeyguardLockedStateListenerRequest) ProtoMessage()
- func (x *RemoveKeyguardLockedStateListenerRequest) ProtoReflect() protoreflect.Message
- func (x *RemoveKeyguardLockedStateListenerRequest) Reset()
- func (x *RemoveKeyguardLockedStateListenerRequest) String() string
- type RemoveKeyguardLockedStateListenerResponse
- func (*RemoveKeyguardLockedStateListenerResponse) Descriptor() ([]byte, []int)deprecated
- func (*RemoveKeyguardLockedStateListenerResponse) ProtoMessage()
- func (x *RemoveKeyguardLockedStateListenerResponse) ProtoReflect() protoreflect.Message
- func (x *RemoveKeyguardLockedStateListenerResponse) Reset()
- func (x *RemoveKeyguardLockedStateListenerResponse) String() string
- type RequestDismissKeyguardRequest
- func (*RequestDismissKeyguardRequest) Descriptor() ([]byte, []int)deprecated
- func (x *RequestDismissKeyguardRequest) GetArg0() int64
- func (x *RequestDismissKeyguardRequest) GetArg1() int64
- func (*RequestDismissKeyguardRequest) ProtoMessage()
- func (x *RequestDismissKeyguardRequest) ProtoReflect() protoreflect.Message
- func (x *RequestDismissKeyguardRequest) Reset()
- func (x *RequestDismissKeyguardRequest) String() string
- type RequestDismissKeyguardResponse
- func (*RequestDismissKeyguardResponse) Descriptor() ([]byte, []int)deprecated
- func (*RequestDismissKeyguardResponse) ProtoMessage()
- func (x *RequestDismissKeyguardResponse) ProtoReflect() protoreflect.Message
- func (x *RequestDismissKeyguardResponse) Reset()
- func (x *RequestDismissKeyguardResponse) String() string
- type UnimplementedManagerServiceServer
- func (UnimplementedManagerServiceServer) AddKeyguardLockedStateListener(context.Context, *AddKeyguardLockedStateListenerRequest) (*AddKeyguardLockedStateListenerResponse, error)
- func (UnimplementedManagerServiceServer) CreateConfirmDeviceCredentialIntent(context.Context, *CreateConfirmDeviceCredentialIntentRequest) (*CreateConfirmDeviceCredentialIntentResponse, error)
- func (UnimplementedManagerServiceServer) ExitKeyguardSecurely(context.Context, *ExitKeyguardSecurelyRequest) (*ExitKeyguardSecurelyResponse, error)
- func (UnimplementedManagerServiceServer) InKeyguardRestrictedInputMode(context.Context, *InKeyguardRestrictedInputModeRequest) (*InKeyguardRestrictedInputModeResponse, error)
- func (UnimplementedManagerServiceServer) IsDeviceLocked(context.Context, *IsDeviceLockedRequest) (*IsDeviceLockedResponse, error)
- func (UnimplementedManagerServiceServer) IsDeviceSecure(context.Context, *IsDeviceSecureRequest) (*IsDeviceSecureResponse, error)
- func (UnimplementedManagerServiceServer) IsKeyguardLocked(context.Context, *IsKeyguardLockedRequest) (*IsKeyguardLockedResponse, error)
- func (UnimplementedManagerServiceServer) IsKeyguardSecure(context.Context, *IsKeyguardSecureRequest) (*IsKeyguardSecureResponse, error)
- func (UnimplementedManagerServiceServer) NewKeyguardLock(context.Context, *NewKeyguardLockRequest) (*NewKeyguardLockResponse, error)
- func (UnimplementedManagerServiceServer) RemoveKeyguardLockedStateListener(context.Context, *RemoveKeyguardLockedStateListenerRequest) (*RemoveKeyguardLockedStateListenerResponse, error)
- func (UnimplementedManagerServiceServer) RequestDismissKeyguard(context.Context, *RequestDismissKeyguardRequest) (*RequestDismissKeyguardResponse, error)
- type UnsafeManagerServiceServer
Constants ¶
const ( ManagerService_AddKeyguardLockedStateListener_FullMethodName = "/keyguard.ManagerService/AddKeyguardLockedStateListener" ManagerService_CreateConfirmDeviceCredentialIntent_FullMethodName = "/keyguard.ManagerService/CreateConfirmDeviceCredentialIntent" ManagerService_ExitKeyguardSecurely_FullMethodName = "/keyguard.ManagerService/ExitKeyguardSecurely" ManagerService_InKeyguardRestrictedInputMode_FullMethodName = "/keyguard.ManagerService/InKeyguardRestrictedInputMode" ManagerService_IsDeviceLocked_FullMethodName = "/keyguard.ManagerService/IsDeviceLocked" ManagerService_IsDeviceSecure_FullMethodName = "/keyguard.ManagerService/IsDeviceSecure" ManagerService_IsKeyguardLocked_FullMethodName = "/keyguard.ManagerService/IsKeyguardLocked" ManagerService_IsKeyguardSecure_FullMethodName = "/keyguard.ManagerService/IsKeyguardSecure" ManagerService_NewKeyguardLock_FullMethodName = "/keyguard.ManagerService/NewKeyguardLock" ManagerService_RemoveKeyguardLockedStateListener_FullMethodName = "/keyguard.ManagerService/RemoveKeyguardLockedStateListener" ManagerService_RequestDismissKeyguard_FullMethodName = "/keyguard.ManagerService/RequestDismissKeyguard" )
Variables ¶
var File_proto_keyguard_keyguard_proto protoreflect.FileDescriptor
var ManagerService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "keyguard.ManagerService", HandlerType: (*ManagerServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "AddKeyguardLockedStateListener", Handler: _ManagerService_AddKeyguardLockedStateListener_Handler, }, { MethodName: "CreateConfirmDeviceCredentialIntent", Handler: _ManagerService_CreateConfirmDeviceCredentialIntent_Handler, }, { MethodName: "ExitKeyguardSecurely", Handler: _ManagerService_ExitKeyguardSecurely_Handler, }, { MethodName: "InKeyguardRestrictedInputMode", Handler: _ManagerService_InKeyguardRestrictedInputMode_Handler, }, { MethodName: "IsDeviceLocked", Handler: _ManagerService_IsDeviceLocked_Handler, }, { MethodName: "IsDeviceSecure", Handler: _ManagerService_IsDeviceSecure_Handler, }, { MethodName: "IsKeyguardLocked", Handler: _ManagerService_IsKeyguardLocked_Handler, }, { MethodName: "IsKeyguardSecure", Handler: _ManagerService_IsKeyguardSecure_Handler, }, { MethodName: "NewKeyguardLock", Handler: _ManagerService_NewKeyguardLock_Handler, }, { MethodName: "RemoveKeyguardLockedStateListener", Handler: _ManagerService_RemoveKeyguardLockedStateListener_Handler, }, { MethodName: "RequestDismissKeyguard", Handler: _ManagerService_RequestDismissKeyguard_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "proto/keyguard/keyguard.proto", }
ManagerService_ServiceDesc is the grpc.ServiceDesc for ManagerService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterManagerServiceServer ¶ added in v0.0.4
func RegisterManagerServiceServer(s grpc.ServiceRegistrar, srv ManagerServiceServer)
Types ¶
type AddKeyguardLockedStateListenerRequest ¶
type AddKeyguardLockedStateListenerRequest struct {
Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
Arg1 int64 `protobuf:"varint,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
// contains filtered or unexported fields
}
func (*AddKeyguardLockedStateListenerRequest) Descriptor
deprecated
func (*AddKeyguardLockedStateListenerRequest) Descriptor() ([]byte, []int)
Deprecated: Use AddKeyguardLockedStateListenerRequest.ProtoReflect.Descriptor instead.
func (*AddKeyguardLockedStateListenerRequest) GetArg0 ¶
func (x *AddKeyguardLockedStateListenerRequest) GetArg0() int64
func (*AddKeyguardLockedStateListenerRequest) GetArg1 ¶
func (x *AddKeyguardLockedStateListenerRequest) GetArg1() int64
func (*AddKeyguardLockedStateListenerRequest) ProtoMessage ¶
func (*AddKeyguardLockedStateListenerRequest) ProtoMessage()
func (*AddKeyguardLockedStateListenerRequest) ProtoReflect ¶
func (x *AddKeyguardLockedStateListenerRequest) ProtoReflect() protoreflect.Message
func (*AddKeyguardLockedStateListenerRequest) Reset ¶
func (x *AddKeyguardLockedStateListenerRequest) Reset()
func (*AddKeyguardLockedStateListenerRequest) String ¶
func (x *AddKeyguardLockedStateListenerRequest) String() string
type AddKeyguardLockedStateListenerResponse ¶
type AddKeyguardLockedStateListenerResponse struct {
// contains filtered or unexported fields
}
func (*AddKeyguardLockedStateListenerResponse) Descriptor
deprecated
func (*AddKeyguardLockedStateListenerResponse) Descriptor() ([]byte, []int)
Deprecated: Use AddKeyguardLockedStateListenerResponse.ProtoReflect.Descriptor instead.
func (*AddKeyguardLockedStateListenerResponse) ProtoMessage ¶
func (*AddKeyguardLockedStateListenerResponse) ProtoMessage()
func (*AddKeyguardLockedStateListenerResponse) ProtoReflect ¶
func (x *AddKeyguardLockedStateListenerResponse) ProtoReflect() protoreflect.Message
func (*AddKeyguardLockedStateListenerResponse) Reset ¶
func (x *AddKeyguardLockedStateListenerResponse) Reset()
func (*AddKeyguardLockedStateListenerResponse) String ¶
func (x *AddKeyguardLockedStateListenerResponse) String() string
type CreateConfirmDeviceCredentialIntentRequest ¶
type CreateConfirmDeviceCredentialIntentRequest struct {
Arg0 string `protobuf:"bytes,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
Arg1 string `protobuf:"bytes,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
// contains filtered or unexported fields
}
func (*CreateConfirmDeviceCredentialIntentRequest) Descriptor
deprecated
func (*CreateConfirmDeviceCredentialIntentRequest) Descriptor() ([]byte, []int)
Deprecated: Use CreateConfirmDeviceCredentialIntentRequest.ProtoReflect.Descriptor instead.
func (*CreateConfirmDeviceCredentialIntentRequest) GetArg0 ¶
func (x *CreateConfirmDeviceCredentialIntentRequest) GetArg0() string
func (*CreateConfirmDeviceCredentialIntentRequest) GetArg1 ¶
func (x *CreateConfirmDeviceCredentialIntentRequest) GetArg1() string
func (*CreateConfirmDeviceCredentialIntentRequest) ProtoMessage ¶
func (*CreateConfirmDeviceCredentialIntentRequest) ProtoMessage()
func (*CreateConfirmDeviceCredentialIntentRequest) ProtoReflect ¶
func (x *CreateConfirmDeviceCredentialIntentRequest) ProtoReflect() protoreflect.Message
func (*CreateConfirmDeviceCredentialIntentRequest) Reset ¶
func (x *CreateConfirmDeviceCredentialIntentRequest) Reset()
func (*CreateConfirmDeviceCredentialIntentRequest) String ¶
func (x *CreateConfirmDeviceCredentialIntentRequest) String() string
type CreateConfirmDeviceCredentialIntentResponse ¶
type CreateConfirmDeviceCredentialIntentResponse struct {
Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*CreateConfirmDeviceCredentialIntentResponse) Descriptor
deprecated
func (*CreateConfirmDeviceCredentialIntentResponse) Descriptor() ([]byte, []int)
Deprecated: Use CreateConfirmDeviceCredentialIntentResponse.ProtoReflect.Descriptor instead.
func (*CreateConfirmDeviceCredentialIntentResponse) GetResult ¶
func (x *CreateConfirmDeviceCredentialIntentResponse) GetResult() int64
func (*CreateConfirmDeviceCredentialIntentResponse) ProtoMessage ¶
func (*CreateConfirmDeviceCredentialIntentResponse) ProtoMessage()
func (*CreateConfirmDeviceCredentialIntentResponse) ProtoReflect ¶
func (x *CreateConfirmDeviceCredentialIntentResponse) ProtoReflect() protoreflect.Message
func (*CreateConfirmDeviceCredentialIntentResponse) Reset ¶
func (x *CreateConfirmDeviceCredentialIntentResponse) Reset()
func (*CreateConfirmDeviceCredentialIntentResponse) String ¶
func (x *CreateConfirmDeviceCredentialIntentResponse) String() string
type ExitKeyguardSecurelyRequest ¶
type ExitKeyguardSecurelyRequest struct {
Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
// contains filtered or unexported fields
}
func (*ExitKeyguardSecurelyRequest) Descriptor
deprecated
func (*ExitKeyguardSecurelyRequest) Descriptor() ([]byte, []int)
Deprecated: Use ExitKeyguardSecurelyRequest.ProtoReflect.Descriptor instead.
func (*ExitKeyguardSecurelyRequest) GetArg0 ¶
func (x *ExitKeyguardSecurelyRequest) GetArg0() int64
func (*ExitKeyguardSecurelyRequest) ProtoMessage ¶
func (*ExitKeyguardSecurelyRequest) ProtoMessage()
func (*ExitKeyguardSecurelyRequest) ProtoReflect ¶
func (x *ExitKeyguardSecurelyRequest) ProtoReflect() protoreflect.Message
func (*ExitKeyguardSecurelyRequest) Reset ¶
func (x *ExitKeyguardSecurelyRequest) Reset()
func (*ExitKeyguardSecurelyRequest) String ¶
func (x *ExitKeyguardSecurelyRequest) String() string
type ExitKeyguardSecurelyResponse ¶
type ExitKeyguardSecurelyResponse struct {
// contains filtered or unexported fields
}
func (*ExitKeyguardSecurelyResponse) Descriptor
deprecated
func (*ExitKeyguardSecurelyResponse) Descriptor() ([]byte, []int)
Deprecated: Use ExitKeyguardSecurelyResponse.ProtoReflect.Descriptor instead.
func (*ExitKeyguardSecurelyResponse) ProtoMessage ¶
func (*ExitKeyguardSecurelyResponse) ProtoMessage()
func (*ExitKeyguardSecurelyResponse) ProtoReflect ¶
func (x *ExitKeyguardSecurelyResponse) ProtoReflect() protoreflect.Message
func (*ExitKeyguardSecurelyResponse) Reset ¶
func (x *ExitKeyguardSecurelyResponse) Reset()
func (*ExitKeyguardSecurelyResponse) String ¶
func (x *ExitKeyguardSecurelyResponse) String() string
type InKeyguardRestrictedInputModeRequest ¶
type InKeyguardRestrictedInputModeRequest struct {
// contains filtered or unexported fields
}
func (*InKeyguardRestrictedInputModeRequest) Descriptor
deprecated
func (*InKeyguardRestrictedInputModeRequest) Descriptor() ([]byte, []int)
Deprecated: Use InKeyguardRestrictedInputModeRequest.ProtoReflect.Descriptor instead.
func (*InKeyguardRestrictedInputModeRequest) ProtoMessage ¶
func (*InKeyguardRestrictedInputModeRequest) ProtoMessage()
func (*InKeyguardRestrictedInputModeRequest) ProtoReflect ¶
func (x *InKeyguardRestrictedInputModeRequest) ProtoReflect() protoreflect.Message
func (*InKeyguardRestrictedInputModeRequest) Reset ¶
func (x *InKeyguardRestrictedInputModeRequest) Reset()
func (*InKeyguardRestrictedInputModeRequest) String ¶
func (x *InKeyguardRestrictedInputModeRequest) String() string
type InKeyguardRestrictedInputModeResponse ¶
type InKeyguardRestrictedInputModeResponse struct {
Result bool `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*InKeyguardRestrictedInputModeResponse) Descriptor
deprecated
func (*InKeyguardRestrictedInputModeResponse) Descriptor() ([]byte, []int)
Deprecated: Use InKeyguardRestrictedInputModeResponse.ProtoReflect.Descriptor instead.
func (*InKeyguardRestrictedInputModeResponse) GetResult ¶
func (x *InKeyguardRestrictedInputModeResponse) GetResult() bool
func (*InKeyguardRestrictedInputModeResponse) ProtoMessage ¶
func (*InKeyguardRestrictedInputModeResponse) ProtoMessage()
func (*InKeyguardRestrictedInputModeResponse) ProtoReflect ¶
func (x *InKeyguardRestrictedInputModeResponse) ProtoReflect() protoreflect.Message
func (*InKeyguardRestrictedInputModeResponse) Reset ¶
func (x *InKeyguardRestrictedInputModeResponse) Reset()
func (*InKeyguardRestrictedInputModeResponse) String ¶
func (x *InKeyguardRestrictedInputModeResponse) String() string
type IsDeviceLockedRequest ¶
type IsDeviceLockedRequest struct {
// contains filtered or unexported fields
}
func (*IsDeviceLockedRequest) Descriptor
deprecated
func (*IsDeviceLockedRequest) Descriptor() ([]byte, []int)
Deprecated: Use IsDeviceLockedRequest.ProtoReflect.Descriptor instead.
func (*IsDeviceLockedRequest) ProtoMessage ¶
func (*IsDeviceLockedRequest) ProtoMessage()
func (*IsDeviceLockedRequest) ProtoReflect ¶
func (x *IsDeviceLockedRequest) ProtoReflect() protoreflect.Message
func (*IsDeviceLockedRequest) Reset ¶
func (x *IsDeviceLockedRequest) Reset()
func (*IsDeviceLockedRequest) String ¶
func (x *IsDeviceLockedRequest) String() string
type IsDeviceLockedResponse ¶
type IsDeviceLockedResponse struct {
Result bool `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*IsDeviceLockedResponse) Descriptor
deprecated
func (*IsDeviceLockedResponse) Descriptor() ([]byte, []int)
Deprecated: Use IsDeviceLockedResponse.ProtoReflect.Descriptor instead.
func (*IsDeviceLockedResponse) GetResult ¶
func (x *IsDeviceLockedResponse) GetResult() bool
func (*IsDeviceLockedResponse) ProtoMessage ¶
func (*IsDeviceLockedResponse) ProtoMessage()
func (*IsDeviceLockedResponse) ProtoReflect ¶
func (x *IsDeviceLockedResponse) ProtoReflect() protoreflect.Message
func (*IsDeviceLockedResponse) Reset ¶
func (x *IsDeviceLockedResponse) Reset()
func (*IsDeviceLockedResponse) String ¶
func (x *IsDeviceLockedResponse) String() string
type IsDeviceSecureRequest ¶
type IsDeviceSecureRequest struct {
// contains filtered or unexported fields
}
func (*IsDeviceSecureRequest) Descriptor
deprecated
func (*IsDeviceSecureRequest) Descriptor() ([]byte, []int)
Deprecated: Use IsDeviceSecureRequest.ProtoReflect.Descriptor instead.
func (*IsDeviceSecureRequest) ProtoMessage ¶
func (*IsDeviceSecureRequest) ProtoMessage()
func (*IsDeviceSecureRequest) ProtoReflect ¶
func (x *IsDeviceSecureRequest) ProtoReflect() protoreflect.Message
func (*IsDeviceSecureRequest) Reset ¶
func (x *IsDeviceSecureRequest) Reset()
func (*IsDeviceSecureRequest) String ¶
func (x *IsDeviceSecureRequest) String() string
type IsDeviceSecureResponse ¶
type IsDeviceSecureResponse struct {
Result bool `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*IsDeviceSecureResponse) Descriptor
deprecated
func (*IsDeviceSecureResponse) Descriptor() ([]byte, []int)
Deprecated: Use IsDeviceSecureResponse.ProtoReflect.Descriptor instead.
func (*IsDeviceSecureResponse) GetResult ¶
func (x *IsDeviceSecureResponse) GetResult() bool
func (*IsDeviceSecureResponse) ProtoMessage ¶
func (*IsDeviceSecureResponse) ProtoMessage()
func (*IsDeviceSecureResponse) ProtoReflect ¶
func (x *IsDeviceSecureResponse) ProtoReflect() protoreflect.Message
func (*IsDeviceSecureResponse) Reset ¶
func (x *IsDeviceSecureResponse) Reset()
func (*IsDeviceSecureResponse) String ¶
func (x *IsDeviceSecureResponse) String() string
type IsKeyguardLockedRequest ¶
type IsKeyguardLockedRequest struct {
// contains filtered or unexported fields
}
func (*IsKeyguardLockedRequest) Descriptor
deprecated
func (*IsKeyguardLockedRequest) Descriptor() ([]byte, []int)
Deprecated: Use IsKeyguardLockedRequest.ProtoReflect.Descriptor instead.
func (*IsKeyguardLockedRequest) ProtoMessage ¶
func (*IsKeyguardLockedRequest) ProtoMessage()
func (*IsKeyguardLockedRequest) ProtoReflect ¶
func (x *IsKeyguardLockedRequest) ProtoReflect() protoreflect.Message
func (*IsKeyguardLockedRequest) Reset ¶
func (x *IsKeyguardLockedRequest) Reset()
func (*IsKeyguardLockedRequest) String ¶
func (x *IsKeyguardLockedRequest) String() string
type IsKeyguardLockedResponse ¶
type IsKeyguardLockedResponse struct {
Result bool `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*IsKeyguardLockedResponse) Descriptor
deprecated
func (*IsKeyguardLockedResponse) Descriptor() ([]byte, []int)
Deprecated: Use IsKeyguardLockedResponse.ProtoReflect.Descriptor instead.
func (*IsKeyguardLockedResponse) GetResult ¶
func (x *IsKeyguardLockedResponse) GetResult() bool
func (*IsKeyguardLockedResponse) ProtoMessage ¶
func (*IsKeyguardLockedResponse) ProtoMessage()
func (*IsKeyguardLockedResponse) ProtoReflect ¶
func (x *IsKeyguardLockedResponse) ProtoReflect() protoreflect.Message
func (*IsKeyguardLockedResponse) Reset ¶
func (x *IsKeyguardLockedResponse) Reset()
func (*IsKeyguardLockedResponse) String ¶
func (x *IsKeyguardLockedResponse) String() string
type IsKeyguardSecureRequest ¶
type IsKeyguardSecureRequest struct {
// contains filtered or unexported fields
}
func (*IsKeyguardSecureRequest) Descriptor
deprecated
func (*IsKeyguardSecureRequest) Descriptor() ([]byte, []int)
Deprecated: Use IsKeyguardSecureRequest.ProtoReflect.Descriptor instead.
func (*IsKeyguardSecureRequest) ProtoMessage ¶
func (*IsKeyguardSecureRequest) ProtoMessage()
func (*IsKeyguardSecureRequest) ProtoReflect ¶
func (x *IsKeyguardSecureRequest) ProtoReflect() protoreflect.Message
func (*IsKeyguardSecureRequest) Reset ¶
func (x *IsKeyguardSecureRequest) Reset()
func (*IsKeyguardSecureRequest) String ¶
func (x *IsKeyguardSecureRequest) String() string
type IsKeyguardSecureResponse ¶
type IsKeyguardSecureResponse struct {
Result bool `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*IsKeyguardSecureResponse) Descriptor
deprecated
func (*IsKeyguardSecureResponse) Descriptor() ([]byte, []int)
Deprecated: Use IsKeyguardSecureResponse.ProtoReflect.Descriptor instead.
func (*IsKeyguardSecureResponse) GetResult ¶
func (x *IsKeyguardSecureResponse) GetResult() bool
func (*IsKeyguardSecureResponse) ProtoMessage ¶
func (*IsKeyguardSecureResponse) ProtoMessage()
func (*IsKeyguardSecureResponse) ProtoReflect ¶
func (x *IsKeyguardSecureResponse) ProtoReflect() protoreflect.Message
func (*IsKeyguardSecureResponse) Reset ¶
func (x *IsKeyguardSecureResponse) Reset()
func (*IsKeyguardSecureResponse) String ¶
func (x *IsKeyguardSecureResponse) String() string
type ManagerServiceClient ¶ added in v0.0.4
type ManagerServiceClient interface {
AddKeyguardLockedStateListener(ctx context.Context, in *AddKeyguardLockedStateListenerRequest, opts ...grpc.CallOption) (*AddKeyguardLockedStateListenerResponse, error)
CreateConfirmDeviceCredentialIntent(ctx context.Context, in *CreateConfirmDeviceCredentialIntentRequest, opts ...grpc.CallOption) (*CreateConfirmDeviceCredentialIntentResponse, error)
ExitKeyguardSecurely(ctx context.Context, in *ExitKeyguardSecurelyRequest, opts ...grpc.CallOption) (*ExitKeyguardSecurelyResponse, error)
InKeyguardRestrictedInputMode(ctx context.Context, in *InKeyguardRestrictedInputModeRequest, opts ...grpc.CallOption) (*InKeyguardRestrictedInputModeResponse, error)
IsDeviceLocked(ctx context.Context, in *IsDeviceLockedRequest, opts ...grpc.CallOption) (*IsDeviceLockedResponse, error)
IsDeviceSecure(ctx context.Context, in *IsDeviceSecureRequest, opts ...grpc.CallOption) (*IsDeviceSecureResponse, error)
IsKeyguardLocked(ctx context.Context, in *IsKeyguardLockedRequest, opts ...grpc.CallOption) (*IsKeyguardLockedResponse, error)
IsKeyguardSecure(ctx context.Context, in *IsKeyguardSecureRequest, opts ...grpc.CallOption) (*IsKeyguardSecureResponse, error)
NewKeyguardLock(ctx context.Context, in *NewKeyguardLockRequest, opts ...grpc.CallOption) (*NewKeyguardLockResponse, error)
RemoveKeyguardLockedStateListener(ctx context.Context, in *RemoveKeyguardLockedStateListenerRequest, opts ...grpc.CallOption) (*RemoveKeyguardLockedStateListenerResponse, error)
RequestDismissKeyguard(ctx context.Context, in *RequestDismissKeyguardRequest, opts ...grpc.CallOption) (*RequestDismissKeyguardResponse, error)
}
ManagerServiceClient is the client API for ManagerService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewManagerServiceClient ¶ added in v0.0.4
func NewManagerServiceClient(cc grpc.ClientConnInterface) ManagerServiceClient
type ManagerServiceServer ¶ added in v0.0.4
type ManagerServiceServer interface {
AddKeyguardLockedStateListener(context.Context, *AddKeyguardLockedStateListenerRequest) (*AddKeyguardLockedStateListenerResponse, error)
CreateConfirmDeviceCredentialIntent(context.Context, *CreateConfirmDeviceCredentialIntentRequest) (*CreateConfirmDeviceCredentialIntentResponse, error)
ExitKeyguardSecurely(context.Context, *ExitKeyguardSecurelyRequest) (*ExitKeyguardSecurelyResponse, error)
InKeyguardRestrictedInputMode(context.Context, *InKeyguardRestrictedInputModeRequest) (*InKeyguardRestrictedInputModeResponse, error)
IsDeviceLocked(context.Context, *IsDeviceLockedRequest) (*IsDeviceLockedResponse, error)
IsDeviceSecure(context.Context, *IsDeviceSecureRequest) (*IsDeviceSecureResponse, error)
IsKeyguardLocked(context.Context, *IsKeyguardLockedRequest) (*IsKeyguardLockedResponse, error)
IsKeyguardSecure(context.Context, *IsKeyguardSecureRequest) (*IsKeyguardSecureResponse, error)
NewKeyguardLock(context.Context, *NewKeyguardLockRequest) (*NewKeyguardLockResponse, error)
RemoveKeyguardLockedStateListener(context.Context, *RemoveKeyguardLockedStateListenerRequest) (*RemoveKeyguardLockedStateListenerResponse, error)
RequestDismissKeyguard(context.Context, *RequestDismissKeyguardRequest) (*RequestDismissKeyguardResponse, error)
// contains filtered or unexported methods
}
ManagerServiceServer is the server API for ManagerService service. All implementations must embed UnimplementedManagerServiceServer for forward compatibility.
type NewKeyguardLockRequest ¶
type NewKeyguardLockRequest struct {
Arg0 string `protobuf:"bytes,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
// contains filtered or unexported fields
}
func (*NewKeyguardLockRequest) Descriptor
deprecated
func (*NewKeyguardLockRequest) Descriptor() ([]byte, []int)
Deprecated: Use NewKeyguardLockRequest.ProtoReflect.Descriptor instead.
func (*NewKeyguardLockRequest) GetArg0 ¶
func (x *NewKeyguardLockRequest) GetArg0() string
func (*NewKeyguardLockRequest) ProtoMessage ¶
func (*NewKeyguardLockRequest) ProtoMessage()
func (*NewKeyguardLockRequest) ProtoReflect ¶
func (x *NewKeyguardLockRequest) ProtoReflect() protoreflect.Message
func (*NewKeyguardLockRequest) Reset ¶
func (x *NewKeyguardLockRequest) Reset()
func (*NewKeyguardLockRequest) String ¶
func (x *NewKeyguardLockRequest) String() string
type NewKeyguardLockResponse ¶
type NewKeyguardLockResponse struct {
Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*NewKeyguardLockResponse) Descriptor
deprecated
func (*NewKeyguardLockResponse) Descriptor() ([]byte, []int)
Deprecated: Use NewKeyguardLockResponse.ProtoReflect.Descriptor instead.
func (*NewKeyguardLockResponse) GetResult ¶
func (x *NewKeyguardLockResponse) GetResult() int64
func (*NewKeyguardLockResponse) ProtoMessage ¶
func (*NewKeyguardLockResponse) ProtoMessage()
func (*NewKeyguardLockResponse) ProtoReflect ¶
func (x *NewKeyguardLockResponse) ProtoReflect() protoreflect.Message
func (*NewKeyguardLockResponse) Reset ¶
func (x *NewKeyguardLockResponse) Reset()
func (*NewKeyguardLockResponse) String ¶
func (x *NewKeyguardLockResponse) String() string
type RemoveKeyguardLockedStateListenerRequest ¶
type RemoveKeyguardLockedStateListenerRequest struct {
Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
// contains filtered or unexported fields
}
func (*RemoveKeyguardLockedStateListenerRequest) Descriptor
deprecated
func (*RemoveKeyguardLockedStateListenerRequest) Descriptor() ([]byte, []int)
Deprecated: Use RemoveKeyguardLockedStateListenerRequest.ProtoReflect.Descriptor instead.
func (*RemoveKeyguardLockedStateListenerRequest) GetArg0 ¶
func (x *RemoveKeyguardLockedStateListenerRequest) GetArg0() int64
func (*RemoveKeyguardLockedStateListenerRequest) ProtoMessage ¶
func (*RemoveKeyguardLockedStateListenerRequest) ProtoMessage()
func (*RemoveKeyguardLockedStateListenerRequest) ProtoReflect ¶
func (x *RemoveKeyguardLockedStateListenerRequest) ProtoReflect() protoreflect.Message
func (*RemoveKeyguardLockedStateListenerRequest) Reset ¶
func (x *RemoveKeyguardLockedStateListenerRequest) Reset()
func (*RemoveKeyguardLockedStateListenerRequest) String ¶
func (x *RemoveKeyguardLockedStateListenerRequest) String() string
type RemoveKeyguardLockedStateListenerResponse ¶
type RemoveKeyguardLockedStateListenerResponse struct {
// contains filtered or unexported fields
}
func (*RemoveKeyguardLockedStateListenerResponse) Descriptor
deprecated
func (*RemoveKeyguardLockedStateListenerResponse) Descriptor() ([]byte, []int)
Deprecated: Use RemoveKeyguardLockedStateListenerResponse.ProtoReflect.Descriptor instead.
func (*RemoveKeyguardLockedStateListenerResponse) ProtoMessage ¶
func (*RemoveKeyguardLockedStateListenerResponse) ProtoMessage()
func (*RemoveKeyguardLockedStateListenerResponse) ProtoReflect ¶
func (x *RemoveKeyguardLockedStateListenerResponse) ProtoReflect() protoreflect.Message
func (*RemoveKeyguardLockedStateListenerResponse) Reset ¶
func (x *RemoveKeyguardLockedStateListenerResponse) Reset()
func (*RemoveKeyguardLockedStateListenerResponse) String ¶
func (x *RemoveKeyguardLockedStateListenerResponse) String() string
type RequestDismissKeyguardRequest ¶
type RequestDismissKeyguardRequest struct {
Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
Arg1 int64 `protobuf:"varint,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
// contains filtered or unexported fields
}
func (*RequestDismissKeyguardRequest) Descriptor
deprecated
func (*RequestDismissKeyguardRequest) Descriptor() ([]byte, []int)
Deprecated: Use RequestDismissKeyguardRequest.ProtoReflect.Descriptor instead.
func (*RequestDismissKeyguardRequest) GetArg0 ¶
func (x *RequestDismissKeyguardRequest) GetArg0() int64
func (*RequestDismissKeyguardRequest) GetArg1 ¶
func (x *RequestDismissKeyguardRequest) GetArg1() int64
func (*RequestDismissKeyguardRequest) ProtoMessage ¶
func (*RequestDismissKeyguardRequest) ProtoMessage()
func (*RequestDismissKeyguardRequest) ProtoReflect ¶
func (x *RequestDismissKeyguardRequest) ProtoReflect() protoreflect.Message
func (*RequestDismissKeyguardRequest) Reset ¶
func (x *RequestDismissKeyguardRequest) Reset()
func (*RequestDismissKeyguardRequest) String ¶
func (x *RequestDismissKeyguardRequest) String() string
type RequestDismissKeyguardResponse ¶
type RequestDismissKeyguardResponse struct {
// contains filtered or unexported fields
}
func (*RequestDismissKeyguardResponse) Descriptor
deprecated
func (*RequestDismissKeyguardResponse) Descriptor() ([]byte, []int)
Deprecated: Use RequestDismissKeyguardResponse.ProtoReflect.Descriptor instead.
func (*RequestDismissKeyguardResponse) ProtoMessage ¶
func (*RequestDismissKeyguardResponse) ProtoMessage()
func (*RequestDismissKeyguardResponse) ProtoReflect ¶
func (x *RequestDismissKeyguardResponse) ProtoReflect() protoreflect.Message
func (*RequestDismissKeyguardResponse) Reset ¶
func (x *RequestDismissKeyguardResponse) Reset()
func (*RequestDismissKeyguardResponse) String ¶
func (x *RequestDismissKeyguardResponse) String() string
type UnimplementedManagerServiceServer ¶ added in v0.0.4
type UnimplementedManagerServiceServer struct{}
UnimplementedManagerServiceServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedManagerServiceServer) AddKeyguardLockedStateListener ¶ added in v0.0.4
func (UnimplementedManagerServiceServer) AddKeyguardLockedStateListener(context.Context, *AddKeyguardLockedStateListenerRequest) (*AddKeyguardLockedStateListenerResponse, error)
func (UnimplementedManagerServiceServer) CreateConfirmDeviceCredentialIntent ¶ added in v0.0.4
func (UnimplementedManagerServiceServer) CreateConfirmDeviceCredentialIntent(context.Context, *CreateConfirmDeviceCredentialIntentRequest) (*CreateConfirmDeviceCredentialIntentResponse, error)
func (UnimplementedManagerServiceServer) ExitKeyguardSecurely ¶ added in v0.0.4
func (UnimplementedManagerServiceServer) ExitKeyguardSecurely(context.Context, *ExitKeyguardSecurelyRequest) (*ExitKeyguardSecurelyResponse, error)
func (UnimplementedManagerServiceServer) InKeyguardRestrictedInputMode ¶ added in v0.0.4
func (UnimplementedManagerServiceServer) InKeyguardRestrictedInputMode(context.Context, *InKeyguardRestrictedInputModeRequest) (*InKeyguardRestrictedInputModeResponse, error)
func (UnimplementedManagerServiceServer) IsDeviceLocked ¶ added in v0.0.4
func (UnimplementedManagerServiceServer) IsDeviceLocked(context.Context, *IsDeviceLockedRequest) (*IsDeviceLockedResponse, error)
func (UnimplementedManagerServiceServer) IsDeviceSecure ¶ added in v0.0.4
func (UnimplementedManagerServiceServer) IsDeviceSecure(context.Context, *IsDeviceSecureRequest) (*IsDeviceSecureResponse, error)
func (UnimplementedManagerServiceServer) IsKeyguardLocked ¶ added in v0.0.4
func (UnimplementedManagerServiceServer) IsKeyguardLocked(context.Context, *IsKeyguardLockedRequest) (*IsKeyguardLockedResponse, error)
func (UnimplementedManagerServiceServer) IsKeyguardSecure ¶ added in v0.0.4
func (UnimplementedManagerServiceServer) IsKeyguardSecure(context.Context, *IsKeyguardSecureRequest) (*IsKeyguardSecureResponse, error)
func (UnimplementedManagerServiceServer) NewKeyguardLock ¶ added in v0.0.4
func (UnimplementedManagerServiceServer) NewKeyguardLock(context.Context, *NewKeyguardLockRequest) (*NewKeyguardLockResponse, error)
func (UnimplementedManagerServiceServer) RemoveKeyguardLockedStateListener ¶ added in v0.0.4
func (UnimplementedManagerServiceServer) RemoveKeyguardLockedStateListener(context.Context, *RemoveKeyguardLockedStateListenerRequest) (*RemoveKeyguardLockedStateListenerResponse, error)
func (UnimplementedManagerServiceServer) RequestDismissKeyguard ¶ added in v0.0.4
func (UnimplementedManagerServiceServer) RequestDismissKeyguard(context.Context, *RequestDismissKeyguardRequest) (*RequestDismissKeyguardResponse, error)
type UnsafeManagerServiceServer ¶ added in v0.0.4
type UnsafeManagerServiceServer interface {
// contains filtered or unexported methods
}
UnsafeManagerServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ManagerServiceServer will result in compilation errors.