keyguard

package
v0.0.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 16, 2026 License: CC0-1.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

const (
	KeyguardManagerService_AddKeyguardLockedStateListener_FullMethodName      = "/keyguard.KeyguardManagerService/AddKeyguardLockedStateListener"
	KeyguardManagerService_CreateConfirmDeviceCredentialIntent_FullMethodName = "/keyguard.KeyguardManagerService/CreateConfirmDeviceCredentialIntent"
	KeyguardManagerService_ExitKeyguardSecurely_FullMethodName                = "/keyguard.KeyguardManagerService/ExitKeyguardSecurely"
	KeyguardManagerService_InKeyguardRestrictedInputMode_FullMethodName       = "/keyguard.KeyguardManagerService/InKeyguardRestrictedInputMode"
	KeyguardManagerService_IsDeviceLocked_FullMethodName                      = "/keyguard.KeyguardManagerService/IsDeviceLocked"
	KeyguardManagerService_IsDeviceSecure_FullMethodName                      = "/keyguard.KeyguardManagerService/IsDeviceSecure"
	KeyguardManagerService_IsKeyguardLocked_FullMethodName                    = "/keyguard.KeyguardManagerService/IsKeyguardLocked"
	KeyguardManagerService_IsKeyguardSecure_FullMethodName                    = "/keyguard.KeyguardManagerService/IsKeyguardSecure"
	KeyguardManagerService_NewKeyguardLock_FullMethodName                     = "/keyguard.KeyguardManagerService/NewKeyguardLock"
	KeyguardManagerService_RemoveKeyguardLockedStateListener_FullMethodName   = "/keyguard.KeyguardManagerService/RemoveKeyguardLockedStateListener"
	KeyguardManagerService_RequestDismissKeyguard_FullMethodName              = "/keyguard.KeyguardManagerService/RequestDismissKeyguard"
)

Variables

var File_proto_keyguard_keyguard_proto protoreflect.FileDescriptor
var KeyguardManagerService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "keyguard.KeyguardManagerService",
	HandlerType: (*KeyguardManagerServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "AddKeyguardLockedStateListener",
			Handler:    _KeyguardManagerService_AddKeyguardLockedStateListener_Handler,
		},
		{
			MethodName: "CreateConfirmDeviceCredentialIntent",
			Handler:    _KeyguardManagerService_CreateConfirmDeviceCredentialIntent_Handler,
		},
		{
			MethodName: "ExitKeyguardSecurely",
			Handler:    _KeyguardManagerService_ExitKeyguardSecurely_Handler,
		},
		{
			MethodName: "InKeyguardRestrictedInputMode",
			Handler:    _KeyguardManagerService_InKeyguardRestrictedInputMode_Handler,
		},
		{
			MethodName: "IsDeviceLocked",
			Handler:    _KeyguardManagerService_IsDeviceLocked_Handler,
		},
		{
			MethodName: "IsDeviceSecure",
			Handler:    _KeyguardManagerService_IsDeviceSecure_Handler,
		},
		{
			MethodName: "IsKeyguardLocked",
			Handler:    _KeyguardManagerService_IsKeyguardLocked_Handler,
		},
		{
			MethodName: "IsKeyguardSecure",
			Handler:    _KeyguardManagerService_IsKeyguardSecure_Handler,
		},
		{
			MethodName: "NewKeyguardLock",
			Handler:    _KeyguardManagerService_NewKeyguardLock_Handler,
		},
		{
			MethodName: "RemoveKeyguardLockedStateListener",
			Handler:    _KeyguardManagerService_RemoveKeyguardLockedStateListener_Handler,
		},
		{
			MethodName: "RequestDismissKeyguard",
			Handler:    _KeyguardManagerService_RequestDismissKeyguard_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/keyguard/keyguard.proto",
}

KeyguardManagerService_ServiceDesc is the grpc.ServiceDesc for KeyguardManagerService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterKeyguardManagerServiceServer

func RegisterKeyguardManagerServiceServer(s grpc.ServiceRegistrar, srv KeyguardManagerServiceServer)

Types

type AddKeyguardLockedStateListenerRequest

type AddKeyguardLockedStateListenerRequest struct {
	Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	Arg1 int64 `protobuf:"varint,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
	// contains filtered or unexported fields
}

func (*AddKeyguardLockedStateListenerRequest) Descriptor deprecated

func (*AddKeyguardLockedStateListenerRequest) Descriptor() ([]byte, []int)

Deprecated: Use AddKeyguardLockedStateListenerRequest.ProtoReflect.Descriptor instead.

func (*AddKeyguardLockedStateListenerRequest) GetArg0

func (*AddKeyguardLockedStateListenerRequest) GetArg1

func (*AddKeyguardLockedStateListenerRequest) ProtoMessage

func (*AddKeyguardLockedStateListenerRequest) ProtoMessage()

func (*AddKeyguardLockedStateListenerRequest) ProtoReflect

func (*AddKeyguardLockedStateListenerRequest) Reset

func (*AddKeyguardLockedStateListenerRequest) String

type AddKeyguardLockedStateListenerResponse

type AddKeyguardLockedStateListenerResponse struct {
	// contains filtered or unexported fields
}

func (*AddKeyguardLockedStateListenerResponse) Descriptor deprecated

func (*AddKeyguardLockedStateListenerResponse) Descriptor() ([]byte, []int)

Deprecated: Use AddKeyguardLockedStateListenerResponse.ProtoReflect.Descriptor instead.

func (*AddKeyguardLockedStateListenerResponse) ProtoMessage

func (*AddKeyguardLockedStateListenerResponse) ProtoReflect

func (*AddKeyguardLockedStateListenerResponse) Reset

func (*AddKeyguardLockedStateListenerResponse) String

type CreateConfirmDeviceCredentialIntentRequest

type CreateConfirmDeviceCredentialIntentRequest struct {
	Arg0 string `protobuf:"bytes,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	Arg1 string `protobuf:"bytes,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
	// contains filtered or unexported fields
}

func (*CreateConfirmDeviceCredentialIntentRequest) Descriptor deprecated

Deprecated: Use CreateConfirmDeviceCredentialIntentRequest.ProtoReflect.Descriptor instead.

func (*CreateConfirmDeviceCredentialIntentRequest) GetArg0

func (*CreateConfirmDeviceCredentialIntentRequest) GetArg1

func (*CreateConfirmDeviceCredentialIntentRequest) ProtoMessage

func (*CreateConfirmDeviceCredentialIntentRequest) ProtoReflect

func (*CreateConfirmDeviceCredentialIntentRequest) Reset

func (*CreateConfirmDeviceCredentialIntentRequest) String

type CreateConfirmDeviceCredentialIntentResponse

type CreateConfirmDeviceCredentialIntentResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*CreateConfirmDeviceCredentialIntentResponse) Descriptor deprecated

Deprecated: Use CreateConfirmDeviceCredentialIntentResponse.ProtoReflect.Descriptor instead.

func (*CreateConfirmDeviceCredentialIntentResponse) GetResult

func (*CreateConfirmDeviceCredentialIntentResponse) ProtoMessage

func (*CreateConfirmDeviceCredentialIntentResponse) ProtoReflect

func (*CreateConfirmDeviceCredentialIntentResponse) Reset

func (*CreateConfirmDeviceCredentialIntentResponse) String

type ExitKeyguardSecurelyRequest

type ExitKeyguardSecurelyRequest struct {
	Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*ExitKeyguardSecurelyRequest) Descriptor deprecated

func (*ExitKeyguardSecurelyRequest) Descriptor() ([]byte, []int)

Deprecated: Use ExitKeyguardSecurelyRequest.ProtoReflect.Descriptor instead.

func (*ExitKeyguardSecurelyRequest) GetArg0

func (x *ExitKeyguardSecurelyRequest) GetArg0() int64

func (*ExitKeyguardSecurelyRequest) ProtoMessage

func (*ExitKeyguardSecurelyRequest) ProtoMessage()

func (*ExitKeyguardSecurelyRequest) ProtoReflect

func (*ExitKeyguardSecurelyRequest) Reset

func (x *ExitKeyguardSecurelyRequest) Reset()

func (*ExitKeyguardSecurelyRequest) String

func (x *ExitKeyguardSecurelyRequest) String() string

type ExitKeyguardSecurelyResponse

type ExitKeyguardSecurelyResponse struct {
	// contains filtered or unexported fields
}

func (*ExitKeyguardSecurelyResponse) Descriptor deprecated

func (*ExitKeyguardSecurelyResponse) Descriptor() ([]byte, []int)

Deprecated: Use ExitKeyguardSecurelyResponse.ProtoReflect.Descriptor instead.

func (*ExitKeyguardSecurelyResponse) ProtoMessage

func (*ExitKeyguardSecurelyResponse) ProtoMessage()

func (*ExitKeyguardSecurelyResponse) ProtoReflect

func (*ExitKeyguardSecurelyResponse) Reset

func (x *ExitKeyguardSecurelyResponse) Reset()

func (*ExitKeyguardSecurelyResponse) String

type InKeyguardRestrictedInputModeRequest

type InKeyguardRestrictedInputModeRequest struct {
	// contains filtered or unexported fields
}

func (*InKeyguardRestrictedInputModeRequest) Descriptor deprecated

func (*InKeyguardRestrictedInputModeRequest) Descriptor() ([]byte, []int)

Deprecated: Use InKeyguardRestrictedInputModeRequest.ProtoReflect.Descriptor instead.

func (*InKeyguardRestrictedInputModeRequest) ProtoMessage

func (*InKeyguardRestrictedInputModeRequest) ProtoMessage()

func (*InKeyguardRestrictedInputModeRequest) ProtoReflect

func (*InKeyguardRestrictedInputModeRequest) Reset

func (*InKeyguardRestrictedInputModeRequest) String

type InKeyguardRestrictedInputModeResponse

type InKeyguardRestrictedInputModeResponse struct {
	Result bool `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*InKeyguardRestrictedInputModeResponse) Descriptor deprecated

func (*InKeyguardRestrictedInputModeResponse) Descriptor() ([]byte, []int)

Deprecated: Use InKeyguardRestrictedInputModeResponse.ProtoReflect.Descriptor instead.

func (*InKeyguardRestrictedInputModeResponse) GetResult

func (*InKeyguardRestrictedInputModeResponse) ProtoMessage

func (*InKeyguardRestrictedInputModeResponse) ProtoMessage()

func (*InKeyguardRestrictedInputModeResponse) ProtoReflect

func (*InKeyguardRestrictedInputModeResponse) Reset

func (*InKeyguardRestrictedInputModeResponse) String

type IsDeviceLockedRequest

type IsDeviceLockedRequest struct {
	// contains filtered or unexported fields
}

func (*IsDeviceLockedRequest) Descriptor deprecated

func (*IsDeviceLockedRequest) Descriptor() ([]byte, []int)

Deprecated: Use IsDeviceLockedRequest.ProtoReflect.Descriptor instead.

func (*IsDeviceLockedRequest) ProtoMessage

func (*IsDeviceLockedRequest) ProtoMessage()

func (*IsDeviceLockedRequest) ProtoReflect

func (x *IsDeviceLockedRequest) ProtoReflect() protoreflect.Message

func (*IsDeviceLockedRequest) Reset

func (x *IsDeviceLockedRequest) Reset()

func (*IsDeviceLockedRequest) String

func (x *IsDeviceLockedRequest) String() string

type IsDeviceLockedResponse

type IsDeviceLockedResponse struct {
	Result bool `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*IsDeviceLockedResponse) Descriptor deprecated

func (*IsDeviceLockedResponse) Descriptor() ([]byte, []int)

Deprecated: Use IsDeviceLockedResponse.ProtoReflect.Descriptor instead.

func (*IsDeviceLockedResponse) GetResult

func (x *IsDeviceLockedResponse) GetResult() bool

func (*IsDeviceLockedResponse) ProtoMessage

func (*IsDeviceLockedResponse) ProtoMessage()

func (*IsDeviceLockedResponse) ProtoReflect

func (x *IsDeviceLockedResponse) ProtoReflect() protoreflect.Message

func (*IsDeviceLockedResponse) Reset

func (x *IsDeviceLockedResponse) Reset()

func (*IsDeviceLockedResponse) String

func (x *IsDeviceLockedResponse) String() string

type IsDeviceSecureRequest

type IsDeviceSecureRequest struct {
	// contains filtered or unexported fields
}

func (*IsDeviceSecureRequest) Descriptor deprecated

func (*IsDeviceSecureRequest) Descriptor() ([]byte, []int)

Deprecated: Use IsDeviceSecureRequest.ProtoReflect.Descriptor instead.

func (*IsDeviceSecureRequest) ProtoMessage

func (*IsDeviceSecureRequest) ProtoMessage()

func (*IsDeviceSecureRequest) ProtoReflect

func (x *IsDeviceSecureRequest) ProtoReflect() protoreflect.Message

func (*IsDeviceSecureRequest) Reset

func (x *IsDeviceSecureRequest) Reset()

func (*IsDeviceSecureRequest) String

func (x *IsDeviceSecureRequest) String() string

type IsDeviceSecureResponse

type IsDeviceSecureResponse struct {
	Result bool `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*IsDeviceSecureResponse) Descriptor deprecated

func (*IsDeviceSecureResponse) Descriptor() ([]byte, []int)

Deprecated: Use IsDeviceSecureResponse.ProtoReflect.Descriptor instead.

func (*IsDeviceSecureResponse) GetResult

func (x *IsDeviceSecureResponse) GetResult() bool

func (*IsDeviceSecureResponse) ProtoMessage

func (*IsDeviceSecureResponse) ProtoMessage()

func (*IsDeviceSecureResponse) ProtoReflect

func (x *IsDeviceSecureResponse) ProtoReflect() protoreflect.Message

func (*IsDeviceSecureResponse) Reset

func (x *IsDeviceSecureResponse) Reset()

func (*IsDeviceSecureResponse) String

func (x *IsDeviceSecureResponse) String() string

type IsKeyguardLockedRequest

type IsKeyguardLockedRequest struct {
	// contains filtered or unexported fields
}

func (*IsKeyguardLockedRequest) Descriptor deprecated

func (*IsKeyguardLockedRequest) Descriptor() ([]byte, []int)

Deprecated: Use IsKeyguardLockedRequest.ProtoReflect.Descriptor instead.

func (*IsKeyguardLockedRequest) ProtoMessage

func (*IsKeyguardLockedRequest) ProtoMessage()

func (*IsKeyguardLockedRequest) ProtoReflect

func (x *IsKeyguardLockedRequest) ProtoReflect() protoreflect.Message

func (*IsKeyguardLockedRequest) Reset

func (x *IsKeyguardLockedRequest) Reset()

func (*IsKeyguardLockedRequest) String

func (x *IsKeyguardLockedRequest) String() string

type IsKeyguardLockedResponse

type IsKeyguardLockedResponse struct {
	Result bool `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*IsKeyguardLockedResponse) Descriptor deprecated

func (*IsKeyguardLockedResponse) Descriptor() ([]byte, []int)

Deprecated: Use IsKeyguardLockedResponse.ProtoReflect.Descriptor instead.

func (*IsKeyguardLockedResponse) GetResult

func (x *IsKeyguardLockedResponse) GetResult() bool

func (*IsKeyguardLockedResponse) ProtoMessage

func (*IsKeyguardLockedResponse) ProtoMessage()

func (*IsKeyguardLockedResponse) ProtoReflect

func (x *IsKeyguardLockedResponse) ProtoReflect() protoreflect.Message

func (*IsKeyguardLockedResponse) Reset

func (x *IsKeyguardLockedResponse) Reset()

func (*IsKeyguardLockedResponse) String

func (x *IsKeyguardLockedResponse) String() string

type IsKeyguardSecureRequest

type IsKeyguardSecureRequest struct {
	// contains filtered or unexported fields
}

func (*IsKeyguardSecureRequest) Descriptor deprecated

func (*IsKeyguardSecureRequest) Descriptor() ([]byte, []int)

Deprecated: Use IsKeyguardSecureRequest.ProtoReflect.Descriptor instead.

func (*IsKeyguardSecureRequest) ProtoMessage

func (*IsKeyguardSecureRequest) ProtoMessage()

func (*IsKeyguardSecureRequest) ProtoReflect

func (x *IsKeyguardSecureRequest) ProtoReflect() protoreflect.Message

func (*IsKeyguardSecureRequest) Reset

func (x *IsKeyguardSecureRequest) Reset()

func (*IsKeyguardSecureRequest) String

func (x *IsKeyguardSecureRequest) String() string

type IsKeyguardSecureResponse

type IsKeyguardSecureResponse struct {
	Result bool `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*IsKeyguardSecureResponse) Descriptor deprecated

func (*IsKeyguardSecureResponse) Descriptor() ([]byte, []int)

Deprecated: Use IsKeyguardSecureResponse.ProtoReflect.Descriptor instead.

func (*IsKeyguardSecureResponse) GetResult

func (x *IsKeyguardSecureResponse) GetResult() bool

func (*IsKeyguardSecureResponse) ProtoMessage

func (*IsKeyguardSecureResponse) ProtoMessage()

func (*IsKeyguardSecureResponse) ProtoReflect

func (x *IsKeyguardSecureResponse) ProtoReflect() protoreflect.Message

func (*IsKeyguardSecureResponse) Reset

func (x *IsKeyguardSecureResponse) Reset()

func (*IsKeyguardSecureResponse) String

func (x *IsKeyguardSecureResponse) String() string

type KeyguardManagerServiceClient

type KeyguardManagerServiceClient interface {
	AddKeyguardLockedStateListener(ctx context.Context, in *AddKeyguardLockedStateListenerRequest, opts ...grpc.CallOption) (*AddKeyguardLockedStateListenerResponse, error)
	CreateConfirmDeviceCredentialIntent(ctx context.Context, in *CreateConfirmDeviceCredentialIntentRequest, opts ...grpc.CallOption) (*CreateConfirmDeviceCredentialIntentResponse, error)
	ExitKeyguardSecurely(ctx context.Context, in *ExitKeyguardSecurelyRequest, opts ...grpc.CallOption) (*ExitKeyguardSecurelyResponse, error)
	InKeyguardRestrictedInputMode(ctx context.Context, in *InKeyguardRestrictedInputModeRequest, opts ...grpc.CallOption) (*InKeyguardRestrictedInputModeResponse, error)
	IsDeviceLocked(ctx context.Context, in *IsDeviceLockedRequest, opts ...grpc.CallOption) (*IsDeviceLockedResponse, error)
	IsDeviceSecure(ctx context.Context, in *IsDeviceSecureRequest, opts ...grpc.CallOption) (*IsDeviceSecureResponse, error)
	IsKeyguardLocked(ctx context.Context, in *IsKeyguardLockedRequest, opts ...grpc.CallOption) (*IsKeyguardLockedResponse, error)
	IsKeyguardSecure(ctx context.Context, in *IsKeyguardSecureRequest, opts ...grpc.CallOption) (*IsKeyguardSecureResponse, error)
	NewKeyguardLock(ctx context.Context, in *NewKeyguardLockRequest, opts ...grpc.CallOption) (*NewKeyguardLockResponse, error)
	RemoveKeyguardLockedStateListener(ctx context.Context, in *RemoveKeyguardLockedStateListenerRequest, opts ...grpc.CallOption) (*RemoveKeyguardLockedStateListenerResponse, error)
	RequestDismissKeyguard(ctx context.Context, in *RequestDismissKeyguardRequest, opts ...grpc.CallOption) (*RequestDismissKeyguardResponse, error)
}

KeyguardManagerServiceClient is the client API for KeyguardManagerService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type KeyguardManagerServiceServer

KeyguardManagerServiceServer is the server API for KeyguardManagerService service. All implementations must embed UnimplementedKeyguardManagerServiceServer for forward compatibility.

type NewKeyguardLockRequest

type NewKeyguardLockRequest struct {
	Arg0 string `protobuf:"bytes,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*NewKeyguardLockRequest) Descriptor deprecated

func (*NewKeyguardLockRequest) Descriptor() ([]byte, []int)

Deprecated: Use NewKeyguardLockRequest.ProtoReflect.Descriptor instead.

func (*NewKeyguardLockRequest) GetArg0

func (x *NewKeyguardLockRequest) GetArg0() string

func (*NewKeyguardLockRequest) ProtoMessage

func (*NewKeyguardLockRequest) ProtoMessage()

func (*NewKeyguardLockRequest) ProtoReflect

func (x *NewKeyguardLockRequest) ProtoReflect() protoreflect.Message

func (*NewKeyguardLockRequest) Reset

func (x *NewKeyguardLockRequest) Reset()

func (*NewKeyguardLockRequest) String

func (x *NewKeyguardLockRequest) String() string

type NewKeyguardLockResponse

type NewKeyguardLockResponse struct {
	Result int64 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	// contains filtered or unexported fields
}

func (*NewKeyguardLockResponse) Descriptor deprecated

func (*NewKeyguardLockResponse) Descriptor() ([]byte, []int)

Deprecated: Use NewKeyguardLockResponse.ProtoReflect.Descriptor instead.

func (*NewKeyguardLockResponse) GetResult

func (x *NewKeyguardLockResponse) GetResult() int64

func (*NewKeyguardLockResponse) ProtoMessage

func (*NewKeyguardLockResponse) ProtoMessage()

func (*NewKeyguardLockResponse) ProtoReflect

func (x *NewKeyguardLockResponse) ProtoReflect() protoreflect.Message

func (*NewKeyguardLockResponse) Reset

func (x *NewKeyguardLockResponse) Reset()

func (*NewKeyguardLockResponse) String

func (x *NewKeyguardLockResponse) String() string

type RemoveKeyguardLockedStateListenerRequest

type RemoveKeyguardLockedStateListenerRequest struct {
	Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	// contains filtered or unexported fields
}

func (*RemoveKeyguardLockedStateListenerRequest) Descriptor deprecated

func (*RemoveKeyguardLockedStateListenerRequest) Descriptor() ([]byte, []int)

Deprecated: Use RemoveKeyguardLockedStateListenerRequest.ProtoReflect.Descriptor instead.

func (*RemoveKeyguardLockedStateListenerRequest) GetArg0

func (*RemoveKeyguardLockedStateListenerRequest) ProtoMessage

func (*RemoveKeyguardLockedStateListenerRequest) ProtoReflect

func (*RemoveKeyguardLockedStateListenerRequest) Reset

func (*RemoveKeyguardLockedStateListenerRequest) String

type RemoveKeyguardLockedStateListenerResponse

type RemoveKeyguardLockedStateListenerResponse struct {
	// contains filtered or unexported fields
}

func (*RemoveKeyguardLockedStateListenerResponse) Descriptor deprecated

func (*RemoveKeyguardLockedStateListenerResponse) Descriptor() ([]byte, []int)

Deprecated: Use RemoveKeyguardLockedStateListenerResponse.ProtoReflect.Descriptor instead.

func (*RemoveKeyguardLockedStateListenerResponse) ProtoMessage

func (*RemoveKeyguardLockedStateListenerResponse) ProtoReflect

func (*RemoveKeyguardLockedStateListenerResponse) Reset

func (*RemoveKeyguardLockedStateListenerResponse) String

type RequestDismissKeyguardRequest

type RequestDismissKeyguardRequest struct {
	Arg0 int64 `protobuf:"varint,1,opt,name=arg0,proto3" json:"arg0,omitempty"`
	Arg1 int64 `protobuf:"varint,2,opt,name=arg1,proto3" json:"arg1,omitempty"`
	// contains filtered or unexported fields
}

func (*RequestDismissKeyguardRequest) Descriptor deprecated

func (*RequestDismissKeyguardRequest) Descriptor() ([]byte, []int)

Deprecated: Use RequestDismissKeyguardRequest.ProtoReflect.Descriptor instead.

func (*RequestDismissKeyguardRequest) GetArg0

func (x *RequestDismissKeyguardRequest) GetArg0() int64

func (*RequestDismissKeyguardRequest) GetArg1

func (x *RequestDismissKeyguardRequest) GetArg1() int64

func (*RequestDismissKeyguardRequest) ProtoMessage

func (*RequestDismissKeyguardRequest) ProtoMessage()

func (*RequestDismissKeyguardRequest) ProtoReflect

func (*RequestDismissKeyguardRequest) Reset

func (x *RequestDismissKeyguardRequest) Reset()

func (*RequestDismissKeyguardRequest) String

type RequestDismissKeyguardResponse

type RequestDismissKeyguardResponse struct {
	// contains filtered or unexported fields
}

func (*RequestDismissKeyguardResponse) Descriptor deprecated

func (*RequestDismissKeyguardResponse) Descriptor() ([]byte, []int)

Deprecated: Use RequestDismissKeyguardResponse.ProtoReflect.Descriptor instead.

func (*RequestDismissKeyguardResponse) ProtoMessage

func (*RequestDismissKeyguardResponse) ProtoMessage()

func (*RequestDismissKeyguardResponse) ProtoReflect

func (*RequestDismissKeyguardResponse) Reset

func (x *RequestDismissKeyguardResponse) Reset()

func (*RequestDismissKeyguardResponse) String

type UnimplementedKeyguardManagerServiceServer

type UnimplementedKeyguardManagerServiceServer struct{}

UnimplementedKeyguardManagerServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedKeyguardManagerServiceServer) ExitKeyguardSecurely

func (UnimplementedKeyguardManagerServiceServer) IsDeviceLocked

func (UnimplementedKeyguardManagerServiceServer) IsDeviceSecure

func (UnimplementedKeyguardManagerServiceServer) IsKeyguardLocked

func (UnimplementedKeyguardManagerServiceServer) IsKeyguardSecure

func (UnimplementedKeyguardManagerServiceServer) NewKeyguardLock

type UnsafeKeyguardManagerServiceServer

type UnsafeKeyguardManagerServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeKeyguardManagerServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to KeyguardManagerServiceServer will result in compilation errors.

Jump to