Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterEditorServiceServer(s grpc.ServiceRegistrar, srv EditorServiceServer)
- func RegisterPreferencesServiceServer(s grpc.ServiceRegistrar, srv PreferencesServiceServer)
- type EditorServiceClient
- type EditorServiceServer
- type PreferencesServiceClient
- type PreferencesServiceServer
- type UnimplementedEditorServiceServer
- func (UnimplementedEditorServiceServer) Apply(context.Context, *ApplyRequest) (*ApplyResponse, error)
- func (UnimplementedEditorServiceServer) Clear(context.Context, *ClearRequest) (*ClearResponse, error)
- func (UnimplementedEditorServiceServer) PutBoolean(context.Context, *PutBooleanRequest) (*PutBooleanResponse, error)
- func (UnimplementedEditorServiceServer) PutFloat(context.Context, *PutFloatRequest) (*PutFloatResponse, error)
- func (UnimplementedEditorServiceServer) PutInt(context.Context, *PutIntRequest) (*PutIntResponse, error)
- func (UnimplementedEditorServiceServer) PutLong(context.Context, *PutLongRequest) (*PutLongResponse, error)
- func (UnimplementedEditorServiceServer) PutString(context.Context, *PutStringRequest) (*PutStringResponse, error)
- func (UnimplementedEditorServiceServer) Remove(context.Context, *RemoveRequest) (*RemoveResponse, error)
- type UnimplementedPreferencesServiceServer
- func (UnimplementedPreferencesServiceServer) Contains(context.Context, *ContainsRequest) (*ContainsResponse, error)
- func (UnimplementedPreferencesServiceServer) Edit(context.Context, *EditRequest) (*EditResponse, error)
- func (UnimplementedPreferencesServiceServer) GetBool(context.Context, *GetBoolRequest) (*GetBoolResponse, error)
- func (UnimplementedPreferencesServiceServer) GetFloat(context.Context, *GetFloatRequest) (*GetFloatResponse, error)
- func (UnimplementedPreferencesServiceServer) GetInt(context.Context, *GetIntRequest) (*GetIntResponse, error)
- func (UnimplementedPreferencesServiceServer) GetLong(context.Context, *GetLongRequest) (*GetLongResponse, error)
- func (UnimplementedPreferencesServiceServer) GetString(context.Context, *GetStringRequest) (*GetStringResponse, error)
- type UnsafeEditorServiceServer
- type UnsafePreferencesServiceServer
Constants ¶
const ( PreferencesService_GetString_FullMethodName = "/preferences.PreferencesService/GetString" PreferencesService_GetInt_FullMethodName = "/preferences.PreferencesService/GetInt" PreferencesService_GetBool_FullMethodName = "/preferences.PreferencesService/GetBool" PreferencesService_GetFloat_FullMethodName = "/preferences.PreferencesService/GetFloat" PreferencesService_GetLong_FullMethodName = "/preferences.PreferencesService/GetLong" PreferencesService_Contains_FullMethodName = "/preferences.PreferencesService/Contains" PreferencesService_Edit_FullMethodName = "/preferences.PreferencesService/Edit" )
const ( EditorService_PutString_FullMethodName = "/preferences.EditorService/PutString" EditorService_PutInt_FullMethodName = "/preferences.EditorService/PutInt" EditorService_PutBoolean_FullMethodName = "/preferences.EditorService/PutBoolean" EditorService_PutFloat_FullMethodName = "/preferences.EditorService/PutFloat" EditorService_PutLong_FullMethodName = "/preferences.EditorService/PutLong" EditorService_Remove_FullMethodName = "/preferences.EditorService/Remove" EditorService_Clear_FullMethodName = "/preferences.EditorService/Clear" EditorService_Apply_FullMethodName = "/preferences.EditorService/Apply" )
Variables ¶
var EditorService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "preferences.EditorService", HandlerType: (*EditorServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "PutString", Handler: _EditorService_PutString_Handler, }, { MethodName: "PutInt", Handler: _EditorService_PutInt_Handler, }, { MethodName: "PutBoolean", Handler: _EditorService_PutBoolean_Handler, }, { MethodName: "PutFloat", Handler: _EditorService_PutFloat_Handler, }, { MethodName: "PutLong", Handler: _EditorService_PutLong_Handler, }, { MethodName: "Remove", Handler: _EditorService_Remove_Handler, }, { MethodName: "Clear", Handler: _EditorService_Clear_Handler, }, { MethodName: "Apply", Handler: _EditorService_Apply_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "proto/preferences/preferences.proto", }
EditorService_ServiceDesc is the grpc.ServiceDesc for EditorService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var File_proto_preferences_preferences_proto protoreflect.FileDescriptor
var PreferencesService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "preferences.PreferencesService", HandlerType: (*PreferencesServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "GetString", Handler: _PreferencesService_GetString_Handler, }, { MethodName: "GetInt", Handler: _PreferencesService_GetInt_Handler, }, { MethodName: "GetBool", Handler: _PreferencesService_GetBool_Handler, }, { MethodName: "GetFloat", Handler: _PreferencesService_GetFloat_Handler, }, { MethodName: "GetLong", Handler: _PreferencesService_GetLong_Handler, }, { MethodName: "Contains", Handler: _PreferencesService_Contains_Handler, }, { MethodName: "Edit", Handler: _PreferencesService_Edit_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "proto/preferences/preferences.proto", }
PreferencesService_ServiceDesc is the grpc.ServiceDesc for PreferencesService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterEditorServiceServer ¶
func RegisterEditorServiceServer(s grpc.ServiceRegistrar, srv EditorServiceServer)
func RegisterPreferencesServiceServer ¶
func RegisterPreferencesServiceServer(s grpc.ServiceRegistrar, srv PreferencesServiceServer)
Types ¶
type EditorServiceClient ¶
type EditorServiceClient interface {
PutString(ctx context.Context, in *PutStringRequest, opts ...grpc.CallOption) (*PutStringResponse, error)
PutInt(ctx context.Context, in *PutIntRequest, opts ...grpc.CallOption) (*PutIntResponse, error)
PutBoolean(ctx context.Context, in *PutBooleanRequest, opts ...grpc.CallOption) (*PutBooleanResponse, error)
PutFloat(ctx context.Context, in *PutFloatRequest, opts ...grpc.CallOption) (*PutFloatResponse, error)
PutLong(ctx context.Context, in *PutLongRequest, opts ...grpc.CallOption) (*PutLongResponse, error)
Remove(ctx context.Context, in *RemoveRequest, opts ...grpc.CallOption) (*RemoveResponse, error)
Clear(ctx context.Context, in *ClearRequest, opts ...grpc.CallOption) (*ClearResponse, error)
Apply(ctx context.Context, in *ApplyRequest, opts ...grpc.CallOption) (*ApplyResponse, error)
}
EditorServiceClient is the client API for EditorService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewEditorServiceClient ¶
func NewEditorServiceClient(cc grpc.ClientConnInterface) EditorServiceClient
type EditorServiceServer ¶
type EditorServiceServer interface {
PutString(context.Context, *PutStringRequest) (*PutStringResponse, error)
PutInt(context.Context, *PutIntRequest) (*PutIntResponse, error)
PutBoolean(context.Context, *PutBooleanRequest) (*PutBooleanResponse, error)
PutFloat(context.Context, *PutFloatRequest) (*PutFloatResponse, error)
PutLong(context.Context, *PutLongRequest) (*PutLongResponse, error)
Remove(context.Context, *RemoveRequest) (*RemoveResponse, error)
Clear(context.Context, *ClearRequest) (*ClearResponse, error)
Apply(context.Context, *ApplyRequest) (*ApplyResponse, error)
// contains filtered or unexported methods
}
EditorServiceServer is the server API for EditorService service. All implementations must embed UnimplementedEditorServiceServer for forward compatibility.
type PreferencesServiceClient ¶
type PreferencesServiceClient interface {
GetString(ctx context.Context, in *GetStringRequest, opts ...grpc.CallOption) (*GetStringResponse, error)
GetInt(ctx context.Context, in *GetIntRequest, opts ...grpc.CallOption) (*GetIntResponse, error)
GetBool(ctx context.Context, in *GetBoolRequest, opts ...grpc.CallOption) (*GetBoolResponse, error)
GetFloat(ctx context.Context, in *GetFloatRequest, opts ...grpc.CallOption) (*GetFloatResponse, error)
GetLong(ctx context.Context, in *GetLongRequest, opts ...grpc.CallOption) (*GetLongResponse, error)
Contains(ctx context.Context, in *ContainsRequest, opts ...grpc.CallOption) (*ContainsResponse, error)
Edit(ctx context.Context, in *EditRequest, opts ...grpc.CallOption) (*EditResponse, error)
}
PreferencesServiceClient is the client API for PreferencesService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewPreferencesServiceClient ¶
func NewPreferencesServiceClient(cc grpc.ClientConnInterface) PreferencesServiceClient
type PreferencesServiceServer ¶
type PreferencesServiceServer interface {
GetString(context.Context, *GetStringRequest) (*GetStringResponse, error)
GetInt(context.Context, *GetIntRequest) (*GetIntResponse, error)
GetBool(context.Context, *GetBoolRequest) (*GetBoolResponse, error)
GetFloat(context.Context, *GetFloatRequest) (*GetFloatResponse, error)
GetLong(context.Context, *GetLongRequest) (*GetLongResponse, error)
Contains(context.Context, *ContainsRequest) (*ContainsResponse, error)
Edit(context.Context, *EditRequest) (*EditResponse, error)
// contains filtered or unexported methods
}
PreferencesServiceServer is the server API for PreferencesService service. All implementations must embed UnimplementedPreferencesServiceServer for forward compatibility.
type UnimplementedEditorServiceServer ¶
type UnimplementedEditorServiceServer struct{}
UnimplementedEditorServiceServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedEditorServiceServer) Apply ¶
func (UnimplementedEditorServiceServer) Apply(context.Context, *ApplyRequest) (*ApplyResponse, error)
func (UnimplementedEditorServiceServer) Clear ¶
func (UnimplementedEditorServiceServer) Clear(context.Context, *ClearRequest) (*ClearResponse, error)
func (UnimplementedEditorServiceServer) PutBoolean ¶
func (UnimplementedEditorServiceServer) PutBoolean(context.Context, *PutBooleanRequest) (*PutBooleanResponse, error)
func (UnimplementedEditorServiceServer) PutFloat ¶
func (UnimplementedEditorServiceServer) PutFloat(context.Context, *PutFloatRequest) (*PutFloatResponse, error)
func (UnimplementedEditorServiceServer) PutInt ¶
func (UnimplementedEditorServiceServer) PutInt(context.Context, *PutIntRequest) (*PutIntResponse, error)
func (UnimplementedEditorServiceServer) PutLong ¶
func (UnimplementedEditorServiceServer) PutLong(context.Context, *PutLongRequest) (*PutLongResponse, error)
type UnimplementedPreferencesServiceServer ¶
type UnimplementedPreferencesServiceServer struct{}
UnimplementedPreferencesServiceServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedPreferencesServiceServer) Contains ¶
func (UnimplementedPreferencesServiceServer) Contains(context.Context, *ContainsRequest) (*ContainsResponse, error)
func (UnimplementedPreferencesServiceServer) Edit ¶
func (UnimplementedPreferencesServiceServer) Edit(context.Context, *EditRequest) (*EditResponse, error)
func (UnimplementedPreferencesServiceServer) GetBool ¶
func (UnimplementedPreferencesServiceServer) GetBool(context.Context, *GetBoolRequest) (*GetBoolResponse, error)
func (UnimplementedPreferencesServiceServer) GetFloat ¶
func (UnimplementedPreferencesServiceServer) GetFloat(context.Context, *GetFloatRequest) (*GetFloatResponse, error)
func (UnimplementedPreferencesServiceServer) GetInt ¶
func (UnimplementedPreferencesServiceServer) GetInt(context.Context, *GetIntRequest) (*GetIntResponse, error)
type UnsafeEditorServiceServer ¶
type UnsafeEditorServiceServer interface {
// contains filtered or unexported methods
}
UnsafeEditorServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to EditorServiceServer will result in compilation errors.
type UnsafePreferencesServiceServer ¶
type UnsafePreferencesServiceServer interface {
// contains filtered or unexported methods
}
UnsafePreferencesServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to PreferencesServiceServer will result in compilation errors.