Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterSettingsGlobalServiceServer(s grpc.ServiceRegistrar, srv SettingsGlobalServiceServer)
- func RegisterSettingsSecureServiceServer(s grpc.ServiceRegistrar, srv SettingsSecureServiceServer)
- func RegisterSettingsSystemServiceServer(s grpc.ServiceRegistrar, srv SettingsSystemServiceServer)
- type GetIntGlobalRequest
- func (*GetIntGlobalRequest) Descriptor() ([]byte, []int)deprecated
- func (x *GetIntGlobalRequest) GetDef() int32
- func (x *GetIntGlobalRequest) GetName() string
- func (x *GetIntGlobalRequest) GetResolver() int64
- func (*GetIntGlobalRequest) ProtoMessage()
- func (x *GetIntGlobalRequest) ProtoReflect() protoreflect.Message
- func (x *GetIntGlobalRequest) Reset()
- func (x *GetIntGlobalRequest) String() string
- type GetIntGlobalResponse
- func (*GetIntGlobalResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetIntGlobalResponse) GetResult() int32
- func (*GetIntGlobalResponse) ProtoMessage()
- func (x *GetIntGlobalResponse) ProtoReflect() protoreflect.Message
- func (x *GetIntGlobalResponse) Reset()
- func (x *GetIntGlobalResponse) String() string
- type GetIntSecureRequest
- func (*GetIntSecureRequest) Descriptor() ([]byte, []int)deprecated
- func (x *GetIntSecureRequest) GetDef() int32
- func (x *GetIntSecureRequest) GetName() string
- func (x *GetIntSecureRequest) GetResolver() int64
- func (*GetIntSecureRequest) ProtoMessage()
- func (x *GetIntSecureRequest) ProtoReflect() protoreflect.Message
- func (x *GetIntSecureRequest) Reset()
- func (x *GetIntSecureRequest) String() string
- type GetIntSecureResponse
- func (*GetIntSecureResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetIntSecureResponse) GetResult() int32
- func (*GetIntSecureResponse) ProtoMessage()
- func (x *GetIntSecureResponse) ProtoReflect() protoreflect.Message
- func (x *GetIntSecureResponse) Reset()
- func (x *GetIntSecureResponse) String() string
- type GetIntSystemRequest
- func (*GetIntSystemRequest) Descriptor() ([]byte, []int)deprecated
- func (x *GetIntSystemRequest) GetDef() int32
- func (x *GetIntSystemRequest) GetName() string
- func (x *GetIntSystemRequest) GetResolver() int64
- func (*GetIntSystemRequest) ProtoMessage()
- func (x *GetIntSystemRequest) ProtoReflect() protoreflect.Message
- func (x *GetIntSystemRequest) Reset()
- func (x *GetIntSystemRequest) String() string
- type GetIntSystemResponse
- func (*GetIntSystemResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetIntSystemResponse) GetResult() int32
- func (*GetIntSystemResponse) ProtoMessage()
- func (x *GetIntSystemResponse) ProtoReflect() protoreflect.Message
- func (x *GetIntSystemResponse) Reset()
- func (x *GetIntSystemResponse) String() string
- type GetStringGlobalRequest
- func (*GetStringGlobalRequest) Descriptor() ([]byte, []int)deprecated
- func (x *GetStringGlobalRequest) GetName() string
- func (x *GetStringGlobalRequest) GetResolver() int64
- func (*GetStringGlobalRequest) ProtoMessage()
- func (x *GetStringGlobalRequest) ProtoReflect() protoreflect.Message
- func (x *GetStringGlobalRequest) Reset()
- func (x *GetStringGlobalRequest) String() string
- type GetStringGlobalResponse
- func (*GetStringGlobalResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetStringGlobalResponse) GetResult() string
- func (*GetStringGlobalResponse) ProtoMessage()
- func (x *GetStringGlobalResponse) ProtoReflect() protoreflect.Message
- func (x *GetStringGlobalResponse) Reset()
- func (x *GetStringGlobalResponse) String() string
- type GetStringSecureRequest
- func (*GetStringSecureRequest) Descriptor() ([]byte, []int)deprecated
- func (x *GetStringSecureRequest) GetName() string
- func (x *GetStringSecureRequest) GetResolver() int64
- func (*GetStringSecureRequest) ProtoMessage()
- func (x *GetStringSecureRequest) ProtoReflect() protoreflect.Message
- func (x *GetStringSecureRequest) Reset()
- func (x *GetStringSecureRequest) String() string
- type GetStringSecureResponse
- func (*GetStringSecureResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetStringSecureResponse) GetResult() string
- func (*GetStringSecureResponse) ProtoMessage()
- func (x *GetStringSecureResponse) ProtoReflect() protoreflect.Message
- func (x *GetStringSecureResponse) Reset()
- func (x *GetStringSecureResponse) String() string
- type GetStringSystemRequest
- func (*GetStringSystemRequest) Descriptor() ([]byte, []int)deprecated
- func (x *GetStringSystemRequest) GetName() string
- func (x *GetStringSystemRequest) GetResolver() int64
- func (*GetStringSystemRequest) ProtoMessage()
- func (x *GetStringSystemRequest) ProtoReflect() protoreflect.Message
- func (x *GetStringSystemRequest) Reset()
- func (x *GetStringSystemRequest) String() string
- type GetStringSystemResponse
- func (*GetStringSystemResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetStringSystemResponse) GetResult() string
- func (*GetStringSystemResponse) ProtoMessage()
- func (x *GetStringSystemResponse) ProtoReflect() protoreflect.Message
- func (x *GetStringSystemResponse) Reset()
- func (x *GetStringSystemResponse) String() string
- type PutIntSystemRequest
- func (*PutIntSystemRequest) Descriptor() ([]byte, []int)deprecated
- func (x *PutIntSystemRequest) GetName() string
- func (x *PutIntSystemRequest) GetResolver() int64
- func (x *PutIntSystemRequest) GetValue() int32
- func (*PutIntSystemRequest) ProtoMessage()
- func (x *PutIntSystemRequest) ProtoReflect() protoreflect.Message
- func (x *PutIntSystemRequest) Reset()
- func (x *PutIntSystemRequest) String() string
- type PutIntSystemResponse
- func (*PutIntSystemResponse) Descriptor() ([]byte, []int)deprecated
- func (x *PutIntSystemResponse) GetResult() bool
- func (*PutIntSystemResponse) ProtoMessage()
- func (x *PutIntSystemResponse) ProtoReflect() protoreflect.Message
- func (x *PutIntSystemResponse) Reset()
- func (x *PutIntSystemResponse) String() string
- type SettingsGlobalServiceClient
- type SettingsGlobalServiceServer
- type SettingsSecureServiceClient
- type SettingsSecureServiceServer
- type SettingsSystemServiceClient
- type SettingsSystemServiceServer
- type UnimplementedSettingsGlobalServiceServer
- type UnimplementedSettingsSecureServiceServer
- type UnimplementedSettingsSystemServiceServer
- func (UnimplementedSettingsSystemServiceServer) GetIntSystem(context.Context, *GetIntSystemRequest) (*GetIntSystemResponse, error)
- func (UnimplementedSettingsSystemServiceServer) GetStringSystem(context.Context, *GetStringSystemRequest) (*GetStringSystemResponse, error)
- func (UnimplementedSettingsSystemServiceServer) PutIntSystem(context.Context, *PutIntSystemRequest) (*PutIntSystemResponse, error)
- type UnsafeSettingsGlobalServiceServer
- type UnsafeSettingsSecureServiceServer
- type UnsafeSettingsSystemServiceServer
Constants ¶
const ( SettingsSystemService_GetIntSystem_FullMethodName = "/settings.SettingsSystemService/GetIntSystem" SettingsSystemService_PutIntSystem_FullMethodName = "/settings.SettingsSystemService/PutIntSystem" SettingsSystemService_GetStringSystem_FullMethodName = "/settings.SettingsSystemService/GetStringSystem" )
const ( SettingsSecureService_GetIntSecure_FullMethodName = "/settings.SettingsSecureService/GetIntSecure" SettingsSecureService_GetStringSecure_FullMethodName = "/settings.SettingsSecureService/GetStringSecure" )
const ( SettingsGlobalService_GetIntGlobal_FullMethodName = "/settings.SettingsGlobalService/GetIntGlobal" SettingsGlobalService_GetStringGlobal_FullMethodName = "/settings.SettingsGlobalService/GetStringGlobal" )
Variables ¶
var File_proto_settings_settings_proto protoreflect.FileDescriptor
var SettingsGlobalService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "settings.SettingsGlobalService", HandlerType: (*SettingsGlobalServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "GetIntGlobal", Handler: _SettingsGlobalService_GetIntGlobal_Handler, }, { MethodName: "GetStringGlobal", Handler: _SettingsGlobalService_GetStringGlobal_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "proto/settings/settings.proto", }
SettingsGlobalService_ServiceDesc is the grpc.ServiceDesc for SettingsGlobalService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var SettingsSecureService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "settings.SettingsSecureService", HandlerType: (*SettingsSecureServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "GetIntSecure", Handler: _SettingsSecureService_GetIntSecure_Handler, }, { MethodName: "GetStringSecure", Handler: _SettingsSecureService_GetStringSecure_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "proto/settings/settings.proto", }
SettingsSecureService_ServiceDesc is the grpc.ServiceDesc for SettingsSecureService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var SettingsSystemService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "settings.SettingsSystemService", HandlerType: (*SettingsSystemServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "GetIntSystem", Handler: _SettingsSystemService_GetIntSystem_Handler, }, { MethodName: "PutIntSystem", Handler: _SettingsSystemService_PutIntSystem_Handler, }, { MethodName: "GetStringSystem", Handler: _SettingsSystemService_GetStringSystem_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "proto/settings/settings.proto", }
SettingsSystemService_ServiceDesc is the grpc.ServiceDesc for SettingsSystemService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterSettingsGlobalServiceServer ¶
func RegisterSettingsGlobalServiceServer(s grpc.ServiceRegistrar, srv SettingsGlobalServiceServer)
func RegisterSettingsSecureServiceServer ¶
func RegisterSettingsSecureServiceServer(s grpc.ServiceRegistrar, srv SettingsSecureServiceServer)
func RegisterSettingsSystemServiceServer ¶
func RegisterSettingsSystemServiceServer(s grpc.ServiceRegistrar, srv SettingsSystemServiceServer)
Types ¶
type GetIntGlobalRequest ¶
type GetIntGlobalRequest struct {
Resolver int64 `protobuf:"varint,1,opt,name=resolver,proto3" json:"resolver,omitempty"`
Name string `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
Def int32 `protobuf:"varint,3,opt,name=def,proto3" json:"def,omitempty"`
// contains filtered or unexported fields
}
func (*GetIntGlobalRequest) Descriptor
deprecated
func (*GetIntGlobalRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetIntGlobalRequest.ProtoReflect.Descriptor instead.
func (*GetIntGlobalRequest) GetDef ¶
func (x *GetIntGlobalRequest) GetDef() int32
func (*GetIntGlobalRequest) GetName ¶
func (x *GetIntGlobalRequest) GetName() string
func (*GetIntGlobalRequest) GetResolver ¶
func (x *GetIntGlobalRequest) GetResolver() int64
func (*GetIntGlobalRequest) ProtoMessage ¶
func (*GetIntGlobalRequest) ProtoMessage()
func (*GetIntGlobalRequest) ProtoReflect ¶
func (x *GetIntGlobalRequest) ProtoReflect() protoreflect.Message
func (*GetIntGlobalRequest) Reset ¶
func (x *GetIntGlobalRequest) Reset()
func (*GetIntGlobalRequest) String ¶
func (x *GetIntGlobalRequest) String() string
type GetIntGlobalResponse ¶
type GetIntGlobalResponse struct {
Result int32 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*GetIntGlobalResponse) Descriptor
deprecated
func (*GetIntGlobalResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetIntGlobalResponse.ProtoReflect.Descriptor instead.
func (*GetIntGlobalResponse) GetResult ¶
func (x *GetIntGlobalResponse) GetResult() int32
func (*GetIntGlobalResponse) ProtoMessage ¶
func (*GetIntGlobalResponse) ProtoMessage()
func (*GetIntGlobalResponse) ProtoReflect ¶
func (x *GetIntGlobalResponse) ProtoReflect() protoreflect.Message
func (*GetIntGlobalResponse) Reset ¶
func (x *GetIntGlobalResponse) Reset()
func (*GetIntGlobalResponse) String ¶
func (x *GetIntGlobalResponse) String() string
type GetIntSecureRequest ¶
type GetIntSecureRequest struct {
Resolver int64 `protobuf:"varint,1,opt,name=resolver,proto3" json:"resolver,omitempty"`
Name string `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
Def int32 `protobuf:"varint,3,opt,name=def,proto3" json:"def,omitempty"`
// contains filtered or unexported fields
}
func (*GetIntSecureRequest) Descriptor
deprecated
func (*GetIntSecureRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetIntSecureRequest.ProtoReflect.Descriptor instead.
func (*GetIntSecureRequest) GetDef ¶
func (x *GetIntSecureRequest) GetDef() int32
func (*GetIntSecureRequest) GetName ¶
func (x *GetIntSecureRequest) GetName() string
func (*GetIntSecureRequest) GetResolver ¶
func (x *GetIntSecureRequest) GetResolver() int64
func (*GetIntSecureRequest) ProtoMessage ¶
func (*GetIntSecureRequest) ProtoMessage()
func (*GetIntSecureRequest) ProtoReflect ¶
func (x *GetIntSecureRequest) ProtoReflect() protoreflect.Message
func (*GetIntSecureRequest) Reset ¶
func (x *GetIntSecureRequest) Reset()
func (*GetIntSecureRequest) String ¶
func (x *GetIntSecureRequest) String() string
type GetIntSecureResponse ¶
type GetIntSecureResponse struct {
Result int32 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*GetIntSecureResponse) Descriptor
deprecated
func (*GetIntSecureResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetIntSecureResponse.ProtoReflect.Descriptor instead.
func (*GetIntSecureResponse) GetResult ¶
func (x *GetIntSecureResponse) GetResult() int32
func (*GetIntSecureResponse) ProtoMessage ¶
func (*GetIntSecureResponse) ProtoMessage()
func (*GetIntSecureResponse) ProtoReflect ¶
func (x *GetIntSecureResponse) ProtoReflect() protoreflect.Message
func (*GetIntSecureResponse) Reset ¶
func (x *GetIntSecureResponse) Reset()
func (*GetIntSecureResponse) String ¶
func (x *GetIntSecureResponse) String() string
type GetIntSystemRequest ¶
type GetIntSystemRequest struct {
Resolver int64 `protobuf:"varint,1,opt,name=resolver,proto3" json:"resolver,omitempty"`
Name string `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
Def int32 `protobuf:"varint,3,opt,name=def,proto3" json:"def,omitempty"`
// contains filtered or unexported fields
}
func (*GetIntSystemRequest) Descriptor
deprecated
func (*GetIntSystemRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetIntSystemRequest.ProtoReflect.Descriptor instead.
func (*GetIntSystemRequest) GetDef ¶
func (x *GetIntSystemRequest) GetDef() int32
func (*GetIntSystemRequest) GetName ¶
func (x *GetIntSystemRequest) GetName() string
func (*GetIntSystemRequest) GetResolver ¶
func (x *GetIntSystemRequest) GetResolver() int64
func (*GetIntSystemRequest) ProtoMessage ¶
func (*GetIntSystemRequest) ProtoMessage()
func (*GetIntSystemRequest) ProtoReflect ¶
func (x *GetIntSystemRequest) ProtoReflect() protoreflect.Message
func (*GetIntSystemRequest) Reset ¶
func (x *GetIntSystemRequest) Reset()
func (*GetIntSystemRequest) String ¶
func (x *GetIntSystemRequest) String() string
type GetIntSystemResponse ¶
type GetIntSystemResponse struct {
Result int32 `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*GetIntSystemResponse) Descriptor
deprecated
func (*GetIntSystemResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetIntSystemResponse.ProtoReflect.Descriptor instead.
func (*GetIntSystemResponse) GetResult ¶
func (x *GetIntSystemResponse) GetResult() int32
func (*GetIntSystemResponse) ProtoMessage ¶
func (*GetIntSystemResponse) ProtoMessage()
func (*GetIntSystemResponse) ProtoReflect ¶
func (x *GetIntSystemResponse) ProtoReflect() protoreflect.Message
func (*GetIntSystemResponse) Reset ¶
func (x *GetIntSystemResponse) Reset()
func (*GetIntSystemResponse) String ¶
func (x *GetIntSystemResponse) String() string
type GetStringGlobalRequest ¶
type GetStringGlobalRequest struct {
Resolver int64 `protobuf:"varint,1,opt,name=resolver,proto3" json:"resolver,omitempty"`
Name string `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
// contains filtered or unexported fields
}
func (*GetStringGlobalRequest) Descriptor
deprecated
func (*GetStringGlobalRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetStringGlobalRequest.ProtoReflect.Descriptor instead.
func (*GetStringGlobalRequest) GetName ¶
func (x *GetStringGlobalRequest) GetName() string
func (*GetStringGlobalRequest) GetResolver ¶
func (x *GetStringGlobalRequest) GetResolver() int64
func (*GetStringGlobalRequest) ProtoMessage ¶
func (*GetStringGlobalRequest) ProtoMessage()
func (*GetStringGlobalRequest) ProtoReflect ¶
func (x *GetStringGlobalRequest) ProtoReflect() protoreflect.Message
func (*GetStringGlobalRequest) Reset ¶
func (x *GetStringGlobalRequest) Reset()
func (*GetStringGlobalRequest) String ¶
func (x *GetStringGlobalRequest) String() string
type GetStringGlobalResponse ¶
type GetStringGlobalResponse struct {
Result string `protobuf:"bytes,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*GetStringGlobalResponse) Descriptor
deprecated
func (*GetStringGlobalResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetStringGlobalResponse.ProtoReflect.Descriptor instead.
func (*GetStringGlobalResponse) GetResult ¶
func (x *GetStringGlobalResponse) GetResult() string
func (*GetStringGlobalResponse) ProtoMessage ¶
func (*GetStringGlobalResponse) ProtoMessage()
func (*GetStringGlobalResponse) ProtoReflect ¶
func (x *GetStringGlobalResponse) ProtoReflect() protoreflect.Message
func (*GetStringGlobalResponse) Reset ¶
func (x *GetStringGlobalResponse) Reset()
func (*GetStringGlobalResponse) String ¶
func (x *GetStringGlobalResponse) String() string
type GetStringSecureRequest ¶
type GetStringSecureRequest struct {
Resolver int64 `protobuf:"varint,1,opt,name=resolver,proto3" json:"resolver,omitempty"`
Name string `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
// contains filtered or unexported fields
}
func (*GetStringSecureRequest) Descriptor
deprecated
func (*GetStringSecureRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetStringSecureRequest.ProtoReflect.Descriptor instead.
func (*GetStringSecureRequest) GetName ¶
func (x *GetStringSecureRequest) GetName() string
func (*GetStringSecureRequest) GetResolver ¶
func (x *GetStringSecureRequest) GetResolver() int64
func (*GetStringSecureRequest) ProtoMessage ¶
func (*GetStringSecureRequest) ProtoMessage()
func (*GetStringSecureRequest) ProtoReflect ¶
func (x *GetStringSecureRequest) ProtoReflect() protoreflect.Message
func (*GetStringSecureRequest) Reset ¶
func (x *GetStringSecureRequest) Reset()
func (*GetStringSecureRequest) String ¶
func (x *GetStringSecureRequest) String() string
type GetStringSecureResponse ¶
type GetStringSecureResponse struct {
Result string `protobuf:"bytes,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*GetStringSecureResponse) Descriptor
deprecated
func (*GetStringSecureResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetStringSecureResponse.ProtoReflect.Descriptor instead.
func (*GetStringSecureResponse) GetResult ¶
func (x *GetStringSecureResponse) GetResult() string
func (*GetStringSecureResponse) ProtoMessage ¶
func (*GetStringSecureResponse) ProtoMessage()
func (*GetStringSecureResponse) ProtoReflect ¶
func (x *GetStringSecureResponse) ProtoReflect() protoreflect.Message
func (*GetStringSecureResponse) Reset ¶
func (x *GetStringSecureResponse) Reset()
func (*GetStringSecureResponse) String ¶
func (x *GetStringSecureResponse) String() string
type GetStringSystemRequest ¶
type GetStringSystemRequest struct {
Resolver int64 `protobuf:"varint,1,opt,name=resolver,proto3" json:"resolver,omitempty"`
Name string `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
// contains filtered or unexported fields
}
func (*GetStringSystemRequest) Descriptor
deprecated
func (*GetStringSystemRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetStringSystemRequest.ProtoReflect.Descriptor instead.
func (*GetStringSystemRequest) GetName ¶
func (x *GetStringSystemRequest) GetName() string
func (*GetStringSystemRequest) GetResolver ¶
func (x *GetStringSystemRequest) GetResolver() int64
func (*GetStringSystemRequest) ProtoMessage ¶
func (*GetStringSystemRequest) ProtoMessage()
func (*GetStringSystemRequest) ProtoReflect ¶
func (x *GetStringSystemRequest) ProtoReflect() protoreflect.Message
func (*GetStringSystemRequest) Reset ¶
func (x *GetStringSystemRequest) Reset()
func (*GetStringSystemRequest) String ¶
func (x *GetStringSystemRequest) String() string
type GetStringSystemResponse ¶
type GetStringSystemResponse struct {
Result string `protobuf:"bytes,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*GetStringSystemResponse) Descriptor
deprecated
func (*GetStringSystemResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetStringSystemResponse.ProtoReflect.Descriptor instead.
func (*GetStringSystemResponse) GetResult ¶
func (x *GetStringSystemResponse) GetResult() string
func (*GetStringSystemResponse) ProtoMessage ¶
func (*GetStringSystemResponse) ProtoMessage()
func (*GetStringSystemResponse) ProtoReflect ¶
func (x *GetStringSystemResponse) ProtoReflect() protoreflect.Message
func (*GetStringSystemResponse) Reset ¶
func (x *GetStringSystemResponse) Reset()
func (*GetStringSystemResponse) String ¶
func (x *GetStringSystemResponse) String() string
type PutIntSystemRequest ¶
type PutIntSystemRequest struct {
Resolver int64 `protobuf:"varint,1,opt,name=resolver,proto3" json:"resolver,omitempty"`
Name string `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
Value int32 `protobuf:"varint,3,opt,name=value,proto3" json:"value,omitempty"`
// contains filtered or unexported fields
}
func (*PutIntSystemRequest) Descriptor
deprecated
func (*PutIntSystemRequest) Descriptor() ([]byte, []int)
Deprecated: Use PutIntSystemRequest.ProtoReflect.Descriptor instead.
func (*PutIntSystemRequest) GetName ¶
func (x *PutIntSystemRequest) GetName() string
func (*PutIntSystemRequest) GetResolver ¶
func (x *PutIntSystemRequest) GetResolver() int64
func (*PutIntSystemRequest) GetValue ¶
func (x *PutIntSystemRequest) GetValue() int32
func (*PutIntSystemRequest) ProtoMessage ¶
func (*PutIntSystemRequest) ProtoMessage()
func (*PutIntSystemRequest) ProtoReflect ¶
func (x *PutIntSystemRequest) ProtoReflect() protoreflect.Message
func (*PutIntSystemRequest) Reset ¶
func (x *PutIntSystemRequest) Reset()
func (*PutIntSystemRequest) String ¶
func (x *PutIntSystemRequest) String() string
type PutIntSystemResponse ¶
type PutIntSystemResponse struct {
Result bool `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*PutIntSystemResponse) Descriptor
deprecated
func (*PutIntSystemResponse) Descriptor() ([]byte, []int)
Deprecated: Use PutIntSystemResponse.ProtoReflect.Descriptor instead.
func (*PutIntSystemResponse) GetResult ¶
func (x *PutIntSystemResponse) GetResult() bool
func (*PutIntSystemResponse) ProtoMessage ¶
func (*PutIntSystemResponse) ProtoMessage()
func (*PutIntSystemResponse) ProtoReflect ¶
func (x *PutIntSystemResponse) ProtoReflect() protoreflect.Message
func (*PutIntSystemResponse) Reset ¶
func (x *PutIntSystemResponse) Reset()
func (*PutIntSystemResponse) String ¶
func (x *PutIntSystemResponse) String() string
type SettingsGlobalServiceClient ¶
type SettingsGlobalServiceClient interface {
GetIntGlobal(ctx context.Context, in *GetIntGlobalRequest, opts ...grpc.CallOption) (*GetIntGlobalResponse, error)
GetStringGlobal(ctx context.Context, in *GetStringGlobalRequest, opts ...grpc.CallOption) (*GetStringGlobalResponse, error)
}
SettingsGlobalServiceClient is the client API for SettingsGlobalService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewSettingsGlobalServiceClient ¶
func NewSettingsGlobalServiceClient(cc grpc.ClientConnInterface) SettingsGlobalServiceClient
type SettingsGlobalServiceServer ¶
type SettingsGlobalServiceServer interface {
GetIntGlobal(context.Context, *GetIntGlobalRequest) (*GetIntGlobalResponse, error)
GetStringGlobal(context.Context, *GetStringGlobalRequest) (*GetStringGlobalResponse, error)
// contains filtered or unexported methods
}
SettingsGlobalServiceServer is the server API for SettingsGlobalService service. All implementations must embed UnimplementedSettingsGlobalServiceServer for forward compatibility.
type SettingsSecureServiceClient ¶
type SettingsSecureServiceClient interface {
GetIntSecure(ctx context.Context, in *GetIntSecureRequest, opts ...grpc.CallOption) (*GetIntSecureResponse, error)
GetStringSecure(ctx context.Context, in *GetStringSecureRequest, opts ...grpc.CallOption) (*GetStringSecureResponse, error)
}
SettingsSecureServiceClient is the client API for SettingsSecureService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewSettingsSecureServiceClient ¶
func NewSettingsSecureServiceClient(cc grpc.ClientConnInterface) SettingsSecureServiceClient
type SettingsSecureServiceServer ¶
type SettingsSecureServiceServer interface {
GetIntSecure(context.Context, *GetIntSecureRequest) (*GetIntSecureResponse, error)
GetStringSecure(context.Context, *GetStringSecureRequest) (*GetStringSecureResponse, error)
// contains filtered or unexported methods
}
SettingsSecureServiceServer is the server API for SettingsSecureService service. All implementations must embed UnimplementedSettingsSecureServiceServer for forward compatibility.
type SettingsSystemServiceClient ¶
type SettingsSystemServiceClient interface {
GetIntSystem(ctx context.Context, in *GetIntSystemRequest, opts ...grpc.CallOption) (*GetIntSystemResponse, error)
PutIntSystem(ctx context.Context, in *PutIntSystemRequest, opts ...grpc.CallOption) (*PutIntSystemResponse, error)
GetStringSystem(ctx context.Context, in *GetStringSystemRequest, opts ...grpc.CallOption) (*GetStringSystemResponse, error)
}
SettingsSystemServiceClient is the client API for SettingsSystemService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewSettingsSystemServiceClient ¶
func NewSettingsSystemServiceClient(cc grpc.ClientConnInterface) SettingsSystemServiceClient
type SettingsSystemServiceServer ¶
type SettingsSystemServiceServer interface {
GetIntSystem(context.Context, *GetIntSystemRequest) (*GetIntSystemResponse, error)
PutIntSystem(context.Context, *PutIntSystemRequest) (*PutIntSystemResponse, error)
GetStringSystem(context.Context, *GetStringSystemRequest) (*GetStringSystemResponse, error)
// contains filtered or unexported methods
}
SettingsSystemServiceServer is the server API for SettingsSystemService service. All implementations must embed UnimplementedSettingsSystemServiceServer for forward compatibility.
type UnimplementedSettingsGlobalServiceServer ¶
type UnimplementedSettingsGlobalServiceServer struct{}
UnimplementedSettingsGlobalServiceServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedSettingsGlobalServiceServer) GetIntGlobal ¶
func (UnimplementedSettingsGlobalServiceServer) GetIntGlobal(context.Context, *GetIntGlobalRequest) (*GetIntGlobalResponse, error)
func (UnimplementedSettingsGlobalServiceServer) GetStringGlobal ¶
func (UnimplementedSettingsGlobalServiceServer) GetStringGlobal(context.Context, *GetStringGlobalRequest) (*GetStringGlobalResponse, error)
type UnimplementedSettingsSecureServiceServer ¶
type UnimplementedSettingsSecureServiceServer struct{}
UnimplementedSettingsSecureServiceServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedSettingsSecureServiceServer) GetIntSecure ¶
func (UnimplementedSettingsSecureServiceServer) GetIntSecure(context.Context, *GetIntSecureRequest) (*GetIntSecureResponse, error)
func (UnimplementedSettingsSecureServiceServer) GetStringSecure ¶
func (UnimplementedSettingsSecureServiceServer) GetStringSecure(context.Context, *GetStringSecureRequest) (*GetStringSecureResponse, error)
type UnimplementedSettingsSystemServiceServer ¶
type UnimplementedSettingsSystemServiceServer struct{}
UnimplementedSettingsSystemServiceServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedSettingsSystemServiceServer) GetIntSystem ¶
func (UnimplementedSettingsSystemServiceServer) GetIntSystem(context.Context, *GetIntSystemRequest) (*GetIntSystemResponse, error)
func (UnimplementedSettingsSystemServiceServer) GetStringSystem ¶
func (UnimplementedSettingsSystemServiceServer) GetStringSystem(context.Context, *GetStringSystemRequest) (*GetStringSystemResponse, error)
func (UnimplementedSettingsSystemServiceServer) PutIntSystem ¶
func (UnimplementedSettingsSystemServiceServer) PutIntSystem(context.Context, *PutIntSystemRequest) (*PutIntSystemResponse, error)
type UnsafeSettingsGlobalServiceServer ¶
type UnsafeSettingsGlobalServiceServer interface {
// contains filtered or unexported methods
}
UnsafeSettingsGlobalServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to SettingsGlobalServiceServer will result in compilation errors.
type UnsafeSettingsSecureServiceServer ¶
type UnsafeSettingsSecureServiceServer interface {
// contains filtered or unexported methods
}
UnsafeSettingsSecureServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to SettingsSecureServiceServer will result in compilation errors.
type UnsafeSettingsSystemServiceServer ¶
type UnsafeSettingsSystemServiceServer interface {
// contains filtered or unexported methods
}
UnsafeSettingsSystemServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to SettingsSystemServiceServer will result in compilation errors.